@@ -43,7 +43,7 @@ namespace ArrayCore {
   {
     Q_OBJECT
   public:
-    AbstractArrayTool();
+    AbstractArrayTool(QObject * parent);
     virtual ~AbstractArrayTool();
 
     virtual bool setSubPool(SubSignalPool * subPool);
@@ -52,17 +52,19 @@ namespace ArrayCore {
 
     SparseTimeRange timeRange() const;
 
-    bool setParameters(const AbstractParameters& param);
     inline const ArrayParameters * parameters() const;
     inline ArrayParameters * parameters();
 
+    bool selectStations();
+    bool setFrequencySampling();
+
+    virtual bool setLoop();
+
     double minimumFrequency(int nWindows, double periodCount) const;
     double maximumFrequency() const;
   public slots:
-    void start();
+    void start(int threadCount, bool forceParallel);
   protected:
-    bool setLoop();
-
     void setResults(AbstractArrayResults * r) {_results=r;}
     AbstractArrayResults * results() const {return _results;}
 
