@@ -39,12 +39,13 @@ namespace ArrayCore {
   /*!
     Description of constructor still missing
   */
-  ActiveFKTool::ActiveFKTool()
-    : FKTool()
+  ActiveFKTool::ActiveFKTool(QObject * parent)
+    : FKTool(parent)
   {
     TRACE;
     _source=nullptr;
     _grid=nullptr;
+    setParameters(new ActiveFKParameters);
   }
 
   /*!
@@ -69,29 +70,21 @@ namespace ArrayCore {
     _source->lock();
   }
 
-  bool ActiveFKTool::setParameters(const AbstractParameters &param)
+  bool ActiveFKTool::setLoop()
   {
     TRACE;
-    const ActiveFKParameters * fkParam=dynamic_cast<const ActiveFKParameters *>(&param);
-    if(!fkParam) {
-      qDebug() << "Parameters are not ActiveFKParameters in ActiveFKTool::setParameters.";
+    if(parameters()->ySampling().count()==0) {
+      App::log(tr("Empty Y sampling\n"));
       return false;
     }
-    if(fkParam->frequencySampling().count()==0) {
-      App::log(tr("ActiveFKTool: null number samples on frequency axis\n"));
-      return false;
-    }
-    if(fkParam->ySampling().count()==0) {
-      App::log(tr("ActiveFKTool: null number samples on Y axis\n"));
-      return false;
-    }
-    setGrid(*fkParam);
-    return FKTool::setParameters(param);
+    setGrid();
+    return FKTool::setLoop();
   }
 
-  void ActiveFKTool::setGrid(const ActiveFKParameters& param)
+  void ActiveFKTool::setGrid()
   {
     TRACE;
+    const ActiveFKParameters& param=*parameters();
     delete _grid;
     _grid=new IrregularGrid2D(param.frequencySampling().count(), param.ySampling().count());
     for(int ix=0; ix<param.frequencySampling().count(); ix++) {
@@ -109,6 +102,8 @@ namespace ArrayCore {
   /*!
     Called automatically by setParameters if minimum and maximum
     waveNumber are not set.
+
+    Calculate kmin and kmax from minimum and maximum distances between stations.
   */
   bool ActiveFKTool::setWaveNumberGrid()
   {
@@ -122,10 +117,11 @@ namespace ArrayCore {
       return false;
     }
     ActiveFKSteering st;
-    st.setSource(_source->position(), arraySel);
+    st.setArray(&arraySel);
+    st.setSource(_source->position());
     st.setDistances();
     int n=st.count();
-    QVector<double> dist(n);
+    VectorList<double> dist(n);
     for(int i=0; i<n; i++) {
       dist[i]=st.distance(i);
     }
