@@ -39,20 +39,21 @@ namespace ArrayCore {
   /*!
     Description of constructor still missing
   */
-  ActiveFKToolSet::ActiveFKToolSet()
-    : AbstractTool()
+  ActiveFKToolSet::ActiveFKToolSet(QObject * parent)
+    : AbstractTool(parent)
   {
     TRACE;
-    AbstractTool::setParameters(ActiveFKParameters());
+    setParameters(new ActiveFKParameters);
   }
 
-  /*!
-    Description of destructor still missing
-  */
   ActiveFKToolSet::~ActiveFKToolSet()
   {
     TRACE;
-    qDeleteAll(_subTools);
+    int n=_subTools.count();
+    for(int i=0; i<n; i++) {
+      FKTool * tool=_subTools.at(i);
+      delete tool->subPool();
+    }
   }
 
   bool ActiveFKToolSet::setSubPool(SubSignalPool * subPool)
@@ -70,7 +71,7 @@ namespace ArrayCore {
     int n=sources.count();
     bool allOK=true;
     for(int i=0; i<n; i++) {
-      ActiveFKTool * tool=new ActiveFKTool;
+      ActiveFKTool * tool=new ActiveFKTool(this);
       tool->setSource(sources.at(i));
       if(!tool->setSubPool(sourceSignals.value(sources.at(i)))) {
         allOK=false;
@@ -80,41 +81,37 @@ namespace ArrayCore {
     return allOK;
   }
 
-  void ActiveFKToolSet::start()
+  void ActiveFKToolSet::start(int, bool)
   {
     int n=_subTools.count();
     for(int i=0; i<n; i++) {
       FKTool * tool=_subTools.at(i);
-      if(tool->setParameters(*parameters())) {
+      *tool->parameters()=*parameters();
+      if(tool->setLoop()) {
         // TODO: implement usual FK picking ????
 
       }
     }
   }
 
-  bool ActiveFKToolSet::setParameters(const AbstractParameters &param)
+  const IrregularGrid2D * ActiveFKToolSet::grid(int index, int threadCount)
   {
-    TRACE;
-    const ActiveFKParameters * fkParam=dynamic_cast<const ActiveFKParameters *>(&param);
-    if(!fkParam) {
-      qDebug() << "Parameters are not ActiveFKParameters in ActiveFKToolSet::setParameters.";
-      return false;
-    }
-    return AbstractTool::setParameters(param);
-  }
-
-  const IrregularGrid2D * ActiveFKToolSet::grid(int index)
-  {
-    const ActiveFKParameters& param=*parameters();
     ActiveFKTool * tool=_subTools.at(index);
-    if(tool->setParameters(param)) {
-      tool->start();
-      tool->waitFinished();
+    *tool->parameters()=*parameters();
+    if(tool->setLoop()) {
+      tool->start(threadCount, true);
+      tool->waitFinished(0);
       return tool->grid();
     } else {
       return nullptr;
     }
   }
 
+  ParallelTaskManager * ActiveFKToolSet::loop(int index) const
+  {
+    ActiveFKTool * tool=_subTools.at(index);
+    return tool->loop();
+  }
+
 } // namespace ArrayCore
 
