@@ -47,8 +47,11 @@ namespace ArrayCore {
     : FKWorker(array, param)
   {
     TRACE;
-    crossSpectrum()->setActiveSource(source);
+    // Does not select stations here, just force a single source
+    // The selection is done be the FK function in setSource()
+    crossSpectrum()->forceActiveSource(source);
     _grid=grid;
+    _function=nullptr;
   }
 
   /*!
@@ -57,16 +60,43 @@ namespace ArrayCore {
   ActiveFKWorker::~ActiveFKWorker()
   {
     TRACE;
+    delete _function;
   }
 
-  void ActiveFKWorker::process(const QVector<int>& blocks)
+  bool ActiveFKWorker::setGrid(FKCache * cache)
   {
-    AbstractFKFunction * function=FKWorker::function();
-    if(function && crossSpectrum()->calculate(blocks, function)) {
+    TRACE;
+    delete _function;
+    _function=AbstractFKFunction::create(taskManager()->array().array()->mode(),
+                                         crossSpectrum()->parameters(), cache);
+    if(_function) {
+      _function->setCrossSpectrum(crossSpectrum());
+      const FKParameters * param=crossSpectrum()->parameters();
+      // Initialization that require the virtual mechanism (e.g. allocation of power engine)
+      _function->initialize(*param);
+      // Limiting search to kmin speedup computation but may pick alias peaks
+      // Better to filter out after FK search
+      //f->setMinimumWavenumber(param->minimumWaveNumber());
+      // Reduce the gridded box to a circle of radius effective grid size
+      _function->setMaximumWavenumber(param->effectiveGridSize());
+      _function->setMaximumSlowness(param->maximumSlowness());
+      return true;
+    } else {
+      return false;
+    }
+  }
+
+  void ActiveFKWorker::process(const VectorList<int>& blocks)
+  {
+    // In each task, there must be only one step: all windows must be stacked in one cross-spectrum matrix
+    ASSERT(!blocks.isEmpty() && blocks.first()==0);
+    if(_function && crossSpectrum()->calculate(blocks, _function)) {
       double omega=crossSpectrum()->timeWindows()->frequency().omega();
       int frequencyIndex=crossSpectrum()->timeWindows()->frequencyIndex();
+      PrivateVector<double> k(2, 0.0);
       for(int iSlow=0; iSlow<_grid->ny(); iSlow++) {
-        _grid->setValue(frequencyIndex, iSlow, function->value(omega*_grid->y(iSlow)));
+        k[0]=omega*_grid->y(iSlow);
+        _grid->setValue(frequencyIndex, iSlow, _function->value(k));
       }
       // Normalize FK spectrum frequency by frequency and following spectrum energy
       const ActiveFKParameters * param=static_cast<const ActiveFKParameters *>(crossSpectrum()->parameters());
@@ -74,7 +104,7 @@ namespace ArrayCore {
       case ActiveFKParameters::Raw:
         break;
       case ActiveFKParameters::Spectrum:
-        _grid->multiplyValues(YAxis, frequencyIndex, 1.0/crossSpectrum()->matrix().trace(0.0).re());
+        _grid->multiplyValues(YAxis, frequencyIndex, 1.0/crossSpectrum()->matrix()->trace(0.0).re());
         break;
       case ActiveFKParameters::Maximum: {
           Curve<Point2D> c=_grid->crossSection(YAxis, frequencyIndex);
