@@ -24,7 +24,6 @@
 ***************************************************************************/
 
 #include "ActiveHRFKVertical.h"
-#include "ActiveFKSteeringOneComponent.h"
 #include "FKCrossSpectrum.h"
 
 namespace ArrayCore {
@@ -41,14 +40,13 @@ namespace ArrayCore {
     return _crossSpectrum->invert();
   }
 
-  double ActiveHRFKVertical::value(const Point& k) const
+  double ActiveHRFKVertical::value(Vector<double>& k) const
   {
+    k[1]=0.0; // Only k[0] is modified by GridSearch
     if(isInsideLimits(k)) {
-      ActiveFKSteeringOneComponent * s=static_cast<ActiveFKSteeringOneComponent *>(_steering);
-      s->initValue(k.x());
-      FKPower p(s);
-      p.setCaponValue(_crossSpectrum->matrix());
-      return p.value();
+      const Vector<Complex>& e=_steering->oneComponent(k[0], powerEngine());
+      powerEngine()->setHighResolutionValue(e);
+      return powerEngine()->value();
     } else {
       return -1.0;
     }
