@@ -34,12 +34,12 @@ namespace ArrayCore {
   class ARRAYCORE_EXPORT ActiveHRFKVertical : public ActiveConvFKVertical
   {
   public:
-    ActiveHRFKVertical(FKCache * gridCache)
-      : ActiveConvFKVertical(gridCache) {}
+    ActiveHRFKVertical(FKCache * cache)
+      : ActiveConvFKVertical(cache) {}
 
-    virtual bool invertCrossSpectrum();
+    bool invertCrossSpectrum();
 
-    virtual double value(const Point& k) const;
+    double value(Vector<double>& k) const;
   };
 
 } // namespace ArrayCore
