@@ -27,6 +27,16 @@
 
 namespace ArrayCore {
 
+// Get a detailled timing report of the processing
+// Run with verbosity level to 3 to get the report.
+// Level 3 also activate pre-loading of signals in AbstractTool.
+// Configure with '-D PROCESS_TIMING'
+
+#ifdef PROCESS_TIMING
+  static double ttadd=0.0;
+  static Mutex globalTimeMutex;
+#endif
+
   /*!
     \class ArrayCrossSpectrum ArrayCrossSpectrum.h
     \brief Brief description of class still missing
@@ -39,11 +49,13 @@ namespace ArrayCore {
   */
   ArrayCrossSpectrum::ArrayCrossSpectrum(const ArraySelection * array,
                                          const ArrayParameters * param)
+    : _array(array)
   {
     TRACE;
+    _matrix=nullptr;
+    _timeWindows=nullptr;
     _parameters=param; // Needed for locking time windows
-    _mode=array->array()->mode();
-    _singleValueSpectrum=(param->frequencyBandwidth()==0.0);
+    _mode=array->mode();
     switch(_mode) {
     case ArrayStations::Vertical:
       _verticalIndex=0;
@@ -68,6 +80,11 @@ namespace ArrayCore {
   {
     TRACE;
     qDeleteAll(_stations);
+    delete _matrix;
+#ifdef PROCESS_TIMING
+    App::log(3, tr("Array cross spectrum: %1 (ms)\n")
+             .arg(ttadd*1e-6));
+#endif
   }
 
   /*!
@@ -110,30 +127,38 @@ namespace ArrayCore {
     qDeleteAll(_stations);
     _stations.clear();
     for(int i=0; i<n; i++) {
-      ArrayStationSignals * s=new ArrayStationSignals(array->at(i));
-      _stations.append(s);
+      StationSignals * sig=array->stationSignals(i);
+      if(sig) {
+        ArrayStationSignals * s=new ArrayStationSignals(sig);
+        _stations.append(s);
+      }
     }
   }
 
   void ArrayCrossSpectrum::resetMatrix()
   {
-    _matrix.zero(0.0);
+    _matrix->zero();
   }
 
   void ArrayCrossSpectrum::addVertical()
   {
+#ifdef PROCESS_TIMING
+    QElapsedTimer chrono;
+    qint64 tadd;
+    chrono.start();
+#endif
     int stationCount=_stations.count();
-    const GaussianFrequencyBand& frequencyFilter=_timeWindows->frequencyFilter();
 
-    ComplexMatrix& covmat=_matrix;
+    ComplexMatrix& covmat=*_matrix;
     ComplexMatrix sig(stationCount, 1);
 
-    if(_singleValueSpectrum) {
+    if(parameters()->frequencyBandwidth()==0.0) {
       for(int is=0; is<stationCount; is++) {
         sig.at(is, 0)=_stations.at(is)->spectrumValue(_verticalIndex);
       }
       covmat+=sig*sig.conjugate().transposed();
     } else {
+      const GaussianFrequencyBand& frequencyFilter=*_timeWindows->frequencyFilter();
       int nFreq=frequencyFilter.maximumIndex();
       double filter;
       for(int iFreq=frequencyFilter.minimumIndex(); iFreq<=nFreq; iFreq++) {
@@ -146,6 +171,12 @@ namespace ArrayCore {
         covmat+=sig*sig.conjugate().transposed();
       }
     }
+#ifdef PROCESS_TIMING
+      tadd=chrono.nsecsElapsed();
+      globalTimeMutex.lock();
+      ttadd+=tadd;
+      globalTimeMutex.unlock();
+#endif
   }
 
   /*!
@@ -153,12 +184,16 @@ namespace ArrayCore {
   */
   void ArrayCrossSpectrum::addHorizontal(ComplexMatrix& covmat)
   {
+#ifdef PROCESS_TIMING
+    QElapsedTimer chrono;
+    qint64 tadd;
+    chrono.start();
+#endif
     int stationCount=_stations.count();
-    const GaussianFrequencyBand& frequencyFilter=_timeWindows->frequencyFilter();
 
     ComplexMatrix sig(2*stationCount, 1);
 
-    if(_singleValueSpectrum) {
+    if(parameters()->frequencyBandwidth()==0.0) {
       for(int is=0; is<stationCount; is++) {
         sig.at(is, 0)=_stations.at(is)->spectrumValue(_eastIndex);
       }
@@ -167,6 +202,7 @@ namespace ArrayCore {
       }
       covmat+=sig*sig.conjugate().transposed();
     } else {
+      const GaussianFrequencyBand& frequencyFilter=*_timeWindows->frequencyFilter();
       int nFreq=frequencyFilter.maximumIndex();
       double filter;
       for(int iFreq=frequencyFilter.minimumIndex(); iFreq<=nFreq; iFreq++) {
@@ -184,11 +220,17 @@ namespace ArrayCore {
         covmat+=sig*sig.conjugate().transposed();
       }
     }
+#ifdef PROCESS_TIMING
+      tadd=chrono.nsecsElapsed();
+      globalTimeMutex.lock();
+      ttadd+=tadd;
+      globalTimeMutex.unlock();
+#endif
   }
 
   void ArrayCrossSpectrum::meanMatrix(int nBlocks)
   {
-    _matrix*=1.0/static_cast<double>(nBlocks);
+    *_matrix*=1.0/static_cast<double>(nBlocks);
   }
 
 } // namespace ArrayCore
