@@ -41,17 +41,18 @@ namespace ArrayCore {
     void setTimeWindows(const ArrayTimeWindows * tw) {_timeWindows=tw;}
     const ArrayTimeWindows * timeWindows() const {return _timeWindows;}
 
+    const ArraySelection& array() const {return _array;}
     const ArrayParameters * parameters() const {return _parameters;}
     int stationCount() const {return _stations.count();}
     ArrayStations::Mode mode() const {return _mode;}
-    bool isSingleValueSpectrum() const {return _singleValueSpectrum;}
 
     void resetMatrix();
-    void addVertical();
-    void addHorizontal() {addHorizontal(_matrix);}
+    virtual void addVertical();
+    void addHorizontal() {addHorizontal(*_matrix);}
     void meanMatrix(int nBlocks);
 
-    inline const ComplexMatrix& matrix() const {return _matrix;}
+    const ComplexMatrix * matrix() const {return _matrix;}
+    ComplexMatrix * matrix() {return _matrix;}
 
     bool lockTimeWindow(const TimeRange& win);
     void unlockTimeWindow();
@@ -59,14 +60,14 @@ namespace ArrayCore {
     void addHorizontal(ComplexMatrix& covmat);
     void setStations(const ArraySelection * array);
 
+    ArraySelection _array;
     QList<ArrayStationSignals *> _stations;
     const ArrayTimeWindows * _timeWindows;
     const ArrayParameters * _parameters;
     ArrayStations::Mode _mode;
     int _verticalIndex, _northIndex, _eastIndex;
-    bool _singleValueSpectrum;
 
-    ComplexMatrix _matrix;
+    ComplexMatrix * _matrix;
   };
 
 } // namespace ArrayCore
