@@ -51,25 +51,6 @@ namespace ArrayCore {
     acceptAllFrequencies();
   }
 
-  ArrayParameters::ArrayParameters(const ArrayParameters& o)
-    : AbstractParameters(o),
-      _timeLimits(o._timeLimits),
-      _windowing(o._windowing),
-      _frequencySampling(o._frequencySampling),
-      _blockAveraging(o._blockAveraging),
-      _taper(o._taper)
-  {
-    _frequencyBandwidth=o._frequencyBandwidth;
-    _oversamplingFactor=o._oversamplingFactor;
-    _outputBaseName=o._outputBaseName;
-    _minimumFrequency=o._minimumFrequency;
-    _maximumFrequency=o._maximumFrequency;
-    _selectArrayCenter=o._selectArrayCenter;
-    _selectArrayRadius=o._selectArrayRadius;
-    _selectDurationFactor=o._selectDurationFactor;
-    _magneticDeclination=o._magneticDeclination;
-  }
-
   void ArrayParameters::setVersion(PARAMETERS_SETVERSION_ARGS)
   {
     TRACE;
@@ -133,8 +114,8 @@ namespace ArrayCore {
          "# SELECT_DURATION_FACTOR*[total required duration]. The factor can vary from 0 to 1\n";
     log+=prefix+"SELECT_DURATION_FACTOR"+suffix+"="+QString::number(_selectDurationFactor)+"\n";
     log+="# A station is selected for processing only if it is located at less than SELECT_ARRAY_RADIUS\n"
-         "# from SELECT_ARRAY_CENTER. SELECT_ARRAY_CENTER is the X, Y coordinates of the center.\n";
-    log+=prefix+"SELECT_ARRAY_CENTER"+suffix+"="+_selectArrayCenter.toString()+"\n";
+         "# from SELECT_ARRAY_CENTER. SELECT_ARRAY_CENTER is the X, Y coordinates of the center or the name of a station.\n";
+    log+=prefix+"SELECT_ARRAY_CENTER"+suffix+"="+_selectArrayCenter+"\n";
     log+=prefix+"SELECT_ARRAY_RADIUS"+suffix+"="+QString::number(_selectArrayRadius)+"\n";
     log+="# Assuming that the north of sensors is aligned to the magnetic north and sensor coordinates to UTM grid,\n"
          "# relative coordinates between stations are calculated with a correction for the difference between the\n"
@@ -158,7 +139,8 @@ namespace ArrayCore {
       _selectDurationFactor=value.toDouble(&ok);
       return ok && _selectDurationFactor>=0.0 && _selectDurationFactor<=1.0;
     case 2:
-      return _selectArrayCenter.fromString(value);
+      _selectArrayCenter=value;
+      return true;
     case 3:
       _selectArrayRadius=value.toDouble(&ok);
       return ok && _selectArrayRadius>=0.0;
@@ -184,39 +166,68 @@ namespace ArrayCore {
   /*!
 
   */
-  void ArrayParameters::selectStations(ArraySelection& array) const
+  bool ArrayParameters::selectStations(ArraySelection& array) const
   {
     TRACE;
-    QVector<int> sel;
-    int n=array.count();
+    VectorList<int> sel;
+    int n=array.array()->count();
 
     if(n>0) {
-      App::log(1, tr("Checking time availibility of station signals...\n"));
-      TimeRange r=timeLimits().absoluteRange(array.at(0));
-      double requiredDuration=r.lengthSeconds()*selectDurationFactor();
-      n=array.count();
-      sel.clear();
-      for(int i=0; i<n; i++) {
-        const StationSignals& s=*array.at(i);
-        SparseTimeRange ssr=s.timeRange(r);
-        if(ssr.totalLength()>=requiredDuration) {
-          sel.append(i);
-        }
-      }
-      array.select(sel);
-      if(array.count()<n) {
-        App::log(1, tr("Selected %1 stations:\n%2")
-                         .arg(array.count())
-                         .arg(array.toString(ArraySelection::Relative)));
-      }
-
-      if(selectArrayRadius()>0.0) {
-        App::log(1, tr("Checking location of stations...\n"));
+      // This count provides the number of full signal stations
+      // where a time range is available. Simulated arrays does
+      // have such feature.
+      if(array.array()->StationList::count()>0) {
+        APP_LOG(1, tr("Checking time availibility of station signals...\n"));
+        TimeRange r=timeLimits().absoluteRange(array.stationSignals(0));
+        APP_LOG(1, tr("Total recording range: %1\n").arg(r.toString()));
+        double requiredDuration=r.lengthSeconds()*selectDurationFactor();
+        APP_LOG(1, tr("Minimum required duration: %1 s\n").arg(requiredDuration));
         n=array.count();
         sel.clear();
         for(int i=0; i<n; i++) {
-          const StationSignals& s=*array.at(i);
-          if(selectArrayCenter().distanceTo(s.coordinates())<=selectArrayRadius()) {
+          const StationSignals& s=*array.stationSignals(i);
+          SparseTimeRange ssr=s.timeRange(r);
+          APP_LOG(2, tr("Station %1 avalaible duration: %2 s\n")
+                  .arg(s.name())
+                  .arg(ssr.totalLength()));
+          if(ssr.totalLength()>=requiredDuration) {
+            sel.append(i);
+          }
+        }
+        array.select(sel);
+        if(array.count()<n) {
+          APP_LOG(1, tr("Selected %1 stations:\n%2")
+                           .arg(array.count())
+                           .arg(array.toString(ArraySelection::Relative)));
+        }
+      }
+
+      if(_selectArrayRadius>0.0 && !_selectArrayCenter.isEmpty()) {
+        APP_LOG(1, tr("Checking location of stations...\n"));
+        n=array.count();
+        sel.clear();
+        Point2D center;
+        if(!center.fromString(_selectArrayCenter)) {
+          int i;
+          for(i=0; i<n; i++) {
+            if(array.name(i)==_selectArrayCenter) {
+              center=array.position(i);
+              break;
+            }
+          }
+          if(i>=n) {
+            App::log(1, tr("Selecting stations, there is no station named '%1'\n")
+                     .arg(_selectArrayCenter));
+            return false;
+          }
+        }
+        APP_LOG(1, tr("Looking for stations at maximum %1 m from %2\n")
+                .arg(_selectArrayRadius).arg(center.toString('f', 3)));
+        for(int i=0; i<n; i++) {
+          APP_LOG(2, tr("Station %1 at %2 m from center\n")
+                  .arg(array.name(i))
+                  .arg(center.distanceTo(array.position(i))));
+          if(center.distanceTo(array.position(i))<=_selectArrayRadius) {
             sel.append(i);
           }
         }
@@ -228,6 +239,7 @@ namespace ArrayCore {
         }
       }
     }
+    return true;
   }
 
 } // namespace ArrayCore
