@@ -39,7 +39,6 @@ namespace ArrayCore {
   {
   public:
     ArrayParameters();
-    ArrayParameters(const ArrayParameters& o);
 
     TimeRangeParameters& timeLimits() {return _timeLimits;}
     const TimeRangeParameters& timeLimits() const {return _timeLimits;}
@@ -69,8 +68,8 @@ namespace ArrayCore {
     double selectDurationFactor() const {return _selectDurationFactor;}
     void setSelectDurationFactor(double f) {_selectDurationFactor=f;}
 
-    const Point2D& selectArrayCenter() const {return _selectArrayCenter;}
-    void setSelectArrayCenter(const Point2D& c) {_selectArrayCenter=c;}
+    const QString& selectArrayCenter() const {return _selectArrayCenter;}
+    void setSelectArrayCenter(const QString& c) {_selectArrayCenter=c;}
 
     double selectArrayRadius() const {return _selectArrayRadius;}
     void setSelectArrayRadius(double f) {_selectArrayRadius=f;}
@@ -83,15 +82,15 @@ namespace ArrayCore {
     void setMaximumFrequency(double frequency) {_maximumFrequency=frequency*(1.0+1e-10);}
     inline bool acceptFrequency(double frequency) const;
 
-    virtual void selectStations(ArraySelection& array) const;
+    bool selectStations(ArraySelection& array) const;
 
-    virtual QString toString(PARAMETERS_TOSTRING_ARGS_DECL) const;
-    virtual void setVersion(PARAMETERS_SETVERSION_ARGS);
-    virtual void collectKeywords(PARAMETERS_COLLECTKEYWORDS_ARGS);
-    virtual int totalKeywordCount(PARAMETERS_TOTALKEYWORDCOUNT_ARGS) const;
+    QString toString(PARAMETERS_TOSTRING_ARGS_DECL) const;
+    void setVersion(PARAMETERS_SETVERSION_ARGS);
+    void collectKeywords(PARAMETERS_COLLECTKEYWORDS_ARGS);
+    int totalKeywordCount(PARAMETERS_TOTALKEYWORDCOUNT_ARGS) const;
   protected:
-    virtual int keywordCount(PARAMETERS_KEYWORDCOUNT_ARGS) const;
-    virtual bool setValue(PARAMETERS_SETVALUE_ARGS);
+    int keywordCount(PARAMETERS_KEYWORDCOUNT_ARGS) const;
+    bool setValue(PARAMETERS_SETVALUE_ARGS);
   private:
     TimeRangeParameters _timeLimits;
     WindowingParameters _windowing;
@@ -99,7 +98,7 @@ namespace ArrayCore {
     BlockAveragingParameters _blockAveraging;
     WindowFunctionParameters _taper;
     double _selectDurationFactor;
-    Point2D _selectArrayCenter;
+    QString _selectArrayCenter;
     double _selectArrayRadius;
     double _magneticDeclination;
     double _minimumFrequency;
