@@ -41,28 +41,31 @@ namespace ArrayCore {
     const ArrayStations * array() const {return _array;}
     StationSignals::Components components() const {return _array->components();}
     ArrayStations::Mode mode() const {return _array->mode();}
+    double samplingFrequency() const {return _array->samplingFrequency();}
 
     int count() const {return _selected.count();}
     bool isEmpty() const {return _selected.isEmpty();}
     void clear();
-    const StationSignals * at(int index) const;
+    QString name(int index) const;
+    Point2D position(int index) const;
+    StationSignals * stationSignals(int index) const;
 
     void select(const Point& src, double minDistance, double maxDistance);
-    void select(QVector<int> sel);
+    void select(VectorList<int> sel);
 
-    const QVector<Point2D>& relativePos() const {return _relativePos;}
+    const VectorList<Point2D>& relativePos() const {return _relativePos;}
     const Point2D& relativePos(int station) const {return _relativePos.at(station);}
 
     enum Coordinates {Absolute, Relative};
 
-    QString toString(Coordinates coord, int precision=2, char format='f') const;
+    QString toString(Coordinates coord, char format='f', int precision=2) const;
   private:
     void setRelativePos();
 
     const ArrayStations * _array;
     const ArraySelection * _parent;
-    QVector<int> _selected;
-    QVector<Point2D> _relativePos;
+    VectorList<int> _selected;
+    VectorList<Point2D> _relativePos;
   };
 
 } // namespace ArrayCore
