@@ -46,8 +46,9 @@ namespace ArrayCore {
 
     inline Complex spectrumValue(int component, int iFreq) const;
     const Complex& spectrumValue(int component) const {return _spectrumValue[component];}
+
+    static void showProcessingTime();
   protected:
-    Point2D _relativePos;
     Complex _spectrumValue[3];
   };
 
