@@ -51,8 +51,9 @@ namespace ArrayCore {
   {
     TRACE;
     Rect r;
-    for(const_iterator it=begin();it!=end();++it) {
-      const Point& p=(*it)->coordinates();
+    int n=count();
+    for(int i=0; i<n; i++) {
+      const Point& p=position(i);
       r.add(p);
     }
     return r;
@@ -68,16 +69,16 @@ namespace ArrayCore {
   void ArrayStations::setReference()
   {
     TRACE;
-    int n=count();
     _reference=Point2D();
+    int n=count();
     for(int i=0; i<n; i++) {
-      _reference+=at(i)->coordinates();
+      _reference+=position(i);
     }
     if(n>1) {
       _reference/=static_cast<double>(n);
     }
     _relativePos.resize(n); // ensure consistent but empty relative coordinates
-    App::log(tr("Relative coordinates with reference at (%1).\n").arg(_reference.toString(2, 'f')));
+    App::log(tr("Relative coordinates with reference at (%1).\n").arg(_reference.toString('f', 2)));
   }
 
   /*!
@@ -103,13 +104,12 @@ namespace ArrayCore {
     bool ok=false;
     _utmZone=utmZone(ok);
     for(int i=0; i<n; i++) {
-      _relativePos[i]=toRelative(at(i)->coordinates());
+      _relativePos[i]=toRelative(position(i));
     }
   }
 
   /*!
     Can be used to get the relative coordinates of any point like a point source.
-    \a ref must in geographical coordinates if \a utm is valid.
   */
   Point2D ArrayStations::toRelative(Point2D p) const
   {
@@ -134,6 +134,28 @@ namespace ArrayCore {
     return p;
   }
 
+  /*!
+    Can be used to get the absolute coordinates.
+  */
+  Point2D ArrayStations::toAbsolute(Point2D p) const
+  {
+    if(_utmZone.isValid()) {
+      Point2D ref=_reference;
+      ref.utmToGeographical(_utmZone);
+      p.rectangularToGeographical(ref);
+      UtmZone utmZone;
+      p.geographicalToUtm(utmZone);
+      if(_magneticDeclination!=0.0) {
+        Angle a;
+        a.setDegrees(-_magneticDeclination);
+        p.rotate(a);
+      }
+    } else {
+      p+=_reference;
+    }
+    return p;
+  }
+
   double ArrayStations::radius() const
   {
     TRACE;
@@ -176,6 +198,11 @@ namespace ArrayCore {
     return z;
   }
 
+  double ArrayStations::samplingFrequency() const
+  {
+    return stationSignals(0)->samplingFrequency();
+  }
+
   ArrayStations::Mode ArrayStations::mode() const
   {
     TRACE;
@@ -190,16 +217,35 @@ namespace ArrayCore {
     return Vertical;
   }
 
-  QString ArrayStations::toString(int precision, char format) const
+  int ArrayStations::count() const
+  {
+    return StationList::count();
+  }
+
+  QString ArrayStations::name(int index) const
+  {
+    return at(index)->name();
+  }
+
+  Point2D ArrayStations::position(int index) const
+  {
+    return at(index)->coordinates();
+  }
+
+  StationSignals * ArrayStations::stationSignals(int index) const
+  {
+    return at(index);
+  }
+
+  QString ArrayStations::toString(char format, int precision) const
   {
     TRACE;
     QString s;
     int n=count();
     for(int i=0; i<n; i++) {
-      const StationSignals& stat=*at(i);
-      s+=stat.name();
+      s+=name(i);
       s+=" ";
-      s+=stat.coordinates().toString(precision, format);
+      s+=position(i).toString(format, precision);
       s+="\n";
     }
     return s;
