@@ -48,7 +48,7 @@ namespace ArrayCore {
 
     void init();
     const ArrayTimeWindows * timeWindows() const {return &_timeWindows;}
-  private:
+  protected:
     ArrayTimeWindows _timeWindows;
   };
 
