@@ -62,7 +62,7 @@ namespace ArrayCore {
     SparseKeepSignal * _keep;
   private:
     bool setTimeLimits();
-    void setGlobalKeep();
+    bool setGlobalKeep();
 
     AbstractArrayResults * _results;
   };
