@@ -46,6 +46,7 @@ namespace ArrayCore {
     void setFrequencyIndex(int iOmega);
     void setFrequency(double f);
     void setWindows();
+    void setWindows(const SeismicEvent * event);
 
     const TimeWindowList& list() const {return _list;}
     TimeWindowList& list() {return _list;}
@@ -53,18 +54,20 @@ namespace ArrayCore {
 
     const FrequencyBand& frequency() const {return _frequency;}
     int frequencyIndex() const {return _frequencyIndex;}
-    const GaussianFrequencyBand& frequencyFilter() const {return _frequencyFilter;}
+    const GaussianFrequencyBand * frequencyFilter() const {return _frequencyFilter;}
     const FourierPlan& plan() const {return *_plan;}
     const TaperDelegate& taper() const {return _taper;}
     QString toString(int index) const;
   private:
+    void initPreprocessing();
+
     const ArrayParameters * _parameters;
     const SparseKeepSignal * _keep;
 
     double _samplingFrequency, _samplingPeriod;
     SeismicEventTable * _events;
 
-    GaussianFrequencyBand _frequencyFilter;
+    GaussianFrequencyBand * _frequencyFilter;
     FrequencyBand _frequency;
     int _frequencyIndex;
     TimeWindowList _list;
