@@ -42,17 +42,17 @@ namespace ArrayCore {
 
     void setTaskManager(ArrayTaskManager * tm) {ParallelTaskWorker::setTaskManager(tm);}
   protected:
-    inline const ArrayTaskManager * taskManager() const;
+    inline ArrayTaskManager * taskManager() const;
 
     void process(ParallelTask * t);
-    virtual void process(const QVector<int>& blocks)=0;
+    virtual void process(const VectorList<int>& blocks)=0;
 
     ArrayCrossSpectrum * _crossSpectrum;
   };
 
-  inline const ArrayTaskManager * ArrayWorker::taskManager() const
+  inline ArrayTaskManager * ArrayWorker::taskManager() const
   {
-    return static_cast<const ArrayTaskManager *>(ParallelTaskWorker::taskManager());
+    return static_cast<ArrayTaskManager *>(ParallelTaskWorker::taskManager());
   }
 
 } // namespace ArrayCore
