@@ -37,6 +37,12 @@ namespace ArrayCore {
     The cross-spectrum is already projected on the radial direction.
   */
 
+  void ConvFKRadial::initialize(const FKParameters& param)
+  {
+    steeringInitialization()->setSensorOrientationErrors(param);
+    ConvFKVertical::initialize(param);
+  }
+
   void ConvFKRadial::resetCrossSpectrum()
   {
     _crossSpectrum->resetRotatedMatrices();
@@ -44,7 +50,7 @@ namespace ArrayCore {
 
   void ConvFKRadial::addCrossSpectrum()
   {
-    _crossSpectrum->addRotatedRadial();
+    _crossSpectrum->addRotatedRadial(steering()->sensorOrientationErrors());
   }
 
   void ConvFKRadial::meanCrossSpectrum(int nBlocks)
@@ -52,25 +58,44 @@ namespace ArrayCore {
     _crossSpectrum->meanRotatedMatrices(nBlocks);
   }
 
-  double ConvFKRadial::value(const Point& k, int index) const
+  void ConvFKRadial::addIncoherentNoise(double horizontal, double)
   {
-    if(isInsideLimits(k)) {
-      FKPower p(&FKSteeringOneComponent::cache(_gridCache, index));
-      p.setConventionalValue(_crossSpectrum->rotatedMatrix(k));
-      return p.value();
+    int n=_crossSpectrum->array().count();
+    int rotCount=_crossSpectrum->rotationStepCount();
+    for(int rotIndex=0; rotIndex<rotCount; rotIndex++) {
+      ComplexMatrix& covmat=*_crossSpectrum->rotatedMatrix(rotIndex);
+      for(int i=0; i<n; i++) {
+        covmat.at(i, i)+=horizontal;
+      }
+    }
+  }
+
+  const ComplexMatrix * ConvFKRadial::crossSpectrum() const
+  {
+    if(_crossSpectrum) {
+      return _crossSpectrum->rotatedMatrix(0);
+    } else {
+      return nullptr;
+    }
+  }
+
+  double ConvFKRadial::value(const Vector<int>& index) const
+  {
+    if(isInsideLimits(index)) {
+      powerEngine()->setCrossSpectrum(_crossSpectrum->rotatedMatrix(index));
+      powerEngine()->setConventionalValue(oneComponentSteering(index));
+      return powerEngine()->value();
     } else {
       return -1.0;
     }
   }
 
-  double ConvFKRadial::value(const Point& k) const
+  double ConvFKRadial::value(Vector<double>& k) const
   {
     if(isInsideLimits(k)) {
-      FKSteeringOneComponent * s=static_cast<FKSteeringOneComponent *>(_steering);
-      s->initValue(k);
-      FKPower p(s);
-      p.setConventionalValue(_crossSpectrum->rotatedMatrix(k));
-      return p.value();
+      powerEngine()->setCrossSpectrum(_crossSpectrum->rotatedMatrix(k));
+      powerEngine()->setConventionalValue(oneComponentSteering(k));
+      return powerEngine()->value();
     } else {
       return -1.0;
     }
