@@ -38,43 +38,9 @@ namespace ArrayCore {
     The cross-spectrum is already projected on the transverse direction.
   */
 
-  void ConvFKTransverse::resetCrossSpectrum()
-  {
-    _crossSpectrum->resetRotatedMatrices();
-  }
-
   void ConvFKTransverse::addCrossSpectrum()
   {
-    _crossSpectrum->addRotatedTransverse();
-  }
-
-  void ConvFKTransverse::meanCrossSpectrum(int nBlocks)
-  {
-    _crossSpectrum->meanRotatedMatrices(nBlocks);
-  }
-
-  double ConvFKTransverse::value(const Point& k, int index) const
-  {
-    if(isInsideLimits(k)) {
-      FKPower p(&FKSteeringOneComponent::cache(_gridCache, index));
-      p.setConventionalValue(_crossSpectrum->rotatedMatrix(k));
-      return p.value();
-    } else {
-      return -1.0;
-    }
-  }
-
-  double ConvFKTransverse::value(const Point& k) const
-  {
-    if(isInsideLimits(k)) {
-      FKSteeringOneComponent * s=static_cast<FKSteeringOneComponent *>(_steering);
-      s->initValue(k);
-      FKPower p(s);
-      p.setConventionalValue(_crossSpectrum->rotatedMatrix(k));
-      return p.value();
-    } else {
-      return -1.0;
-    }
+    _crossSpectrum->addRotatedTransverse(steering()->sensorOrientationErrors());
   }
 
 } // namespace ArrayCore
