@@ -27,22 +27,17 @@
 #ifndef CONVFKTRANSVERSE_H
 #define CONVFKTRANSVERSE_H
 
-#include "AbstractFKFunction.h"
+#include "ConvFKRadial.h"
 
 namespace ArrayCore {
 
-  class ARRAYCORE_EXPORT ConvFKTransverse : public AbstractFKFunction
+  class ARRAYCORE_EXPORT ConvFKTransverse : public ConvFKRadial
   {
   public:
-    ConvFKTransverse(FKCache * gridCache)
-      : AbstractFKFunction(gridCache) {}
+    ConvFKTransverse(FKCache * cache)
+      : ConvFKRadial(cache) {}
 
-    virtual void resetCrossSpectrum();
-    virtual void addCrossSpectrum();
-    virtual void meanCrossSpectrum(int nBlocks);
-
-    virtual double value(const Point& k) const;
-    virtual double value(const Point& k, int index) const;
+    void addCrossSpectrum();
   };
 
 } // namespace ArrayCore
