@@ -36,6 +36,32 @@ namespace ArrayCore {
     Vertical conventional FK power versus wavenumber (k) function.
   */
 
+  ConvFKVertical::ConvFKVertical(FKCache * cache)
+    : AbstractFKFunction(cache)
+  {
+    cache->setPassiveSteering();
+  }
+
+  void ConvFKVertical::initialize(const FKParameters& param)
+  {
+    setPowerEngine(new FKPower(cache()->array()->count(), 1));
+    if(_crossSpectrum) {
+      powerEngine()->setCrossSpectrum(_crossSpectrum->matrix());
+    }
+    steeringInitialization()->setSensorPositionErrors(param);
+    steeringInitialization()->setPhaseShifts(param.gridStep(), param.effectiveGridSize());
+  }
+
+  FunctionSearch * ConvFKVertical::createSearch(const FKParameters& param)
+  {
+    GridSearch2D * grid=new GridSearch2D;
+    grid->setRelativePrecision(0, param.velocityRelativePrecision());
+    grid->setRelativePrecision(1, param.velocityRelativePrecision());
+    grid->setFunction(this);
+    grid->setGrid(param.gridStep(), param.effectiveGridSize());
+    return grid;
+  }
+
   void ConvFKVertical::resetCrossSpectrum()
   {
     _crossSpectrum->resetMatrix();
@@ -51,25 +77,30 @@ namespace ArrayCore {
     _crossSpectrum->meanMatrix(nBlocks);
   }
 
-  double ConvFKVertical::value(const Point& k, int index) const
+  void ConvFKVertical::addIncoherentNoise(double, double vertical)
   {
-    if(isInsideLimits(k)) {
-      FKPower p(&FKSteeringOneComponent::cache(_gridCache, index));
-      p.setConventionalValue(_crossSpectrum->matrix());
-      return p.value();
+    int n=_crossSpectrum->array().count();
+    ComplexMatrix& covmat=*_crossSpectrum->matrix();
+    for(int i=0; i<n; i++) {
+      covmat.at(i, i)+=vertical;
+    }
+  }
+
+  double ConvFKVertical::value(const Vector<int>& index) const
+  {
+    if(isInsideLimits(index)) {
+      powerEngine()->setConventionalValue(oneComponentSteering(index));
+      return powerEngine()->value();
     } else {
       return -1.0;
     }
   }
 
-  double ConvFKVertical::value(const Point& k) const
+  double ConvFKVertical::value(Vector<double>& k) const
   {
     if(isInsideLimits(k)) {
-      FKSteeringOneComponent * s=static_cast<FKSteeringOneComponent *>(_steering);
-      s->initValue(k);
-      FKPower p(s);
-      p.setConventionalValue(_crossSpectrum->matrix());
-      return p.value();
+      powerEngine()->setConventionalValue(oneComponentSteering(k));
+      return powerEngine()->value();
     } else {
       return -1.0;
     }
