@@ -41,7 +41,7 @@ namespace ArrayCore {
   */
   FKCrossSpectrum::FKCrossSpectrum(const ArraySelection * array,
                                    const FKParameters * param)
-    : ArrayCrossSpectrum(array, param), _array(array)
+    : ArrayCrossSpectrum(array, param)
   {
     TRACE;
     _rotateStepCount=param->rotateStepCount();
@@ -52,7 +52,10 @@ namespace ArrayCore {
     _invRotateStep=1.0/_rotateStep;
 
     _rotatedMatrices=nullptr;
-
+    _rotatedRadialMatrices=nullptr;
+    _verticalMatrix=nullptr;
+    _horizontalMatrix=nullptr;
+    _source=nullptr;
     resize();
   }
 
@@ -63,20 +66,39 @@ namespace ArrayCore {
   {
     TRACE;
     delete [] _rotatedMatrices;
+    delete [] _rotatedRadialMatrices;
+    delete _verticalMatrix;
+    delete _horizontalMatrix;
   }
 
+  /*!
+    Must be run whenever the process type changes in parameters.
+  */
   void FKCrossSpectrum::resize()
   {
-    int stationCount=_stations.count();
+    // Clear rotated matrices and one-component splits
+    delete [] _rotatedMatrices;
+    delete [] _rotatedRadialMatrices;
+    delete _verticalMatrix;
+    delete _horizontalMatrix;
+    delete _matrix;
+    _rotatedMatrices=nullptr;
+    _rotatedRadialMatrices=nullptr;
+    _verticalMatrix=nullptr;
+    _horizontalMatrix=nullptr;
+    _matrix=nullptr;
+
+    int stationCount=_array.count();
     FKParameters::ProcessType processType;
     processType=static_cast<const FKParameters *>(_parameters)->processType();
     switch(processType) {
+    case FKParameters::Undefined:
     case FKParameters::Conventional:
     case FKParameters::Capon:
     case FKParameters::Omni:
     case FKParameters::ActiveConventional:
     case FKParameters::ActiveCapon:
-      _matrix.resize(stationCount);
+      _matrix=new ComplexMatrix(stationCount);
       break;
     case FKParameters::PoggiVertical:
     case FKParameters::PoggiRadial:
@@ -84,7 +106,6 @@ namespace ArrayCore {
     case FKParameters::CaponTransverse:
     case FKParameters::ConventionalRadial:
     case FKParameters::ConventionalTransverse:
-      delete [] _rotatedMatrices;
       _rotatedMatrices=new ComplexMatrix[_rotateStepCount];
       for(int i=0; i<_rotateStepCount; i++) {
         _rotatedMatrices[i].resize(stationCount);
@@ -92,27 +113,30 @@ namespace ArrayCore {
       break;
     case FKParameters::ConventionalRayleigh:
     case FKParameters::RTBF:
-    case FKParameters::RTBFRadial:
+    case FKParameters::ARTBF:
     case FKParameters::RTBFFixedEll:
-    case FKParameters::ActiveConventionalRayleigh:
-    case FKParameters::ActiveRTBF:
-      delete [] _rotatedMatrices;
       _rotatedMatrices=new ComplexMatrix[_rotateStepCount];
+      _rotatedRadialMatrices=new ComplexMatrix[_rotateStepCount];
       for(int i=0; i<_rotateStepCount; i++) {
         _rotatedMatrices[i].resize(2*stationCount);
+        _rotatedRadialMatrices[i].resize(stationCount);
       }
+      _verticalMatrix=new ComplexMatrix(stationCount);
       break;
-    case FKParameters::LDS:
-      _matrix.resize(2*stationCount);
+    case FKParameters::LDS2:
+    case FKParameters::ActiveRTBF:
+    case FKParameters::ActiveConventionalRayleigh:
+      _matrix=new ComplexMatrix(2*stationCount);
       break;
-    case FKParameters::RDS:
-    case FKParameters::RDSRadial:
-    case FKParameters::RDSVertical:
-    case FKParameters::RDSRefined:
+    case FKParameters::ARDS:
+      _matrix=new ComplexMatrix(3*stationCount);
+      _verticalMatrix=new ComplexMatrix(stationCount);
+      _horizontalMatrix=new ComplexMatrix(2*stationCount);
+      break;
+    case FKParameters::LDS3:
+    case FKParameters::SensorOrientation:
     case FKParameters::RDSSingle:
-    case FKParameters::RDSFixedEll:
-    case FKParameters::ActiveDS:
-      _matrix.resize(3*stationCount);
+      _matrix=new ComplexMatrix(3*stationCount);
       break;
     }
   }
@@ -121,7 +145,7 @@ namespace ArrayCore {
     Get the average source location from all active sources during blockset.
     Stations are then selected according to min and max distance parameters.
   */
-  Point FKCrossSpectrum::setActiveSource(const QVector<int>& blocks, bool& ok)
+  Point FKCrossSpectrum::setActiveSource(const VectorList<int>& blocks, bool& ok)
   {
     const FKParameters * param=parameters();
     Point src;
@@ -135,11 +159,13 @@ namespace ArrayCore {
       QMap<const SeismicEvent *, int> eventList;
       QMap<const SeismicEvent *, int>::iterator eventIt;
       QList<const SeismicEvent *> srcList;
+      // Total number of receivers independently of the current selections
       int nRec=_array.array()->count();
       for(int iRec=0; iRec<nRec; iRec++) {
-        for(QVector<int>::const_iterator it=blocks.begin(); it!=blocks.end(); it++) {
+        for(VectorList<int>::const_iterator it=blocks.begin(); it!=blocks.end(); it++) {
           const TimeRange& win=_timeWindows->list().at(*it);
-          srcList=activeSources->events(win, _array.array()->at(iRec)->coordinates(), param->maximumSlowness());
+          srcList=activeSources->events(win, _array.array()->at(iRec)->coordinates(),
+                                        param->minimumSlowness(), param->maximumSlowness());
           for(QList<const SeismicEvent *>::iterator it=srcList.begin(); it!=srcList.end(); it++) {
             eventIt=eventList.find(*it);
             if(eventIt!=eventList.end()) {
@@ -150,6 +176,22 @@ namespace ArrayCore {
           }
         }
       }
+      if(eventList.isEmpty()) {
+        ok=false;
+        App::log(tr("  No source found, aborting.\n"));
+        return Point();
+      }
+
+      // Check that the sources are not too far away
+      eventIt=eventList.begin();
+      Point ref=eventIt.key()->position();
+      for(eventIt++; eventIt!=eventList.end(); eventIt++) {
+        if(eventIt.key()->position().distanceTo(ref)>1.0) {
+          ok=false;
+          App::log(tr("Skip blockset because it contains a mix of too distant sources.\n"));
+          return Point();
+        }
+      }
 
       // Average the position of sources recorded by at least half of the receivers
       int nSrc=0;
@@ -171,29 +213,37 @@ namespace ArrayCore {
       }
       src/=static_cast<double>(nSrc);
     }
-
-    _array.clear();
-    APP_LOG(1, tr("Checking distances from source (%1)...\n").arg(src.toString(2, 'f')))
-    int n=_array.count();
-    _array.select(src, param->minimumDistance(), param->maximumDistance());
-    if(_array.count()<n) {
-      App::log(1, tr("Selected %1 stations:\n%2")
-                       .arg(_array.count())
-                       .arg(_array.toString(ArraySelection::Absolute)));
-    }
-    parameters()->selectStations(_array);
-
-    if(_array.count()<2) {
-      ok=false;
-      App::log(tr("Less than 2 stations selected, aborting\n"));
-    } else {
-      setStations(&_array);
-      resize();
-    }
+    ok=selectStations(src);
     return src;
   }
 
-  bool FKCrossSpectrum::calculate(const QVector<int>& blocks, AbstractFKFunction * function)
+  bool FKCrossSpectrum::selectStations(const Point& src)
+  {
+    const FKParameters * param=parameters();
+    _array.clear();
+    APP_LOG(1, tr("Checking distances from source (%1)...\n").arg(src.toString('f', 2)))
+    int n=_array.count();
+    _array.select(src, param->minimumDistance(), param->maximumDistance());
+    if(_array.count()<n) {
+      APP_LOG(1, tr("Selected %1 stations:\n%2")
+                       .arg(_array.count())
+                       .arg(_array.toString(ArraySelection::Absolute)));
+    }
+    if(!parameters()->selectStations(_array)) {
+      return false;
+    }
+
+    if(_array.count()<2) {
+      App::log(tr("Less than 2 stations selected, aborting\n"));
+      return false;
+    } else {
+      setStations(&_array);
+      resize();
+      return true;
+    }
+  }
+
+  bool FKCrossSpectrum::calculate(const VectorList<int>& blocks, AbstractFKFunction * function)
   {
     TRACE;
 #ifdef CROSS_SPECTRUM_TIMING
@@ -215,7 +265,7 @@ namespace ArrayCore {
 #ifdef CROSS_SPECTRUM_TIMING
     t2=chrono.elapsed();
 #endif
-    for(QVector<int>::const_iterator it=blocks.begin(); it!=blocks.end(); it++) {
+    for(VectorList<int>::const_iterator it=blocks.begin(); it!=blocks.end(); it++) {
 #ifdef CROSS_SPECTRUM_TIMING
     tBeforeLock=chrono.elapsed();
 #endif
@@ -224,7 +274,9 @@ namespace ArrayCore {
     tLock+=chrono.elapsed()-tBeforeLock;
 #endif
         function->addCrossSpectrum();
-         unlockTimeWindow();
+        unlockTimeWindow();
+      } else {
+        return false;
       }
     }
 #ifdef CROSS_SPECTRUM_TIMING
@@ -238,25 +290,13 @@ namespace ArrayCore {
 
     // Experimental, mask built once with station name lists (1 or 0)
     if(!_arrayMask.isEmpty()) {
-      _matrix=_matrix.dotMultiply(_arrayMask);
-      APP_LOG(4, _matrix.toOctaveString()+"\n")
+      *_matrix=_matrix->dotMultiply(_arrayMask);
+      APP_LOG(4, _matrix->toOctaveString()+"\n")
     }
-
-    switch(parameters()->processType()) {
-    case FKParameters::RDSSingle:
-    case FKParameters::Conventional:
-    case FKParameters::ConventionalRadial:
-    case FKParameters::ConventionalTransverse:
-    case FKParameters::ActiveConventional:
-    case FKParameters::ActiveConventionalRayleigh:
-      return true;
-    default:
-      break;
-    }
-
 #ifdef CROSS_SPECTRUM_TIMING
     t4=chrono.elapsed();
 #endif
+
     // Invert average cross spectra
     // Using Cholesky does not change speed for Vertical
     // Using Cholesky does change speed for 3-Component: from ~11' to 3'20" for a typical case.
@@ -274,28 +314,28 @@ namespace ArrayCore {
   void FKCrossSpectrum::resetRotatedMatrices()
   {
     for(int i=0; i<_rotateStepCount; i++) {
-      _rotatedMatrices[i].zero(0.0);
+      _rotatedMatrices[i].zero();
     }
   }
 
-  void FKCrossSpectrum::addRotatedRadial()
+  void FKCrossSpectrum::addRotatedRadial(const Complex * sensorRotations)
   {
     for(int i=0; i<_rotateStepCount; i++) {
-      addRotatedRadial(i);
+      addRotatedRadial(i, sensorRotations);
     }
   }
 
-  void FKCrossSpectrum::addRotatedTransverse()
+  void FKCrossSpectrum::addRotatedTransverse(const Complex * sensorRotations)
   {
     for(int i=0; i<_rotateStepCount; i++) {
-      addRotatedTransverse(i);
+      addRotatedTransverse(i, sensorRotations);
     }
   }
 
-  void FKCrossSpectrum::addRotatedRayleigh()
+  void FKCrossSpectrum::addRotatedRayleigh(const Complex * sensorRotations)
   {
     for(int i=0; i<_rotateStepCount; i++) {
-      addRotatedRayleigh(i);
+      addRotatedRayleigh(i, sensorRotations);
     }
   }
 
@@ -309,7 +349,23 @@ namespace ArrayCore {
 
   bool FKCrossSpectrum::invert()
   {
-    if(!invert(_matrix)) {
+    if(_horizontalMatrix && _verticalMatrix) {
+      int n=_array.count();
+      int n2=2*n;
+      int n21=2*n-1;
+      int n31=3*n-1;
+      *_verticalMatrix=_matrix->subMatrix(n2, n2, n31, n31);
+      if(!invert(*_verticalMatrix)) {
+        App::log(tr("Cannot invert cross spectrum for vertical sub matrix\n"));
+        return false;
+      }
+      *_horizontalMatrix=_matrix->subMatrix(0, 0, n21, n21);
+      if(!invert(*_horizontalMatrix)) {
+        App::log(tr("Cannot invert cross spectrum for horizontal sub matrix\n"));
+        return false;
+      }
+    }
+    if(!invert(*_matrix)) {
       App::log(tr("Cannot invert cross spectrum\n"));
       return false;
     }
@@ -318,26 +374,44 @@ namespace ArrayCore {
 
   bool FKCrossSpectrum::invertRotatedMatrices()
   {
+    if(_rotatedRadialMatrices && _verticalMatrix) {
+      int n=_array.count();
+      int n1=n-1;
+      int n2=2*n-1;
+      *_verticalMatrix=_rotatedMatrices[0].subMatrix(n, n, n2, n2);
+      if(!invert(*_verticalMatrix)) {
+        App::log(tr("Cannot invert cross spectrum for vertical sub matrix\n"));
+        return false;
+      }
+      for(int i=0; i<_rotateStepCount; i++) {
+        _rotatedRadialMatrices[i]=_rotatedMatrices[i].subMatrix(0, 0, n1, n1);
+        if(!invert(_rotatedRadialMatrices[i])) {
+          App::log(tr("Cannot invert cross spectrum for radial sub matrix in direction %1 deg\n")
+                   .arg(Angle::radiansToDegrees(i*_rotateStep)));
+          return false;
+        }
+      }
+    }
     for(int i=0; i<_rotateStepCount; i++) {
       if(!invert(_rotatedMatrices[i])) {
-        App::log(tr("Cannot invert cross spectrum for direction %1\n").arg(i));
+        App::log(tr("Cannot invert cross spectrum for direction %1 deg\n")
+                 .arg(Angle::radiansToDegrees(i*_rotateStep)));
         return false;
       }
     }
     return true;
   }
 
-  void FKCrossSpectrum::addRotatedRadial(int rotationIndex)
+  void FKCrossSpectrum::addRotatedRadial(int rotationIndex, const Complex * sensorRotations)
   {
     int stationCount=_stations.count();
-    const GaussianFrequencyBand& frequencyFilter=_timeWindows->frequencyFilter();
 
     const ArrayStationSignals * stat;
     ComplexMatrix& covmat=_rotatedMatrices[rotationIndex];
     ComplexMatrix sig(stationCount, 1);
     Angle rotation;
     rotation.setRadians(_rotateStep*rotationIndex);
-
+    Complex rsv;
     // Calculate orientation of each station
     // TODO: take that value from station data itself
     /*Angle * orientations=new Angle[stationCount];
@@ -348,16 +422,21 @@ namespace ArrayCore {
       orientation.set(p.x(), p.y());
       orientation.chSign();
     }*/
-
-    if(_singleValueSpectrum) {
+    if(parameters()->frequencyBandwidth()==0.0) {
       for(int is=0; is<stationCount; is++) {
         stat=_stations.at(is);
         Complex& s=sig.at(is, 0);
-        s=rotation.sin()*stat->spectrumValue(_northIndex);
-        s+=rotation.cos()*stat->spectrumValue(_eastIndex);
+        const Complex& rot=sensorRotations[is];
+        rsv=stat->spectrumValue(_eastIndex)*rot.re();
+        rsv-=stat->spectrumValue(_northIndex)*rot.im();
+        s=rotation.cos()*rsv;   // Rotated east
+        rsv=stat->spectrumValue(_northIndex)*rot.re();
+        rsv+=stat->spectrumValue(_eastIndex)*rot.im();
+        s+=rotation.sin()*rsv;  // Rotated north
       }
-      covmat+=sig*sig.conjugate().transposed();
+      covmat+=sig*sig.conjugateTransposedVector();
     } else {
+      const GaussianFrequencyBand& frequencyFilter=*_timeWindows->frequencyFilter();
       int nFreq=frequencyFilter.maximumIndex();
       double filter;
       //Complex north, east;
@@ -366,9 +445,15 @@ namespace ArrayCore {
         for(int is=0; is<stationCount; is++) {
           stat=_stations.at(is);
           Complex& s=sig.at(is, 0);
-          s=rotation.sin()*stat->spectrumValue(_northIndex, iFreq);
-          s+=rotation.cos()*stat->spectrumValue(_eastIndex, iFreq);
-          /*north=stat->spectrumValue(_northIndex, iFreq);
+          const Complex& rot=sensorRotations[is];
+          rsv=stat->spectrumValue(_eastIndex, iFreq)*rot.re();
+          rsv-=stat->spectrumValue(_northIndex, iFreq)*rot.im();
+          s=rotation.cos()*rsv;   // Rotated east
+          rsv=stat->spectrumValue(_northIndex, iFreq)*rot.re();
+          rsv+=stat->spectrumValue(_eastIndex, iFreq)*rot.im();
+          s+=rotation.sin()*rsv;  // Rotated north
+          /* Test optical fiber array
+          north=stat->spectrumValue(_northIndex, iFreq);
           if(is%5==0) {
             east=stat->spectrumValue(_eastIndex, iFreq);
           } else {
@@ -378,15 +463,14 @@ namespace ArrayCore {
           s+=rotation.cos()*(east*orientations[is].cos()-north*orientations[is].sin());*/
           s*=filter;
         }
-        covmat+=sig*sig.conjugate().transposed();
+        covmat+=sig*sig.conjugateTransposedVector();
       }
     }
   }
 
-  void FKCrossSpectrum::addRotatedTransverse(int rotationIndex)
+  void FKCrossSpectrum::addRotatedTransverse(int rotationIndex, const Complex * sensorRotations)
   {
     int stationCount=_stations.count();
-    const GaussianFrequencyBand& frequencyFilter=_timeWindows->frequencyFilter();
 
     // Calculate orientation of each station
     // TODO: take that value from station data itself
@@ -404,15 +488,22 @@ namespace ArrayCore {
     ComplexMatrix sig(stationCount, 1);
     Angle rotation;
     rotation.setRadians(_rotateStep*rotationIndex);
+    Complex rsv;
     if(parameters()->frequencyBandwidth()==0.0) {
       for(int is=0; is<stationCount; is++) {
         stat=_stations.at(is);
         Complex& s=sig.at(is, 0);
-        s=rotation.cos()*stat->spectrumValue(_northIndex);
-        s-=rotation.sin()*stat->spectrumValue(_eastIndex);
+        const Complex& rot=sensorRotations[is];
+        rsv=stat->spectrumValue(_northIndex)*rot.re();
+        rsv+=stat->spectrumValue(_eastIndex)*rot.im();
+        s=rotation.cos()*rsv;    // Rotated north
+        rsv=stat->spectrumValue(_eastIndex)*rot.re();
+        rsv-=stat->spectrumValue(_northIndex)*rot.im();
+        s-=rotation.sin()*rsv;   // Rotated east
       }
-      covmat+=sig*sig.conjugate().transposed();
+      covmat+=sig*sig.conjugateTransposedVector();
     } else {
+      const GaussianFrequencyBand& frequencyFilter=*_timeWindows->frequencyFilter();
       int nFreq=frequencyFilter.maximumIndex();
       //Complex north, east;
       double filter;
@@ -421,8 +512,13 @@ namespace ArrayCore {
         for(int is=0; is<stationCount; is++) {
           stat=_stations.at(is);
           Complex& s=sig.at(is, 0);
-          s=rotation.cos()*stat->spectrumValue(_northIndex, iFreq);
-          s-=rotation.sin()*stat->spectrumValue(_eastIndex, iFreq);
+          const Complex& rot=sensorRotations[is];
+          rsv=stat->spectrumValue(_northIndex, iFreq)*rot.re();
+          rsv+=stat->spectrumValue(_eastIndex, iFreq)*rot.im();
+          s=rotation.cos()*rsv;    // Rotated north
+          rsv=stat->spectrumValue(_eastIndex, iFreq)*rot.re();
+          rsv-=stat->spectrumValue(_northIndex, iFreq)*rot.im();
+          s-=rotation.sin()*rsv;   // Rotated east
           /* Test optical fiber array
           north=stat->spectrumValue(_northIndex, iFreq);
           if(is%5==0) {
@@ -434,33 +530,39 @@ namespace ArrayCore {
           s-=rotation.sin()*(east*orientations[is].cos()-north*orientations[is].sin());*/
           s*=filter;
         }
-        covmat+=sig*sig.conjugate().transposed();
+        covmat+=sig*sig.conjugateTransposedVector();
       }
     }
   }
 
-  void FKCrossSpectrum::addRotatedRayleigh(int rotationIndex)
+  void FKCrossSpectrum::addRotatedRayleigh(int rotationIndex, const Complex * sensorRotations)
   {
     int stationCount=_stations.count();
-    const GaussianFrequencyBand& frequencyFilter=_timeWindows->frequencyFilter();
 
     const ArrayStationSignals * stat;
     ComplexMatrix& covmat=_rotatedMatrices[rotationIndex];
     ComplexMatrix sig(2*stationCount, 1);
     Angle rotation;
     rotation.setRadians(_rotateStep*rotationIndex);
+    Complex rsv;
     if(parameters()->frequencyBandwidth()==0.0) {
       for(int is=0; is<stationCount; is++) {
         stat=_stations.at(is);
         Complex& s=sig.at(is, 0);
-        s=rotation.sin()*stat->spectrumValue(_northIndex);
-        s+=rotation.cos()*stat->spectrumValue(_eastIndex);
+        const Complex& rot=sensorRotations[is];
+        rsv=stat->spectrumValue(_eastIndex)*rot.re();
+        rsv-=stat->spectrumValue(_northIndex)*rot.im();
+        s=rotation.cos()*rsv;   // Rotated east
+        rsv=stat->spectrumValue(_northIndex)*rot.re();
+        rsv+=stat->spectrumValue(_eastIndex)*rot.im();
+        s+=rotation.sin()*rsv;  // Rotated north
       }
       for(int is=0; is<stationCount; is++) {
         sig.at(stationCount+is, 0)=_stations.at(is)->spectrumValue(_verticalIndex);
       }
-      covmat+=sig*sig.conjugate().transposed();
+      covmat+=sig*sig.conjugateTransposedVector();
     } else {
+      const GaussianFrequencyBand& frequencyFilter=*_timeWindows->frequencyFilter();
       int nFreq=frequencyFilter.maximumIndex();
       double filter;
       for(int iFreq=frequencyFilter.minimumIndex(); iFreq<=nFreq; iFreq++) {
@@ -468,8 +570,13 @@ namespace ArrayCore {
         for(int is=0; is<stationCount; is++) {
           stat=_stations.at(is);
           Complex& s=sig.at(is, 0);
-          s=rotation.sin()*stat->spectrumValue(_northIndex, iFreq);
-          s+=rotation.cos()*stat->spectrumValue(_eastIndex, iFreq);
+          const Complex& rot=sensorRotations[is];
+          rsv=stat->spectrumValue(_eastIndex, iFreq)*rot.re();
+          rsv-=stat->spectrumValue(_northIndex, iFreq)*rot.im();
+          s=rotation.cos()*rsv;   // Rotated east
+          rsv=stat->spectrumValue(_northIndex, iFreq)*rot.re();
+          rsv+=stat->spectrumValue(_eastIndex, iFreq)*rot.im();
+          s+=rotation.sin()*rsv;  // Rotated north
           s*=filter;
         }
         for(int is=0; is<stationCount; is++) {
@@ -477,43 +584,58 @@ namespace ArrayCore {
           s=_stations.at(is)->spectrumValue(_verticalIndex, iFreq);
           s*=filter;
         }
-        covmat+=sig*sig.conjugate().transposed();
+        covmat+=sig*sig.conjugateTransposedVector();
       }
     }
   }
 
-  void FKCrossSpectrum::addThreeComponent()
+  void FKCrossSpectrum::addThreeComponent(const Complex * sensorRotations)
   {
     int stationCount=_stations.count();
     int stationCount2=2*stationCount;
-    const GaussianFrequencyBand& frequencyFilter=_timeWindows->frequencyFilter();
 
-    ComplexMatrix& covmat=_matrix;
+    const ArrayStationSignals * stat;
+    ComplexMatrix& covmat=*_matrix;
     ComplexMatrix sig(3*stationCount, 1);
     if(parameters()->frequencyBandwidth()==0.0) {
       for(int is=0; is<stationCount; is++) {
-         sig.at(is, 0)=_stations.at(is)->spectrumValue(_eastIndex);
+        stat=_stations.at(is);
+        Complex& s=sig.at(is, 0);
+        const Complex& rot=sensorRotations[is];
+         s=stat->spectrumValue(_eastIndex)*rot.re();
+         s-=stat->spectrumValue(_northIndex)*rot.im();
       }
       for(int is=0; is<stationCount; is++) {
-         sig.at(stationCount+is, 0)=_stations.at(is)->spectrumValue(_northIndex);
+        stat=_stations.at(is);
+        Complex& s=sig.at(stationCount+is, 0);
+        const Complex& rot=sensorRotations[is];
+        s=stat->spectrumValue(_northIndex)*rot.re();
+        s+=stat->spectrumValue(_eastIndex)*rot.im();
       }
       for(int is=0; is<stationCount; is++) {
         sig.at(stationCount2+is, 0)=_stations.at(is)->spectrumValue(_verticalIndex);
       }
-      covmat+=sig*sig.conjugate().transposed();
+      covmat+=sig*sig.conjugateTransposedVector();
     } else {
+      const GaussianFrequencyBand& frequencyFilter=*_timeWindows->frequencyFilter();
       int nFreq=frequencyFilter.maximumIndex();
       double filter;
       for(int iFreq=frequencyFilter.minimumIndex(); iFreq<=nFreq; iFreq++) {
         filter=frequencyFilter.taperValue(iFreq);
         for(int is=0; is<stationCount; is++) {
+          stat=_stations.at(is);
           Complex& s=sig.at(is, 0);
-          s=_stations.at(is)->spectrumValue(_eastIndex, iFreq);
+          const Complex& rot=sensorRotations[is];
+          s=stat->spectrumValue(_eastIndex, iFreq)*rot.re();
+          s-=stat->spectrumValue(_northIndex, iFreq)*rot.im();
           s*=filter;
         }
         for(int is=0; is<stationCount; is++) {
+          stat=_stations.at(is);
           Complex& s=sig.at(stationCount+is, 0);
-          s=_stations.at(is)->spectrumValue(_northIndex, iFreq);
+          const Complex& rot=sensorRotations[is];
+          s=stat->spectrumValue(_northIndex, iFreq)*rot.re();
+          s+=stat->spectrumValue(_eastIndex, iFreq)*rot.im();
           s*=filter;
         }
         for(int is=0; is<stationCount; is++) {
@@ -521,7 +643,7 @@ namespace ArrayCore {
           s=_stations.at(is)->spectrumValue(_verticalIndex, iFreq);
           s*=filter;
         }
-        covmat+=sig*sig.conjugate().transposed();
+        covmat+=sig*sig.conjugateTransposedVector();
       }
     }
   }
@@ -554,7 +676,7 @@ namespace ArrayCore {
         sig.at(stationCount+is, 0)=_stations.at(is)->spectrumValue(_northIndex)*orientations[is].cos()
                                   +_stations.at(is)->spectrumValue(_eastIndex)*orientations[is].sin();
       }
-      covmat+=sig*sig.conjugate().transposed();
+      covmat+=sig*sig.conjugateTransposedVector();
     } else {
       int nFreq=frequencyFilter.maximumIndex();
       double filter;
@@ -572,7 +694,7 @@ namespace ArrayCore {
            +_stations.at(is)->spectrumValue(_eastIndex, iFreq)*orientations[is].sin();
           s*=filter;
         }
-        covmat+=sig*sig.conjugate().transposed();
+        covmat+=sig*sig.conjugateTransposedVector();
       }
     }
     delete [] orientations;
@@ -584,9 +706,8 @@ namespace ArrayCore {
   void FKCrossSpectrum::addActiveVertical(const ActiveFKSteering& geom)
   {
     int stationCount=_stations.count();
-    const GaussianFrequencyBand& frequencyFilter=_timeWindows->frequencyFilter();
 
-    ComplexMatrix& covmat=_matrix;
+    ComplexMatrix& covmat=*_matrix;
     ComplexMatrix sig(stationCount, 1);
 #ifndef COMPATIBILITY_2_5_0
     if(parameters()->frequencyBandwidth()==0.0) {
@@ -595,9 +716,10 @@ namespace ArrayCore {
         s=_stations.at(is)->spectrumValue(_verticalIndex);
         s*=geom.amplitudeFactor(is);
       }
-      covmat+=sig*sig.conjugate().transposed();
+      covmat+=sig*sig.conjugateTransposedVector();
     } else {
 #endif
+      const GaussianFrequencyBand& frequencyFilter=*_timeWindows->frequencyFilter();
       int nFreq=frequencyFilter.maximumIndex();
       double filter;
       for(int iFreq=frequencyFilter.minimumIndex(); iFreq<=nFreq; iFreq++) {
@@ -611,7 +733,7 @@ namespace ArrayCore {
           s*=filter*geom.amplitudeFactor(is);
 #endif
         }
-        covmat+=sig*sig.conjugate().transposed();
+        covmat+=sig*sig.conjugateTransposedVector();
       }
 #ifndef COMPATIBILITY_2_5_0
     }
@@ -621,10 +743,9 @@ namespace ArrayCore {
   void FKCrossSpectrum::addActiveRayleigh(const ActiveFKSteering& geom)
   {
     int stationCount=_stations.count();
-    const GaussianFrequencyBand& frequencyFilter=_timeWindows->frequencyFilter();
 
     const ArrayStationSignals * stat;
-    ComplexMatrix& covmat=_matrix;
+    ComplexMatrix& covmat=*_matrix;
     ComplexMatrix sig(2*stationCount, 1);
     if(parameters()->frequencyBandwidth()==0.0) {
       for(int is=0; is<stationCount; is++) {
@@ -639,7 +760,9 @@ namespace ArrayCore {
         s=_stations.at(is)->spectrumValue(_verticalIndex);
         s*=geom.amplitudeFactor(is);
       }
+      covmat+=sig*sig.conjugateTransposedVector();
     } else {
+      const GaussianFrequencyBand& frequencyFilter=*_timeWindows->frequencyFilter();
       int nFreq=frequencyFilter.maximumIndex();
       double filter;
       for(int iFreq=frequencyFilter.minimumIndex(); iFreq<=nFreq; iFreq++) {
@@ -656,7 +779,7 @@ namespace ArrayCore {
           s=_stations.at(is)->spectrumValue(_verticalIndex, iFreq);
           s*=filter*geom.amplitudeFactor(is);
         }
-        covmat+=sig*sig.conjugate().transposed();
+        covmat+=sig*sig.conjugateTransposedVector();
       }
     }
   }
@@ -664,10 +787,9 @@ namespace ArrayCore {
   void FKCrossSpectrum::addActiveTransverse(const ActiveFKSteering& geom)
   {
     int stationCount=_stations.count();
-    const GaussianFrequencyBand& frequencyFilter=_timeWindows->frequencyFilter();
 
     const ArrayStationSignals * stat;
-    ComplexMatrix& covmat=_matrix;
+    ComplexMatrix& covmat=*_matrix;
     ComplexMatrix sig(stationCount, 1);
     if(parameters()->frequencyBandwidth()==0.0) {
       for(int is=0; is<stationCount; is++) {
@@ -677,8 +799,9 @@ namespace ArrayCore {
         s+=geom.transverseRotation(is).cos()*stat->spectrumValue(_eastIndex);
         s*=geom.amplitudeFactor(is);
       }
-      covmat+=sig*sig.conjugate().transposed();
+      covmat+=sig*sig.conjugateTransposedVector();
     } else {
+      const GaussianFrequencyBand& frequencyFilter=*_timeWindows->frequencyFilter();
       int nFreq=frequencyFilter.maximumIndex();
       double filter;
       for(int iFreq=frequencyFilter.minimumIndex(); iFreq<=nFreq; iFreq++) {
@@ -690,7 +813,7 @@ namespace ArrayCore {
           s+=geom.transverseRotation(is).cos()*stat->spectrumValue(_eastIndex, iFreq);
           s*=filter*geom.amplitudeFactor(is);
         }
-        covmat+=sig*sig.conjugate().transposed();
+        covmat+=sig*sig.conjugateTransposedVector();
       }
     }
   }
@@ -699,12 +822,12 @@ namespace ArrayCore {
   {
     int stationCount=_stations.count();
     int stationCount2=2*stationCount;
-    const GaussianFrequencyBand& frequencyFilter=_timeWindows->frequencyFilter();
 
-    ComplexMatrix& covmat=_matrix;
+    ComplexMatrix& covmat=*_matrix;
     ComplexMatrix sig(3*stationCount, 1);
     if(parameters()->frequencyBandwidth()==0.0) {
     } else {
+      const GaussianFrequencyBand& frequencyFilter=*_timeWindows->frequencyFilter();
       int nFreq=frequencyFilter.maximumIndex();
       double filter;
       for(int iFreq=frequencyFilter.minimumIndex(); iFreq<=nFreq; iFreq++) {
@@ -724,59 +847,69 @@ namespace ArrayCore {
           s=_stations.at(is)->spectrumValue(_verticalIndex, iFreq);
           s*=filter*geom.amplitudeFactor(is);
         }
-        covmat+=sig*sig.conjugate().transposed();
+        covmat+=sig*sig.conjugateTransposedVector();
       }
     }
   }
 
-  /*!
-    Normilize by diagonal terms
-  */
-  void FKCrossSpectrum::normalize(ComplexMatrix& covmat)
-  {
-    double * scales=new double[covmat.rowCount()];
-    for(int i=covmat.rowCount()-1; i>=0; i--) {
-      scales[i]=1.0/::sqrt(covmat.at(i, i).re());
-    }
-    for(int i=covmat.rowCount()-1; i>=0; i--) {
-      for(int j=covmat.columnCount()-1; j>=0; j--) {
-        covmat.at(i, j)*=scales[i]*scales[j];
-      }
-    }
-    delete [] scales;
-  }
-
   /*!
   */
   bool FKCrossSpectrum::invert(ComplexMatrix& covmat)
   {
     ComplexMatrix u, vt;
-    QVector<double> sigma;
+    VectorList<double> sigma;
     int n=covmat.rowCount();
+
+    /*covmat.singularValue(sigma, u, vt);
+    ComplexMatrix sigma1(sigma.count());
+    sigma1.zero();
+    for(int i=n-2; i>=0; i--) {
+      sigma1.at(i, i)=sigma.at(i);
+    }
+    covmat=u;
+    covmat*=sigma1;
+    covmat*=vt;*/
+
     if(parameters()->damping()>0.0) {
-      // We need an estimation of average power
-      double d=covmat.trace(0.0).re()/static_cast<double>(n);
+      // The total power
+      double d=covmat.trace(0.0).re();
+      //App::log(tr("Trace %1\n").arg(d));
       d*=parameters()->damping();
       for(int ir=0; ir<n; ir++) {
         covmat.at(ir, ir)+=d;
       }
     }
-    //ComplexMatrix original=covmat;
     covmat.singularValue(sigma, u, vt);
     double sRef=1e-12*sigma.first();
     for(int row=0; row<n ;row++ ) {
       if(sigma.at(row)<sRef) {
-        App::log(tr("%1 Hz, effective rank of cross-spectrum matrix: %2\n")
-                         .arg(_timeWindows->frequency().center())
-                         .arg(row));
+        if(_timeWindows) {
+          App::log(tr("%1 Hz, effective rank of cross-spectrum matrix: %2\n")
+                           .arg(_timeWindows->frequency().center())
+                           .arg(row));
+        } else {
+          App::log(tr("Effective rank of cross-spectrum matrix: %1\n")
+                           .arg(row));
+        }
         return false;
       }
     }
+    //App::log(tr("Largest sigma %1 smallest sigma %2\n").arg(sigma.first()).arg(sigma.last()));
+    /*ComplexMatrix sigma1(sigma.count());
+    sigma1.zero();
+    int index=3;
+    sigma1.at(index, index)=sigma.at(index);
+    covmat=u;
+    covmat*=sigma1;
+    covmat*=vt;
+    return true;*/
+
+    //ComplexMatrix original=covmat;
     if(!covmat.invert(u, sigma, vt)) {
       return false;
     }
-
     /*original*=covmat;
+    // Quantify distance from identity
     double sum=0.0;
     for(int i=original.rowCount()-1; i>=0; i--) {
       for(int j=original.columnCount()-1; j>i; j--) {
@@ -787,8 +920,7 @@ namespace ArrayCore {
         sum+=original.at(i, j).abs();
       }
     }
-    QTextStream(stdout) << sum;
-    exit(2);*/
+    App::log(tr("Identity misfit %1\n").arg(sum));*/
     return true;
   }
 
@@ -811,7 +943,7 @@ namespace ArrayCore {
       break;
     case ArrayStations::ThreeComponents:
       switch(processType) {
-      case FKParameters::RDS:
+      case FKParameters::ARDS:
         return setRayleighArrayMask();
       default:
         break;
@@ -834,11 +966,11 @@ namespace ArrayCore {
       stationIndex.insert(_stations.at(i)->originalSignals()->name(), i);
     }
     _arrayMask.resize(3*n);
-    _arrayMask.zero(0.0);
+    _arrayMask.zero();
     QList<QStringList>::const_iterator ita;
     APP_LOG(1, tr("Mapping station names to index...\n"))
     for(ita=arrays.begin(); ita!=arrays.end(); ita++) {
-      QVector<int> index;
+      VectorList<int> index;
       index.reserve(ita->count());
       for(QStringList::const_iterator it=ita->begin(); it!=ita->end(); it++) {
         int i=stationIndex.value(*it, -1);
@@ -849,9 +981,9 @@ namespace ArrayCore {
         index.append(i);
         APP_LOG(1, tr("'%1' ---> %2\n").arg(*it).arg(i))
       }
-      for(QVector<int>::const_iterator itr=index.begin(); itr!=index.end(); itr++) {
+      for(VectorList<int>::const_iterator itr=index.begin(); itr!=index.end(); itr++) {
         int ir0=*itr;
-        for(QVector<int>::const_iterator itc=index.begin(); itc!=index.end(); itc++) {
+        for(VectorList<int>::const_iterator itc=index.begin(); itc!=index.end(); itc++) {
           int ic0=*itc;
           for(int ir=2*n+ir0; ir>=ir0; ir-=n) {
             for(int ic=2*n+ic0; ic>=ic0; ic-=n) {
@@ -881,11 +1013,11 @@ namespace ArrayCore {
       stationIndex.insert(_stations.at(i)->originalSignals()->name(), i);
     }
     _arrayMask.resize(n);
-    _arrayMask.zero(0.0);
+    _arrayMask.zero();
     QList<QStringList>::const_iterator ita;
     APP_LOG(1, tr("Mapping station names to index...\n"))
     for(ita=arrays.begin(); ita!=arrays.end(); ita++) {
-      QVector<int> index;
+      VectorList<int> index;
       index.reserve(ita->count());
       APP_LOG(1, tr("  Array containing %1 stations\n").arg(ita->count()))
       for(QStringList::const_iterator it=ita->begin(); it!=ita->end(); it++) {
@@ -897,8 +1029,8 @@ namespace ArrayCore {
         index.append(i);
         APP_LOG(1, tr("    '%1' ---> %2\n").arg(*it).arg(i))
       }
-      for(QVector<int>::const_iterator itr=index.begin(); itr!=index.end(); itr++) {
-        for(QVector<int>::const_iterator itc=index.begin(); itc!=index.end(); itc++) {
+      for(VectorList<int>::const_iterator itr=index.begin(); itr!=index.end(); itr++) {
+        for(VectorList<int>::const_iterator itc=index.begin(); itc!=index.end(); itc++) {
           double& v=_arrayMask.at(*itr, *itc);
           if(v==0.0) {
             v=1;
@@ -910,27 +1042,16 @@ namespace ArrayCore {
     return true;
   }
 
-  void FKCrossSpectrum::setEllipticity(const ComplexMatrix& ell)
-  {
-    if(_rotatedMatrices) {
-      for(int i=0; i<_rotateStepCount; i++) {
-        _rotatedMatrices[i]=_rotatedMatrices[i].dotMultiply(ell);
-      }
-    } else {
-      _matrix=_matrix.dotMultiply(ell);
-    }
-  }
-
   void FKCrossSpectrum::addRayleighSingle()
   {
     Complex east, north, vertical;
     ASSERT(_stations.count()==1);
-    const GaussianFrequencyBand& frequencyFilter=_timeWindows->frequencyFilter();
     if(parameters()->frequencyBandwidth()==0.0) {
       east=_stations.at(0)->spectrumValue(_eastIndex);
       north=_stations.at(0)->spectrumValue(_northIndex);
       vertical=_stations.at(0)->spectrumValue(_verticalIndex);
     } else {
+      const GaussianFrequencyBand& frequencyFilter=*_timeWindows->frequencyFilter();
       int nFreq=frequencyFilter.maximumIndex();
       double filter;
       for(int iFreq=frequencyFilter.minimumIndex(); iFreq<=nFreq; iFreq++) {
@@ -959,8 +1080,8 @@ namespace ArrayCore {
      // Set a null phase for vertical: real for vertical and imaginary positive for horizontal
     h*=delay;
     vertical*=delay;
-    _matrix.at(0, 0)+=h;
-    _matrix.at(0, 1)+=vertical;
+    _matrix->at(0, 0)+=h;
+    _matrix->at(0, 1)+=vertical;
     // TODO:
     //  - check that the stupid stack of abs values is as good
     //  - write it in a dedicated SingleEllipticityCrossSpectrum avoid fake grid search
@@ -972,7 +1093,7 @@ namespace ArrayCore {
 
   void FKCrossSpectrum::meanRayleighSingle()
   {
-    _matrix.at(2, 2)=sqrt(_matrix.at(0, 0).abs2()/_matrix.at(0, 1).abs2());
+    _matrix->at(2, 2)=sqrt(_matrix->at(0, 0).abs2()/_matrix->at(0, 1).abs2());
   }
 
 } // namespace ArrayCore
