@@ -45,29 +45,28 @@ namespace ArrayCore {
     double rotationStep() const {return _rotateStep;}
     int rotationStepCount() const {return _rotateStepCount;}
 
-    bool calculate(const QVector<int>& blocks, AbstractFKFunction * function);
+    bool calculate(const VectorList<int>& blocks, AbstractFKFunction * function);
 
-    void setActiveSource(const SeismicEvent * src) {_source=src;}
-    Point setActiveSource(const QVector<int>& blocks, bool& ok);
+    virtual Point setActiveSource(const VectorList<int>& blocks, bool& ok);
+    void forceActiveSource(const SeismicEvent * src) {_source=src;}
 
     const Point& sourceOffset() const {return _sourceOffset;}
     void setSourceOffset(const Point& o) {_sourceOffset=o;}
 
-    const ArraySelection& array() const {return _array;}
-
+    void resize();
     void resetRotatedMatrices();
 
-    void addThreeComponent();
+    virtual void addThreeComponent(const Complex * sensorRotations);
     // Test of optical fiber arrays
     //void addHorizontalRotatedRayleigh() {addHorizontalRotated(_rayleigh);}
     //void addHorizontalRotatedLove() {addHorizontalRotated(_love);}
-    void addRotatedRadial();
-    void addRotatedTransverse();
-    void addRotatedRayleigh();
-    void addActiveVertical(const ActiveFKSteering& geom);
-    void addActiveRayleigh(const ActiveFKSteering& geom);
-    void addActiveTransverse(const ActiveFKSteering& geom);
-    void addActiveThreeComponent(const ActiveFKSteering& geom);
+    void addRotatedRadial(const Complex * sensorRotations);
+    void addRotatedTransverse(const Complex * sensorRotations);
+    void addRotatedRayleigh(const Complex * sensorRotations);
+    virtual void addActiveVertical(const ActiveFKSteering& geom);
+    virtual void addActiveRayleigh(const ActiveFKSteering& geom);
+    virtual void addActiveTransverse(const ActiveFKSteering& geom);
+    virtual void addActiveThreeComponent(const ActiveFKSteering& geom);
     void addRayleighSingle();
 
     void meanRotatedMatrices(int nBlocks);
@@ -75,40 +74,48 @@ namespace ArrayCore {
 
     bool invert();
     bool invertRotatedMatrices();
+    bool invert(ComplexMatrix& covmat);
 
-    inline const ComplexMatrix& rotatedMatrix(const Point2D& k) const;
-    inline const ComplexMatrix& rotatedMatrix(int rotationIndex) const;
+    inline const ComplexMatrix * rotatedMatrix(const Vector<double>& k) const;
+    inline const ComplexMatrix * rotatedMatrix(const Vector<int>& index) const;
+    inline ComplexMatrix * rotatedMatrix(int rotationIndex);
+
+    inline const ComplexMatrix * rotatedRadialMatrix(const Vector<double>& k) const;
+    const ComplexMatrix * verticalMatrix() const {return _verticalMatrix;}
 
     bool setMask();
-    void setEllipticity(const ComplexMatrix& ell);
+  protected:
+    bool selectStations(const Point& src);
+
+    virtual void addRotatedRadial(int rotationIndex, const Complex * sensorRotations);
+    virtual void addRotatedTransverse(int rotationIndex, const Complex * sensorRotations);
+    virtual void addRotatedRayleigh(int rotationIndex, const Complex * sensorRotations);
+
+    inline int rotationIndex(double kx, double ky) const;
+
+    ComplexMatrix * _rotatedMatrices;
+    ComplexMatrix * _rotatedRadialMatrices;
+    ComplexMatrix * _verticalMatrix;
+    ComplexMatrix * _horizontalMatrix;
+
+    int _rotateStepCount;
+    double _rotateStep, _invRotateStep;
   private:
-    void resize();
     // Test of optical fiber arrays
     //void addHorizontalRotated(ComplexMatrix& covmat);
-    void addRotatedRadial(int rotationIndex);
-    void addRotatedTransverse(int rotationIndex);
-    void addRotatedRayleigh(int rotationIndex);
-    inline int rotationIndex(const Point2D& k) const;
-    void normalize(ComplexMatrix& covmat);
-    bool invert(ComplexMatrix& covmat);
 
     bool setRayleighArrayMask();
     bool setOneComponentArrayMask();
 
-    int _rotateStepCount;
-    double _rotateStep, _invRotateStep;
-
-    ArraySelection _array;
     const SeismicEvent * _source;
     Point _sourceOffset;
 
     DoubleMatrix _arrayMask;
-    ComplexMatrix * _rotatedMatrices;
   };
 
-  inline int FKCrossSpectrum::rotationIndex(const Point2D& k) const
+  inline int FKCrossSpectrum::rotationIndex(double kx, double ky) const
   {
-    double angle=::atan2(k.y(), k.x()); // From -M_PI to M_PI
+    double angle=::atan2(ky, kx); // From -M_PI to M_PI
     if(angle<0.0) {
       angle+=2.0*M_PI;
     }
@@ -121,14 +128,24 @@ namespace ArrayCore {
     }
   }
 
-  inline const ComplexMatrix& FKCrossSpectrum::rotatedMatrix(const Point2D& k) const
+  inline const ComplexMatrix * FKCrossSpectrum::rotatedMatrix(const Vector<int>& index) const
   {
-    return _rotatedMatrices[rotationIndex(k)];
+    return _rotatedMatrices+rotationIndex(index[0], index[1]);
   }
 
-  inline const ComplexMatrix& FKCrossSpectrum::rotatedMatrix(int rotationIndex) const
+  inline const ComplexMatrix * FKCrossSpectrum::rotatedMatrix(const Vector<double>& k) const
   {
-    return _rotatedMatrices[rotationIndex];
+    return _rotatedMatrices+rotationIndex(k[0], k[1]);
+  }
+
+  inline ComplexMatrix * FKCrossSpectrum::rotatedMatrix(int rotationIndex)
+  {
+    return _rotatedMatrices+rotationIndex;
+  }
+
+  inline const ComplexMatrix * FKCrossSpectrum::rotatedRadialMatrix(const Vector<double>& k) const
+  {
+    return _rotatedRadialMatrices+rotationIndex(k[0], k[1]);
   }
 
 } // namespace ArrayCore
