@@ -38,7 +38,10 @@ namespace ArrayCore {
   FKParameters::FKParameters()
     : ArrayParameters()
   {
-    setDefaultValues(RTBF, RefinedGrid);
+    _processType=Undefined;
+    _ellipticityCorrection=None;
+    _inversionMethod=RefinedGrid;
+    setDefaultValues();
     _cacheGridStepFactor=0.05;
     _cacheGridStep=0.0;
     _gridStep=0.0;
@@ -51,64 +54,64 @@ namespace ArrayCore {
     _maxAzimuth=0.0;
     _sourceGridStep=1.0;
     _sourceGridSize=0.0;
+    // dV/V=-dk/k, hence a relative precision in wavenumber is approximately the
+    // same as a relative precision in velocity or slowness (dV/V=-ds/s)
+    _velocityRelativePrecision=1e-3;
+    _ellipticityAbsolutePrecision=M_PI/180000.0;
+
+    _sensorOrientationApertureAngle=M_PI;
+    _sensorOrientationMaximumRadius=0.0;
+    _sensorOrientationMaximumCorrection=M_PI/9.0;
+    _sensorOrientationMaximumIterations=100;
+
+    _brightSpots=0;
   }
 
-  FKParameters::FKParameters(const FKParameters& o)
-    : ArrayParameters(o)
+  /*!
+    Set default processing type according to mode \a m if it is not
+    already set. Other values are also set to their defaults.
+  */
+  void FKParameters::setDefaultValues(ArrayStations::Mode m)
   {
-    _inversionMethod=o._inversionMethod;
-    _cacheGridStepFactor=o._cacheGridStepFactor;
-    _cacheGridStep=o._cacheGridStep;
-    _gridStepFactor=o._gridStepFactor;
-    _gridStep=o._gridStep;
-    _gridSizeFactor=o._gridSizeFactor;
-    _gridSize=o._gridSize;
-    _kmin=o._kmin;
-    _kmax=o._kmax;
-    _smin=o._smin;
-    _smax=o._smax;
-    _minAzimuth=o._minAzimuth;
-    _maxAzimuth=o._maxAzimuth;
-    _refineSlowMin=o._refineSlowMin;
-    _refineSlowMax=o._refineSlowMax;
-    _maxPeakCount=o._maxPeakCount;
-    _absoluteThreshold=o._absoluteThreshold;
-    _relativeThreshold=o._relativeThreshold;
-    _saveUndefinedEllipticities=o._saveUndefinedEllipticities;
-    _exportAllFKGrids=o._exportAllFKGrids;
-    _damping=o._damping;
-    _rotateStepCount=o._rotateStepCount;
-    _processType=o._processType;
-    _arrays=o._arrays;
-    _fixedEllipticityFileName=o._fixedEllipticityFileName;
-    _minimumDistance=o._minimumDistance;
-    _maximumDistance=o._maximumDistance;
-    _sourceGridStep=o._sourceGridStep;
-    _sourceGridSize=o._sourceGridSize;
+    if(_processType==Undefined) {
+      switch(m) {
+      case ArrayStations::Vertical:
+        _processType=Capon;
+        break;
+      case ArrayStations::Horizontal:
+        _processType=CaponRadial;
+        break;
+      case ArrayStations::ThreeComponents:
+        _processType=ARDS;
+        break;
+      }
+    }
+    setDefaultValues();
   }
 
-  void FKParameters::setDefaultValues(ProcessType t, InversionMethod invm)
+  /*!
+    Process type and inversion mthod must be already set.
+  */
+  void FKParameters::setDefaultValues()
   {
-    _processType=t;
-    _maxPeakCount=INT_MAX; // Avoid sensitivity to negligible differences between
-                           // peak amplitudes. Accept all peaks down to
-                           // 90% of the maximum amplitude rather than a single value
-                           // If null ellipticities are not saved, max file size is kept
-                           // reasonable even without filter (RTBF and RDS).
+    _maxPeakCount=0;
+    _maxPeakCountFactor=1.0;
     _absoluteThreshold=0.0;
-    _relativeThreshold=90.0;
+    _relativeThreshold=0.9;
 
-    _saveUndefinedEllipticities=false;
+    _saveUndefinedEllipticities=true;
+    _sortResultValues=true;
     _exportAllFKGrids=false;
     _damping=0.0;
     _rotateStepCount=72;
-    setfrequencyBandwidth(0.05);
+    setfrequencyBandwidth(0.0);
     blockAveraging().setStatisticCount(50);
     blockAveraging().setStatisticMaxOverlap(0.0);
 
     switch(_processType) {
+    case Undefined:
     FKPARAMETERS_PASSIVE_PROCESS_TYPES
-      windowing().setPeriodCount(100.0);
+      windowing().setPeriodCount(50.0);
       setOversamplingFactor(1.0);
       _minimumDistance=0.0;
       _maximumDistance=std::numeric_limits<double>::infinity();
@@ -127,16 +130,16 @@ namespace ArrayCore {
     }
 
     switch(_processType) {
-    case RDS:
-    case RDSRadial:
-    case RDSVertical:
-    case RDSRefined:
+    case ARDS:
+    case LDS3:
+    case SensorOrientation:
     case RDSSingle:
-    case RDSFixedEll:
       blockAveraging().setCount(0);
       blockAveraging().setCountFactor(6.0);
-      _relativeThreshold=0.0; //
+      _relativeThreshold=0.01;
+      _saveUndefinedEllipticities=false;
       break;
+    case Undefined:
     case Capon:
     case CaponRadial:
     case CaponTransverse:
@@ -147,14 +150,15 @@ namespace ArrayCore {
       blockAveraging().setCountFactor(2.0);
       break;
     case RTBF:
-    case RTBFRadial:
+    case ARTBF:
     case RTBFFixedEll:
       blockAveraging().setCount(0);
       blockAveraging().setCountFactor(4.0);
-      _relativeThreshold=0.0;
-      invm=RefinedGrid; // Gradient not supported for RTBF
+      _relativeThreshold=0.01;
+      _inversionMethod=RefinedGrid; // Gradient not supported for RTBF
+      _saveUndefinedEllipticities=false;
       break;
-    case LDS:
+    case LDS2:
       blockAveraging().setCount(0);
       blockAveraging().setCountFactor(4.0);
       break;
@@ -162,6 +166,9 @@ namespace ArrayCore {
     case ConventionalRadial:
     case ConventionalTransverse:
     case ConventionalRayleigh:
+      blockAveraging().setCount(0);
+      blockAveraging().setCountFactor(0.5);
+      break;
     case ActiveConventionalRayleigh:
       blockAveraging().setCount(0);
       blockAveraging().setCountFactor(0.5);
@@ -172,13 +179,21 @@ namespace ArrayCore {
       setMaximumPeakCount(1);
       break;
     case ActiveRTBF:
-    case ActiveDS:
     case ActiveCapon:
       blockAveraging().setCount(3);
       break;
     }
-    _inversionMethod=invm;
-    _gridStepFactor=defaultGridStepFactor(t, _inversionMethod);
+    // Ellipticity correction
+    switch(_processType) {
+    case ARDS:
+    case ARTBF:
+      _ellipticityCorrection=ThreeComponent;
+      break;
+    default:
+      _ellipticityCorrection=None;
+      break;
+    }
+    _gridStepFactor=defaultGridStepFactor(_processType, _inversionMethod);
     _gridSizeFactor=2.0;
     // Force default grid step and size if they are not yet set
     setKmin(_kmin);
@@ -188,25 +203,23 @@ namespace ArrayCore {
   double FKParameters::defaultGridStepFactor(ProcessType t, InversionMethod m)
   {
     switch(t) {
+    case Undefined:
     case Capon:
     case Omni:
     case CaponRadial:
     case CaponTransverse:
     case RTBF:
-    case RTBFRadial:
+    case ARTBF:
     case RTBFFixedEll:
-    case RDS:
-    case RDSRadial:
-    case RDSVertical:
-    case RDSRefined:
+    case ARDS:
+    case SensorOrientation:
     case RDSSingle:
-    case RDSFixedEll:
     case PoggiVertical:
     case PoggiRadial:
-    case LDS:
+    case LDS2:
+    case LDS3:
     case ActiveCapon:
     case ActiveRTBF:
-    case ActiveDS:
       switch(m) {
       case Gradient:
         return 0.5;
@@ -267,6 +280,19 @@ namespace ArrayCore {
     _kmax=k;
   }
 
+  int FKParameters::maximumPeakCount(int sensorCount) const
+  {
+    if(_maxPeakCount<1) {
+      int n=qRound(_maxPeakCountFactor*sensorCount);
+      if(n<1) {
+        n=1;
+      }
+      return n;
+    } else {
+      return _maxPeakCount;
+    }
+  }
+
   /*!
     Limit grid size to fall inside the frequency-slowness area of interest.
   */
@@ -314,7 +340,7 @@ namespace ArrayCore {
 
   int FKParameters::keywordCount(PARAMETERS_KEYWORDCOUNT_ARGS) const
   {
-    return 29+ArrayParameters::keywordCount();
+    return 41+ArrayParameters::keywordCount();
   }
 
   void FKParameters::collectKeywords(PARAMETERS_COLLECTKEYWORDS_ARGS)
@@ -336,10 +362,12 @@ namespace ArrayCore {
     keywords.add(prefix+"MIN_AZIMUTH"+suffix, this, baseIndex+25);
     keywords.add(prefix+"MAX_AZIMUTH"+suffix, this, baseIndex+26);
     keywords.add(prefix+"N_MAXIMA"+suffix, this, baseIndex+3);
+    keywords.add(prefix+"N_MAXIMA_FACTOR"+suffix, this, baseIndex+40);
     keywords.add(prefix+"ABSOLUTE_THRESHOLD"+suffix, this, baseIndex+4);
     keywords.add(prefix+"RELATIVE_THRESHOLD"+suffix, this, baseIndex+5);
     keywords.add(prefix+"EXPORT_ALL_FK_GRIDS"+suffix, this, baseIndex+6);
     keywords.add(prefix+"SAVE_UNDEFINED_ELLIPTICITIES"+suffix, this, baseIndex+27);
+    keywords.add(prefix+"SORT_RESULT_VALUES"+suffix, this, baseIndex+29);
     keywords.add(prefix+"DAMPING_FACTOR"+suffix, this, baseIndex+7);
     keywords.add(prefix+"ROTATE_STEP_COUNT"+suffix, this, baseIndex+8);
     keywords.add(prefix+"PROCESS_TYPE"+suffix, this, baseIndex+9);
@@ -351,6 +379,16 @@ namespace ArrayCore {
     keywords.add(prefix+"DO_DAMPING_FACTOR"+suffix, this, baseIndex+15); // For compatibility
     keywords.add(prefix+"SOURCE_GRID_STEP"+suffix, this, baseIndex+22);
     keywords.add(prefix+"SOURCE_GRID_SIZE"+suffix, this, baseIndex+23);
+    keywords.add(prefix+"SENSOR_ORIENTATION_ERRORS"+suffix, this, baseIndex+30);
+    keywords.add(prefix+"SENSOR_POSITION_ERRORS"+suffix, this, baseIndex+31);
+    keywords.add(prefix+"VELOCITY_RELATIVE_PRECISION"+suffix, this, baseIndex+32);
+    keywords.add(prefix+"ELLIPTICITY_ABSOLUTE_PRECISION"+suffix, this, baseIndex+33);
+    keywords.add(prefix+"SENSOR_ORIENTATION_APERTURE_ANGLE"+suffix, this, baseIndex+36);
+    keywords.add(prefix+"SENSOR_ORIENTATION_MAXIMUM_RADIUS"+suffix, this, baseIndex+37);
+    keywords.add(prefix+"SENSOR_ORIENTATION_MAXIMUM_CORRECTION"+suffix, this, baseIndex+34);
+    keywords.add(prefix+"SENSOR_ORIENTATION_MAXIMUM_ITERATIONS"+suffix, this, baseIndex+35);
+    keywords.add(prefix+"BRIGHT_SPOTS"+suffix, this, baseIndex+38);
+    keywords.add(prefix+"ELLIPTICITY_CORRECTION"+suffix, this, baseIndex+39);
   }
 
   QString FKParameters::toString(PARAMETERS_TOSTRING_ARGS_IMPL) const
@@ -375,52 +413,32 @@ namespace ArrayCore {
          "#  CaponTransverse          EN   High resolution FK processing (Capon, 1969) for transverse projections.\n"
          "#  RTBF                     ENZ  According to Wathelet et al (2018).\n"
          "#                                Cross spectrum made of radial projections and vertical.\n"
-         "#                                Combined radial and vertical ellipticity steering.\n"
-         "#  RTBFRadial               ENZ  According to Wathelet et al (2018).\n"
+         "#                                Product of radial and vertical ellipticity steering.\n"
+         "#  ARTBF                    ENZ  RTBF with all-component ellipticity steering.\n"
          "#                                Cross spectrum made of radial projections and vertical.\n"
-         "#                                Radial ellipticity steering, better for small ellipticities.\n"
          "#  PoggiVertical            ENZ  According Poggi et al. (2010)\n"
          "#                                k picked from vertical processing.\n"
          "#  PoggiRadial              ENZ  According Poggi et al. (2010)\n"
          "#                                k picked from radial processing.\n"
-         "#  RDS                      ENZ  Rayleigh Direct Steering.\n"
+         "#  ARDS                     ENZ  Rayleigh Direct Steering with All-component ellipticity steerting.\n"
          "#                                Cross spectrum made of raw components E, N and Z.\n"
          "#                                Radial projections included in the steering matrix.\n"
-         "#                                Combined radial and vertical ellipticity steering.\n"
-         "#  LDS                      EN   Love Direct Steering.\n"
+         "#  LDS3                     ENZ  Love Direct Steering.\n"
+         "#                                Cross spectrum made of raw components E, N and Z.\n"
+         "#                                Transverse projections included in the steering matrix.\n"
+         "#  LDS2                     EN   Love Direct Steering.\n"
          "#                                Cross spectrum made of raw components E and N.\n"
          "#                                Transverse projections included in the steering matrix.\n"
-         "#  RDSRadial                ENZ  Rayleigh Direct Steering.\n"
-         "#                                Cross spectrum made of raw components E, N and Z.\n"
-         "#                                Radial projections included in the steering matrix.\n"
-         "#                                Radial ellipticity steering, better for small ellipticities.\n"
          "#  Experimental modes:\n"
          "#  RTBFFixedEll             ENZ  Same as RTBF but ellipticity is fixed.\n"
          "#                                FIXED_ELLIPTICITY_FILE_NAME must be provided.\n"
-         "#  RDSFixedEll              ENZ  Same as RDS but ellipticity is fixed.\n"
-         "#                                FIXED_ELLIPTICITY_FILE_NAME must be provided.\n"
          "#  ActiveConventional       Z    Conventional FK processing for active sources.\n"
          "#  ActiveRTBF               ENZ  RTBF for active sources\n"
-         "#                                Cross spectrum made of radial and transverse projections.\n"
-         "#  ActiveDS                 ENZ  Cross spectrum made of raw components E, N and Z.\n"
-         "#                                Radial and transverse projections included in steering matrix.\n"
-         "#  ActiveConventional            Conventional FK processing for active sources\n"
-         "#                                Cross spectrum made of radial and transverse projections.\n"
-         "#  Omni                     ENZ  Same cross spectrum as RDS.\n"
-         "#                                Ouput power is the sum of power in all directions\n"
-         "#  RDSVertical              ENZ  Cross spectrum made of raw components E, N and Z.\n"
-         "#                                Radial and transverse projections included in steering matrix.\n"
-         "#                                Radial ellipticity steering.\n"
-         "#  RDSRadial                ENZ  Cross spectrum made of raw components E, N and Z.\n"
-         "#                                Radial and transverse projections included in steering matrix.\n"
-         "#                                Vertical ellipticity steering.\n"
-         "#  RDSRefined               ENZ  Cross spectrum made of raw components E, N and Z.\n"
-         "#                                Radial and transverse projections included in steering matrix.\n"
-         "#                                Iterative ellitpticity assessment.\n";
-    log+=prefix+"PROCESS_TYPE"+suffix+"="+processTypeString()+"\n";
+         "#                                Cross spectrum made of radial and transverse projections.\n";
+    log+=prefix+"PROCESS_TYPE"+suffix+"="+convertProcessType(_processType)+"\n";
     switch(_processType) {
     case RTBF:
-    case RTBFRadial:
+    case ARTBF:
     case RTBFFixedEll:
     case PoggiVertical:
     case PoggiRadial:
@@ -435,8 +453,15 @@ namespace ArrayCore {
     default:
       break;
     }
+    log+="# Correction can be: None, OneComponent, ThreeComponent or Mixed\n";
+    log+=prefix+"ELLIPTICITY_CORRECTION"+suffix+"="+convertEllipticityCorrection(_ellipticityCorrection)+"\n";
     log+=prefix+"DAMPING_FACTOR"+suffix+"="+QString::number(_damping)+"\n";
-    log+="# If provided and PROCESS_TYPE==DirectSteering, the ellipticity is forced to the provided curve.\n"
+    log+="# Iterative bright spot removal: the cross-spectrum for the best peak\n"
+         "# is reconstructed and removed from the cross-spectral matrix. Another best\n"
+         "# peak is searched with the modified cross-spectral matrix. The process is\n"
+         "# repeated until removing the expected number of bright spots.\n";
+    log+=prefix+"BRIGHT_SPOTS"+suffix+"="+QString::number(_brightSpots)+"\n";
+    log+="# If provided and PROCESS_TYPE==RTBF, ARTBF or ARDS, the ellipticity is forced to the provided curve.\n"
          "# The file must contain two columns: frequency and signed ellipticity.\n"
          "# Provided sampling must not necessarily match the processing sampling frequency, linear interpolation is used.\n"
          "# Better for precision if the two sampling match.\n"
@@ -448,6 +473,19 @@ namespace ArrayCore {
     log+=prefix+"MAXIMUM_DISTANCE"+suffix+"="+QString::number(_maximumDistance)+"\n";
     log+=prefix+"SOURCE_GRID_STEP"+suffix+"="+QString::number(_sourceGridStep)+"\n";
     log+=prefix+"SOURCE_GRID_SIZE"+suffix+"="+QString::number(_sourceGridSize)+"\n";
+    log+="# Introduces errors in sensor orientation to test the robustness of methods.\n"
+         "# Provides a list of names and values like: STATION_NAME1:error,STATION_NAME2:error,... in degrees.\n"
+         "# To set random perturbations to each sensor lower than a threshold value, use '@RANDOM:error' keyword.\n"
+         "# To set a fixed value for all station use '@ALL:error'.\n";
+    log+=prefix+"SENSOR_ORIENTATION_ERRORS"+suffix+" (deg)="+sensorOrientationErrorsToString()+"\n";
+    log+="# Introduces errors in sensor position to test the robustness of methods.\n"
+         "# Provides a list of names and values like: STATION_NAME1:dx dy,STATION_NAME2:dx dy,....\n"
+         "# To set random perturbations to each sensor lower than a threshold value, use '@RANDOM:dx dy' keyword.\n"
+         "# To set a fixed value for all station use '@ALL:dx dy'.\n";
+    log+=prefix+"SENSOR_POSITION_ERRORS"+suffix+" (m)="+sensorPositionErrorsToString()+"\n";
+    for(QList<QStringList>::const_iterator it=_arrays.begin(); it!=_arrays.end(); it++) {
+      log+=prefix+"ARRAY"+suffix+"="+it->join(',')+"\n";
+    }
     log+="# Experimental join processing of several arrays\n";
     log+="# Several ARRAY can be defined with a list of station names\n";
     for(QList<QStringList>::const_iterator it=_arrays.begin(); it!=_arrays.end(); it++) {
@@ -493,12 +531,26 @@ namespace ArrayCore {
          "#\n"
          "#\n";
     log+="# Inversion method used for getting FK peaks: Gradient or RefinedGrid\n";
-    log+=prefix+"INVERSION_METHOD"+suffix+"="+inversionMethodString()+"\n";
+    log+=prefix+"INVERSION_METHOD"+suffix+"="+convertInversionMethod(_inversionMethod)+"\n";
+    log+="# When refining a peak these two precision thresholds define the end conditions.\n";
+    log+=prefix+"VELOCITY_RELATIVE_PRECISION"+suffix+"="+QString::number(velocityRelativePrecision())+"\n";
+    log+=prefix+"ELLIPTICITY_ABSOLUTE_PRECISION"+suffix+" (deg)="+QString::number(Angle::radiansToDegrees(ellipticityAbsolutePrecision()))+"\n";
     log+=prefix+"N_MAXIMA"+suffix+"="+QString::number(_maxPeakCount)+"\n";
+    log+=prefix+"N_MAXIMA_FACTOR"+suffix+"="+QString::number(_maxPeakCountFactor)+"\n";
     log+=prefix+"ABSOLUTE_THRESHOLD"+suffix+"="+QString::number(_absoluteThreshold)+"\n";
-    log+=prefix+"RELATIVE_THRESHOLD"+suffix+" (%)="+QString::number(_relativeThreshold)+"\n";
+    log+=prefix+"RELATIVE_THRESHOLD"+suffix+" (%)="+QString::number(_relativeThreshold*100.0)+"\n";
     log+=prefix+"SAVE_UNDEFINED_ELLIPTICITIES"+suffix+"="+(_saveUndefinedEllipticities ? "y" : "n")+"\n";
+    log+=prefix+"SORT_RESULT_VALUES"+suffix+"="+(_sortResultValues ? "y" : "n")+"\n";
     log+=prefix+"EXPORT_ALL_FK_GRIDS"+suffix+"="+(_exportAllFKGrids ? "y" : "n")+"\n";
+    log+="#\n"
+         "#\n"
+         "#     Sensor orientation (only for PROCESS_TYPE=SensorOrientation)\n"
+         "#\n"
+         "#\n";
+    log+=prefix+"SENSOR_ORIENTATION_APERTURE_ANGLE"+suffix+"="+QString::number(Angle::radiansToDegrees(_sensorOrientationApertureAngle))+"\n";
+    log+=prefix+"SENSOR_ORIENTATION_MAXIMUM_RADIUS"+suffix+"="+QString::number(_sensorOrientationMaximumRadius)+"\n";
+    log+=prefix+"SENSOR_ORIENTATION_MAXIMUM_CORRECTION"+suffix+"="+QString::number(Angle::radiansToDegrees(_sensorOrientationMaximumCorrection))+"\n";
+    log+=prefix+"SENSOR_ORIENTATION_MAXIMUM_ITERATIONS"+suffix+"="+QString::number(_sensorOrientationMaximumIterations)+"\n";
     return log;
   }
 
@@ -508,8 +560,8 @@ namespace ArrayCore {
     bool ok=true;
     switch(index-ArrayParameters::keywordCount()) {
     case 19:
-      setInversionMethod(value);
-      return true;
+      setInversionMethod(convertInversionMethod(value, ok));
+      return ok;
     case 20:
       _cacheGridStep=value.toDouble(&ok);
       return ok;
@@ -563,7 +615,7 @@ namespace ArrayCore {
       _absoluteThreshold=value.toDouble(&ok);
       return ok;
     case 5:
-      _relativeThreshold=value.toDouble(&ok);
+      _relativeThreshold=value.toDouble(&ok)*0.01;
       return ok;
     case 6:
       _exportAllFKGrids=(value=="y");
@@ -580,8 +632,8 @@ namespace ArrayCore {
       _rotateStepCount=value.toInt(&ok);
       return ok;
     case 9:
-      setProcessType(value);
-      return true;
+      _processType=convertProcessType(value, ok);
+      return ok;
     case 10:
       _arrays.append(value.split(','));
       return true;
@@ -609,173 +661,178 @@ namespace ArrayCore {
     case 23:
       _sourceGridSize=value.toDouble(&ok);
       return ok;
+    case 29:
+      _sortResultValues=(value=="y");
+      return ok;
+    case 30:
+      sensorOrientationErrorsFromString(value, ok);
+      return ok;
+    case 31:
+      sensorPositionErrorsFromString(value, ok);
+      return ok;
+    case 32:
+      _velocityRelativePrecision=value.toDouble(&ok);
+      return ok;
+    case 33:
+      _ellipticityAbsolutePrecision=Angle::degreesToRadians(value.toDouble(&ok));
+      return ok;
+    case 34:
+      _sensorOrientationMaximumCorrection=Angle::degreesToRadians(value.toDouble(&ok));
+      return ok;
+    case 35:
+      _sensorOrientationMaximumIterations=value.toInt(&ok);
+      return ok && _sensorOrientationMaximumIterations>1;
+    case 36:
+      _sensorOrientationApertureAngle=Angle::degreesToRadians(value.toDouble(&ok));
+      return ok;
+    case 37:
+      _sensorOrientationMaximumRadius=value.toDouble(&ok);
+      return ok && _sensorOrientationMaximumRadius>=0.0;
+    case 38:
+      _brightSpots=value.toInt(&ok);
+      return ok;
+    case 39:
+      _ellipticityCorrection=convertEllipticityCorrection(value, ok);
+      return ok;
+    case 40:
+      _maxPeakCountFactor=value.toDouble(&ok);
+      return ok;
     default:
       break;
     }
     return ArrayParameters::setValue(index, value, unit, keywords);
   }
 
-  bool FKParameters::setProcessType(QString p)
+  QString FKParameters::sensorOrientationErrorsToString() const
   {
-    p=p.toLower();
-    if(p.count()<3) {
-      return false;
+    if(_sensorOrientationErrors.isEmpty()) {
+      return "@ALL:0";
     }
-    switch(p[2].unicode()) {
-    case 'b':
-      if(p=="rtbf") {
-        _processType=RTBF;
-      } else if(p=="rtbfradial") {
-        _processType=RTBFRadial;
-      } else if(p=="rtbffixedell") {
-        _processType=RTBFFixedEll;
-      }
-      return false;
-    case 'g':
-      if(p=="poggivertical") {
-        _processType=PoggiVertical;
-      } else if(p=="poggiradial") {
-        _processType=PoggiRadial;
-      }
-      return false;
-    case 'n':
-      if(p=="conventional") {
-        _processType=Conventional;
-      } else if(p=="omni") {
-        _processType=Omni;
-      } else if(p=="conventionalradial") {
-        _processType=ConventionalRadial;
-      } else if(p=="conventionaltransverse") {
-        _processType=ConventionalTransverse;
-      } else if(p=="conventionalrayleigh") {
-        _processType=ConventionalRayleigh;
-      }
-      return false;
-    case 'o':
-      if(p=="projections") {                     // Kept for compatibility
-        _processType=RTBF;
-      }
-      return false;
-    case 'p':
-      if(p=="capon") {
-        _processType=Capon;
-      } else if(p=="caponradial") {
-        _processType=CaponRadial;
-      } else if(p=="capontransverse") {
-        _processType=CaponTransverse;
-      }
-      return false;
-    case 'r':
-      if(p=="directsteering") {                  // Kept for compatibility
-        _processType=RDS;
-      } else if(p=="directsteeringrefined") {    // Kept for compatibility
-        _processType=RDSRefined;
-      } else if(p=="directsteeringvertical") {   // Kept for compatibility
-        _processType=RDSVertical;
-      } else if(p=="directsteeringradial") {    // Kept for compatibility
-        _processType=RDSRadial;
-      } else if(p=="directsteeringsingle") {    // Kept for compatibility
-        _processType=RDSSingle;
-      }
-      return false;
-    case 's':
-      if(p=="rds") {
-        _processType=RDS;
-      } else if(p=="lds") {
-        _processType=LDS;
-      } else if(p=="rdsradial") {
-        _processType=RDSRadial;
-      } else if(p=="rdsvertical") {
-        _processType=RDSVertical;
-      } else if(p=="rdsrefined") {
-        _processType=RDSRefined;
-      } else if(p=="rdssingle") {
-        _processType=RDSSingle;
-      } else if(p=="rdsfixedell") {
-        _processType=RDSFixedEll;
-      }
-      return false;
-    case 't':
-      if(p=="activeconventional") {
-        _processType=ActiveConventional;
-      } else if(p=="activecapon") {
-        _processType=ActiveCapon;
-      } else if(p=="activeconventionalrayleigh") {
-        _processType=ActiveConventionalRayleigh;
-      } else if(p=="activertbf") {
-        _processType=ActiveRTBF;
-      } else if(p=="activeds") {
-        _processType=ActiveDS;
-      } else if(p=="activeprojections") {        // Kept for compatibility
-        _processType=ActiveRTBF;
-      } else if(p=="activedirectsteering") {     // Kept for compatibility
-        _processType=ActiveDS;
-      }
-      return false;
+    QMap<QString, double>::const_iterator it;
+    QString str;
+    if(_sensorPositionErrors.count()>1) {
+      str+="\\\n  ";
     }
-    return true;
+    for(it=_sensorOrientationErrors.begin(); it!=_sensorOrientationErrors.end(); it++) {
+      if(!str.isEmpty()) {
+        str+=", \\\n";
+      }
+      str+=it.key();
+      str+=":";
+      str+=QString::number(it.value(), 'g', 20);
+    }
+    return str;
   }
 
-  QString FKParameters::processTypeString() const
+  void FKParameters::sensorOrientationErrorsFromString(const QString& values, bool& ok)
   {
-    switch(_processType) {
-    case Conventional:
-      break;
-    case Capon:
-      return "Capon";
-    case ActiveConventional:
-      return "ActiveConventional";
-    case ActiveCapon:
-      return "ActiveCapon";
-    case Omni:
-      return "Omni";
-    case ConventionalRadial:
-      return "ConventionalRadial";
-    case CaponRadial:
-      return "CaponRadial";
-    case ConventionalTransverse:
-      return "ConventionalTransverse";
-    case CaponTransverse:
-      return "CaponTransverse";
-    case ConventionalRayleigh:
-      return "ConventionalRayleigh";
-    case RTBF:
-      return "RTBF";
-    case RTBFRadial:
-      return "RTBFRadial";
-    case RTBFFixedEll:
-      return "RTBFFixedEll";
-    case RDS:
-      return "RDS";
-    case RDSRadial:
-      return "RDSRadial";
-    case RDSVertical:
-      return "RDSVertical";
-    case RDSRefined:
-      return "RDSRefined";
-    case RDSSingle:
-      return "RDSSingle";
-    case RDSFixedEll:
-      return "RDSFixedEll";
-    case PoggiVertical:
-      return "PoggiVertical";
-    case PoggiRadial:
-      return "PoggiRadial";
-    case LDS:
-      return "LDS";
-    case ActiveConventionalRayleigh:
-      return "ActiveConventionalRayleigh";
-    case ActiveRTBF:
-      return "ActiveRTBF";
-    case ActiveDS:
-      return "ActiveDS";
+    _sensorOrientationErrors.clear();
+    QStringList list=values.split(",");
+    for(QStringList::const_iterator it=list.begin(); it!=list.end(); it++) {
+      const QString& item=*it;
+      if(!item.trimmed().isEmpty()) {
+        _sensorOrientationErrors.insert(item.section(':', 0, 0).trimmed(), item.section(':', 1, 1).toDouble(&ok));
+        if(!ok) {
+          _sensorOrientationErrors.clear();
+          break;
+        }
+      }
     }
-    return "Conventional";
+  }
+
+  double FKParameters::sensorOrientationError(const QString& name) const
+  {
+     QMap<QString, double>::const_iterator it=_sensorOrientationErrors.find(name);
+     if(it==_sensorOrientationErrors.end()) {
+       return 0.0;
+     } else {
+       return it.value();
+     }
+  }
+
+  QString FKParameters::sensorPositionErrorsToString() const
+  {
+    if(_sensorPositionErrors.isEmpty()) {
+      return "@ALL:0 0";
+    }
+    QMap<QString, Point2D>::const_iterator it;
+    QString str;
+    if(_sensorPositionErrors.count()>1) {
+      str+="\\\n  ";
+    }
+    for(it=_sensorPositionErrors.begin(); it!=_sensorPositionErrors.end(); it++) {
+      if(!str.isEmpty()) {
+        str+=", \\\n  ";
+      }
+      str+=it.key();
+      str+=":";
+      str+=it.value().toString('g', 20);
+    }
+    return str;
+
+  }
+
+  void FKParameters::sensorPositionErrorsFromString(const QString& values, bool& ok)
+  {
+    _sensorPositionErrors.clear();
+    QStringList list=values.split(",");
+    for(QStringList::const_iterator it=list.begin(); it!=list.end(); it++) {
+      const QString& item=*it;
+      if(!item.trimmed().isEmpty()) {
+        Point2D p;
+        ok=p.fromString(item.section(':', 1, 1));
+        if(ok) {
+          _sensorPositionErrors.insert(item.section(':', 0, 0).trimmed(), p);
+        } else {
+          _sensorPositionErrors.clear();
+          break;
+        }
+      }
+    }
+  }
+
+  Point2D FKParameters::sensorPositionError(const QString& name) const
+  {
+     QMap<QString, Point2D>::const_iterator it=_sensorPositionErrors.find(name);
+     if(it==_sensorPositionErrors.end()) {
+       return Point2D();
+     } else {
+       return it.value();
+     }
+  }
+
+  ENUM_AS_STRING_BEGIN(FKParameters, ProcessType)
+  ENUM_AS_STRING_DATA_23(ActiveCapon, ActiveConventional, ActiveConventionalRayleigh,
+                         ActiveRTBF, ARDS, ARTBF, Capon, CaponRadial, CaponTransverse,
+                         Conventional, ConventionalRadial, ConventionalRayleigh,
+                         ConventionalTransverse, LDS2, LDS3, Omni, PoggiRadial,
+                         PoggiVertical, RDSSingle, RTBF, RTBFFixedEll,
+                         SensorOrientation, Undefined);
+  ENUM_AS_STRING_SYNONYM("Projections", RTBF);
+  ENUM_AS_STRING_DEFAULT_VALUE(Undefined);
+  ENUM_AS_STRING_END
+
+  ENUM_AS_STRING_BEGIN(FKParameters, InversionMethod)
+  ENUM_AS_STRING_DATA_2(Gradient, RefinedGrid);
+  ENUM_AS_STRING_END
+
+  ENUM_AS_STRING_BEGIN(FKParameters, EllipticityCorrection)
+  ENUM_AS_STRING_DATA_2(None, ThreeComponent);
+  ENUM_AS_STRING_END
+
+  QStringList FKParameters::processTypes()
+  {
+    QStringList l;
+    for(int i=1; i<=RDSSingle; i++) {
+      l.append(convertProcessType(static_cast<ProcessType>(i)));
+    }
+    return l;
   }
 
   bool FKParameters::isActiveProcessType() const
   {
     switch(_processType) {
+    case Undefined:
     FKPARAMETERS_PASSIVE_PROCESS_TYPES
       return false;
     FKPARAMETERS_ACTIVE_PROCESS_TYPES
@@ -784,38 +841,12 @@ namespace ArrayCore {
     return true;
   }
 
-
-  bool FKParameters::setInversionMethod(QString p)
-  {
-    p=p.toLower();
-    if(p=="refinedgrid") {
-      _inversionMethod=RefinedGrid;
-    } else if(p=="gradient") {
-      _inversionMethod=Gradient;
-    } else {
-      return false;
-    }
-    return true;
-  }
-
-  QString FKParameters::inversionMethodString() const
-  {
-    switch(_inversionMethod) {
-    case Gradient:
-      break;
-    case RefinedGrid:
-      return "RefinedGrid";
-    }
-    return "Gradient";
-  }
-
   QString FKParameters::outputName(const QString& groupName) const
   {
-    QString fn;
     if(ArrayParameters::outputBaseName().endsWith(".max")) {
       return ArrayParameters::outputBaseName();
     } else if(ArrayParameters::outputBaseName().isEmpty()) {
-      return processTypeString().toLower()+"-"+groupName;
+      return QString(convertProcessType(_processType)).toLower()+"-"+groupName+".max";
     } else {
       QString baseName;
       if(!ArrayParameters::outputBaseName().endsWith("-") &&
@@ -824,10 +855,12 @@ namespace ArrayCore {
       } else {
         baseName=ArrayParameters::outputBaseName();
       }
-      if(baseName.contains(processTypeString().toLower())) {
-        return baseName+groupName;
+      QString p=convertProcessType(_processType);
+      p=p.toLower();
+      if(baseName.contains(p)) {
+        return baseName+groupName+".max";
       } else {
-        return baseName+processTypeString().toLower()+"-"+groupName;
+        return baseName+p+"-"+groupName+".max";
       }
     }
   }
