@@ -29,7 +29,13 @@
 
 namespace ArrayCore {
 
-const char * FKPeaks::maxHeaderLine="# abs_time frequency slowness azimuth ellipticity noise power valid";
+  const char * FKPeaks::maxHeaderLine="# abs_time frequency slowness azimuth ellipticity Rz/N Rh/N power valid";
+
+
+  void FKPeaks::Value::setExtraValues(const Vector<double>& val, int firstIndex, int lastIndex, double factor)
+  {
+    extraValues=new PrivateVector<double>(val, firstIndex, lastIndex, factor);
+  }
 
   /*!
     \class FKPeaks FKPeaks.h
@@ -55,6 +61,10 @@ const char * FKPeaks::maxHeaderLine="# abs_time frequency slowness azimuth ellip
   FKPeaks::~FKPeaks()
   {
     TRACE;
+    int n=size();
+    for(int i=0; i<n; i++) {
+      delete _values[i].extraValues;
+    }
     free(_values);
   }
 
@@ -90,41 +100,18 @@ const char * FKPeaks::maxHeaderLine="# abs_time frequency slowness azimuth ellip
             .arg(n))
   }
 
-  /*!
-    Ellipticity must be the plain value not the angle.
-  */
-  bool FKPeaks::add(const Point2D &k, double ell, double noise, double power,
-                    const WaveNumberConverter& conv, double minimumSlowness)
+  FKPeaks::Value * FKPeaks::add()
   {
-    double slow=conv.slowness(k);
-    if(slow>minimumSlowness) {
-      if(_full) {
-        return false;
-      } else {
-        int n=size();
-        IncreaseStorage::add();
-        Value& v=_values[n];
-        v.time=_timeReference.secondsTo(conv.time());
-        v.frequency=conv.frequency();
-        v.slowness=slow;
-        v.azimuth=conv.azimuth(k);
-        v.ellipticity=ell;
-        v.noise=noise;
-        v.power=power;
-        v.valid=true;
-        APP_LOG(8, tr("%1 Hz: new peak at %2 m/s propagating towards %3 with ellippticity %4\n")
-                            .arg(conv.frequency())
-                            .arg(1.0/slow)
-                            .arg(conv.azimuth(k))
-                            .arg(::atan(ell)))
-      }
+    if(_full) {
+      return nullptr;
+    } else {
+      IncreaseStorage::add();
+      return lastValue();
     }
-    return true;
   }
 
-  void FKPeaks::add(const FKPeaks& peaks)
+  void FKPeaks::add(FKPeaks& peaks)
   {
-    App::log(tr("Merging results...\n"));
     _addLock.lock();
     int i0=size();
     int n=peaks.size();
@@ -133,8 +120,11 @@ const char * FKPeaks::maxHeaderLine="# abs_time frequency slowness azimuth ellip
     _addLock.unlock();
     for(int i=0; i<n; i++) {
       _values[i0+i]=peaks._values[i];
+      // Ownership of extra values transfered to the destination
+      peaks._values[i].extraValues=nullptr;
     }
     _dataLock.unlock();
+    App::log(tr("  %1 peaks merged\n").arg(n));
   }
 
   bool FKPeaks::save(const QString &fileName,
@@ -162,6 +152,7 @@ const char * FKPeaks::maxHeaderLine="# abs_time frequency slowness azimuth ellip
         s << "#\n"
              "# BEGIN PARAMETERS\n"
              "#\n";
+        s << param->AbstractParameters::toString();
         s << param->toString();
         s << "#\n"
              "# END PARAMETERS\n"
@@ -188,9 +179,17 @@ const char * FKPeaks::maxHeaderLine="# abs_time frequency slowness azimuth ellip
           << v.slowness << " "
           << v.azimuth << " "
           << v.ellipticity << " "
-          << v.noise << " "
+          << v.verticalNoise << " "
+          << v.horizontalNoise << " "
           << v.power << " "
-          << (v.valid ? 1 : 0) << "\n";
+          << (v.valid ? 1 : 0);
+        if(v.extraValues) {
+          int n=v.extraValues->count();
+          for(int i=0; i<n; i++) {
+            s << " " << v.extraValues->at(i);
+          }
+        }
+        s << "\n";
       }
       return true;
     } else {
@@ -222,26 +221,30 @@ const char * FKPeaks::maxHeaderLine="# abs_time frequency slowness azimuth ellip
     do {
       line=s.readLine();
     } while(!line.isEmpty() && line[0]=='#');
+    bool ok=true;
     if(!line.isEmpty()) {
       const QChar * ptr=nullptr;
       StringSection field,fields(line);
       field=fields.nextField(ptr);
-      v.time=_timeReference.secondsTo(field.toTime(DateTime::defaultFormat));
+      v.time=_timeReference.secondsTo(field.toTime(DateTime::defaultFormat, ok));
       field=fields.nextField(ptr);
-      v.frequency=field.toDouble();
+      v.frequency=field.toDouble(ok);
       field=fields.nextField(ptr);
-      v.slowness=field.toDouble();
+      v.slowness=field.toDouble(ok);
       field=fields.nextField(ptr);
-      v.azimuth=field.toDouble();
+      v.azimuth=field.toDouble(ok);
       field=fields.nextField(ptr);
-      v.ellipticity=field.toDouble();
+      v.ellipticity=field.toDouble(ok);
       field=fields.nextField(ptr);
-      v.noise=field.toDouble();
+      v.verticalNoise=field.toDouble(ok);
       field=fields.nextField(ptr);
-      v.power=field.toDouble();
+      v.horizontalNoise=field.toDouble(ok);
       field=fields.nextField(ptr);
-      v.valid=(field.toInt()==1);
-      return true;
+      v.power=field.toDouble(ok);
+      field=fields.nextField(ptr);
+      v.valid=(field.toInt(ok)==1);
+      v.extraValues=nullptr;
+      return ok;
     } else {
       return false;
     }
@@ -406,6 +409,8 @@ const char * FKPeaks::maxHeaderLine="# abs_time frequency slowness azimuth ellip
   void FKPeaks::horizontalSingleDirection(double angleTolerance)
   {
     TRACE;
+    Q_UNUSED(angleTolerance);
+    TODO_WARNING;
     /*sort();
     int n=size();
     if(n==0) {
@@ -414,7 +419,7 @@ const char * FKPeaks::maxHeaderLine="# abs_time frequency slowness azimuth ellip
     double currentTime=_values[0].time;
     double currentFrequency=_values[0].frequency;
     AverageAngle rayleighAverage, loveAverage;
-    QVector<Azimuth> rayleighValues, loveValues;
+    VectorList<Azimuth> rayleighValues, loveValues;
     int notValidCount=0;
     int totalCount=0;
     for(int i=0; i<n; i++) {
@@ -462,44 +467,44 @@ const char * FKPeaks::maxHeaderLine="# abs_time frequency slowness azimuth ellip
   /*!
     Return number invalidated entries
   */
-  int FKPeaks::validateSingleDirection(double rayleighAverage, const QVector<Azimuth>& rayleighValues,
-                                       double loveAverage, const QVector<Azimuth>& loveValues,
+  int FKPeaks::validateSingleDirection(double rayleighAverage, const VectorList<Azimuth>& rayleighValues,
+                                       double loveAverage, const VectorList<Azimuth>& loveValues,
                                        double angleTolerance)
   {
     TRACE;
     int notValidCount=0;
     if(isSingleDirection(rayleighAverage, rayleighValues, angleTolerance)) {
-      for(QVector<Azimuth>::const_iterator it=loveValues.begin(); it!=loveValues.end(); it++) {
+      for(VectorList<Azimuth>::const_iterator it=loveValues.begin(); it!=loveValues.end(); it++) {
         if(fabs(Angle::differenceDegrees(it->value, rayleighAverage))>angleTolerance) {
           _values[it->index].valid=false;
           notValidCount++;
         }
       }
       if(notValidCount>0) { // several directions for Love
-        for(QVector<Azimuth>::const_iterator it=rayleighValues.begin(); it!=rayleighValues.end(); it++) {
+        for(VectorList<Azimuth>::const_iterator it=rayleighValues.begin(); it!=rayleighValues.end(); it++) {
           _values[it->index].valid=false;
           notValidCount++;
         }
       }
     } else if(isSingleDirection(loveAverage, loveValues, angleTolerance)) {
-      for(QVector<Azimuth>::const_iterator it=rayleighValues.begin(); it!=rayleighValues.end(); it++) {
+      for(VectorList<Azimuth>::const_iterator it=rayleighValues.begin(); it!=rayleighValues.end(); it++) {
         if(fabs(Angle::differenceDegrees(it->value, loveAverage))>angleTolerance) {
           _values[it->index].valid=false;
           notValidCount++;
         }
       }
       if(notValidCount>0) { // several directions for Rayleigh
-        for(QVector<Azimuth>::const_iterator it=loveValues.begin(); it!=loveValues.end(); it++) {
+        for(VectorList<Azimuth>::const_iterator it=loveValues.begin(); it!=loveValues.end(); it++) {
           _values[it->index].valid=false;
           notValidCount++;
         }
       }
     } else { // Plenty of directions for both polarization
-      for(QVector<Azimuth>::const_iterator it=rayleighValues.begin(); it!=rayleighValues.end(); it++) {
+      for(VectorList<Azimuth>::const_iterator it=rayleighValues.begin(); it!=rayleighValues.end(); it++) {
         _values[it->index].valid=false;
         notValidCount++;
       }
-      for(QVector<Azimuth>::const_iterator it=loveValues.begin(); it!=loveValues.end(); it++) {
+      for(VectorList<Azimuth>::const_iterator it=loveValues.begin(); it!=loveValues.end(); it++) {
         _values[it->index].valid=false;
         notValidCount++;
       }
@@ -509,10 +514,10 @@ const char * FKPeaks::maxHeaderLine="# abs_time frequency slowness azimuth ellip
 
   /*!
   */
-  bool FKPeaks::isSingleDirection(double average, const QVector<Azimuth>& values, double angleTolerance)
+  bool FKPeaks::isSingleDirection(double average, const VectorList<Azimuth>& values, double angleTolerance)
   {
     TRACE;
-    for(QVector<Azimuth>::const_iterator it=values.begin(); it!=values.end(); it++) {
+    for(VectorList<Azimuth>::const_iterator it=values.begin(); it!=values.end(); it++) {
       if(fabs(Angle::differenceDegrees(it->value, average))>angleTolerance) {
         return false;
       }
@@ -533,16 +538,23 @@ const char * FKPeaks::maxHeaderLine="# abs_time frequency slowness azimuth ellip
 
   /*!
     Sort as primary key decreasing frequency and secondary increasing time
+
+    If \a sortValues is true, slowness, azimuth,... are sorted. If not, they are left in
+    their original order.
   */
-  void FKPeaks::sort()
+  void FKPeaks::sort(bool sortValues)
   {
     TRACE;
     int n=size();
-    QVector<Value *> list(n);
+    VectorList<Value *> list(n);
     for(int i=0; i<n; i++) {
       list[i]=_values+i;
     }
-    std::sort(list.begin(), list.end(), valueLessThan);
+    if(sortValues) {
+      std::sort(list.begin(), list.end(), valueLessThan);
+    } else {
+      std::stable_sort(list.begin(), list.end(), valueLessThanFrequenceTime);
+    }
     Value * newValues=static_cast<Value *>(allocateVector(sizeof(Value)));
     for(int i=0; i<n; i++) {
       memcpy(newValues+i, list.at(i), sizeof(Value));
@@ -580,5 +592,25 @@ const char * FKPeaks::maxHeaderLine="# abs_time frequency slowness azimuth ellip
     }
   }
 
+  /*!
+    Keep slowness in their original order if stable sort is used (help debug)
+  */
+  bool FKPeaks::valueLessThanFrequenceTime(Value * v1, Value * v2)
+  {
+    if(v1->frequency>v2->frequency) {
+      return true;
+    } else if(v1->frequency<v2->frequency) {
+      return false;
+    } else {
+      if(v1->time<v2->time) {
+        return true;
+      } else if(v1->time>v2->time) {
+        return false;
+      } else {
+        return false;
+      }
+    }
+  }
+
 } // namespace ArrayCore
 
