@@ -27,6 +27,7 @@
 #define FKPEAKS_H
 
 #include <QGpCoreWave.h>
+#include <QGpCoreStat.h>
 
 #include "ArrayCoreDLLExport.h"
 
@@ -45,19 +46,24 @@ namespace ArrayCore {
     class Value
     {
     public:
+      void setExtraValues(const Vector<double>& val, int firstIndex, int lastIndex, double factor);
+
       double frequency;
       double time;
-      double slowness, azimuth, ellipticity, noise, power;
+      double slowness, azimuth, ellipticity,
+             verticalNoise, horizontalNoise, power;
+      PrivateVector<double> * extraValues;
       bool valid;
     };
 
     void clear();
     int size() const {return IncreaseStorage::size();}
 
-    bool add(const Point2D &k, double ell, double noise, double power,
-             const WaveNumberConverter& conv, double minimumSlowness);
-    void add(const FKPeaks& peaks);
-    void sort();
+    Value * add();
+    Value * lastValue() {return _values+size()-1;}
+    void removeLast() {IncreaseStorage::removeLast();}
+    void add(FKPeaks& peaks);
+    void sort(bool sortValues);
     bool save(const QString &fileName,
               const AbstractParameters * param=nullptr,
               const ArraySelection * array=nullptr,
@@ -78,6 +84,7 @@ namespace ArrayCore {
     Value& valueAt(int index) const {return _values[index];}
 
     void setTimeReference(const DateTime& t) {_timeReference=t;}
+    double time(const DateTime& t) const {return _timeReference.secondsTo(t);}
 
     static const char * maxHeaderLine;
   private:
@@ -89,13 +96,15 @@ namespace ArrayCore {
       double value;
       int index;
     };
-    int validateSingleDirection(double rayleighAverage, const QVector<Azimuth>& rayleighValues,
-                                double loveAverage, const QVector<Azimuth>& loveValues,
+    int validateSingleDirection(double rayleighAverage, const VectorList<Azimuth>& rayleighValues,
+                                double loveAverage, const VectorList<Azimuth>& loveValues,
                                 double angleTolerance);
-    bool isSingleDirection(double average, const QVector<Azimuth>& values, double angleTolerance);
+    bool isSingleDirection(double average, const VectorList<Azimuth>& values, double angleTolerance);
     void singleDirectionReport(double frequency, int notValidCount, int totalCount);
 
     static bool valueLessThan(Value * v1, Value * v2);
+    static bool valueLessThanFrequenceTime(Value * v1, Value * v2);
+
     void reallocate();
 
     Value * _values;
