@@ -47,7 +47,6 @@ namespace ArrayCore {
   {
     TRACE;
     _binCount=200;
-    _minimumSlowness=0.0;
   }
 
   /*!
@@ -79,7 +78,7 @@ namespace ArrayCore {
     Histogram2D * h=new Histogram2D(freqParam.count(), _binCount);
     h->setXSampling(freqParam);
     SamplingParameters slowParam;
-    slowParam.setMinimum(_minimumSlowness);
+    slowParam.setMinimum(parameters()->minimumSlowness());
     slowParam.setMaximum(parameters()->maximumSlowness());
     slowParam.setScaleType(SamplingParameters::Log);
     slowParam.setCount(_binCount); // Required only for log
@@ -101,7 +100,7 @@ namespace ArrayCore {
     kParam.setMaximum(parameters()->kmax());
     h->setXSampling(kParam);
     SamplingParameters slowParam;
-    slowParam.setMinimum(_minimumSlowness);
+    slowParam.setMinimum(parameters()->minimumSlowness());
     slowParam.setMaximum(parameters()->maximumSlowness());
     slowParam.setScaleType(SamplingParameters::Log);
     h->setYSampling(slowParam);
@@ -203,7 +202,9 @@ namespace ArrayCore {
   {
     TRACE;
     h->normalizeAmplitude(YAxis);
-    h->filterThreshold(_value);
+    SampleClassificationParameters param;
+    param.setThreshold(_value);
+    h->threshold<Histogram2D::Invalidate>(param);
   }
 
   FKResults::HitCountFilter::HitCountFilter(double value)
@@ -214,7 +215,9 @@ namespace ArrayCore {
   void FKResults::HitCountFilter::run(Histogram2D * h)
   {
     TRACE;
-    h->filterThreshold(_value);
+    SampleClassificationParameters param;
+    param.setThreshold(_value);
+    h->threshold<Histogram2D::Invalidate>(param);
   }
 
   /*!
@@ -236,7 +239,10 @@ namespace ArrayCore {
   void FKResults::MedianCurve::run(Histogram2D * h)
   {
     TRACE;
-    Curve<RealStatisticalPoint> c=h->medianCurve();
+    RealStatisticalCurve c;
+    RealStatisticalProxy p;
+    p.setCurve(&c);
+    h->medianCurve(&p);
     if(_maxMisfit>0.0) {
       h->validateCurve(c, _maxMisfit);
     }
@@ -248,7 +254,10 @@ namespace ArrayCore {
   */
   void FKResults::MedianCurve::run(Histogram2D * h, QGpCoreWave::Mode::Polarization polarization)
   {
-    Curve<RealStatisticalPoint> c=h->medianCurve();
+    RealStatisticalCurve c;
+    RealStatisticalProxy p;
+    p.setCurve(&c);
+    h->medianCurve(&p);
     if(_maxMisfit>0.0) {
       h->validateCurve(c, _maxMisfit);
     }
@@ -270,14 +279,12 @@ namespace ArrayCore {
   QList<Curve<RealStatisticalPoint>> FKResults::GaussianMixture::scan(Histogram2D * h, QGpCoreWave::Mode::Polarization polarization)
   {
     TRACE;
-    HistogramDensities hd;
+    HistogramInversion hd(1);
     Curve<RealStatisticalPoint> curve;
 
-    hd.setHistogram(h);
+    hd.setHistogram(0, h);
     GaussianMixtureParameters param;
     param.setModeCount(4);
-    param.setInversionType(GaussianMixtureParameters::MeanOnly);
-    param.setAbsoluteError(0.125*_results->parameters()->kmin());
     param.setKmin(0.25*_results->parameters()->kmin());
     param.setKmax(_results->parameters()->kmax());
     hd.setParameters(param);
@@ -290,13 +297,13 @@ namespace ArrayCore {
 
     for(int f=0; f<nf; f++) {
       p.setX(frequencies.value(f));
-      Densities d=hd.densities(f);
+      GaussianMixtureDistribution d=hd.distribution(f);
       d.filterWeight(0.05);
-      d.filterRange(1.01*param.kmin(), 0.99*param.kmax());
+      d.filterRange(0, 1.01*param.kmin(), 0.99*param.kmax());
       d.filterWeight(0.1);
-      for(int i=0; i<d.count(); i++) {
-        p.setMean(d.density(i).mean());
-        p.setStddev(d.density(i).stddev());
+      for(int i=0; i<d.modeCount(); i++) {
+        p.setMean(d.mode(i).mean(0));
+        p.setStddev(d.mode(i).stddev(0));
         p.setWeight(d.weight(i));
         curve.append(p);
       }
@@ -344,6 +351,8 @@ namespace ArrayCore {
   void FKResults::aviosPick(const QString &groupName)
   {
     TRACE;
+    Q_UNUSED(groupName);
+    TODO_WARNING;
     /*Histogram2D * h;
     h=initWaveNumberHistogram();
     _peaks.fillWaveNumber(h);
@@ -380,13 +389,12 @@ namespace ArrayCore {
   }
 
   /*!
-   If \a baseName does not have any extension, it is added automatically.
-   \a duration of process in milliseconds
+   If \a fileName does not have any extension, it is added automatically.
   */
   bool FKResults::save(QString fileName, const QString& log)
   {
     TRACE;
-    _peaks.sort();
+    _peaks.sort(parameters()->sortResultValues());
     if(!fileName.endsWith(".max")) {
       fileName+=".max";
     }
@@ -394,7 +402,7 @@ namespace ArrayCore {
       App::log(tr("Error saving results to '%1'.\n").arg(fileName));
       return false;
     }
-    App::log(tr("results saved in '%1'.\n").arg(fileName));
+    App::log(tr("Results saved in '%1'.\n").arg(fileName));
     return true;
   }
 
@@ -419,7 +427,7 @@ namespace ArrayCore {
       s.setRealNumberPrecision(20);
       int n=c.count();
       for(int i=0; i<n; i++) {
-        s << c.constAt(i).toString(20) << "\n";
+        s << c.constAt(i).toString('g', 20) << "\n";
       }
       return true;
     } else {
@@ -510,7 +518,9 @@ namespace ArrayCore {
       const Curve<RealStatisticalPoint>& cc=c;
       // Extrapolate the curve until reaching the kmin and kmax limits
       bool extrapolated=true;
-      while(2.0*M_PI*cc.firstX()*cc.firstY()>kmin && extrapolated) {
+      int index=0;
+      cc.firstValid(index);
+      while(2.0*M_PI*cc.constAt(index).x()*cc.constAt(index).y()>kmin && extrapolated) {
         // too risky to extrapolate small curves and decreasing slopes, skip extrapolation.
         extrapolated=c.extrapolateFromStart(4, true, LogScale);
       }
