@@ -78,7 +78,9 @@ namespace ArrayCore {
     }
 
     selectStations();
-    setFrequencySampling();
+    if(!setFrequencySampling()) {
+      return false;
+    }
 
     FKParameters * param=parameters();
     if(param->kmin()==0.0 ||
