@@ -30,7 +30,6 @@
 #include "ArrayWorker.h"
 #include "FKTaskManager.h"
 #include "FKCache.h"
-#include "FKGridSearch.h"
 #include "FKParameters.h"
 #include "FKCrossSpectrum.h"
 #include "FKPeaks.h"
@@ -46,28 +45,36 @@ namespace ArrayCore {
              const FKParameters * param);
     ~FKWorker();
 
-    bool setGrid(FKCache * gridCache);
+    virtual bool setGrid(FKCache * cache);
     void setTaskManager(FKTaskManager * tm) {ArrayWorker::setTaskManager(tm);}
-    AbstractFKFunction * function() const {return _grid->function();}
+    inline AbstractFKFunction * function() const;
   protected:
-    inline const FKTaskManager * taskManager() const;
+    inline FKTaskManager * taskManager() const;
 
-    virtual void process(const QVector<int>& blocks);
-    virtual void mergeResults();
+    void process(const VectorList<int>& blocks);
+    void mergeResults();
 
     AbstractFKFunction * function();
     void localizeMax();
-    bool addPeak(const WaveNumberConverter& conv);
+    bool addPeaks(const WaveNumberConverter& conv);
+    void decompose(const WaveNumberConverter& conv);
+    bool addPeak(const FunctionSearchMaximum& m, const WaveNumberConverter& conv,
+                 const FKParameters * param, AbstractFKFunction * function);
     bool setSlownessRange();
     FKCrossSpectrum * crossSpectrum() {return static_cast<FKCrossSpectrum *>(_crossSpectrum);}
-  private:
-    FKGridSearch * _grid;
+
+    FunctionSearch * _search;
     FKPeaks _peaks;
   };
 
-  inline const FKTaskManager * FKWorker::taskManager() const
+  inline FKTaskManager * FKWorker::taskManager() const
   {
-    return static_cast<const FKTaskManager *>(ArrayWorker::taskManager());
+    return static_cast<FKTaskManager *>(ArrayWorker::taskManager());
+  }
+
+  inline AbstractFKFunction * FKWorker::function() const
+  {
+    return static_cast<AbstractFKFunction *>(_search->function());
   }
 
 } // namespace ArrayCore
