@@ -26,7 +26,6 @@
 #include "HRFKDirectRadial.h"
 #include "FKCrossSpectrum.h"
 #include "FKPower.h"
-#include "FKSteeringTwoComponentRadial.h"
 
 namespace ArrayCore {
 
@@ -39,18 +38,16 @@ namespace ArrayCore {
     Projection on the radial direction is included in the steering matrix.
   */
 
-  HRFKDirectRadial::HRFKDirectRadial(FKCache * gridCache)
-    : AbstractFKFunction(gridCache)
+  void HRFKDirectRadial::initialize(const FKParameters& param)
   {
-    delete _steering;
-    _steering=new FKSteeringTwoComponentRadial;
-    _steering->setArray(gridCache->array());
-    static_cast<FKSteeringTwoComponentRadial *>(_steering)->resize();
-  }
-
-  void HRFKDirectRadial::resetCrossSpectrum()
-  {
-    _crossSpectrum->resetMatrix();
+    setPowerEngine(new FKPower(cache()->array()->count(), 2));
+    if(_crossSpectrum) {
+      powerEngine()->setCrossSpectrum(_crossSpectrum->matrix());
+    }
+    steeringInitialization()->setSensorPositionErrors(param);
+    steeringInitialization()->setSensorOrientationErrors(param);
+    steeringInitialization()->setPhaseShifts(param.gridStep(), param.effectiveGridSize());
+    steeringInitialization()->setRadialRotations(param.gridStep());
   }
 
   void HRFKDirectRadial::addCrossSpectrum()
@@ -58,53 +55,32 @@ namespace ArrayCore {
     _crossSpectrum->addHorizontal();
   }
 
-  void HRFKDirectRadial::meanCrossSpectrum(int nBlocks)
+  void HRFKDirectRadial::addIncoherentNoise(double horizontal, double )
   {
-    _crossSpectrum->meanMatrix(nBlocks);
-  }
-
-  bool HRFKDirectRadial::invertCrossSpectrum()
-  {
-    return _crossSpectrum->invert();
-  }
-
-  bool HRFKDirectRadial::initGrid(int n)
-  {
-    if(_gridCache->isEmpty(FKCache::TwoComponentRadial)) {
-      App::log(tr("Caching steering vectors for 2-component radial ... (%1 values)\n").arg(n) );
-      _gridCache->resize(FKCache::TwoComponentRadial, n);
-      _gridCache->reportCacheVolume(FKCache::TwoComponentRadial, n,
-                                    FKSteeringTwoComponentRadial::sizeFactor);
-      return true;
-    } else {
-      return false;
+    ComplexMatrix& covmat=*_crossSpectrum->matrix();
+    int n=covmat.rowCount();
+    for(int i=0; i<n; i++) {
+      covmat.at(i, i)+=horizontal;
     }
   }
 
-  void HRFKDirectRadial::initGrid(const Point& k, int index)
+  double HRFKDirectRadial::value(const Vector<int>& index) const
   {
-    FKSteeringTwoComponentRadial::init(_gridCache, index , k);
-  }
-
-  double HRFKDirectRadial::value(const Point& kell, int index) const
-  {
-    if(isInsideLimits(kell)) {
-      FKPower p(&FKSteeringTwoComponentRadial::cache(_gridCache, index));
-      p.setCaponValue(_crossSpectrum->matrix());
-      return p.value();
+    if(isInsideLimits(index)) {
+      const Vector<Complex>& e=steering()->twoComponentHorizontal(index, powerEngine());
+      powerEngine()->setHighResolutionValue(e);
+      return powerEngine()->value();
     } else {
       return -1.0;
     }
   }
 
-  double HRFKDirectRadial::value(const Point& k) const
+  double HRFKDirectRadial::value(Vector<double>& k) const
   {
     if(isInsideLimits(k)) {
-      FKSteeringTwoComponentRadial * s=static_cast<FKSteeringTwoComponentRadial *>(_steering);
-      s->initValue(k);
-      FKPower p(s);
-      p.setCaponValue(_crossSpectrum->matrix());
-      return p.value();
+      const Vector<Complex>& e=steering()->twoComponentRadial(k, powerEngine());
+      powerEngine()->setHighResolutionValue(e);
+      return powerEngine()->value();
     } else {
       return -1.0;
     }
