@@ -42,29 +42,45 @@ namespace ArrayCore {
     return _crossSpectrum->invertRotatedMatrices();
   }
 
-  double HRFKRadial::value(const Point& k, int index) const
+  double HRFKRadial::value(const Vector<int>& index) const
   {
-    if(isInsideLimits(k)) {
-      FKPower p(&FKSteeringOneComponent::cache(_gridCache, index));
-      p.setCaponValue(_crossSpectrum->rotatedMatrix(k));
-      return p.value();
+    if(isInsideLimits(index)) {
+      const Vector<Complex>& e=steering()->oneComponent(index, powerEngine());
+      powerEngine()->setCrossSpectrum(_crossSpectrum->rotatedMatrix(index));
+      powerEngine()->setHighResolutionValue(e);
+      return powerEngine()->value();
     } else {
       return -1.0;
     }
   }
 
-  double HRFKRadial::value(const Point& k) const
+  double HRFKRadial::value(Vector<double>& k) const
   {
     if(isInsideLimits(k)) {
-      FKSteeringOneComponent * s=static_cast<FKSteeringOneComponent *>(_steering);
-      s->initValue(k);
-      FKPower p(s);
-      p.setCaponValue(_crossSpectrum->rotatedMatrix(k));
-      return p.value();
+      const Vector<Complex>& e=steering()->oneComponent(k, powerEngine());
+      powerEngine()->setCrossSpectrum(_crossSpectrum->rotatedMatrix(k));
+      powerEngine()->setHighResolutionValue(e);
+      return powerEngine()->value();
     } else {
       return -1.0;
     }
   }
 
+
+  /*!
+    Calculates a noise factor from the second derivative of beam power
+    and the second derivative of the beam pattern.
+  */
+  double HRFKRadial::wavenumberNormalizedConcavity(const Vector<double>& k) const
+  {
+    powerEngine()->setCrossSpectrum(_crossSpectrum->rotatedMatrix(k));
+    powerEngine()->setHighResolutionValue(steering()->oneComponent(k, powerEngine()));
+    double p=powerEngine()->value();
+    steering()->oneComponentSensorRadialProjections(k, powerEngine());
+    powerEngine()->highResolutionKRadialFirstDerivative(powerEngine()->steeringVector());
+    return powerEngine()->highResolutionKRadialSecondDerivative()/p;
+  }
+
+
 } // namespace ArrayCore
 
