@@ -24,10 +24,8 @@
 ***************************************************************************/
 
 #include "HRFKRayleighFixedEll.h"
-#include "FKGridSearch.h"
 #include "FKCrossSpectrum.h"
 #include "FKPower.h"
-#include "FKSteeringTwoComponentRayleighFixedEll.h"
 
 namespace ArrayCore {
 
@@ -44,7 +42,7 @@ namespace ArrayCore {
       return true;
     } else {
       if(_fixedEllipticities.isInsideRange(frequency)) {
-        setEllipticity(_fixedEllipticities.y(frequency));
+        _currentFixedEllipticity=_fixedEllipticities.interpole(frequency, LogScale, LinearScale).y();
         return true;
       } else {
         App::log(tr("  Frequency %1 Hz out of fixed ellipticity range\n").arg(frequency));
@@ -53,89 +51,42 @@ namespace ArrayCore {
     return false;
   }
 
-  void HRFKRayleighFixedEll::setGrid(FKGridSearch * g, double step, double size)
+  double HRFKRayleighFixedEll::value(const Vector<int>& index) const
   {
-    // Classical kx, ky
-    g->setGrid(-size, size, step, -size, size, step);
-  }
-
-  bool HRFKRayleighFixedEll::initGrid(int n)
-  {
-    if(_gridCache->isEmpty(FKCache::TwoComponentRayleighFixedEll)) {
-      App::log(tr("Caching steering vectors for 2-component Rayleigh (fixed ell) ... (%1 values)\n").arg(n) );
-      _gridCache->resize(FKCache::TwoComponentRayleighFixedEll, n);
-      _gridCache->reportCacheVolume(FKCache::TwoComponentRayleighFixedEll, n,
-                                    FKSteeringTwoComponentRayleighFixedEll::sizeFactor);
-      return true;
-    } else {
-      return false;
-    }
-  }
-
-  void HRFKRayleighFixedEll::initGrid(const Point& k, int index)
-  {
-    FKSteeringTwoComponentRayleighFixedEll::init(_gridCache, index , k);
-  }
-
-  void HRFKRayleighFixedEll::setEllipticity(double ell)
-  {
-    _ellipticity=ell;
-    // Build a matrix with factors to dot multiply cross-spectral matrix
-    // I did not check in details but this way is maybe faster than directly
-    // assigning values to _ellipticityCrossSpectrum due to at() function
-    // that require an index multiplication, while dotMultiply() uses simple indexes.
-    int n=_crossSpectrum->array().count();
-    int n2=2*n;
-    ComplexMatrix ellMat(n2);
-    Complex cell(0.0, -ell);
-    Complex ccell(0.0, ell);
-    Complex cell2(ell*ell, 0.0);
-    Complex unit(1.0, 0.0);
-    for(int i=0; i<n; i++) {
-      for(int j=0; j<n; j++) {
-        ellMat.at(i, j)=cell2;
-      }
-    }
-    for(int i=n; i<n2; i++) {
-      for(int j=0; j<n; j++) {
-        ellMat.at(i, j)=cell;
-        ellMat.at(j, i)=ccell;
-      }
-      for(int j=n; j<n2; j++) {
-        ellMat.at(i, j)=unit;
-      }
-    }
-    _crossSpectrum->setEllipticity(ellMat);
-  }
-
-  double HRFKRayleighFixedEll::value(const Point& k, int index) const
-  {
-    // General grid is not compatible with the local grids
-    // For testing, skip grid cache.
-    return value(k);
-    if(isInsideLimits(k)) {
-      FKPower p(&FKSteeringTwoComponentRayleighFixedEll::cache(_gridCache, index));
-      p.setCaponValue(_crossSpectrum->rotatedMatrix(k));
-      return p.value()*p.value()*_ellipticity*_ellipticity;
+    if(isInsideLimits(index)) {
+      steering()->oneComponent(index, powerEngine());
+      const Vector<Complex>& e=steering()->twoComponentRayleighRadial(_currentFixedEllipticity,
+                                                                      powerEngine());
+      // Because the elipticity is fixed the type of power (h, z, s or x) does not
+      // matter.
+      powerEngine()->setCrossSpectrum(_crossSpectrum->rotatedMatrix(index));
+      powerEngine()->setHighResolutionValue(e);
+      return powerEngine()->value();
     } else {
       return -1.0;
     }
   }
 
-  double HRFKRayleighFixedEll::value(const Point& k) const
+  double HRFKRayleighFixedEll::value(Vector<double>& k) const
   {
     if(isInsideLimits(k)) {
-      FKSteeringTwoComponentRayleighFixedEll * s=static_cast<FKSteeringTwoComponentRayleighFixedEll *>(_steering);
-      s->initValue(k);
-      FKPower p(s);
-      p.setCaponValue(_crossSpectrum->rotatedMatrix(k));
-      return p.value()*p.value()*_ellipticity*_ellipticity;
+      steering()->oneComponent(k, powerEngine());
+      const Vector<Complex>& e=steering()->twoComponentRayleighRadial(_currentFixedEllipticity,
+                                                                      powerEngine());
+      // Because the elipticity is fixed the type of power (h, z, s or x) does not
+      // matter.
+      powerEngine()->setCrossSpectrum(_crossSpectrum->rotatedMatrix(k));
+      powerEngine()->setHighResolutionValue(e);
+      return powerEngine()->value();
     } else {
       return -1.0;
     }
   }
 
-
+  /*!
+    Load fixed ellipticities from \a fileName.
+    They are in radians.
+  */
   bool HRFKRayleighFixedEll::loadFixedEllipticityCurve(const QString& fileName)
   {
     TRACE;
@@ -151,7 +102,8 @@ namespace ArrayCore {
         lineNumber++;
         if(!buf.isEmpty() && buf[0]!='#') {
           lp.setString(buf);
-          Point2D p(lp.toDouble(0, ok), lp.toDouble(1, ok));
+          // Ellipticity is stored as e not xi.
+          Point2D p(lp.toDouble(0, ok), tan(Angle::degreesToRadians(lp.toDouble(1, ok))));
           if(!ok) {
             App::log(tr("Error parsing line %1 in file '%2'\n").arg(lineNumber).arg(fileName));
             return false;
@@ -159,6 +111,10 @@ namespace ArrayCore {
           _fixedEllipticities.append(p);
         }
       }
+      App::log(tr("%1 fixed ellipticities from %2 to %3 Hz\n")
+               .arg(_fixedEllipticities.count())
+               .arg(_fixedEllipticities.constAt(0).x())
+               .arg(_fixedEllipticities.constAt(_fixedEllipticities.count()-1).x()));
       return true;
     } else {
       App::log(tr("Cannot open file '%1'\n").arg(fileName));
