@@ -34,19 +34,18 @@ namespace ArrayCore {
   class ARRAYCORE_EXPORT HRFKRayleighRadial : public HRFKRayleigh
   {
   public:
-    HRFKRayleighRadial(FKCache * gridCache)
-      : HRFKRayleigh(gridCache) {}
+    HRFKRayleighRadial(FKCache * cache)
+      : HRFKRayleigh(cache) {}
 
-    virtual double value(const Point& kell, int index) const;
-    virtual double value(const Point& kell) const;
+    double value(const Vector<int>& index) const;
+    double value(Vector<double>& k) const;
 
-    virtual double ellipticity(const Point& kell, bool& ok);
-    virtual double noise(const Point&) const {return 0.0;}
-    virtual double power(double optimumPower) const {return optimumPower;}
+    void setFunctionValue(Attributes& a) const;
+    void setFunctionDerivatives(Attributes& a) const;
 
-    virtual bool refine(const Point2D & k, double ell0,
-                        FKPeaks * results,
-                        const WaveNumberConverter& conv);
+    double wavenumberNormalizedConcavity(const Vector<double>& kell) const;
+  private:
+    inline void maximumEllipticity() const;
   };
 
 } // namespace ArrayCore
