@@ -26,20 +26,19 @@
 #ifndef HRFKTRANSVERSE_H
 #define HRFKTRANSVERSE_H
 
-#include "ConvFKTransverse.h"
+#include "HRFKRadial.h"
 
 namespace ArrayCore {
 
-  class ARRAYCORE_EXPORT HRFKTransverse : public ConvFKTransverse
+  class ARRAYCORE_EXPORT HRFKTransverse : public HRFKRadial
   {
   public:
-    HRFKTransverse(FKCache * gridCache)
-      : ConvFKTransverse(gridCache) {}
+    HRFKTransverse(FKCache * cache)
+      : HRFKRadial(cache) {}
 
-    virtual bool invertCrossSpectrum();
+    void addCrossSpectrum();
 
-    virtual double value(const Point& k) const;
-    virtual double value(const Point& k, int index) const;
+    double ellipticity(const Vector<double>&) {return std::numeric_limits<double>::infinity();}
   };
 
 } // namespace ArrayCore
