@@ -24,13 +24,12 @@
 ***************************************************************************/
 
 #include "OmniFKRayleigh.h"
-#include "FKGridSearch.h"
 #include "FKCrossSpectrum.h"
 #include "FKPower.h"
-#include "FKSteeringTwoComponentRayleighRadial.h"
 
 namespace ArrayCore {
 
+#if 0
   /*!
     \class OmniFKRayleigh OmniFKRayleigh.h
     \brief Brief description of class still missing
@@ -60,7 +59,7 @@ namespace ArrayCore {
 
   void OmniFKRayleigh::setGrid(FKGridSearch * g, double step, double size)
   {
-    g->setGrid(0.0, size, step, -0.5*M_PI, 0.5*M_PI, M_PI/20);
+    //g->setGrid(0.0, size, step, -0.5*M_PI, 0.5*M_PI, M_PI/20);
     //setAngleGrid();
   }
 
@@ -114,7 +113,7 @@ namespace ArrayCore {
       double ell2=ell*ell;
       for(int i=startIndex; i<endIndex; i++) {
         FKPower p(&FKSteeringTwoComponentRayleighRadial::cache(_gridCache, i));
-        p.setCaponValue(_crossSpectrum->matrix());
+        p.setHighResolutionValue(_crossSpectrum->matrix());
         sum+=p.value()*p.value()*ell2;
       }
       return sum;
@@ -142,7 +141,7 @@ namespace ArrayCore {
         k.setX(kell.x()*::cos(a));
         k.setY(kell.x()*::sin(a));
         s->initValue(k, ell);
-        p.setCaponValue(_crossSpectrum->matrix());
+        p.setHighResolutionValue(_crossSpectrum->matrix());
         sum+=p.value()*p.value()*ell2;
       }
       return sum;
@@ -150,6 +149,6 @@ namespace ArrayCore {
       return -1.0;
     }
   }
-
+#endif
 } // namespace ArrayCore
 
