@@ -31,11 +31,12 @@
 
 namespace ArrayCore {
 
+#if 0
   class ARRAYCORE_EXPORT OmniFKRayleigh : public OmniFKVertical
   {
   public:
-    OmniFKRayleigh(FKCache * gridCache)
-      : OmniFKVertical(gridCache) {}
+    OmniFKRayleigh(FKCache * cache)
+      : OmniFKVertical(cache) {}
 
     virtual void resetCrossSpectrum();
     virtual void addCrossSpectrum();
@@ -54,6 +55,7 @@ namespace ArrayCore {
   protected:
     virtual AbstractFunction * createAngleFunction() const;
   };
+#endif
 
 } // namespace ArrayCore
 
