@@ -25,11 +25,11 @@
 
 #include "OmniFKVertical.h"
 #include "FKCrossSpectrum.h"
-#include "FKGridSearch.h"
 #include "FKPower.h"
 
 namespace ArrayCore {
 
+#if 0
   /*!
     \class OmniFKVertical OmniFKVertical.h
     \brief Brief description of class still missing
@@ -39,7 +39,7 @@ namespace ArrayCore {
 
   void OmniFKVertical::setGrid(FKGridSearch * g, double step, double size)
   {
-    g->setGrid(0.0, size, step);
+    //g->setGrid(0.0, size, step);
     //setAngleGrid();
   }
 
@@ -54,7 +54,7 @@ namespace ArrayCore {
 
   AbstractFunction * OmniFKVertical::createAngleFunction() const
   {
-    return new Angle(_gridCache);
+    return new Angle(cache());
   }
 
   /*!
@@ -99,7 +99,7 @@ namespace ArrayCore {
       double sum=0.0;
       for(int i=startIndex; i<endIndex; i++) {
         FKPower p(&FKSteeringOneComponent::cache(_gridCache, i));
-        p.setCaponValue(_crossSpectrum->matrix());
+        p.setHighResolutionValue(_crossSpectrum->matrix());
         sum+=p.value();
       }
       return sum;
@@ -131,7 +131,7 @@ namespace ArrayCore {
         k.setX(kell.x()*::cos(a));
         k.setY(kell.x()*::sin(a));
         s->initValue(k);
-        p.setCaponValue(_crossSpectrum->matrix());
+        p.setHighResolutionValue(_crossSpectrum->matrix());
         sum+=p.value();
       }
       return sum;
@@ -177,9 +177,9 @@ namespace ArrayCore {
     FKSteeringOneComponent * s=static_cast<FKSteeringOneComponent *>(_steering);
     FKPower p(s);
     s->initValue(k);
-    p.setCaponValue(_crossSpectrum->matrix());
+    p.setHighResolutionValue(_crossSpectrum->matrix());
     return p.value();
   }
-
+#endif
 } // namespace ArrayCore
 
