@@ -33,10 +33,15 @@ namespace ArrayCore {
   class ARRAYCORE_EXPORT PoggiFKRadial : public HRFKRadial
   {
   public:
-    PoggiFKRadial(FKCache * gridCache)
-      : HRFKRadial(gridCache) {}
+    PoggiFKRadial(FKCache * cache)
+      : HRFKRadial(cache) {}
 
-    virtual double ellipticity(const Point& k, bool& ok);
+    void resetCrossSpectrum();
+    void addCrossSpectrum();
+    void meanCrossSpectrum(int nBlocks);
+    bool invertCrossSpectrum();
+
+    double ellipticity(const Vector<double>& k);
   };
 
 } // namespace ArrayCore
