@@ -37,11 +37,34 @@ namespace ArrayCore {
     Ellipticity is computed according Poggi et al. (2010) in GJI.
   */
 
-  double PoggiFKVertical::ellipticity(const Point& k, bool& ok)
+  void PoggiFKVertical::resetCrossSpectrum()
   {
-    HRFKRadial radial(_gridCache);
-    ok=true;
-    return ::sqrt(radial.value(k)/value(k));
+    _crossSpectrum->resetMatrix();
+    _crossSpectrum->resetRotatedMatrices();
+  }
+
+  void PoggiFKVertical::addCrossSpectrum()
+  {
+    _crossSpectrum->addVertical();
+    _crossSpectrum->addRotatedRadial(steering()->sensorOrientationErrors());
+  }
+
+  void PoggiFKVertical::meanCrossSpectrum(int nBlocks)
+  {
+    _crossSpectrum->meanMatrix(nBlocks);
+    _crossSpectrum->meanRotatedMatrices(nBlocks);
+  }
+
+  bool PoggiFKVertical::invertCrossSpectrum()
+  {
+    return _crossSpectrum->invert() && _crossSpectrum->invertRotatedMatrices();
+  }
+
+  double PoggiFKVertical::ellipticity(const Vector<double>& k)
+  {
+    HRFKRadial radial(cache());
+    PrivateVector<double> nck(k);
+    return ::sqrt(radial.value(nck)/value(nck));
   }
 
 } // namespace ArrayCore
