@@ -40,13 +40,19 @@ namespace ArrayCore {
     TRANSLATIONS("SPACParameters")
   public:
     SPACParameters();
-    SPACParameters(const SPACParameters& o);
 
-    virtual AbstractParameters * clone() const {return new SPACParameters(*this);}
+    AbstractParameters * clone() const {return new SPACParameters(*this);}
 
+    enum Method {MSPAC, ESAC};
+    ENUM_AS_STRING_DECL(Method)
+
+    Method method() const {return _method;}
+    void setMethod(Method m) {_method=m;}
+
+    void clearRings();
     void addRing(double minRadius, double maxRadius);
     int ringCount() const {return _rings.count();}
-    const QVector<AutocorrRing>& rings() const {return _rings;}
+    const VectorList<AutocorrRing>& rings() const {return _rings;}
 
     void setMaximumImaginary(double m) {_maximumImaginary=m;}
     double maximumImaginary() const {return _maximumImaginary;}
@@ -59,10 +65,11 @@ namespace ArrayCore {
     QString toString(PARAMETERS_TOSTRING_ARGS_DECL) const;
     void collectKeywords(PARAMETERS_COLLECTKEYWORDS_ARGS);
   protected:
-    virtual int keywordCount(PARAMETERS_KEYWORDCOUNT_ARGS) const;
-    virtual bool setValue(PARAMETERS_SETVALUE_ARGS);
+    int keywordCount(PARAMETERS_KEYWORDCOUNT_ARGS) const;
+    bool setValue(PARAMETERS_SETVALUE_ARGS);
   private:
-    QVector<AutocorrRing> _rings;
+    Method _method;
+    VectorList<AutocorrRing> _rings;
     double _maximumImaginary;
     bool _dotMaxOutput;
   };
