@@ -44,8 +44,9 @@ namespace ArrayCore {
     : AbstractArrayResults()
   {
     TRACE;
-    _target=nullptr;
-    _stats=nullptr;
+    _mspacTarget=nullptr;
+    _mspacStats=nullptr;
+    _esacStats=nullptr;
     for(int i=0; i<3; i++) {
       _rejected[i]=nullptr;
     }
@@ -63,11 +64,12 @@ namespace ArrayCore {
   SPACResults::~SPACResults()
   {
     TRACE;
-    delete [] _stats;
+    delete [] _mspacStats;
+    delete [] _esacStats;
     for(int i=0; i<3; i++) {
       delete [] _rejected[i];
     }
-    delete _target;
+    delete _mspacTarget;
     delete _peaks;
   }
 
@@ -97,13 +99,16 @@ namespace ArrayCore {
     ASSERT(_nComponents>0);
     _nRings=param.ringCount();
     _nFrequencies=param.frequencySampling().count();
-    delete _target;
-    _target=new AutocorrCurves;
-    delete [] _stats;
-    _stats=new SPACStatistics[_nFrequencies];
-    for(int i=0; i<_nFrequencies; i++) {
-      _stats[i].setParameters(_nRings, _nComponents);
-    }
+
+    delete _mspacTarget;
+    _mspacTarget=nullptr;
+    delete [] _mspacStats;
+    _mspacStats=nullptr;
+    delete [] _esacStats;
+    _esacStats=nullptr;
+    delete _peaks;
+    _peaks=nullptr;
+
     for(int i=0; i<_nComponents; i++) {
       _rejected[i]=new int[_nFrequencies];
       for(int iFreq=0; iFreq<_nFrequencies; iFreq++) {
@@ -111,39 +116,61 @@ namespace ArrayCore {
       }
     }
 
-    // Set the correct number of sample directly
-    ModalCurve refCurve(param.frequencySampling().count());
-    for(int iFreq=0; iFreq<_nFrequencies; iFreq++) {
-      refCurve.setX(iFreq, param.frequencySampling().value(iFreq));
-    }
-    for(int iRing=0; iRing<_nRings; iRing++) {
-      _target->addRing(param.rings().at(iRing) );
-      if(_nComponents==3) {
-        _target->add(refCurve);
-        _target->lastCurve().modes().last()=Mode(Mode::Vertical, iRing, 0);
-        _target->add(refCurve);
-        _target->lastCurve().modes().last()=Mode(Mode::Radial, iRing, 0);
-        _target->add(refCurve);
-        _target->lastCurve().modes().last()=Mode(Mode::Transverse, iRing, 0);
-      } else {
-        _target->add(refCurve);
-        _target->lastCurve().modes().last()=Mode(Mode::Vertical, iRing, 0);
-      }
-    }
+    switch(param.method()) {
+    case SPACParameters::MSPAC: {
+        _mspacTarget=new AutocorrCurves;
+        _mspacStats=new MSPACStatistics[_nFrequencies];
+        for(int i=0; i<_nFrequencies; i++) {
+          _mspacStats[i].setParameters(_nRings, _nComponents);
+        }
 
+        // Set the correct number of sample directly
+        ModalCurve refCurve(param.frequencySampling().count());
+        for(int iFreq=0; iFreq<_nFrequencies; iFreq++) {
+          refCurve.setX(iFreq, param.frequencySampling().value(iFreq));
+        }
+        for(int iRing=0; iRing<_nRings; iRing++) {
+          _mspacTarget->addRing(param.rings().at(iRing) );
+          if(_nComponents==3) {
+            _mspacTarget->add(refCurve);
+            _mspacTarget->lastCurve().modes().last()=Mode(Mode::Vertical, iRing, 0);
+            _mspacTarget->add(refCurve);
+            _mspacTarget->lastCurve().modes().last()=Mode(Mode::Radial, iRing, 0);
+            _mspacTarget->add(refCurve);
+            _mspacTarget->lastCurve().modes().last()=Mode(Mode::Transverse, iRing, 0);
+          } else {
+            _mspacTarget->add(refCurve);
+            _mspacTarget->lastCurve().modes().last()=Mode(Mode::Vertical, iRing, 0);
+          }
+        }
+      }
+      break;
+    case SPACParameters::ESAC:
+      _esacStats=new ESACStatistics[_nFrequencies];
+      for(int i=0; i<_nFrequencies; i++) {
+        _esacStats[i].setParameters(_nComponents);
+      }
+      break;
+    }
     if(param.dotMaxOutput()) {
       _peaks=new SPACPeaks;
       _peaks->setTimeReference(_array->array()->first()->minTime());
     }
   }
 
-  void SPACResults::addValue(Mode::Polarization polarization, const ValueInfo& info,
-                             int ring, double value)
+  void SPACResults::addValue(Mode::Polarization polarization,
+                             const ValueInfo& info,
+                             double value)
   {
     _addLock.lock();
-    _stats[info.frequencyIndex].addValue(polarization, ring, value);
+    if(_mspacStats) {
+      _mspacStats[info.frequencyIndex].addValue(polarization, info.ringIndex, value);
+    }
+    if(_esacStats) {
+      _esacStats[info.frequencyIndex].addValue(polarization, info.distance, value);
+    }
     if(_peaks) {
-      _peaks->add(polarization, info, ring, value);
+      _peaks->add(polarization, info, value);
     }
     _addLock.unlock();
   }
@@ -159,17 +186,19 @@ namespace ArrayCore {
 
   void SPACResults::commitStatistics()
   {
-    QList<ModalCurve>& curves=_target->curves();
-    for(int iFreq=0; iFreq<_nFrequencies; iFreq++) {
-      for(int iRing=0; iRing<_nRings; iRing++) {
-        int ringOffset=iRing*_nComponents;
-        for(int iComp=0; iComp<_nComponents; iComp++){
-          const Statistics& s=_stats[iFreq].result(iRing, iComp);
-          ModalCurve& curve=curves[ringOffset+iComp];
-          FactoryPoint& p=curve.constXAt(iFreq);
-          p.setMean(s.mean());
-          p.setStddev(s.stddev());
-          p.setWeight(s.count());
+    if(_mspacTarget && _mspacStats) {
+      QList<ModalCurve>& curves=_mspacTarget->curves();
+      for(int iFreq=0; iFreq<_nFrequencies; iFreq++) {
+        for(int iRing=0; iRing<_nRings; iRing++) {
+          int ringOffset=iRing*_nComponents;
+          for(int iComp=0; iComp<_nComponents; iComp++){
+            const Statistics& s=_mspacStats[iFreq].result(iRing, iComp);
+            ModalCurve& curve=curves[ringOffset+iComp];
+            FactoryPoint& p=curve.constXAt(iFreq);
+            p.setMean(s.mean());
+            p.setStddev(s.stddev());
+            p.setWeight(s.count());
+          }
         }
       }
     }
@@ -177,61 +206,118 @@ namespace ArrayCore {
 
   void SPACResults::reportRejects()
   {
-    if(_target->curves().isEmpty() ||
-       static_cast<const SPACParameters *>(_parameters)->maximumImaginary()>=1.0) {
+    if(static_cast<const SPACParameters *>(_parameters)->maximumImaginary()>=1.0) {
       return;
     }
     int nVal, nRej;
-    ModalCurve& curve=_target->curves().first();
     for(int iFreq=0; iFreq<_nFrequencies; iFreq++) {
       if(_nComponents==3) {
-        nVal=_stats[iFreq].count(1);
+        if(_mspacStats) {
+          nVal=_mspacStats[iFreq].count(1);
+        } else if(_esacStats) {
+          nVal=_esacStats[iFreq].count(1);
+        } else {
+          nVal=0;
+        }
         nRej=_rejected[1][iFreq];
         App::log(tr("%1 values, %2 rejected (%3 %) at %4 Hz for radial component.\n")
                  .arg(nVal)
                  .arg(nRej)
                  .arg((100.0*nRej)/(nRej+nVal))
-                 .arg(curve.x(iFreq)));
-        nVal=_stats[iFreq].count(2);
+                 .arg(_parameters->frequencySampling().value(iFreq)));
+        if(_mspacStats) {
+          nVal=_mspacStats[iFreq].count(2);
+        } else if(_esacStats) {
+          nVal=_esacStats[iFreq].count(2);
+        } else {
+          nVal=0;
+        }
         nRej=_rejected[2][iFreq];
         App::log(tr("%1 values, %2 rejected (%3 %) at %4 Hz for transverse component.\n")
                  .arg(nVal)
                  .arg(nRej)
                  .arg((100.0*nRej)/(nRej+nVal))
-                 .arg(curve.x(iFreq)));
+                 .arg(_parameters->frequencySampling().value(iFreq)));
 
       }
-      nVal=_stats[iFreq].count(0);
+      if(_mspacStats) {
+        nVal=_mspacStats[iFreq].count(0);
+      } else if(_esacStats) {
+        nVal=_esacStats[iFreq].count(0);
+      } else {
+        nVal=0;
+      }
       nRej=_rejected[0][iFreq];
       App::log(tr("%1 values, %2 rejected (%3 %) at %4 Hz for vertical component.\n")
                .arg(nVal)
                .arg(nRej)
                .arg((100.0*nRej)/(nRej+nVal))
-               .arg(curve.x(iFreq)));
+               .arg(_parameters->frequencySampling().value(iFreq)));
     }
   }
 
-  void SPACResults::save(QString fileName, const QString& log)
+  bool SPACResults::save(QString fileName, const QString& log)
   {
     TRACE;
     QFileInfo fi(fileName);
-    if(_target) {
-      fileName=fi.baseName()+".target";
+    QDir d(fi.dir());
+    if(_mspacTarget) {
+      fileName=d.absoluteFilePath(fi.baseName()+".target");
       TargetList tl;
-      tl.autocorrTarget().setCurves( *_target);
+      tl.autocorrTarget().setCurves(*_mspacTarget);
       XMLHeader hdr(&tl);
       hdr.xml_saveFile(fileName);
-      App::log(tr("results saved in '%1'.\n").arg(fileName));
+      App::log(tr("Results saved in '%1'.\n").arg(fileName));
+    }
+    if(_esacStats) {
+      fileName=d.absoluteFilePath(fi.baseName()+".target");
+      TargetList tl;
+      tl.dispersionTarget().addCurve(esacDispersionCurve(0));
+      if(_nComponents==3) {
+        tl.dispersionTarget().addCurve(esacDispersionCurve(1));
+        tl.dispersionTarget().addCurve(esacDispersionCurve(2));
+      }
+      XMLHeader hdr(&tl);
+      hdr.xml_saveFile(fileName);
+      App::log(tr("Results saved in '%1'.\n").arg(fileName));
     }
     if(_peaks) {
-      fileName=fi.baseName()+".max";
+      fileName=d.absoluteFilePath(fi.baseName()+".max");
       _peaks->sort();
       if(!_peaks->save(fileName, *parameters(), *_array, log)) {
         App::log(tr("Error saving results to '%1'.\n").arg(fileName));
-        return;
+        return false;
       }
-      App::log(tr("results saved in '%1'.\n").arg(fileName));
+      App::log(tr("Results saved in '%1'.\n").arg(fileName));
     }
+    return true;
+  }
+
+  ModalCurve SPACResults::esacDispersionCurve(int iComp)
+  {
+    ModalCurve curve;
+    if(_esacStats) {
+      // Take array aperture as a starting wavenumber
+      double k=2.0*M_PI/(2.0*_array->array()->radius());
+      for(int iFreq=0; iFreq<_nFrequencies; iFreq++) {
+        double f=_parameters->frequencySampling().value(iFreq);
+        double omega=2.0*M_PI*f;
+        k=_esacStats[iFreq].leastSquareWaveNumber(k, iComp);
+        curve.append(FactoryPoint(f, k/omega));
+      }
+    }
+    switch(iComp) {
+    case 1:
+      curve.addMode(Mode(Mode::Phase, Mode::Radial, 0));
+      break;
+    case 2:
+      curve.addMode(Mode(Mode::Phase, Mode::Transverse, 0));
+      break;
+    default:
+      curve.addMode(Mode(Mode::Phase, Mode::Vertical, 0));
+      break;
+    }
+    return curve;
   }
 
 #if 0
