@@ -37,19 +37,22 @@ namespace ArrayCore {
   class ARRAYCORE_EXPORT SPACTool : public AbstractArrayTool
   {
   public:
-    SPACTool();
+    SPACTool(QObject * parent);
     ~SPACTool();
 
-    virtual bool setSubPool(SubSignalPool *subPool);
+    bool setSubPool(SubSignalPool *subPool);
 
-    virtual bool setParameters(const AbstractParameters& param);
     inline const SPACParameters * parameters() const;
-    inline  SPACParameters * parameters();
+    inline SPACParameters * parameters();
+
+    bool setLoop();
 
     SPACResults * results() const {return static_cast<SPACResults *>(AbstractArrayTool::results());}
+
+    bool saveResults(const QString& fileName);
   protected:
-    virtual QString toolName() {return tr("SPAC Array analysis");}
-    virtual ParallelTaskManager * createLoop() {return new SPACTaskManager(array());}
+    QString toolName() {return tr("SPAC Array analysis");}
+    ParallelTaskManager * createLoop() {return new SPACTaskManager(array());}
   private:
     void autoRings();
   };
