@@ -1,4 +1,4 @@
-/***************************************************************************
+﻿/***************************************************************************
 **
 **  This file is part of ArrayCore.
 **
@@ -25,7 +25,6 @@
 
 #include "SPACWorker.h"
 #include "SPACResults.h"
-#include "SPACCrossSpectrum.h"
 
 namespace ArrayCore {
 
@@ -55,7 +54,7 @@ namespace ArrayCore {
     TRACE;
   }
 
-  void SPACWorker::process(const QVector<int>& blocks)
+  void SPACWorker::process(const VectorList<int>& blocks)
   {
     if(crossSpectrum()->calculate(blocks)) {
       SPACResults::ValueInfo info;
@@ -69,30 +68,64 @@ namespace ArrayCore {
       nRejected[2]=0;
 
       Complex val;
-      double maxImaginary=crossSpectrum()->parameters()->maximumImaginary();
+      const SPACParameters& param=*crossSpectrum()->parameters();
+      double maxImaginary=param.maximumImaginary();
       SPACResults * res=static_cast<SPACResults *>(taskManager()->results());
-      for(int iRing=crossSpectrum()->ringCount()-1; iRing>=0; iRing--) {
-        const RingPairs& ring=crossSpectrum()->ring(iRing);
-        if(crossSpectrum()->mode()==ArrayStations::ThreeComponents) {
-          val=ring.radialAutocorr(crossSpectrum());
-          if(fabs(val.im())<maxImaginary) {
-            res->addValue(Mode::Radial, info, iRing, val.re());
-          } else {
-            nRejected[1]++;
+      switch(param.method()) {
+      case SPACParameters::MSPAC:
+        for(int iRing=crossSpectrum()->ringCount()-1; iRing>=0; iRing--) {
+          const RingPairs& ring=crossSpectrum()->ring(iRing);
+          info.ringIndex=iRing;
+          info.distance=0.5*(ring.minRadius()+ring.maxRadius());
+          if(crossSpectrum()->mode()==ArrayStations::ThreeComponents) {
+            val=ring.radialAutocorr(crossSpectrum());
+            if(fabs(val.im())<maxImaginary) {
+              res->addValue(Mode::Radial, info, val.re());
+            } else {
+              nRejected[1]++;
+            }
+            val=ring.transverseAutocorr(crossSpectrum());
+            if(fabs(val.im())<maxImaginary) {
+              res->addValue(Mode::Transverse, info, val.re());
+            } else {
+              nRejected[2]++;
+            }
           }
-          val=ring.transverseAutocorr(crossSpectrum());
+          val=ring.verticalAutocorr(crossSpectrum());
           if(fabs(val.im())<maxImaginary) {
-            res->addValue(Mode::Transverse, info, iRing, val.re());
+            res->addValue(Mode::Vertical, info, val.re());
           } else {
-            nRejected[2]++;
+            nRejected[0]++;
           }
         }
-        val=ring.verticalAutocorr(crossSpectrum());
-        if(fabs(val.im())<maxImaginary) {
-          res->addValue(Mode::Vertical, info, iRing, val.re());
-        } else {
-          nRejected[0]++;
+        break;
+      case SPACParameters::ESAC:
+        info.ringIndex=-1;
+        for(int iPair=crossSpectrum()->stationPairCount()-1; iPair>=0; iPair--) {
+          const StationPair& pair=crossSpectrum()->stationPair(iPair);
+          info.distance=pair.distance();
+          if(crossSpectrum()->mode()==ArrayStations::ThreeComponents) {
+            val=crossSpectrum()->radialAutocorr(pair.station1(), pair.station2(), pair.azimuth());
+            if(fabs(val.im())<maxImaginary) {
+              res->addValue(Mode::Radial, info, val.re());
+            } else {
+              nRejected[1]++;
+            }
+            val=crossSpectrum()->transverseAutocorr(pair.station1(), pair.station2(), pair.azimuth());
+            if(fabs(val.im())<maxImaginary) {
+              res->addValue(Mode::Transverse, info, val.re());
+            } else {
+              nRejected[2]++;
+            }
+          }
+          val=crossSpectrum()->verticalAutocorr(pair.station1(), pair.station2());
+          if(fabs(val.im())<maxImaginary) {
+            res->addValue(Mode::Vertical, info, val.re());
+          } else {
+            nRejected[0]++;
+          }
         }
+        break;
       }
       res->addRejected(info.frequencyIndex, nRejected);
     }
