@@ -44,7 +44,7 @@ namespace ArrayCore {
   protected:
     inline const SPACTaskManager * taskManager() const;
 
-    virtual void process(const QVector<int>& blocks);
+    virtual void process(const VectorList<int>& blocks);
   private:
     SPACCrossSpectrum * crossSpectrum() {return static_cast<SPACCrossSpectrum *>(_crossSpectrum);}
   };
