@@ -35,22 +35,13 @@ namespace ArrayCore {
     _s2=0;
   }
 
-  StationPair::StationPair(const StationPair& o)
-  {
-    _s1=o._s1;
-    _s2=o._s2;
-    _distance=o._distance;
-    _azimuth=o._azimuth;
-    _name=o._name;
-  }
-
   void StationPair::setStations(const ArraySelection& array, int index1, int index2)
   {
     TRACE;
     _s1=index1;
     _s2=index2;
-    const StationSignals * ss1=array.at(_s1);
-    const StationSignals * ss2=array.at(_s2);
+    const StationSignals * ss1=array.stationSignals(_s1);
+    const StationSignals * ss2=array.stationSignals(_s2);
     _name=ss1->name()+"-"+ss2->name();
     const Point& p1=ss1->coordinates();
     const Point& p2=ss2->coordinates();
