@@ -41,14 +41,21 @@ namespace ArrayCore {
     const DateTime& time() const {return _time;}
 
     double frequency() const {return _frequency;}
-    double slowness(const Point2D &k) const {return k.length()*_waveNumberFactor;}
-    double azimuth(const Point2D &k) const;
+    double slowness(const Vector<double>& k) const {return k.length(0, 1)*_waveNumberFactor;}
+    inline double azimuth(const Vector<double>& k) const;
   private:
     DateTime _time;
     double _frequency;
     double _waveNumberFactor;
   };
 
+
+  inline double WaveNumberConverter::azimuth(const Vector<double>& k) const
+  {
+    double a=90.0-Angle::radiansToDegrees(k.azimuth(0, 1));
+    return Angle::canonicalDegrees(a);
+  }
+
 } // namespace ArrayCore
 
 #endif // WAVENUMBERCONVERTER_H
