@@ -37,7 +37,7 @@ ArrayResponse::ArrayResponse(QWidget *parent, Qt::WindowFlags f)
 {
   TRACE;
   setAttribute(Qt::WA_DeleteOnClose);
-  _palette.generateColorScale(20, ColorPalette::McNamesClip, true);
+  _palette.generate(0, 19, ColorPalette::defaultSequential, ColorPalette::Continuous);
   _palette.setObjectName("Palette");
 
   Settings::getSize(this, "ArrayResponse");
@@ -45,9 +45,11 @@ ArrayResponse::ArrayResponse(QWidget *parent, Qt::WindowFlags f)
   connect(waveNum.kminSpin, SIGNAL(valueChanged(double)),
            this, SLOT(setKmin( double)));
   connect(waveNum.kmaxSpin, SIGNAL(valueChanged(double)),
-           this, SLOT(setKmax( double)));
+           this, SLOT(setKmax(double)));
   connect(waveNum.azimuthSpin, SIGNAL(valueChanged(double)),
-           this, SLOT(setAzimuth( double) ));
+          this, SLOT(setGeographicDegrees(double)));
+  connect(waveNum.scanButton, SIGNAL(clicked()),
+          this, SLOT(scanAzimuth()));
 
   _kmin=0.0;
   _kmaxSolver=nullptr;
@@ -74,7 +76,7 @@ ArrayResponse::~ArrayResponse()
   }
 }
 
-void ArrayResponse::setArray(const QVector<Point2D>& p)
+void ArrayResponse::setArray(const VectorList<Point2D>& p)
 {
   TRACE;
   if(_kmaxSolver) {
@@ -87,7 +89,10 @@ void ArrayResponse::setArray(const QVector<Point2D>& p)
 
   _gridLayer->lockDelayPainting(); // required before touching the stations
   _stations=p;
-  _gridLayer->setFunction(new TheoreticalFK(_stations));
+  _gridLayer->setFunction(new FunctionPlot(2, new TheoreticalFK(_stations)));
+  //OmnidirectionalArrayResponse * f=new OmnidirectionalArrayResponse(_stations);
+  //f->setWavenumber(0.5);
+  //_gridLayer->setFunction(new FunctionPlot(2, f));
   shiftStations();
   _gridLayer->unlock();
 
@@ -112,7 +117,7 @@ void ArrayResponse::setArray(const QVector<Point2D>& p)
     _comments->setText(tr("Error computing kmin (linear array?)"));
     _comments->update();
   }
-  setAzimuth(waveNum.azimuthSpin->value());
+  setGeographicDegrees(waveNum.azimuthSpin->value());
   waveNum.kminSpin->setValue(_kmin);
   setKmin(_kmin);
 
@@ -174,7 +179,7 @@ void ArrayResponse::setComputedKmax()
                                   "kmax-kmin: %4 rad/m\n"
                                   "kaverage: %5 rad/m");
       KminSolver kminSolver(_stations);
-      double groundLevel=kminSolver.groundLevel(_kmin,kmax);
+      double groundLevel=kminSolver.groundLevel(_kmin, kmax);
       _comments->setText(cmt.arg(_kmin).arg(kmax).arg(groundLevel).arg(kmax-_kmin).arg(0.5*(kmax+_kmin)));
       _comments->update();
 
@@ -239,9 +244,9 @@ void ArrayResponse::createObjects(bool showDispersion)
   // Wavenumber map
   w=sheet()->addGraph();
   w->xAxis()->setTitle(tr("Wave number X (rad/m)"));
-  w->xAxis()->setTitleInversedScale(tr("Wave length X/(2*pi) (m/rad)"));
+  w->xAxis()->setTitleInverseScale(tr("Wave length X/(2*pi) (m/rad)"));
   w->yAxis()->setTitle(tr("Wave number Y (rad/m)"));
-  w->yAxis()->setTitleInversedScale(tr("Wave length Y/(2*pi) (m/rad)"));
+  w->yAxis()->setTitleInverseScale(tr("Wave length Y/(2*pi) (m/rad)"));
   w->xAxis()->setSizeType(Axis::AxisSize);
   w->xAxis()->setSizeInfo(7);
   w->setPrintXAnchor(0.5);
@@ -265,7 +270,7 @@ void ArrayResponse::createObjects(bool showDispersion)
   _directionLayer->setEditable(false);
   PlotLine2D * line;
   line=new PlotLine2D;
-  line->setPen(Pen( Qt::black, 0.6, Qt::SolidLine));
+  line->setPen(Pen( Qt::black, 0.6, Pen::SolidLine));
   line->setSymbol(Symbol());
   _directionLayer->setReferenceLine(line);
   static_cast<PlotLine2D *>(_directionLayer->addLine())->curve().resize(2);
@@ -275,9 +280,9 @@ void ArrayResponse::createObjects(bool showDispersion)
   // Wavenumber map cross section
   w=sheet()->addGraph();
   w->xAxis()->setTitle(tr("Wave number (rad/m)"));
-  w->xAxis()->setTitleInversedScale(tr("Wave length/(2*pi) (m/rad)"));
+  w->xAxis()->setTitleInverseScale(tr("Wave length/(2*pi) (m/rad)"));
   w->yAxis()->setTitle(tr("Array Transfer function"));
-  w->yAxis()->setTitleInversedScale(tr("1/Array Transfer function"));
+  w->yAxis()->setTitleInverseScale(tr("1/Array Transfer function"));
   w->setGeometry(0.5, 9.0, 9.0, 6.0);
   _crossGrayLayer=new XUniqueYColorLines(w);
   _crossGrayLayer->setObjectName( "Cross background" );
@@ -285,7 +290,7 @@ void ArrayResponse::createObjects(bool showDispersion)
   _crossBlackLayer=new LineLayer(w);
   _crossBlackLayer->setObjectName( "Cross current" );
   line=new PlotLine2D;
-  line->setPen(Pen( Qt::black, 0.6, Qt::SolidLine) );
+  line->setPen(Pen( Qt::black, 0.6, Pen::SolidLine) );
   line->setSymbol(Symbol());
   _crossBlackLayer->setReferenceLine(line);
   _crossBlackLayer->addLine();
@@ -293,7 +298,7 @@ void ArrayResponse::createObjects(bool showDispersion)
   _midHeightLayer=new LineLayer(w);
   _midHeightLayer->setEditable(false);
   line=new PlotLine2D;
-  line->setPen(Pen( Qt::black, 0.4, Qt::SolidLine) );
+  line->setPen(Pen( Qt::black, 0.4, Pen::SolidLine) );
   line->setSymbol(Symbol());
   _midHeightLayer->setReferenceLine(line);
   Curve<Point2D>& limitLine=static_cast<PlotLine2D *>(_midHeightLayer->addLine())->curve();
@@ -306,7 +311,7 @@ void ArrayResponse::createObjects(bool showDispersion)
     w=sheet()->addGraph();
     w->xAxis()->setFrequency();
     w->yAxis()->setTitle(tr("Slowness (s/m)"));
-    w->yAxis()->setTitleInversedScale(tr("Velocity (m/s)"));
+    w->yAxis()->setTitleInverseScale(tr("Velocity (m/s)"));
     w->setGeometry(10.0, 9.0, 9.0, 6.0);
     _dispLimitLayer=new DispersionLimitLayer(w);
     _dispLimitLayer->setObjectName("FK dispersion limits");
@@ -321,7 +326,7 @@ void ArrayResponse::createObjects(bool showDispersion)
     _lambdaLegend->setPrintYAnchor(15.5);
     _lambdaLegend->setTitle(tr("Lambda/ArraySize"));
     Legend l;
-    l.generateColorScale(3, ColorPalette::Sardine);
+    l.generate(0, 2);
     for(int i=0; i<3; i++) {
       l.setText(i, QString::number(i+1));
     }
@@ -334,7 +339,7 @@ void ArrayResponse::createObjects(bool showDispersion)
     w=sheet()->addGraph();
     w->xAxis()->setFrequency();
     w->yAxis()->setTitle(tr("Slowness (s/m)"));
-    w->yAxis()->setTitleInversedScale(tr("Velocity (m/s)"));
+    w->yAxis()->setTitleInverseScale(tr("Velocity (m/s)"));
     w->setGeometry(10.0, 15.5, 9.0, 6.0);
     _dispLambdaLayer=new DispersionLimitLayer(w);
     _dispLambdaLayer->setObjectName("Lambda/ArraySize ratio");
@@ -368,16 +373,16 @@ void ArrayResponse::shiftStations()
   double x0=0, y0=0;
   int n=_stations.count();
   // Get min and max distances
-  for(int i=0;i < n;i++ ) {
-    x0 += _stations[ i ].x();
-    y0 += _stations[ i ].y();
+  for(int i=0; i<n; i++) {
+    x0+=_stations[i].x();
+    y0+=_stations[i].y();
   }
   // Calculate relative coordinates to avoid big number computations
-  x0 /= n;
-  y0 /= n;
-  for(int i=0;i < n;i++ ) {
-    _stations[ i ].setX(_stations[ i ].x() - x0);
-    _stations[ i ].setY(_stations[ i ].y() - y0);
+  x0/=n;
+  y0/=n;
+  for(int i=0; i<n; i++) {
+    _stations[i].setX(_stations[i].x()-x0);
+    _stations[i].setY(_stations[i].y()-y0);
   }
 }
 
@@ -437,17 +442,22 @@ double ArrayResponse::gridKmax() const
 double ArrayResponse::gridKmin() const
 {
   TRACE;
-  GraphContent * gc=_gridLayer->graphContent();
+  GraphContents * gc=_gridLayer->graphContents();
   return fabs(gc->options().xs2r(_gridLayer->sampling())-gc->options().xs2r(0));
 }
 
 void ArrayResponse::setKmin(double kmin)
 {
   TRACE;
-  _circleLayer->set(0, 0, 0, 0.5*kmin, 0.5*kmin, 0.0, Qt::black);
+  /*OmnidirectionalArrayResponse * kmap=static_cast<OmnidirectionalArrayResponse *>(_gridLayer->function()->function());
+  kmap->setWavenumber(kmin);
+  _gridLayer->deepUpdate();
+  scanAzimuth();*/
+
+  _circleLayer->set(0, 0.0, 0.0, 0.5*kmin, 0.5*kmin, 0.0, Pen());
   _circleLayer->deepUpdate();
   emit kminChanged(kmin);
-  setAzimuth(waveNum.azimuthSpin->value());
+  setGeographicDegrees(waveNum.azimuthSpin->value());
 }
 
 double ArrayResponse::kmin() const
@@ -459,10 +469,10 @@ void ArrayResponse::setKmax(double kmax)
 {
   TRACE;
   _kmaxTouched=true;
-  _circleLayer->set(1, 0, 0, kmax, kmax, 0.0, Qt::black);
+  _circleLayer->set(1, 0.0, 0.0, kmax, kmax, 0.0, Pen());
   _circleLayer->deepUpdate();
   emit kmaxChanged(kmax);
-  setAzimuth(waveNum.azimuthSpin->value());
+  setGeographicDegrees(waveNum.azimuthSpin->value());
 }
 
 double ArrayResponse::kmax() const
@@ -470,7 +480,7 @@ double ArrayResponse::kmax() const
   return waveNum.kmaxSpin->value();
 }
 
-void ArrayResponse::setAzimuth(double azimuth)
+void ArrayResponse::setGeographicDegrees(double azimuth)
 {
   TRACE;
   LayerLocker lla(_directionLayer);
@@ -481,7 +491,7 @@ void ArrayResponse::setAzimuth(double azimuth)
   double kmax=waveNum.kmaxSpin->value();
 
   KminSolver kSolver(_stations);
-  kSolver.setAzimuth(azimuth);
+  kSolver.setGeographicDegrees(azimuth);
   azLine1.setX(0, kminHalf*kSolver.angle().cos());
   azLine1.setY(0, kminHalf*kSolver.angle().sin());
   azLine1.setX(1, kmax*kSolver.angle().cos());
@@ -499,15 +509,23 @@ void ArrayResponse::setAzimuth(double azimuth)
   crossCurve1.clear();
   crossCurve2.clear();
 
+  AbstractFunction * kmap=_gridLayer->function()->function();
+  PrivateVector<double> kvector(2);
+  Angle angle;
+  angle.setGeographicDegrees(azimuth);
   double dk=0.005*(kmax-kminHalf);
-  for(double k=-kmax; k < -kminHalf; k+=dk) {
-    crossCurve1.append(Point(k, kSolver.value(k)));
+  for(double k=-kmax; k<-kminHalf; k+=dk) {
+    kvector.setValues(k*angle.cos(), k*angle.sin());
+    crossCurve1.append(Point(k, kmap->value(kvector)));
   }
-  crossCurve1.append(Point(-kminHalf, kSolver.value( -kminHalf) ));
-  for(double k=kminHalf; k < kmax; k+=dk) {
-    crossCurve2.append(Point(k, kSolver.value(k)));
+  kvector.setValues(-kminHalf*angle.cos(), -kminHalf*angle.sin());
+  crossCurve1.append(Point(-kminHalf, kmap->value(kvector)));
+  for(double k=kminHalf; k<kmax; k+=dk) {
+    kvector.setValues(k*angle.cos(), k*angle.sin());
+    crossCurve2.append(Point(k, kmap->value(kvector)));
   }
-  crossCurve2.append(Point(kmax, kSolver.value(kmax) ));
+  kvector.setValues(-kminHalf*angle.cos(), kmax*angle.sin());
+  crossCurve2.append(Point(kmax, kmap->value(kvector)));
 
   _crossBlackLayer->resetLineProperties();
   _crossBlackLayer->deepUpdate();
@@ -523,9 +541,9 @@ void ArrayResponse::scanAzimuth()
 {
   TRACE;
   double kmax=gridKmax();
-  int n=(int)round(3.0*gridKmax()/gridKmin());
+  int n=qRound(3.0*gridKmax()/gridKmin());
   int n21=2*n+1;
-  KminSolver fkmap(_stations);
+  AbstractFunction * kmap=_gridLayer->function()->function();
   _crossGrayLayer->setPointCount(180, n21);
   // Set common x
   double * k=_crossGrayLayer->x();
@@ -537,15 +555,19 @@ void ArrayResponse::scanAzimuth()
   double * y=_crossGrayLayer->y();
   Color * colors=new Color[180];
   double dAng=M_PI/180; // every one degree
+  PrivateVector<double> kvector(2);
+  Angle angle;
   for(int iAng=0; iAng<180; iAng++) {
-    double ang=(double)iAng*dAng;
-    fkmap.setRadians(ang);
-    for(int i=0; i < n21; i++ ) {
-      *(y++)=fkmap.value(k[i] );
+    angle.setRadians(iAng*dAng);
+    for(int i=0; i<n21; i++) {
+      kvector.setValues(k[i]*angle.cos(), k[i]*angle.sin());
+      *(y++)=kmap->value(kvector);
     }
     colors[iAng]=Qt::gray;
   }
   _crossGrayLayer->setColors(colors);
+  _crossGrayLayer->graph()->xAxis()->setRange(-kmax, kmax);
+  _crossGrayLayer->graphContents()->deepUpdate();
 }
 
 } // namespace ArrayGui
