@@ -42,8 +42,8 @@ public:
   inline ActiveModel& add(const SetIndex& s, double parentVolume);
   inline ActiveModel& add(const ActiveModel& m);
   void clear();
-  void addNavigatorHits(const QVector<ActiveIndex>& indexes);
-  void setNavigatorHits(const QVector<ActiveIndex>& indexes);
+  void addNavigatorHits(const VectorList<ActiveIndex>& indexes);
+  void setNavigatorHits(const VectorList<ActiveIndex>& indexes);
 
   void reserve(int n) {IncreaseStorage::reserve(n);}
   int count() const {return IncreaseStorage::size();}
@@ -54,9 +54,12 @@ public:
   ActiveModel& at(const ActiveIndex& i) {return _infos[i.value()];}
   const ActiveModel& at(const ActiveIndex& i) const {return _infos[i.value()];}
 
+  inline const SetIndex& setIndex(const ActiveIndex& i) const;
   inline double misfit(const ActiveIndex& i, const TargetIndex& t) const;
   inline const int * model(const ActiveIndex& i) const;
 
+  int distance(const ActiveIndex& i1, const ActiveIndex& i2) const;
+
   void print(const ActiveIndex& i);
   void printNavigatorHits() const;
 private:
@@ -80,16 +83,22 @@ inline ActiveModel& ActiveModels::add(const ActiveModel& m)
   return _infos[size()-1]; // reallocate possible with add
 }
 
+inline const SetIndex& ActiveModels::setIndex(const ActiveIndex& i) const
+{
+  return _infos[i.value()].index();
+}
+
 inline double ActiveModels::misfit(const ActiveIndex& i, const TargetIndex& t) const
 {
-  return _allModels->misfit(_infos[i.value()].index(), t);
+  return _allModels->misfit(setIndex(i), t);
 }
 
 inline const int * ActiveModels::model(const ActiveIndex& i) const
 {
-  return _allModels->model(_infos[i.value()].index());
+  return _allModels->model(setIndex(i));
 }
 
+
 } // namespace DinverCore
 
 #endif // ACTIVEMODELS_H
