@@ -46,6 +46,7 @@ namespace DinverCore {
     void setNr(int nr);
     void update();
     void add(const ActiveIndex& index);
+    void addDistinct(const ActiveIndex& index);
     void setIndex(const BestIndex& b, const ActiveIndex& a) {_indexes[b.value()]=a;}
     void remove(const ActiveIndex& index);
     void clear();
@@ -53,13 +54,14 @@ namespace DinverCore {
     void reserve(int n) {IncreaseStorage::reserve(n);}
     int count() const {return size();}
     inline  bool isSaturated() const;
+    const SetIndex& setIndex(const BestIndex& i) const {return _models->setIndex(_indexes[i.value()]);}
     const ActiveIndex& activeIndex(const BestIndex& i) const {return _indexes[i.value()];}
     inline double misfit(const BestIndex& i, const TargetIndex& t) const;
     const int * model(const BestIndex& i) const {return _models->model(_indexes[i.value()]);}
 
     BestIndex * activeModelMap() const;
     BestIndex * allModelMap() const;
-    const ActiveIndex& randomIndex(double randomValue) const;
+    BestIndex randomIndex(double randomValue) const;
     double averageVolume() const;
   private:
     virtual void reallocate();
