@@ -190,7 +190,7 @@ namespace DinverCore {
 
     // Sort model to keep models with the best hit count in front
     // Potential speed up in VoronoiNavigator
-    QVector<ActiveModel *> sortedModels(activeCount);
+    VectorList<ActiveModel *> sortedModels(activeCount);
     for(int i=0; i<activeCount; i++) {
       sortedModels[i]=&_activeModels->at(i);
     }
@@ -232,7 +232,7 @@ namespace DinverCore {
       // Fully commit statistics only to models based on this GeneratorModels
       if(m->parentIndex()->serialNumber()==serialNumber()) {
         _activeModels->addNavigatorHits(m->navigatorHits());
-        ActiveModel& am=_activeModels->at(m->parentIndex()->index());
+        ActiveModel& am=_activeModels->at(m->parentIndex()->activeIndex());
         if(m->isValidParent()) {
           am.setVolume(m->parentVolume());
           if(m->isValidMisfit()) {
@@ -245,16 +245,20 @@ namespace DinverCore {
             am.addRejected();
             if(am.giveUp(giveUp)) {
               _giveUpCount++;
-              am.setAtomic();
-              _atomicCount++;
-              App::log(1, tr("Give up cell %1: too much rejections, considered as atomic\n").arg(am.index().value()));
+              if(!am.isAtomic()) {
+                am.setAtomic();
+                _atomicCount++;
+                App::log(1, tr("Give up cell %1: too much rejections, considered as atomic\n").arg(am.index().value()));
+              }
             }
           }
         } else {
           // This is an atomic cell, keep it but remove its parent from best cells and prevent its re-insertion
-          am.setAtomic();
-          _atomicCount++;
-          App::log(1, tr("Invalid parent %1 (no new model can be generated): considered as atomic\n").arg(am.index().value()));
+          if(!am.isAtomic()) {
+            am.setAtomic();
+            _atomicCount++;
+            App::log(1, tr("Invalid parent %1 (no new model can be generated): considered as atomic\n").arg(am.index().value()));
+          }
         }
       } else { // Count only rejected models, we do not have access to parent cell anymore
                // Atomic cells must not be confused with rejected ones 
@@ -270,15 +274,17 @@ namespace DinverCore {
   }
 
   /*!
-    Adds model \a m to active and best models.
+    Adds \a model to active and best models.
   */
-  void GeneratorModels::add(const SetIndex& index, double parentVolume)
+  void GeneratorModels::add(const NewModel * model)
   {
     TRACE;
     ActiveIndex i;
     i.setValue(_activeModels->count());
-    _activeModels->add(index, parentVolume);
+    _activeModels->add(model->index(), model->parentVolume());
     _bestModels->add(i);
+    // Experimental improvement of exploration
+    //_bestModels->addDistinct(i);
   }
 
 } // namespace DinverCore
