@@ -59,7 +59,7 @@ namespace DinverCore {
     void clear();
 
     void commitStatistics(NewModel * m, double giveUp);
-    void add(const SetIndex& index, double parentVolume);
+    void add(const NewModel * model);
 
     int rejectedCount() const {return _rejectedCount;}
     int giveUpCount() const {return _giveUpCount;}
