@@ -59,9 +59,8 @@ namespace DinverCore {
     _stableMisfitCount=INT_MAX;       // by default do not check misfit stability
     _significantMisfitReduction=0.01; // Defines what's a significant misfit reduction (for misfit stability assessment)
                                       // Default=1%
-    _lastBestMisfit=std::numeric_limits<double>::infinity();         // Misfit increases when many atomic cells are detected
+    _bestMisfitEver=std::numeric_limits<double>::infinity();         // Misfit increases when many atomic cells are detected
                                       // Best cell has already been found, it starts exploring elsewhere
-    _lastBestIndex=INT_MAX;           // Prevent stopping too early
     _giveUp=0.9;
     _walkCount=2;
 
@@ -100,7 +99,7 @@ namespace DinverCore {
   void ModelRepository::setMaximumModelCount(int n)
   {
     TRACE;
-    _maximumModelCount=n+_allModels->count();
+    _maximumModelCount=n+_allModels->size();
     if(_maximumQueueLenght>n) {
       App::log(tr("Queue length reduced to %1\n").arg(n) );
       _maximumQueueLenght=n;
@@ -352,7 +351,6 @@ namespace DinverCore {
     const BestModels * bestModels=_generatorModels->bestModels();
     if(bestModels->count()>0) {
       ParentIndex * parentIndex=new ParentIndex(_generatorModels, bestModels->randomIndex(randomValue));
-      //printf("Best active index %i\n", parentIndex->activeIndex());
       _generatorModelLock.unlock();
       return parentIndex;
     } else {
@@ -367,7 +365,7 @@ namespace DinverCore {
   void ModelRepository::modelToRealSpace(const ActiveIndex& index, RealSpace& parameterSpace)
   {
     _generatorModelLock.lockForRead();
-    _allModels->lock();
+    _allModels->lockForRead();
     const int * v=_generatorModels->activeModels()->model(index);
     int ndVar=parameterSpace.variableParameterCount();
     for(int ip=0; ip<ndVar; ip++) {
@@ -431,58 +429,66 @@ namespace DinverCore {
       newGenModels->addReference();
       //int removeDeadTime=_chrono.elapsed();
 
-      _allModels->lock();  // update() makes use of misfit()
-                           // This lock may be blocked by model generation in other threads
-                           // during reallocation only, which is likely to occur seldomly.
+      _allModels->lockForRead();  // update() makes use of misfit()
+                                  // This lock may be blocked by model generation in other threads
+                                  // during reallocation only, which is likely to occur seldomly.
 
       // Update best models if there are less than nr models in best models
       newGenModels->bestModels()->update();
+      _allModels->unlock();
 
       // Adds new models and set misfits to the main repository (avoid multiple locks in Generator)
+      // This part requires a lock for write because misfit values are changed.
+      // It may disturb the sort on PSViewer.
+      _allModels->lockForWrite();
       for(QList<NewModel *>::iterator it=modelList.begin(); it!=modelList.end(); ++it) {
         NewModel * m=*it;
         if(m->isValidMisfit()) {
           _allModels->setMisfit(m->index(), TargetIndex::first, m->misfit());
-          newGenModels->add(m->index(), m->parentVolume());
+          newGenModels->add(m);
         }
         delete m;
       }
+      _allModels->unlock();
       //int addNewTime=_chrono.elapsed();
 
       // Regenerates an up-to-date ScaledModels
+      _allModels->lockForRead();
       newGenModels->setScaledModels(_forward->parameterSpace());
-      int nGenerated=_allModels->count();
+      int nGenerated=_allModels->size();
       int nBestModels=newGenModels->bestModels()->count();
+      _allModels->unlock();
       //int scaleTime=_chrono.elapsed();
 
-      _allModels->unlock();
-
       if(nGenerated==0 || nBestModels==0) {
+        APP_LOG(1, tr("Inversion stopped: no model is generated or best models is list empty\n"))
         stop();
       } else {
         double bestMisfit=newGenModels->bestModels()->misfit(BestIndex::first, TargetIndex::first);
         int effectiveModelCount=nGenerated-newGenModels->rejectedCount();
         if(effectiveModelCount>=_maximumModelCount ||
            newGenModels->bestModels()->count()>=_maximumBestModelCount) {
+          APP_LOG(1, tr("Inversion stopped: maximum number of models or best models is reached\n"))
           stop();
         }
         // Monitor best misfit values
-        if(bestMisfit<=_lastBestMisfit) { // If misfit increases because of atomic cells
+        if(bestMisfit<=_bestMisfitEver) { // If misfit increases because of atomic cells
                                           // we want to keep track of the very best misfit
                                           // and not just the current one
-          // _lastBestMisfit can be infinite while bestMisift is always finite
-          if(_lastBestMisfit-bestMisfit>_significantMisfitReduction*bestMisfit) {
-            _lastBestIndex=newGenModels->activeModels()->at(newGenModels->bestModels()->activeIndex(BestIndex::first)).index().value();
+          // _bestMisfitEver can be infinite while bestMisift is always finite
+          if(_bestMisfitEver-bestMisfit>_significantMisfitReduction*bestMisfit) {
+            _bestIndexEver=newGenModels->activeModels()->at(newGenModels->bestModels()->activeIndex(BestIndex::first)).index();
           }
-          _lastBestMisfit=bestMisfit;
+          _bestMisfitEver=bestMisfit;
         }
         if(effectiveModelCount>_stableMisfitCount) {
-          if(effectiveModelCount>_lastBestIndex+_stableMisfitCount) {
+          if(effectiveModelCount>_bestIndexEver.value()+_stableMisfitCount) {
+            APP_LOG(1, tr("Inversion stopped: stable misfit\n"))
             stop();
           }
         }
         App::log(tr("[stat] %1 models, %2 models/s, %3 active models, %4 rejected, "
-                    "%5 atomic, %6 best models, best misfit %7 last best %8 at index %9, "
+                    "%5 atomic, %6 best models, best misfit %7 best ever %8 at index %9, "
                     "best average volume %10\n")
             .arg(nGenerated)
             .arg(1000.0*modelList.count()/generationTime)
@@ -490,7 +496,7 @@ namespace DinverCore {
             .arg(newGenModels->rejectedCount())
             .arg(newGenModels->atomicCount())
             .arg(newGenModels->bestModels()->count())
-            .arg(bestMisfit).arg(_lastBestMisfit).arg(_lastBestIndex)
+            .arg(bestMisfit).arg(_bestMisfitEver).arg(_bestIndexEver.value())
             .arg(newGenModels->bestModels()->averageVolume()));
       }
       //newGenModels->bestModels()->print();
@@ -509,7 +515,7 @@ namespace DinverCore {
           .arg(removeDeadTime-statisticsTime)
           .arg(addNewTime-removeDeadTime)
           .arg(scaleTime-addNewTime)
-          << endl;*/
+          << Qt::endl;*/
     }
 
     _processingQueue=false;
@@ -536,7 +542,7 @@ namespace DinverCore {
   {
     TRACE;
     SetIndex i;
-    i.setValue(_allModels->count());
+    i.setValue(_allModels->size());
 
     if(ReportReader::isReportFormat(fileName)) {
       ReportReader report(fileName);
@@ -556,9 +562,12 @@ namespace DinverCore {
       }
     }
     SetIndex end;
-    end.setValue(_allModels->count());
+    end.setValue(_allModels->size());
+    NewModel m;
+    m.setParentVolume(std::numeric_limits<double>::infinity());
     for(; i<end; i++) {
-      _generatorModels->add(i, std::numeric_limits<double>::infinity());
+      m.setIndex(i);
+      _generatorModels->add(&m);
     }
     _generatorModels->setScaledModels(_forward->parameterSpace());
     return true;
@@ -570,7 +579,7 @@ namespace DinverCore {
   void ModelRepository::lock() const
   {
     if(_allModels) {
-      _allModels->lock();
+      _allModels->lockForRead();
     }
     _generatorModelLock.lockForRead();
   }
@@ -588,7 +597,7 @@ namespace DinverCore {
 
   int ModelRepository::validModelCount() const
   {
-    return _allModels->count()-_generatorModels->rejectedCount();
+    return _allModels->size()-_generatorModels->rejectedCount();
   }
 
   int ModelRepository::activeModelCount() const
@@ -614,7 +623,7 @@ namespace DinverCore {
   int ModelRepository::visitedModelCount() const
   {
     if(!_allModels) printf("Blank all models\n");
-    return _allModels ? _allModels->count() : 0;
+    return _allModels ? _allModels->size() : 0;
   }
 
   int ModelRepository::variableParameterCount() const
@@ -639,6 +648,14 @@ namespace DinverCore {
     return _allModels->bestModel();
   }
 
+  /*!
+    The model repository must be locked before using this function
+  */
+  const BestModels * ModelRepository::bestModels() const
+  {
+    return _generatorModels->bestModels();
+  }
+
   const Parameter * ModelRepository::variableParameter(int paramIndex) const
   {
     const RealSpace& parameterSpace=_forward->parameterSpace();
