@@ -36,6 +36,7 @@ namespace DinverCore {
 
   class ModelSet;
   class GeneratorModels;
+  class BestModels;
   class NewModel;
   class ParentIndex;
   class AbstractForward;
@@ -99,6 +100,8 @@ namespace DinverCore {
     double misfit(const SetIndex& index) const;
     const int * model(const SetIndex& index) const;
     SetIndex bestModelIndex() const;
+    const BestModels * bestModels() const;
+    const SetIndex& bestIndexEver() const {return _bestIndexEver;}
 
     AbstractForward * forward() {return _forward;}
     const AbstractForward * forward() const {return _forward;}
@@ -121,8 +124,8 @@ namespace DinverCore {
     int _maximumBestModelCount;
     int _stableMisfitCount;
     double _significantMisfitReduction;
-    double _lastBestMisfit;
-    int _lastBestIndex;
+    double _bestMisfitEver;
+    SetIndex _bestIndexEver;
     int _maximumQueueLenght;
     double _maximumSavedMisfit;
     double _giveUp;
