@@ -65,7 +65,7 @@ bool ParamSpaceScript::xml_setProperty(XML_SETPROPERTY_ARGS)
   Q_UNUSED(attributes)
   Q_UNUSED(context)
   switch(memberID) {
-  case 0: _text=content.toString(); return true;
+  case 0: _text=content.toStringBuffer(); return true;
   default: return false;
   }
 }
@@ -123,7 +123,7 @@ bool ParamExpressionContext::isValidFunction(const QString& name) const
   return false;
 }
 
-QVariant ParamExpressionContext::functionValue(const QString& name, const QVector<ExpressionAction *>& args) const
+QVariant ParamExpressionContext::functionValue(const QString& name, const VectorList<ExpressionAction *>& args) const
 {
   TRACE;
   switch(name[0].unicode()) {
