@@ -27,6 +27,7 @@
 #define PARENTINDEX_H
 
 #include "GeneratorModels.h"
+#include "BestModels.h"
 #include "DinverCoreDLLExport.h"
 
 namespace DinverCore {
@@ -34,31 +35,35 @@ namespace DinverCore {
   class DINVERCORE_EXPORT ParentIndex
   {
   public:
-    inline ParentIndex(GeneratorModels * models, const ActiveIndex& index);
+    inline ParentIndex(GeneratorModels * models, const BestIndex& index);
     inline ParentIndex(const ParentIndex& o);
     inline ~ParentIndex();
 
     int serialNumber() const {return _models->serialNumber();}
     const ActiveModels * activeModels() const {return _models->activeModels();}
     const ScaledModels * scaledModels() const {return _models->scaledModels();}
-    const ActiveIndex& index() const {return _index;}
+    const BestIndex& bestIndex() const {return _bestIndex;}
+    const ActiveIndex& activeIndex() const {return _activeIndex;}
   private:
     GeneratorModels * _models;
-    ActiveIndex _index;
+    BestIndex _bestIndex;
+    ActiveIndex _activeIndex;
   };
 
-  inline ParentIndex::ParentIndex(GeneratorModels * models, const ActiveIndex& index)
+  inline ParentIndex::ParentIndex(GeneratorModels * models, const BestIndex& index)
   {
     _models=models;
     _models->addReference();
-    _index=index;
+    _bestIndex=index;
+    _activeIndex=_models->bestModels()->activeIndex(_bestIndex);
   }
 
   inline ParentIndex::ParentIndex(const ParentIndex& o)
   {
     _models=o._models;
     _models->addReference();
-    _index=o._index;
+    _bestIndex=o._bestIndex;
+    _activeIndex=o._activeIndex;
   }
 
   inline ParentIndex::~ParentIndex()
