@@ -279,6 +279,9 @@ namespace DinverCore {
 
   void PdfCurve::setBorderShapeCosine(int i1, int i2)
   {
+    Q_UNUSED(i1);
+    Q_UNUSED(i2);
+    TODO_WARNING;
     /*for(int i=i1; i<=i2; i++) {
       double x=operator[](i).x();
       operator[](i).setValue(1.0+cos((operator[](i).x()-x1)*period));
