@@ -190,7 +190,7 @@ namespace DinverCore {
   void QuadraticCondition::xml_writeProperties( XML_WRITEPROPERTIES_ARGS ) const
   {
     TRACE;
-    writeProperty(s, "type", toString(_type));
+    writeProperty(s, "type", convertType(_type));
     writeProperty(s, "constant", _constant);
     XMLSaveAttributes att;
     att.add(indexKey);
@@ -221,23 +221,24 @@ namespace DinverCore {
   bool QuadraticCondition::xml_setProperty(XML_SETPROPERTY_ARGS)
   {
     TRACE;
+    bool ok=true;
     switch(memberID) {
     case 0: {
         XMLRestoreAttributeIterator it=attributes.find(indexKey);
         if(it!=attributes.end()) {
-          int i=it.value().toInt();
+          int i=it.value().toInt(ok);
           if(i<count()) {
-            _factors[i]=content.toDouble();
+            _factors[i]=content.toDouble(ok);
           }
         }
       }
-      return true;
+      return ok;
     case 1:
-      _constant=content.toDouble();
-      return true;
+      _constant=content.toDouble(ok);
+      return ok;
     case 2: {
         bool ok=true;
-        _type=fromString(content.toString(), ok);
+        _type=convertType(content.toStringView(), ok);
         return ok;
       }
     default:
