@@ -50,8 +50,8 @@ namespace DinverCore {
     //inline void setCurrentPoint(const int * coordinates);
 
     const ActiveIndex& currentCell() const {return _currentCell;}
-    QVector<ActiveIndex> cellAt(const int * p) const;
-    QVector<ActiveIndex> cellAt(const double * p) const;
+    VectorList<ActiveIndex> cellAt(const int * p) const;
+    VectorList<ActiveIndex> cellAt(const double * p) const;
     int cellCount() const {return _cells->modelCount();}
 
     void initDistances(int axis);
