@@ -129,7 +129,7 @@ namespace DinverDCCore {
     TRACE;
     switch(memberID) {
     case 0:
-      _layerName=content.toString();
+      _layerName=content.toStringBuffer();
       return true;
     default:
       return AbstractCondition::xml_setProperty(memberID-1, tag, attributes, content, context);
