@@ -288,12 +288,12 @@ void DCReportBlock::readModalStorages(int nStorages)
   for(int i=0;i<nStorages;i++) stream() >> _modalStorageOffsets[i];
 }
 
-Seismic1DModel * DCReportBlock::surfaceWaveModel(const QVector<double>& zProf,
-                                               QVector<double>& vpProf,
-                                               const QVector<double>& vsProf,
-                                               const QVector<double>& rhoProf,
-                                               const QVector<double> * nuMinProf,
-                                               const QVector<double> * nuMaxProf)
+Seismic1DModel * DCReportBlock::surfaceWaveModel(const VectorList<double>& zProf,
+                                               VectorList<double>& vpProf,
+                                               const VectorList<double>& vsProf,
+                                               const VectorList<double>& rhoProf,
+                                               const VectorList<double> * nuMinProf,
+                                               const VectorList<double> * nuMaxProf)
 {
   TRACE;
   ASSERT(!nuMinProf || (nuMinProf && nuMaxProf));
@@ -326,9 +326,9 @@ Seismic1DModel * DCReportBlock::surfaceWaveModel(const QVector<double>& zProf,
   return surfModel;
 }
 
-Seismic1DModel * DCReportBlock::vspModel(const QVector<double>& zProf,
-                                       const QVector<double>& vpProf,
-                                       const QVector<double>& vsProf)
+Seismic1DModel * DCReportBlock::vspModel(const VectorList<double>& zProf,
+                                       const VectorList<double>& vpProf,
+                                       const VectorList<double>& vsProf)
 {
   TRACE;
   int nLayers=zProf.size();
@@ -353,8 +353,8 @@ Seismic1DModel * DCReportBlock::vspModel(const QVector<double>& zProf,
   return surfModel;
 }
 
-Seismic1DModel * DCReportBlock::vpModel(const QVector<double>& zProf,
-                                      const QVector<double>& vpProf)
+Seismic1DModel * DCReportBlock::vpModel(const VectorList<double>& zProf,
+                                      const VectorList<double>& vpProf)
 {
   TRACE;
   int nLayers=zProf.size();
@@ -379,8 +379,8 @@ Seismic1DModel * DCReportBlock::vpModel(const QVector<double>& zProf,
   return surfModel;
 }
 
-Seismic1DModel * DCReportBlock::vsModel(const QVector<double>& zProf,
-                                      const QVector<double>& vsProf)
+Seismic1DModel * DCReportBlock::vsModel(const VectorList<double>& zProf,
+                                      const VectorList<double>& vsProf)
 {
   TRACE;
   int nLayers=zProf.size();
@@ -416,7 +416,7 @@ Seismic1DModel * DCReportBlock::readSeismicModel()
   if(vs()) vsProf.readReport(*_s);
   if(rho()) rhoProf.readReport(*_s);
   if(pitch()) pitchProf.readReport(*_s); // Used only to ensure complete sampling
-  QVector<double> depths;
+  VectorList<double> depths;
   if(vpProf.count()==0) {
     if(vsProf.count()==0) {
       return nullptr;
@@ -455,7 +455,7 @@ Seismic1DModel * DCReportBlock::readSeismicModel()
       vpProf.resample(depths);
       vsProf.resample(depths);
       rhoProf.resample(depths);
-      QVector<double> vp=vpProf.values();
+      VectorList<double> vp=vpProf.values();
       return surfaceWaveModel(depths ,vp, vsProf.values(), rhoProf.values());
     }
   }
@@ -469,7 +469,7 @@ Resistivity1DModel * DCReportBlock::readElectricModel()
   TRACE;
   Profile resProf;
   if(res()) resProf.readReport(*_s);
-  QVector<double> depths;
+  VectorList<double> depths;
   if(resProf.count()>0) {
     return new Resistivity1DModel(resProf);
   } else {
