@@ -44,13 +44,13 @@ namespace DinverDCCore {
   {
     TRACE;
     // From 20190218, stddev of dispersion curve is computed on a log scale
-    setMisfitType(L2_LogNormalized);
+    setMisfitType(Misfit::L2_LogNormalized);
   }
 
   bool DispersionTarget::xml_polish(XML_POLISH_ARGS)
   {
     Q_UNUSED(context)
-    if(misfitType()==L2_Normalized) { // Kept for compatibity
+    if(misfitType()==Misfit::L2_Normalized) { // Kept for compatibity
       // Convert stddev in slowness to log
       for(QList<ModalCurve>::iterator it=curves().begin(); it!=curves().end(); ++it) {
         ModalCurve& c=*it;
@@ -59,9 +59,9 @@ namespace DinverDCCore {
           p.setStddev(0.5*((p.mean()+p.stddev())/p.mean()+p.mean()/(p.mean()-p.stddev())));
         }
       }
-     }
-    // Force L2_LogNormalized and ignore value read from file
-    setMisfitType(L2_LogNormalized);
+      // Force L2_LogNormalized and ignore value read from file
+      setMisfitType(Misfit::L2_LogNormalized);
+    }
     return true;
   }
 
