@@ -639,17 +639,21 @@ double ParamLayer::fixedBottomDepth() const
   return std::numeric_limits<double>::infinity(); // No fixed bottom depth, half space reached
 }
 
+ENUM_AS_STRING_BEGIN(ParamLayer, Shape)
+ENUM_AS_STRING_DATA_5(Linear, LinearDecrease, LinearIncrease, PowerLaw, Uniform);
+ENUM_AS_STRING_SYNONYM("LinearIncr", LinearIncrease);
+ENUM_AS_STRING_SYNONYM("LinearDecr", LinearDecrease);
+ENUM_AS_STRING_END
+
+ENUM_AS_STRING_BEGIN(ParamLayer, GradientParameter)
+ENUM_AS_STRING_DATA_2(BottomValue, GradientValue);
+ENUM_AS_STRING_END
+
 void ParamLayer::xml_writeProperties(XML_WRITEPROPERTIES_ARGS) const
 {
   TRACE;
   Q_UNUSED(context)
-  switch (_shape) {
-  case Linear: writeProperty(s, "shape", "Linear"); break;
-  case LinearIncrease: writeProperty(s, "shape", "LinearIncrease"); break;
-  case LinearDecrease: writeProperty(s, "shape", "LinearDecrease"); break;
-  case PowerLaw: writeProperty(s, "shape", "PowerLaw"); break;
-  case Uniform: writeProperty(s, "shape", "Uniform"); break;
-  }
+  writeProperty(s, "shape", convertShape(_shape));
   writeProperty(s, "lastParamCondition", _lastParamCondition);
   writeProperty(s, "nSubayers", _gradientProfile->subLayerCount());
   writeProperty(s, "topMin", _topMin);
@@ -695,50 +699,41 @@ bool ParamLayer::xml_setProperty(XML_SETPROPERTY_ARGS)
   Q_UNUSED(tag)
   Q_UNUSED(attributes)
   Q_UNUSED(context)
+  bool ok=true;
   switch(memberID) {
   case 0:
-    if(content=="Uniform") setShape(Uniform);
-    else if(content=="Linear") setShape(Linear);
-    else if(content=="LinearIncrease") setShape(LinearIncrease);
-    else if(content=="LinearDecrease") setShape(LinearDecrease);
-    else if(content=="PowerLaw") setShape(PowerLaw);
-    else if(content=="LinearIncr") setShape(LinearIncrease); // Kept for compatibility
-    else if(content=="LinearDecr") setShape(LinearDecrease); // Kept for compatibility
-    else {
-      App::log(tr("Unknown value %1 for shape\n").arg(content.toString()));
-      return false;
-    }
-    return true;
+    setShape(convertShape(content.toStringView(), ok));
+    return ok;
   case 1:
-    _lastParamCondition=content.toBool();
-    return true;
+    _lastParamCondition=content.toBool(ok);
+    return ok;
   case 2:
-    setSubLayerCount(content.toInt());
-    return true;
+    setSubLayerCount(content.toInt(ok));
+    return ok;
   case 3:
-    _topMin=content.toDouble();
-    return true;
+    _topMin=content.toDouble(ok);
+    return ok;
   case 4:
-    _topMax=content.toDouble();
-    return true;
+    _topMax=content.toDouble(ok);
+    return ok;
   case 5:
-    _bottomMin=content.toDouble();
-    return true;
+    _bottomMin=content.toDouble(ok);
+    return ok;
   case 6:
-    _bottomMax=content.toDouble();
-    return true;
+    _bottomMax=content.toDouble(ok);
+    return ok;
   case 7:
-    _linkedTo=content.toString();
+    _linkedTo=content.toStringBuffer();
     return true;
   case 8:
-    _isDepth=content.toBool();
-    return true;
+    _isDepth=content.toBool(ok);
+    return ok;
   case 9:
-    _dhMin=content.toDouble();
-    return true;
+    _dhMin=content.toDouble(ok);
+    return ok;
   case 10:
-    _dhMax=content.toDouble();
-    return true;
+    _dhMax=content.toDouble(ok);
+    return ok;
   case 11:
     return true;
   default:
