@@ -45,7 +45,7 @@ Target::Target()
   _selected=true;
   _misfitWeight=1.0;
   _minimumMisfit=0.0;
-  _misfitType=L2_Normalized;
+  _misfitType=Misfit::L2_Normalized;
 }
 
 /*!
@@ -68,7 +68,7 @@ void Target::xml_writeProperties(XML_WRITEPROPERTIES_ARGS) const
   writeProperty(s, "selected", _selected);
   writeProperty(s, "misfitWeight", _misfitWeight);
   writeProperty(s, "minimumMisfit", _minimumMisfit);
-  writeProperty(s, "misfitType", RealStatisticalValue::misfitTypeString(_misfitType));
+  writeProperty(s, "misfitType", Misfit::convertType(_misfitType));
 }
 
 XMLMember Target::xml_member(XML_MEMBER_ARGS)
@@ -90,11 +90,12 @@ bool Target::xml_setProperty(XML_SETPROPERTY_ARGS)
   Q_UNUSED(tag)
   Q_UNUSED(attributes)
   Q_UNUSED(context)
+  bool ok=true;
   switch(memberID) {
-  case 0: _misfitWeight=content.toDouble(); return true;
-  case 1: _minimumMisfit=content.toDouble(); return true;
-  case 2: _misfitType=RealStatisticalValue::misfitType(content.toString()); return true;
-  case 3: _selected=content.toBool(); return true;
+  case 0: _misfitWeight=content.toDouble(ok); return ok;
+  case 1: _minimumMisfit=content.toDouble(ok); return ok;
+  case 2: _misfitType=Misfit::convertType(content.toStringView(), ok); return ok;
+  case 3: _selected=content.toBool(ok); return ok;
   default: return false;
   }
 }
