@@ -149,7 +149,7 @@ void TargetList::setParamProfiles(ParamGroundModel * gm, RealSpace& ps)
   }
 }
 
-void TargetList::setMisfitType(MisfitType t)
+void TargetList::setMisfitType(Misfit::Type t)
 {
   TRACE;
   _dispersionTarget.setMisfitType(t);
@@ -316,7 +316,6 @@ double TargetList::misfit(int nDimensions, bool& ok)
                                       _rho->resampledProfile().values(),
                                       &_nu->minResampledProfile().values(),
                                       &_nu->maxResampledProfile().values());
-    //fprintf(stdout,"%s\n",surfModel->toString().toLatin1().data());
     surfaceMisfit(totalMisfit, totalWeight, m, nDimensions, ok);
     if((_refractionVpTarget.selected() && !_refractionVpTarget.curves().isEmpty()) ||
        (_refractionVsTarget.selected() && !_refractionVsTarget.curves().isEmpty())) {
@@ -350,8 +349,11 @@ double TargetList::misfit(int nDimensions, bool& ok)
     Resistivity1DModel m(_res->resampledProfile());
     magnetoTelluricMisfit(totalMisfit, totalWeight, &m, staticShift, nDimensions, ok);
   }
-  if(totalWeight > 0) return totalMisfit/totalWeight;
-  else return totalMisfit;
+  if(totalWeight>0.0) {
+    return totalMisfit/totalWeight;
+  } else {
+    return totalMisfit;
+  }
 }
 
 void TargetList::surfaceMisfit(double& totalMisfit, double& totalWeight,
@@ -369,14 +371,14 @@ void TargetList::surfaceMisfit(double& totalMisfit, double& totalWeight,
   }
 
   // Compute dispersion curves; Rayleigh and/or Love modes, phase and/or group
-  if(_dispersionTarget.misfitType()!=Determinant &&
+  if(_dispersionTarget.misfitType()!=Misfit::Determinant &&
      !_dispersionFactory->calculate(surfModel, _ellipticityFactory)) {
     ok=false;
     return;
   }
 
   if(_dispersionTarget.selected() && !_dispersionTarget.curves().isEmpty()) {
-    if(_dispersionTarget.misfitType()==Determinant) {
+    if(_dispersionTarget.misfitType()==Misfit::Determinant) {
       individualMisfit=determinantMisfit(_dispersionTarget.curves(), surfModel);
     } else {
       individualMisfit=curveMisfit(_dispersionTarget.curves(), *_dispersionFactory, _dispersionTarget, nDimensions);
@@ -436,7 +438,7 @@ void TargetList::surfaceMisfit(double& totalMisfit, double& totalWeight,
 }
 
 void TargetList::refractionMisfit(double& totalMisfit, double& totalWeight,
-                                  Seismic1DModel * surfModel, const QVector<double>& pitch,
+                                  Seismic1DModel * surfModel, const VectorList<double>& pitch,
                                   int nDimensions, bool& ok)
 {
   TRACE;
@@ -545,29 +547,31 @@ double TargetList::curveMisfit(const QList<ModalCurve>& curveList, ModalFactory&
   }
   if(nValues>0) {
     switch(target.misfitType()) {
-    case L1:
-    case L1_Normalized:
-    case L1_LogNormalized:
-    case L1_NormalizedBySigmaOnly:
+    case Misfit::L1:
+    case Misfit::L1_Normalized:
+    case Misfit::L1_LogNormalized:
+    case Misfit::L1_NormalizedBySigmaOnly:
       rms_val/=nValues;
       break;
-    case RMS:
+    case Misfit::RMS:
       rms_val=sqrt(rms_val/nValues);
       break;
-    case L2:
-    case L2_Normalized:
-    case L2_LogNormalized:
-    case L2_NormalizedBySigmaOnly:
+    case Misfit::L2:
+    case Misfit::L2_Normalized:
+    case Misfit::L2_Inverse:
+    case Misfit::L2_LogNormalized:
+    case Misfit::L2_NormalizedBySigmaOnly:
       rms_val=sqrt(rms_val/nValues);
       break;
-    case Akaike:
+    case Misfit::Akaike:
       rms_val=nValues*log(sqrt(rms_val))+2.0*nDimensions;
       break;
-    case AkaikeFewSamples:
+    case Misfit::AkaikeFewSamples:
       rms_val=nValues*log(sqrt(rms_val))
                 +2.0*nDimensions+(2.0*nDimensions*(nDimensions+1.0))/(nValues-nDimensions-1.0);
       break;
-    case Determinant:
+    case Misfit::Determinant:
+    case Misfit::TypeCount:
       ASSERT(false);
     }
     // Penalty factor if the number of data is greater than number of values
@@ -597,30 +601,32 @@ double TargetList::curveMisfit(const QList<RefractionCurve>& curveList, Refracti
   }
   if(nValues>0) {
     switch(target.misfitType()) {
-      case L1:
-      case L1_Normalized:
-      case L1_LogNormalized:
-      case L1_NormalizedBySigmaOnly:
-        rms_val/=nValues;
-        break;
-      case RMS:
-        rms_val=sqrt(rms_val/nValues);
-        break;
-      case L2:
-      case L2_Normalized:
-      case L2_LogNormalized:
-      case L2_NormalizedBySigmaOnly:
-        rms_val=sqrt(rms_val);
-        break;
-      case Akaike:
-        rms_val=nValues*log10(sqrt(rms_val))+2.0*nDimensions;
-        break;
-      case AkaikeFewSamples:
-        rms_val=nValues*log10(sqrt(rms_val))
-                  +2.0*nDimensions+(2.0*nDimensions*(nDimensions+1.0))/(nValues-nDimensions-1.0);
-        break;
-      case Determinant:
-        ASSERT(false);
+    case Misfit::L1:
+    case Misfit::L1_Normalized:
+    case Misfit::L1_LogNormalized:
+    case Misfit::L1_NormalizedBySigmaOnly:
+      rms_val/=nValues;
+      break;
+    case Misfit::RMS:
+      rms_val=sqrt(rms_val/nValues);
+      break;
+    case Misfit::L2:
+    case Misfit::L2_Normalized:
+    case Misfit::L2_Inverse:
+    case Misfit::L2_LogNormalized:
+    case Misfit::L2_NormalizedBySigmaOnly:
+      rms_val=sqrt(rms_val);
+      break;
+    case Misfit::Akaike:
+      rms_val=nValues*log10(sqrt(rms_val))+2.0*nDimensions;
+      break;
+    case Misfit::AkaikeFewSamples:
+      rms_val=nValues*log10(sqrt(rms_val))
+                +2.0*nDimensions+(2.0*nDimensions*(nDimensions+1.0))/(nValues-nDimensions-1.0);
+      break;
+    case Misfit::Determinant:
+    case Misfit::TypeCount:
+      ASSERT(false);
     }
     // Penalty factor if the number of data is greater than number of values
     rms_val*=1.0+nData-nValues;
@@ -649,30 +655,32 @@ double TargetList::curveMisfit(const QList<MagnetoTelluricCurve>& curveList, Mag
   }
   if(nValues>0) {
     switch(target.misfitType()) {
-      case L1:
-      case L1_Normalized:
-      case L1_LogNormalized:
-      case L1_NormalizedBySigmaOnly:
-        rms_val/=nValues;
-        break;
-      case RMS:
-        rms_val=sqrt(rms_val/nValues);
-        break;
-      case L2:
-      case L2_Normalized:
-      case L2_LogNormalized:
-      case L2_NormalizedBySigmaOnly:
-        rms_val=sqrt(rms_val);
-        break;
-      case Akaike:
-        rms_val=nValues * log10(sqrt( rms_val)) + 2.0*nDimensions;
-        break;
-      case AkaikeFewSamples:
-        rms_val=nValues * log10(sqrt( rms_val))
-                  +2.0*nDimensions+(2.0*nDimensions*(nDimensions+1.0))/(nValues-nDimensions-1.0);
-        break;
-      case Determinant:
-        ASSERT(false);
+    case Misfit::L1:
+    case Misfit::L1_Normalized:
+    case Misfit::L1_LogNormalized:
+    case Misfit::L1_NormalizedBySigmaOnly:
+      rms_val/=nValues;
+      break;
+    case Misfit::RMS:
+      rms_val=sqrt(rms_val/nValues);
+      break;
+    case Misfit::L2:
+    case Misfit::L2_Normalized:
+    case Misfit::L2_Inverse:
+    case Misfit::L2_LogNormalized:
+    case Misfit::L2_NormalizedBySigmaOnly:
+      rms_val=sqrt(rms_val);
+      break;
+    case Misfit::Akaike:
+      rms_val=nValues * log10(sqrt( rms_val)) + 2.0*nDimensions;
+      break;
+    case Misfit::AkaikeFewSamples:
+      rms_val=nValues * log10(sqrt( rms_val))
+                +2.0*nDimensions+(2.0*nDimensions*(nDimensions+1.0))/(nValues-nDimensions-1.0);
+      break;
+    case Misfit::Determinant:
+    case Misfit::TypeCount:
+      ASSERT(false);
     }
     // Penalty factor if the number of data is greater than number of values
     rms_val*=1.0+nData-nValues;
@@ -702,7 +710,7 @@ void TargetList::xml_writeProperties(XML_WRITEPROPERTIES_ARGS) const
 {
   TRACE;
   Q_UNUSED(context)
-  writeProperty(s, "position", _position.toString(20));
+  writeProperty(s, "position", _position.toString('g', 20));
 }
 
 void TargetList::xml_writeChildren(XML_WRITECHILDREN_ARGS) const
@@ -741,7 +749,7 @@ XMLMember TargetList::xml_member(XML_MEMBER_ARGS)
                                              // See in DispersionTarget.cpp
         return XMLMember(&_dispersionTarget);
       } else {
-        App::log(tr("Wrong type of modal curve target: %1\n").arg(it.value().toString()) );
+        App::log(tr("Wrong type of modal curve target: %1\n").arg(it.value().toStringView()));
         return XMLMember(XMLMember::Unknown);
       }
     } else {
@@ -757,7 +765,7 @@ XMLMember TargetList::xml_member(XML_MEMBER_ARGS)
       if(it.value()=="ellipticity peak") {
         return XMLMember(&_ellipticityPeakTarget);
       } else {
-        App::log(tr("Wrong type of value target: %1\n").arg(it.value().toString()) );
+        App::log(tr("Wrong type of value target: %1\n").arg(it.value().toStringView()));
         return XMLMember(XMLMember::Unknown);
       }
     }  else {
@@ -772,7 +780,7 @@ XMLMember TargetList::xml_member(XML_MEMBER_ARGS)
       } else if(it.value()=="Vs") {
         return XMLMember(&_refractionVsTarget);
       } else {
-        App::log(tr("Wrong type of refraction target: %1\n").arg(it.value().toString()) );
+        App::log(tr("Wrong type of refraction target: %1\n").arg(it.value().toStringView()));
         return XMLMember(XMLMember::Unknown);
       }
     }  else {
@@ -796,7 +804,7 @@ XMLMember TargetList::xml_member(XML_MEMBER_ARGS)
         _ellipticityCurveTarget.curves().append(ModalCurve());
         return XMLMember(&_ellipticityCurveTarget.curves().last());
       } else {
-        App::log(tr("Wrong type of modal curve %1\n").arg(it.value().toString()) );
+        App::log(tr("Wrong type of modal curve %1\n").arg(it.value().toStringView()));
         return XMLMember(XMLMember::Unknown);
       }
     } else {
@@ -817,7 +825,7 @@ XMLMember TargetList::xml_member(XML_MEMBER_ARGS)
         _refractionVsTarget.curves().append(RefractionCurve());
         return XMLMember(&_refractionVsTarget.curves().last());
       } else {
-        App::log(tr("Wrong type of refraction curve %1\n").arg(it.value().toString()) );
+        App::log(tr("Wrong type of refraction curve %1\n").arg(it.value().toStringView()));
         return XMLMember(XMLMember::Unknown);
       }
     } else {
@@ -864,27 +872,28 @@ bool TargetList::xml_setProperty(XML_SETPROPERTY_ARGS)
   Q_UNUSED(tag)
   Q_UNUSED(attributes)
   Q_UNUSED(context)
+  bool ok=true;
   switch(memberID) {
-  case 19: _position.fromString(content.toString()); return true;
+  case 19: return _position.fromString(content.toStringView());
   case 0: return true; // kept for compatibility only
-  case 1: _dispersionTarget.setMisfitWeight(content.toDouble()); return true; // kept for compatibility only
-  case 2: _autocorrTarget.setMisfitWeight(content.toDouble()); return true; // kept for compatibility only
-  case 3: _ellipticityCurveTarget.setMisfitWeight(content.toDouble()); return true; // kept for compatibility only
-  case 4: _ellipticityPeakTarget.setMisfitWeight(content.toDouble()); return true; // kept for compatibility only
-  case 5: _refractionVpTarget.setMisfitWeight(content.toDouble()); return true; // kept for compatibility only
-  case 6: _refractionVsTarget.setMisfitWeight(content.toDouble()); return true; // kept for compatibility only
-  case 7: _dispersionTarget.setMinimumMisfit(content.toDouble()); return true; // kept for compatibility only
-  case 8: _autocorrTarget.setMinimumMisfit(content.toDouble()); return true; // kept for compatibility only
-  case 9: _ellipticityCurveTarget.setMinimumMisfit(content.toDouble()); return true; // kept for compatibility only
-  case 10: _ellipticityPeakTarget.setMinimumMisfit(content.toDouble()); return true; // kept for compatibility only
-  case 11: _refractionVpTarget.setMinimumMisfit(content.toDouble()); return true; // kept for compatibility only
-  case 12: _refractionVsTarget.setMinimumMisfit(content.toDouble()); return true; // kept for compatibility only
-  case 13: _dispersionTarget.setMisfitType(RealStatisticalValue::misfitType(content.toString())); return true; // kept for compatibility only
-  case 14: _autocorrTarget.setMisfitType(RealStatisticalValue::misfitType(content.toString())); return true; // kept for compatibility only
-  case 15: _ellipticityCurveTarget.setMisfitType(RealStatisticalValue::misfitType(content.toString())); return true; // kept for compatibility only
-  case 16: _ellipticityPeakTarget.setMisfitType(RealStatisticalValue::misfitType(content.toString())); return true; // kept for compatibility only
-  case 17: _refractionVpTarget.setMisfitType(RealStatisticalValue::misfitType(content.toString())); return true; // kept for compatibility only
-  case 18: _refractionVsTarget.setMisfitType(RealStatisticalValue::misfitType(content.toString())); return true; // kept for compatibility only
+  case 1: _dispersionTarget.setMisfitWeight(content.toDouble(ok)); return ok; // kept for compatibility only
+  case 2: _autocorrTarget.setMisfitWeight(content.toDouble(ok)); return ok; // kept for compatibility only
+  case 3: _ellipticityCurveTarget.setMisfitWeight(content.toDouble(ok)); return ok; // kept for compatibility only
+  case 4: _ellipticityPeakTarget.setMisfitWeight(content.toDouble(ok)); return ok; // kept for compatibility only
+  case 5: _refractionVpTarget.setMisfitWeight(content.toDouble(ok)); return ok; // kept for compatibility only
+  case 6: _refractionVsTarget.setMisfitWeight(content.toDouble(ok)); return ok; // kept for compatibility only
+  case 7: _dispersionTarget.setMinimumMisfit(content.toDouble(ok)); return ok; // kept for compatibility only
+  case 8: _autocorrTarget.setMinimumMisfit(content.toDouble(ok)); return ok; // kept for compatibility only
+  case 9: _ellipticityCurveTarget.setMinimumMisfit(content.toDouble(ok)); return ok; // kept for compatibility only
+  case 10: _ellipticityPeakTarget.setMinimumMisfit(content.toDouble(ok)); return ok; // kept for compatibility only
+  case 11: _refractionVpTarget.setMinimumMisfit(content.toDouble(ok)); return ok; // kept for compatibility only
+  case 12: _refractionVsTarget.setMinimumMisfit(content.toDouble(ok)); return ok; // kept for compatibility only
+  case 13: _dispersionTarget.setMisfitType(Misfit::convertType(content.toStringView(), ok)); return ok; // kept for compatibility only
+  case 14: _autocorrTarget.setMisfitType(Misfit::convertType(content.toStringView(), ok)); return ok; // kept for compatibility only
+  case 15: _ellipticityCurveTarget.setMisfitType(Misfit::convertType(content.toStringView(), ok)); return ok; // kept for compatibility only
+  case 16: _ellipticityPeakTarget.setMisfitType(Misfit::convertType(content.toStringView(), ok)); return ok; // kept for compatibility only
+  case 17: _refractionVpTarget.setMisfitType(Misfit::convertType(content.toStringView(), ok)); return ok; // kept for compatibility only
+  case 18: _refractionVsTarget.setMisfitType(Misfit::convertType(content.toStringView(), ok)); return ok; // kept for compatibility only
   default: return false;
   }
 }
