@@ -67,7 +67,7 @@ public:
                       Seismic1DModel * surfModel,
                       int nDimensions, bool& ok);
   void refractionMisfit(double& totalMisfit, double& totalWeight,
-                         Seismic1DModel * surfModel, const QVector<double>& pitch,
+                         Seismic1DModel * surfModel, const VectorList<double>& pitch,
                          int nDimensions, bool& ok);
   void refractionMisfit(double& totalMisfit, double& totalWeight,
                          RefractionDippingModel * tiltModel,
@@ -101,7 +101,7 @@ public:
   const Point& position() const {return _position;}
   void setPosition(const Point& p) {_position=p;}
 
-  void setMisfitType(MisfitType t);
+  void setMisfitType(Misfit::Type t);
 
   bool isEmpty() const;
   void validateTargets();
