@@ -49,17 +49,19 @@ public:
   virtual void setFrequencyAxis(bool) {}
   virtual void setTarget(const TargetList * tl);
   void setLayerComments(const QStringList& reportList);
+  void setColorMap(const ColorMap& m);
   void selectModels(QString reportFileName, double maxMisfit, int minIndex, int maxIndex);
-  void selectModels(DCModelViewer * w, const QVector<int> * indexes);
-  void rejectModels(DCModelViewer * w, const QVector<int> * indexes);
+  void selectModels(DCModelViewer * w, const VectorList<int> * indexes);
+  void rejectModels(DCModelViewer * w, const VectorList<int> * indexes);
   void loadModels();
   int modelCount() const {return _models.count();}
 
   GraphicSheet * sheet() {return &_sheet;}
+  void exportPlot(const ExportOptions& o);
 public slots:
   void setLimits();
   void setDefaultPalette();
-  void showSelectedModels(int id, const QVector<int>* indexes);
+  void showSelectedModels(int id, const VectorList<int>* indexes);
 protected slots:
   virtual void showTarget(bool isVisible);
 protected:
@@ -70,7 +72,7 @@ protected:
   GraphicSheet _sheet;
   ColorMapWidget * _colorMap;
   QVBoxLayout* _childLayout;
-#ifndef Q_OS_MAC
+#ifndef Q_OS_DARWIN
   QMenuBar * _menuBar;
 #endif
 
