@@ -81,8 +81,8 @@ void DispersionViewer::setTitles(int i)
   TRACE;
   AxisWindow * w=_graphs[i];
   w->yAxis()->setTitle("Slowness (s/m)");
-  w->yAxis()->setTitleInversedScale("Velocity (m/s)");
-  w->yAxis()->setScaleType(Scale::InversedLog);
+  w->yAxis()->setTitleInverseScale("Velocity (m/s)");
+  w->yAxis()->setScaleType(Scale::InverseLog);
   w->xAxis()->setFrequency();
   w->setObjectName(QString("dc_%1").arg(i));
 }
