@@ -78,7 +78,7 @@ void MagnetoTelluricViewer::setTitles(int i)
   TRACE;
   AxisWindow * w=_graphs[i];
   w->xAxis()->setTitle( "Frequency (kHz)" );
-  w->xAxis()->setTitleInversedScale( "Period (ms)" );
+  w->xAxis()->setTitleInverseScale( "Period (ms)" );
   w->xAxis()->setScaleType(Scale::Log);
   w->xAxis()->setReversedScale(true);
   w->xAxis()->setUnitFactor(1e-3);
@@ -86,11 +86,11 @@ void MagnetoTelluricViewer::setTitles(int i)
   switch(i) {
   default:
     w->yAxis()->setTitle(tr("Apparent resistivity (ohm m)"));
-    w->yAxis()->setTitleInversedScale(tr("Apparent conductivity (S/m)"));
+    w->yAxis()->setTitleInverseScale(tr("Apparent conductivity (S/m)"));
     break;
   case 1:
     w->yAxis()->setTitle(tr("Phase (degrees)"));
-    w->yAxis()->setTitleInversedScale(tr("1/Phase (1/degrees)"));
+    w->yAxis()->setTitleInverseScale(tr("1/Phase (1/degrees)"));
     break;
   }
 }
@@ -118,7 +118,7 @@ void MagnetoTelluricViewer::report2plot(DCReportBlock& dcBlock, Point2D ** point
   TRACE;
   MagnetoTelluricFactory f;
   f.readReport(dcBlock.stream());
-  const QVector<double>& x=f.angularFrequencies();
+  const VectorList<double>& x=f.angularFrequencies();
   int nFrequencies=x.count();
   const ComplexValue * values=f.impedanceXY();
   MagnetoTelluricPointOptions options;
