@@ -43,6 +43,8 @@ namespace GeopsyCore {
     Full description of class still missing
   */
 
+  const QString AbstractSignalGroup::xmlAbstractSignalGroupTag="AbstractGroup";
+
   /*!
     Constructor with \a parent group.
 
@@ -68,29 +70,43 @@ namespace GeopsyCore {
     }
   }
 
+  /*!
+    Must be re-implemented in sub-classes
+  */
+  bool AbstractSignalGroup::xml_inherits(const QString& tagName) const
+  {
+    if(tagName==xmlAbstractSignalGroupTag) {
+      return true;
+    } else {
+      return TreeContainer::xml_inherits(tagName);
+    }
+  }
+
   /*!
     Reparent this group. Modified flag is changed if parent is changed.
     New parent must belong to the same tree as the current parent. To move
     one group from one tree to another, first set parent to null and then
     insert it in the new tree.
   */
-  void AbstractSignalGroup::setParent(AbstractSignalGroup * p)
+  void AbstractSignalGroup::setParent(TreeContainer * p)
   {
     TRACE;
+    ASSERT(xml_inherits(xmlAbstractSignalGroupTag));
+    AbstractSignalGroup * gp=static_cast<AbstractSignalGroup *>(p);
     AbstractSignalGroup * oldp=parent();
     if(p!=oldp) {
       if(isValidParent(p)) { // Check circular references
-        ASSERT(!oldp || oldp->isSameMaster(p));
+        //ASSERT(!oldp || oldp->isSameMaster(gp));
         if(p) {
-          p->reportParentAboutToBeChanged(this, p);
+          gp->reportParentAboutToBeChanged(this, gp);
           TreeContainer::setParent(p);
-          p->reportParentChanged(this, oldp);
+          gp->reportParentChanged(this, oldp);
           setModified(true);
           if(id()<0) {
             setId(-1);
           }
         } else {
-          oldp->reportParentAboutToBeChanged(this, p);
+          oldp->reportParentAboutToBeChanged(this, gp);
           TreeContainer::setParent(p);
           oldp->reportParentChanged(this, oldp);
           oldp->setModified(true); // Old parent lost a child, changing modification status of this group has no effect
@@ -193,7 +209,11 @@ namespace GeopsyCore {
         prefix+="/";
       }
       prefix+=name();
-      App::log(prefix+"\n");
+      SubSignalPool s=subPool();
+      if(!s.isEmpty()) {
+        TimeRange r=s.timeRange();
+        App::log(tr("%1: %2 (%3 sec.)\n").arg(prefix).arg(r.toString()).arg(r.lengthSeconds()));
+      }
     }
     for(const_iterator it=begin(); it!=end(); ++it) {
       static_cast<AbstractSignalGroup *>(*it)->printList(prefix);
@@ -345,7 +365,7 @@ namespace GeopsyCore {
   /*!
     Returns all groups whose name matches \a name.
   */
-  QList<const AbstractSignalGroup *> AbstractSignalGroup::find(const QRegExp& name) const
+  QList<const AbstractSignalGroup *> AbstractSignalGroup::find(const QRegularExpression& name) const
   {
     TRACE;
     QList<const AbstractSignalGroup *> l;
@@ -364,7 +384,7 @@ namespace GeopsyCore {
   /*!
     Returns all groups whose name matches \a name.
   */
-  QList<AbstractSignalGroup *> AbstractSignalGroup::find(const QRegExp& name)
+  QList<AbstractSignalGroup *> AbstractSignalGroup::find(const QRegularExpression& name)
   {
     TRACE;
     QList<AbstractSignalGroup *> l;
@@ -684,7 +704,7 @@ namespace GeopsyCore {
         if(tag=="folder") return XMLMember(XMLMember::Skip);         // Kept for compatibility
         break;
       default: {
-          AbstractSignalGroup * g=SignalGroupFactory::instance()->create(tag.toString());
+          AbstractSignalGroup * g=SignalGroupFactory::instance()->create(tag.toStringBuffer());
           if(g) {
             g->setParent(this);
             return XMLMember(g);
@@ -694,14 +714,14 @@ namespace GeopsyCore {
       }
     }
     // Custom group types
-    int id=SignalResultsFactory::instance()->id(tag.toString());
+    int id=SignalResultsFactory::instance()->id(tag.toStringBuffer());
     if(id>-1) {
       AbstractSignalResults * r=SignalResultsFactory::instance()->create(id);
       r->TreeContainer::setParent(this); // Avoid modified flag
       return XMLMember(r);
     } else {
       App::log(tr("Unknown result type '%1', probably a missing plugin.\n"
-                  "You may loose some results if you save the database!\n").arg(tag.toString()));
+                  "You may loose some results if you save the database!\n").arg(tag.toStringView()));
       SignalDatabase * db=static_cast<SignalDatabase *>(context);
       db->setName(QString()); // Forces saveAs() and avoid overwriting
       return XMLMember(new SignalGroup(this));
@@ -711,16 +731,17 @@ namespace GeopsyCore {
   bool AbstractSignalGroup::xml_setProperty(XML_SETPROPERTY_ARGS)
   {
     TRACE;
+    bool ok=true;
     switch(memberID) {
     case 0:
-      setName(content.toString());
+      setName(content.toStringBuffer());
       return true;
     case 1:
-      setComments(content.toString());
+      setComments(content.toStringBuffer());
       return true;
     case 2:
-      setId(content.toInt());
-      return true;
+      setId(content.toInt(ok));
+      return ok;
     default:
       return TreeContainer::xml_setProperty(memberID-3, tag, attributes, content, context);
     }
