@@ -56,6 +56,12 @@ namespace GeopsyCore {
     delete _param;
   }
 
+  void AbstractTool::setParameters(AbstractParameters * param)
+  {
+    delete _param;
+    _param=param;
+  }
+
   bool AbstractTool::setSubPool(SubSignalPool * subPool)
   {
     TRACE;
@@ -68,14 +74,6 @@ namespace GeopsyCore {
     }
   }
 
-  bool AbstractTool::setParameters(const AbstractParameters& param)
-  {
-    TRACE;
-    delete _param;
-    _param=param.clone();
-    return true;
-  }
-
   bool AbstractTool::setLoop()
   {
     delete _loop;
@@ -88,7 +86,7 @@ namespace GeopsyCore {
     }
   }
 
-  void AbstractTool::start()
+  void AbstractTool::start(int threadCount, bool forceParallel)
   {
     TRACE;
     _log.clear();
@@ -111,7 +109,8 @@ namespace GeopsyCore {
      App::log(log);
      _log+=log;
     _chrono.start();
-    _loop->start();
+    _loop->setThreadCount(threadCount);
+    _loop->start(forceParallel);
   }
 
   void AbstractTool::finish()
@@ -119,17 +118,23 @@ namespace GeopsyCore {
     QTime timeElapsed(0,0);
     QString log;
     log=tr("\nProcess ended at %1\n").arg(QDateTime::currentDateTime().toString("yyyy-MM-dd hh:mm:ss"))
-       +tr("Process run in %1\n").arg(timeElapsed.addMSecs(_chrono.elapsed()).toString("hh:mm:ss"));
+       +tr("Process run in %1 (%2 threads)\n")
+        .arg(timeElapsed.addMSecs(_chrono.elapsed()).toString("hh:mm:ss"))
+                .arg(_loop->threadCount());
     App::log(log);
     _log+=log;
     emit finished();
   }
 
-  void AbstractTool::waitFinished()
+  /*!
+    If \a ms is null, it waits for the termination of workers without
+    any time limit.
+  */
+  void AbstractTool::waitFinished(int ms)
   {
     TRACE;
     if(_loop) {
-      _loop->waitFinished();
+      _loop->waitFinished(ms);
     }
   }
 
