@@ -222,15 +222,16 @@ namespace GeopsyCore {
   bool AsciiSignalFormat::xml_setProperty(XML_SETPROPERTY_ARGS)
   {
     TRACE;
+    bool ok=true;
     switch(memberID) {
-    case 0: setHeaderType(content.toString()); return true;
-    case 1: _headerPattern=content.toString(); return true;
-    case 2: _headerLineCount=content.toInt(); return true;
-    case 3: _timeFormat=content.toString(); return true;
-    case 4: _separators=AsciiLineParser::stringToSeparators(content.toString()); return true;
-    case 5: _emptyValues=content.toBool(); return true;
-    case 6: _quotes=content.toBool(); return true;
-    case 7: _hexadecimal=content.toBool(); return true;
+    case 0: setHeaderType(content.toStringBuffer()); return true;
+    case 1: _headerPattern=content.toStringBuffer(); return true;
+    case 2: _headerLineCount=content.toInt(ok); return ok;
+    case 3: _timeFormat=content.toStringBuffer(); return true;
+    case 4: _separators=AsciiLineParser::stringToSeparators(content.toStringBuffer()); return true;
+    case 5: _emptyValues=content.toBool(ok); return ok;
+    case 6: _quotes=content.toBool(ok); return ok;
+    case 7: _hexadecimal=content.toBool(ok); return ok;
     default:
       break;
     }
@@ -293,10 +294,10 @@ namespace GeopsyCore {
       }
       break;
     case HeaderPattern: {
-        QRegExp rexp(_headerPattern);
+        QRegularExpression rexp(_headerPattern);
         qint64 offset=s.pos();
         QString line=s.readLine();
-        while(!s.atEnd() && rexp.indexIn(line)>-1) {
+        while(!s.atEnd() && line.indexOf(rexp)>-1) {
           headerText+=line+"\n";
           lineNumber++;
           offset=s.pos();
@@ -314,10 +315,10 @@ namespace GeopsyCore {
       }
       break;
     case EndHeaderPattern: { // Line just after match contains data
-        QRegExp rexp(_headerPattern);
+        QRegularExpression rexp(_headerPattern);
         QString line=s.readLine();
         lineNumber++;
-        while(!s.atEnd() && rexp.indexIn(line)==-1) {
+        while(!s.atEnd() && line.indexOf(rexp)==-1) {
           headerText+=line+"\n";
           line=s.readLine();
           lineNumber++;
@@ -334,7 +335,7 @@ namespace GeopsyCore {
         qint64 offset=s.pos();
         line=s.readLine();
         lineNumber++;
-        while(!s.atEnd() && rexp.indexIn(line)>-1) {
+        while(!s.atEnd() && line.indexOf(rexp)>-1) {
           offset=s.pos();
           line=s.readLine();
           lineNumber++;
@@ -368,17 +369,17 @@ namespace GeopsyCore {
     for(QList<AsciiSignalFormatRule>::iterator it=_rules.begin();it!=_rules.end();it++) {
       AsciiSignalFormatRule& r=*it;
       if(!r.constant()) {
-        QRegExp rexp(r.pattern());
-        if(rexp.indexIn(headerText)>-1) {
+        QRegularExpression rexp(r.pattern());
+        QRegularExpressionMatch match;
+        if(headerText.indexOf(rexp, 0, &match)>-1) {
           if(_verbose) {
             App::log(tr("  Rule '%1' matched with value '%2'\n")
-                          .arg(r.pattern()).arg(rexp.cap(r.patternIndex())));
+                          .arg(r.pattern()).arg(match.captured(r.patternIndex())));
           }
-          r.setValue(rexp.cap(r.patternIndex()));
+          r.setValue(match.captured(r.patternIndex()));
         } else {
           if(_verbose) {
-            App::log(tr("  Rule '%1' NOT matched\n")
-                          .arg(r.pattern()));
+            App::log(tr("  Rule '%1' NOT matched\n").arg(r.pattern()));
           }
           r.setValue(QVariant());
           if(r.mandatory()) {
@@ -419,8 +420,8 @@ namespace GeopsyCore {
               App::log(tr("    setting Component from value '%1'\n").arg(r.value().toString()));
             }
             for(QList<AsciiSignalFormatComponent>::const_iterator it=_components.begin();it!=_components.end();it++) {
-              QRegExp exp(it->pattern());
-              if(exp.exactMatch(r.value().toString())) {
+              QRegularExpression exp(it->pattern());
+              if(exp.globalMatch(r.value().toString()).hasNext()) {
                 sig->setComponent(it->component());
                 if(_verbose) {
                   App::log(tr("    found match in Component table: '%1'\n").arg(sig->componentStandardName()) );
@@ -434,7 +435,11 @@ namespace GeopsyCore {
           break;
         default: {
             bool ret=false;
+#if(QT_VERSION>=QT_VERSION_CHECK(6, 0, 0))
+            if(r.value().canConvert(QMetaType(QMetaType::Double))) {
+#else
             if(r.value().convert(QVariant::Double)) {
+#endif
               double v0=sig->header(r.data()).toDouble();
               double v=r.value().toDouble()*r.factor();
               switch(r.operation()) {
@@ -473,7 +478,7 @@ namespace GeopsyCore {
               case AsciiSignalFormatRule::Divide:
                 if(_verbose) {
                   App::log(tr("    operation '%1' not supported for strings.\n")
-                                   .arg(r.operationString()));
+                                 .arg(AsciiSignalFormatRule::convertOperation(r.operation())));
                 }
                 break;
               }
@@ -517,8 +522,8 @@ namespace GeopsyCore {
         const AsciiSignalFormatRule& r=*it;
         if((r.channel()==-1 || i==r.channel()) && r.value().isValid() && r.data().id()==MetaDataFactory::Component) {
           for(QList<AsciiSignalFormatComponent>::const_iterator it=_components.begin();it!=_components.end();it++) {
-            QRegExp exp(it->pattern());
-            if(it->component()==Signal::Time && exp.exactMatch(r.value().toString())) {
+            QRegularExpression exp(it->pattern());
+            if(it->component()==Signal::Time && exp.globalMatch(r.value().toString()).hasNext()) {
               columnIndex=i;
               i=columnCount;
               break;
@@ -612,11 +617,11 @@ namespace GeopsyCore {
       const AsciiSignalFormatRule& r=*it;
       if((r.channel()==-1 || columnIndex==r.channel()) && r.value().isValid() && r.data().id()==MetaDataFactory::Component) {
         for(QList<AsciiSignalFormatComponent>::const_iterator it=_components.begin();it!=_components.end();it++) {
-          QRegExp exp(it->pattern());
+          QRegularExpression exp(it->pattern());
           switch(it->component()) {
           case Signal::Time:
           case Signal::Ignore:
-            if(exp.exactMatch(r.value().toString())) {
+            if(exp.globalMatch(r.value().toString()).hasNext()) {
               return true;
             }
           default:
