@@ -45,16 +45,6 @@ AsciiSignalFormatComponent::AsciiSignalFormatComponent()
   _component=Signal::UndefinedComponent;
 }
 
-/*!
-  Copy constructor
-*/
-AsciiSignalFormatComponent::AsciiSignalFormatComponent(const AsciiSignalFormatComponent& o)
-    : XMLClass()
-{
-  _pattern=o._pattern;
-  _component=o._component;
-}
-
 void AsciiSignalFormatComponent::xml_writeProperties(XML_WRITEPROPERTIES_ARGS) const
 {
   TRACE;
@@ -80,8 +70,8 @@ bool AsciiSignalFormatComponent::xml_setProperty(XML_SETPROPERTY_ARGS)
   Q_UNUSED(context)
   Q_UNUSED(attributes)
   switch(memberID) {
-  case 0: _pattern=content.toString(); return true;
-  case 1: _component=Signal::standardComponent(content.toString()); return true;
+  case 0: _pattern=content.toStringBuffer(); return true;
+  case 1: _component=Signal::standardComponent(content.toStringBuffer()); return true;
   default:
     break;
   }
