@@ -31,6 +31,8 @@
 
 namespace GeopsyCore {
 
+  class AbstractTool;
+
   class GEOPSYCORE_EXPORT CoreToolInterface
   {
   public:
@@ -40,6 +42,7 @@ namespace GeopsyCore {
     void setParameters(AbstractParameters * param);
     bool setOptions(int& argc, char ** argv);
     static void setHelp(ApplicationHelp * h);
+    static void showArguments();
 
     int subPoolCount() const;
     SubSignalPool subPool(int index) const;
@@ -50,13 +53,21 @@ namespace GeopsyCore {
 
     void setOutputBaseName(const QString& f) {_outputBaseName=f;}
     const QString& outputBaseName() const {return _outputBaseName;}
+
+    bool overwrite(const QString& fileName) const;
+    static void setTool(AbstractTool * tool) {_tool=tool;}
   private:
     bool fixDatabasePaths(QString databaseFileName);
+    bool setUtmCoordinates(const QString& utmCoordinateFile);
+    static void showProgress(int);
+    static void stopAndSave(int);
 
     AbstractParameters * _param;
     QList<const AbstractSignalGroup *> _groups;
     QString _outputBaseName;
     QStringList _stationList;
+    static AbstractTool * _tool;
+    bool _overwrite;
   };
 
 } // namespace GeopsyCore
