@@ -46,6 +46,7 @@ namespace GeopsyCore {
      TRANSLATIONS("DoubleSignal")
   public:
     enum SignalType {Waveform, Spectrum, Phase, UndefinedSignalType};
+    ENUM_AS_STRING_DECL(SignalType)
 
     DoubleSignal();
     DoubleSignal(int n);
@@ -69,9 +70,6 @@ namespace GeopsyCore {
     void copyBasicProperties(const DoubleSignal& o);
     int nyquistIndex() const {return _nyquistIndex;}
 
-    static SignalType type(QString t, bool * ok);
-    static QString typeString(SignalType st);
-
     inline void copySamplesFrom(const DoubleSignal * sig);
     bool copySamplesFrom(const DoubleSignal * sig, double sigStart, double thisStart, double tToCopy);
     bool copySamplesFrom(const DoubleSignal * sig, int isigStart, int ithisStart, int nToCopy);
@@ -106,10 +104,13 @@ namespace GeopsyCore {
     bool removeTrend();
     bool multiply(double value) {return SignalTemplate<double>::multiply(value);}
     bool multiply(const Complex& value);
+    bool random(double maxAmplitude, Random * generator=nullptr);
 
     bool discreteFourierTransform();
     Complex discreteFourierTransform(const FourierPlan& plan) const;
+    void testDiscreteFourierTransform() const;
     bool overSample(double factor, const DoubleSignal * sig);
+    bool frequencyOverSample(double factor, const DoubleSignal * sig);
     bool decimateTime(int factor, const DoubleSignal * sig);
 
     ComplexSignal * morletWavelet(const MorletParameters& param) const;
@@ -127,7 +128,6 @@ namespace GeopsyCore {
     bool removeInstrumentalResponse(const InstrumentalResponse& sensor);
 
     double amplitudeAt(double abscissa) const;
-    double interpoleAt(double abscissa) const;
     double maximumAmplitude(int itmin, int itmax) const;
     int maximumAmplitudeAt(int itmin, int itmax) const;
     int maximumAt(int itmin, int itmax) const;
@@ -135,6 +135,10 @@ namespace GeopsyCore {
     double power(double minF, double maxF) const;
     double power(double excludeBorderRatio=0.0) const;
 
+    double at(const double * samples, double abscissa) const;
+    Complex complexAt(const double * samples, double abscissa) const;
+    void valueRange(const double * samples, double minTime, double maxTime,
+                    double& min, double &max) const;
     Complex complex(const double * samples, int i) const;
     void setComplex(double * samples, int i, const Complex& value) const;
     double amplitude2(const double * samples, int i) const;
