@@ -40,7 +40,7 @@ namespace GeopsyCore {
   FilterParameters::FilterParameters()
   {
     _fmin=1.0;
-    _fmax=std::numeric_limits<double>::quiet_NaN();;
+    _fmax=1.0;
     _band=LowPass;
     _method=FrequencyWindow;
     _window.setShape(WindowFunctionParameters::Cosine);
@@ -58,6 +58,17 @@ namespace GeopsyCore {
     _width=o._width;
   }
 
+  void FilterParameters::operator=(const FilterParameters& o)
+  {
+    AbstractParameters::operator=(o);
+    _window=o._window;
+    _band=o._band;
+    setFrequencyRange(o._fmin, o._fmax);
+    _method=o._method;
+    _order=o._order;
+    _width=o._width;
+  }
+
   void FilterParameters::setBand(Band b)
   {
     _band=b;
@@ -72,7 +83,7 @@ namespace GeopsyCore {
     case LowPass:
     case HighPass:
       _fmin=min;
-      _fmax=std::numeric_limits<double>::quiet_NaN();
+      _fmax=min;
       break;
     case BandPass:
     case BandReject:
@@ -87,91 +98,17 @@ namespace GeopsyCore {
     }
   }
 
-  QString FilterParameters::bandString() const
-  {
-    switch(_band) {
-    case LowPass:
-      break;
-    case HighPass:
-      return "HighPass";
-    case BandPass:
-      return "BandPass";
-    case BandReject:
-      return "BandReject";
-    }
-    return "LowPass";
-  }
+  ENUM_AS_STRING_BEGIN(FilterParameters, Band)
+  ENUM_AS_STRING_DATA_4(BandPass, BandReject, HighPass, LowPass);
+  ENUM_AS_STRING_SYNONYM("band pass", BandPass);
+  ENUM_AS_STRING_SYNONYM("band reject", BandReject);
+  ENUM_AS_STRING_END
 
-  void FilterParameters::setBand(const QString& b)
-  {
-    if(!b.isEmpty()) {
-      QString bl=b.toLower();
-      switch(bl[0].unicode()) {
-      case 'l':
-        setBand(LowPass);
-        break;
-      case 'h':
-        setBand(HighPass);
-        break;
-      case 'b':
-        if(bl=="bandpass" ||
-           bl=="band pass") {            // For compatibility
-          setBand(BandPass);
-        } else if(bl=="bandreject" ||
-                  bl=="band reject") {   // For compatibility
-          setBand(BandReject);
-        }
-        break;
-      default:
-        break;
-      }
-    }
-  }
-
-  QString FilterParameters::methodString() const
-  {
-    switch(_method) {
-    case Butterworth:
-      break;
-    case ChebyshevTypeI:
-      return "ChebyshevTypeI";
-    case FrequencyWindow:
-      return "FrequencyWindow";
-    }
-    return "Butterworth";
-  }
-
-  void FilterParameters::setMethod(const QString& m)
-  {
-    if(!m.isEmpty()) {
-      QString ml=m.toLower();
-      switch(ml[0].unicode()) {
-      case 'b':
-        if(ml=="butterworth") {
-          _method=Butterworth;
-          return;
-        }
-        break;
-      case 'f':
-        if(ml=="frequencywindow") {
-          _method=FrequencyWindow;
-          return;
-        }
-      case 'c':
-        if(ml=="chebyshevtypei") {
-          _method=ChebyshevTypeI;
-        } else if(ml=="convolution" ||  // For compatibility
-                  ml=="cosineTaper") {  // For compatibility
-          _method=FrequencyWindow;
-          return;
-        }
-        break;
-      default:
-        break;
-      }
-    }
-    App::log(tr("Bad filter method '%1'.\n").arg(m) );
-  }
+  ENUM_AS_STRING_BEGIN(FilterParameters, Method)
+  ENUM_AS_STRING_DATA_2(Butterworth, FrequencyWindow);
+  ENUM_AS_STRING_SYNONYM("Convolution", FrequencyWindow);
+  ENUM_AS_STRING_SYNONYM("CosineTaper", FrequencyWindow);
+  ENUM_AS_STRING_END
 
   void FilterParameters::setVersion(PARAMETERS_SETVERSION_ARGS)
   {
@@ -208,25 +145,26 @@ namespace GeopsyCore {
   bool FilterParameters::setValue(PARAMETERS_SETVALUE_ARGS)
   {
     TRACE;
+    bool ok=true;
     switch(index-AbstractParameters::keywordCount()) {
     case 0:
-      setBand(value);
-      return true;
+      setBand(convertBand(value, ok));
+      return ok;
     case 1:
-      setMethod(value);
-      return true;
+      setMethod(convertMethod(value, ok));
+      return ok;
     case 2:
-      _fmin=value.toDouble();
-      return true;
+      _fmin=value.toDouble(&ok);
+      return ok;
     case 3:
-      _fmax=value.toDouble();
-      return true;
+      _fmax=value.toDouble(&ok);
+      return ok;
     case 4:
       setCausal(value=="y");
       return true;
     case 5:
-      setOrder(value.toInt());
-      return true;
+      setOrder(value.toInt(&ok));
+      return ok;
     default:
       break;
     }
@@ -237,8 +175,8 @@ namespace GeopsyCore {
   {
     TRACE;
     QString log;
-    log+=prefix+"FILTER_TYPE"+suffix+"="+bandString()+"\n";
-    log+=prefix+"FILTER_METHOD"+suffix+"="+methodString()+"\n";
+    log+=prefix+"FILTER_TYPE"+suffix+"="+convertBand(_band)+"\n";
+    log+=prefix+"FILTER_METHOD"+suffix+"="+convertMethod(_method)+"\n";
     log+=prefix+"FILTER_MIN_FREQUENCY"+suffix+" (Hz)="+QString::number(_fmin)+"\n";
     log+=prefix+"FILTER_MAX_FREQUENCY"+suffix+" (Hz)="+QString::number(_fmax)+"\n";
     switch(_method) {
@@ -246,9 +184,6 @@ namespace GeopsyCore {
       log+=prefix+"FILTER_CAUSAL"+suffix+" (y/n)="+(causal() ? "y" : "n")+"\n";
       log+=prefix+"FILTER_ORDER"+suffix+"="+QString::number(_order)+"\n";
       break;
-    case ChebyshevTypeI:
-      log+=prefix+"FILTER_ORDER"+suffix+"="+QString::number(_order)+"\n";
-      break;
     case FrequencyWindow:
       log+=_window.toString(prefix+"FILTER_", suffix);
       log+=prefix+"FILTER_WIDTH"+suffix+"="+QString::number(_width);
@@ -257,65 +192,4 @@ namespace GeopsyCore {
     return log;
   }
 
-  /*!
-    Minimum and maximum frequencies, and width must be already set correcty.
-
-    \a passBandRippledB is the allowable passband ripple measured in decibels.
-    \a stopBandAttenuationdB is the minimum attenuation in the stop band, also in decibels.
-
-    Inspired from Octave signal toolbox.
-  */
-  void FilterParameters::setChebyshevOrder(double passBandRippledB, double stopBandAttenuationdB)
-  {
-    TRACE;
-    // prewarping https://en.wikipedia.org/wiki/Bilinear_transform#Frequency_warping
-    //Wpw = (2 / T) .* tan (M_PI .* Wp ./ T);
-    //Wsw = (2 / T) .* tan (M_PI .* Ws ./ T);
-    double wp, ws;
-    switch(_band) {
-    case LowPass:
-      wp=_fmin*(1.0-_width);
-      ws=_fmin;
-      break;
-    case HighPass:
-      ws=_fmin*(1.0+_width);
-      wp=_fmin;
-      break;
-    case BandPass:
-      wp=_fmin;
-      break;
-    case BandReject:
-      break;
-    }
-    /*
-      The stop band attenuation (Rs) must be effective at frequency ws
-      The pass band ripple attenuation (Rp) must be effective at frequency wp
-
-      Filter definition: G=1/sqrt(1+epsilon^2*T_n^2(w/w0))
-      where w0=wp
-
-      Stop band attenuation:
-      10^(-Rs/20)=1/sqrt(1+epsilon^2*T_n^2(wp/ws)
-      sqrt(10^(Rs/10)-1)/epsilon=T_n(ws/wp)
-
-      By definition,
-      T_n(cosh(x))=cosh(n*x)
-
-      T_n(ws/wp)=T_n(ws/wp)=T_n(cosh(acosh(ws/wp)))=cosh(n*acosh(ws/wp))
-
-      epsilon=1/sqrt(10^(-Rp/10)-1), because G=1/sqrt(1+epsilon^2) at wp
-
-      Hence,
-
-      sqrt((10^(Rs/10)-1)/(10^(-Rp/10)-1))=cosh(n*acosh(ws/wp))
-      acosh(sqrt((10^(Rs/10)-1)/(10^(-Rp/10)-1)))=n*acosh(ws/wp)
-      And we get the value of n
-    */
-    // Conversions from dB scale
-    double stopAttenuation=pow(10.0, 0.1*stopBandAttenuationdB);
-    double passAttenuation=pow(10.0, 0.1*passBandRippledB);
-    _order=qCeil(acosh(sqrt((stopAttenuation-1.0)/(passAttenuation-1.0)))/acosh(ws/wp));
-    _rippleFactor=1/sqrt(passAttenuation-1.0);
-  }
-
 } // namespace GeopsyCore
