@@ -39,28 +39,26 @@ public:
   FilterParameters();
   FilterParameters(const FilterParameters& o);
 
-  virtual AbstractParameters * clone() const {return new FilterParameters(*this);}
+  void operator=(const FilterParameters& o);
+  AbstractParameters * clone() const {return new FilterParameters(*this);}
 
   enum Band {LowPass, HighPass, BandPass, BandReject};
-  enum Method {Butterworth, ChebyshevTypeI, FrequencyWindow};
+  enum Method {Butterworth, FrequencyWindow};
+  ENUM_AS_STRING_DECL(Band)
+  ENUM_AS_STRING_DECL(Method)
 
   void setFrequencyRange(double min, double max=0.0);
   double minimumFrequency() const {return _fmin;}
   double maximumFrequency() const {return _fmax;}
 
   Band band() const {return _band;}
-  QString bandString() const;
   void setBand(Band b);
-  void setBand(const QString& b);
 
   Method method() const {return _method;}
-  QString methodString() const;
   void setMethod(Method m) {_method=m;}
-  void setMethod(const QString& m);
 
   int order() const {return _order;}
   void setOrder(int o) {if(::abs(o)<16777216) _order=o;}
-  void setChebyshevOrder(double passBandRippledB, double stopBandAttenuationdB);
 
   double rippleFactor() const {return _rippleFactor;}
   void setRippleFactor(double rf) {_rippleFactor=rf;}
@@ -74,13 +72,13 @@ public:
   double width() const {return _width;}
   void setWidth(double w) {_width=w;}
 
-  virtual QString toString(PARAMETERS_TOSTRING_ARGS_DECL) const;
-  virtual void setVersion(PARAMETERS_SETVERSION_ARGS);
-  virtual void collectKeywords(PARAMETERS_COLLECTKEYWORDS_ARGS);
-  virtual int totalKeywordCount(PARAMETERS_TOTALKEYWORDCOUNT_ARGS) const;
+  QString toString(PARAMETERS_TOSTRING_ARGS_DECL) const;
+  void setVersion(PARAMETERS_SETVERSION_ARGS);
+  void collectKeywords(PARAMETERS_COLLECTKEYWORDS_ARGS);
+  int totalKeywordCount(PARAMETERS_TOTALKEYWORDCOUNT_ARGS) const;
 protected:
-  virtual int keywordCount(PARAMETERS_KEYWORDCOUNT_ARGS) const;
-  virtual bool setValue(PARAMETERS_SETVALUE_ARGS);
+  int keywordCount(PARAMETERS_KEYWORDCOUNT_ARGS) const;
+  bool setValue(PARAMETERS_SETVALUE_ARGS);
 private:
   Band _band;
   Method _method;
