@@ -65,10 +65,10 @@ namespace GeopsyCore {
   {
     Complex hn(1.0, 0.0), hd(1.0, 0.0);
     Complex z(0.0, frequency*_frequencyFactor);
-    for(QVector<Complex>::const_iterator it=_zeros.begin(); it!=_zeros.end(); it++) {
+    for(VectorList<Complex>::const_iterator it=_zeros.begin(); it!=_zeros.end(); it++) {
       hn*=(z-*it);
     }
-    for(QVector<Complex>::const_iterator it=_poles.begin(); it!=_poles.end(); it++) {
+    for(VectorList<Complex>::const_iterator it=_poles.begin(); it!=_poles.end(); it++) {
       hd*=(z-*it);
     }
     if(hn.isNull()) {
@@ -86,10 +86,10 @@ namespace GeopsyCore {
   {
     Complex hn(1.0, 0.0), hd(1.0, 0.0);
     Complex z(0.0, frequency*_frequencyFactor);
-    for(QVector<Complex>::const_iterator it=_zeros.begin(); it!=_zeros.end(); it++) {
+    for(VectorList<Complex>::const_iterator it=_zeros.begin(); it!=_zeros.end(); it++) {
       hn*=(z-*it);
     }
-    for(QVector<Complex>::const_iterator it=_poles.begin(); it!=_poles.end(); it++) {
+    for(VectorList<Complex>::const_iterator it=_poles.begin(); it!=_poles.end(); it++) {
       hd*=(z-*it);
     }
     if(hn.isNull()) {
@@ -107,7 +107,7 @@ namespace GeopsyCore {
     QString s;
     s+=QString::number(_poles.count());
     s+=", ";
-    for(QVector<Complex>::const_iterator it=_poles.begin(); it!=_poles.end(); it++) {
+    for(VectorList<Complex>::const_iterator it=_poles.begin(); it!=_poles.end(); it++) {
       s+=QString::number(it->re());
       s+=", ";
       s+=QString::number(it->im());
@@ -115,7 +115,7 @@ namespace GeopsyCore {
     }
     s+=QString::number(_zeros.count());
     s+=", ";
-    for(QVector<Complex>::const_iterator it=_zeros.begin(); it!=_zeros.end(); it++) {
+    for(VectorList<Complex>::const_iterator it=_zeros.begin(); it!=_zeros.end(); it++) {
       s+=QString::number(it->re());
       s+=", ";
       s+=QString::number(it->im());
@@ -133,10 +133,10 @@ namespace GeopsyCore {
     writeProperty(s, "normalizationFactor", _normalizationFactor);
     writeProperty(s, "frequencyFactor", _frequencyFactor);
     writeProperty(s, "noiseLevel", _noiseLevel);
-    for(QVector<Complex>::const_iterator it=_poles.begin(); it!=_poles.end(); it++) {
+    for(VectorList<Complex>::const_iterator it=_poles.begin(); it!=_poles.end(); it++) {
       writeProperty(s, "pole", it->toString('g', 20));
     }
-    for(QVector<Complex>::const_iterator it=_zeros.begin(); it!=_zeros.end(); it++) {
+    for(VectorList<Complex>::const_iterator it=_zeros.begin(); it!=_zeros.end(); it++) {
       writeProperty(s, "zero", it->toString('g', 20));
     }
   }
@@ -160,28 +160,29 @@ namespace GeopsyCore {
     Q_UNUSED(context)
     Q_UNUSED(tag)
     Q_UNUSED(attributes)
+    bool ok=true;
     switch(memberID) {
     case 0:
-      _name=content.toString();
+      _name=content.toStringBuffer();
       return true;
     case 1:
-      _transductionFactor=content.toDouble();
-      return true;
+      _transductionFactor=content.toDouble(ok);
+      return ok;
     case 2:
-      _noiseLevel=content.toDouble();
-      return true;
+      _noiseLevel=content.toDouble(ok);
+      return ok;
     case 3:
-      addPole(content.toComplex());
-      return true;
+      addPole(content.toComplex(ok));
+      return ok;
     case 4:
-      addZero(content.toComplex());
-      return true;
+      addZero(content.toComplex(ok));
+      return ok;
     case 5:
-      _normalizationFactor=content.toDouble();
-      return true;
+      _normalizationFactor=content.toDouble(ok);
+      return ok;
     case 6:
-      _frequencyFactor=content.toDouble();
-      return true;
+      _frequencyFactor=content.toDouble(ok);
+      return ok;
     }
     return false;
   }
