@@ -28,6 +28,16 @@
 #include <QGpCoreTools.h>
 #include <mseed.h>
 
+// This include has not the same name on all platforms
+// See admin/customconfig for the definition of macros
+#ifdef HAS_HDF5
+#  if defined(HDF5_HDF5)
+#    include <hdf5.h>
+#  elif defined(HDF5_HDF5_SERIAL_HDF5)
+#    include <hdf5/serial/hdf5.h>
+#  endif
+#endif
+
 #include "SignalDatabase.h"
 #include "SignalFile.h"
 #include "SubSignalPool.h"
@@ -233,6 +243,9 @@ bool SignalFile::load()
   case SignalFileFormat::Efispec3D:
     ret=loadEfispec3D();
     break;
+  case SignalFileFormat::FebusHDF5:
+    ret=loadFebusHDF5();
+    break;
   case SignalFileFormat::Tomo:
   case SignalFileFormat::Unknown:
   case SignalFileFormat::Temporary:
@@ -399,7 +412,7 @@ bool SignalFile::loadSeg2()
   TRACE;
   int i;
   QString str;
-  QVector<qint32> offsets;
+  VectorList<qint32> offsets;
 
   QFile f(_name);
   if(!f.open(QIODevice::ReadOnly)) {
@@ -447,7 +460,7 @@ bool SignalFile::loadSeg2()
 
   DateTime acquisitionTime;
   double conversionFactor=1.0;
-  static const QRegExp sep("[ \\t]");
+  static const QRegularExpression sep("[ \\t]");
   // Client and instrument specification (between current pos and first offset)
   while(f.pos()<offsets[0]) {
     f.read(buf, 2);
@@ -513,10 +526,13 @@ bool SignalFile::loadSeg2()
       events=_db->seismicEvents()->eventsAt(acquisitionTime);
     }
   }
-  SeismicEvent e;
-  e.setType(SeismicEvent::Hammer);
-  e.setForce(Point(0.0, 0.0, -1.0));
-  e.setTime(acquisitionTime);
+  SeismicEvent evt;
+  evt.setType(SeismicEvent::Hammer);
+  evt.setForce(Point(0.0, 0.0, -1.0));
+  evt.setTime(acquisitionTime);
+  if(GeopsyCoreEngine::instance()->preferences()->eventNameFile()) {
+    evt.setName(shortName());
+  }
 
   // File Ptr is normally equal to offsets[0], the next statement make it sure.
   // Read all channels according to their offsets in the offsets table
@@ -602,7 +618,7 @@ bool SignalFile::loadSeg2()
       APP_LOG(2, "signal header: "+str+"\n")
       if(key=="DELAY") {
         double dt=str.section(sep, 1, 1, QString::SectionSkipEmpty).toDouble();
-        newSignal->setStartTime(e.time().shifted(dt));
+        newSignal->setStartTime(evt.time().shifted(dt));
       } else if(key=="SAMPLE_INTERVAL") {
         QString s=str.section(sep, 1, 1, QString::SectionSkipEmpty);
         if(s.count(",")==1 && !s.contains(".")) {
@@ -615,14 +631,13 @@ bool SignalFile::loadSeg2()
         double z=str.section(sep, 3, 3, QString::SectionSkipEmpty).toDouble();
         newSignal->setReceiver(Point(x, y, z));
       } else if(key=="SOURCE_LOCATION") {
-        e.setPosition(Point(str.section(sep, 1, 1, QString::SectionSkipEmpty).toDouble(),
-                            str.section(sep, 2, 2, QString::SectionSkipEmpty).toDouble(),
-                            str.section(sep, 3, 3, QString::SectionSkipEmpty).toDouble()));
-        _db->seismicEvents()->add(e);
+        evt.setPosition(Point(str.section(sep, 1, 1, QString::SectionSkipEmpty).toDouble(),
+                              str.section(sep, 2, 2, QString::SectionSkipEmpty).toDouble(),
+                              str.section(sep, 3, 3, QString::SectionSkipEmpty).toDouble()));
       } else if(key=="ARRIVAL_TIME") {  // Sardine extension to SEG2
         TimePick& tp=newSignal->beginModifyMetaData<TimePick>();
         double p=str.section(sep, 2, 2, QString::SectionSkipEmpty).toDouble();
-        tp.setValue(str.section(sep, 1, 1, QString::SectionSkipEmpty), e.time().shifted(p));
+        tp.setValue(str.section(sep, 1, 1, QString::SectionSkipEmpty), evt.time().shifted(p));
         newSignal->endModifyMetaData(tp);
       } else if(key=="NAME") {
         setSignalName(newSignal, str.section( "\n", 1, 1, QString::SectionSkipEmpty), "", i + 1, shortName());
@@ -668,6 +683,7 @@ bool SignalFile::loadSeg2()
       }
     }
     if(newSignal->name().isEmpty()) setSignalName(newSignal, "", "", i + 1, shortName());
+    _db->seismicEvents()->add(evt);
     lastSignal=newSignal;
   }
   delete [] buf;
@@ -681,7 +697,7 @@ bool SignalFile::loadSegD()
 {
   TRACE;
   QString str;
-  QVector<int> offsets;
+  VectorList<int> offsets;
 
   QFile f(_name);
   if(!f.open(QIODevice::ReadOnly)) {
@@ -690,6 +706,7 @@ bool SignalFile::loadSegD()
   }
   QFileInfo fi(_name);
   SEGDHeader h;
+  h.init();
   return false;
   // Not yet implemented
 }
@@ -807,9 +824,18 @@ bool SignalFile::loadSegY(QDataStream::ByteOrder bo)
   } else { // fixed Extended Textual, conforming rev 0 (1975)
     f.seek(binHeaderOffset+400);
   }
+
+  SeismicEvent e;
+  e.setType(SeismicEvent::Hammer);
+  e.setForce(Point(0.0, 0.0, -1.0));
+  if(GeopsyCoreEngine::instance()->preferences()->eventNameFile()) {
+    e.setName(shortName());
+  }
+
   while(!s.atEnd()) {
     qint64 sigBeginOffset=f.pos();
     SEGYTraceHeader h;
+    h.init();
     h.read(s);
     if(h.field.sampleNumber <= 0) {
       App::log(tr("Negative or null number of samples, try little and big endian\n"));
@@ -830,11 +856,8 @@ bool SignalFile::loadSegY(QDataStream::ByteOrder bo)
       newSignal->setType(Signal::Waveform);
       newSignal->setStartTime(h.startTime(SEGYTraceHeader::SEGYDelay));
       newSignal->setSamplingPeriod(( double) h.field.sampleInterval * 1.e-6);
-      SeismicEvent e;
       e.setPosition(h.source());
       e.setTime(h.startTime(SEGYTraceHeader::NoDelay));
-      e.setType(SeismicEvent::Hammer);
-      e.setForce(Point(0.0, 0.0, -1.0));
       _db->seismicEvents()->add(e);
       newSignal->setReceiver(h.receiver());
       setSignalName(newSignal, "", "", nChannels + 1, shortName());
@@ -861,9 +884,18 @@ bool SignalFile::loadSu(QDataStream::ByteOrder bo)
   QDataStream s(&f);
   s.setByteOrder(bo);
   int nChannels=0;
+
+  SeismicEvent e;
+  e.setType(SeismicEvent::Hammer);
+  e.setForce(Point(0.0, 0.0, -1.0));
+  if(GeopsyCoreEngine::instance()->preferences()->eventNameFile()) {
+    e.setName(shortName());
+  }
+
   while(!s.atEnd()) {
     qint64 sigBeginOffset=f.pos();
     SEGYTraceHeader h;
+    h.init();
     h.read(s);
     f.seek(sigBeginOffset+sizeof(SEGYTraceHeader)+4*(qint64)h.field.sampleNumber);
     if(s.status()==QDataStream::Ok) {
@@ -875,11 +907,8 @@ bool SignalFile::loadSu(QDataStream::ByteOrder bo)
       newSignal->setType(Signal::Waveform);
       newSignal->setStartTime(h.startTime(SEGYTraceHeader::SUDelay));
       newSignal->setSamplingPeriod((double) h.field.sampleInterval * 1.e-6);
-      SeismicEvent e;
       e.setPosition(h.source());
       e.setTime(h.startTime(SEGYTraceHeader::NoDelay));
-      e.setType(SeismicEvent::Hammer);
-      e.setForce(Point(0.0, 0.0, -1.0));
       _db->seismicEvents()->add(e);
       newSignal->setReceiver(h.receiver());
       newSignal->setMetaData<StackCount>(h.field.numberSumVertical);
@@ -914,6 +943,7 @@ bool SignalFile::loadPasscalSegY(QDataStream::ByteOrder bo)
   while( !s.atEnd()) {
     qint64 sigBeginOffset=f.pos();
     PasscalSegYHeader h;
+    h.init();
     h.read(s);
     f.seek(sigBeginOffset+240+h.sampleSize()*(qint64)h.nSamples());
     if(s.status()==QDataStream::Ok) {
@@ -1126,6 +1156,7 @@ bool SignalFile::loadSaf()
   comp[0]=Signal::UndefinedComponent;
   comp[1]=Signal::UndefinedComponent;
   comp[2]=Signal::UndefinedComponent;
+  bool ok=true;
   while(!s.atEnd()) {
     QString line=s.readLine();
     StringSection str(line);
@@ -1133,30 +1164,30 @@ bool SignalFile::loadSaf()
     const QChar * ptr=nullptr;
     StringSection value=str.nextField(ptr, "=");
     value.trimmed();
-    QString keyword=value.toString().toUpper();
+    QString keyword=value.toStringBuffer().toUpper();
     value=str.nextField(ptr, "=");
     value.trimmed();
     // List of accepted keywords:
     if(keyword=="STA_CODE")
-      statName=value.toString();
+      statName=value.toStringBuffer();
     else if(keyword=="START_TIME") {
       ptr=nullptr;
-      int year=value.nextField(ptr).toInt();
-      int month=value.nextField(ptr).toInt();
-      int day=value.nextField(ptr).toInt();
+      int year=value.nextField(ptr).toInt(ok);
+      int month=value.nextField(ptr).toInt(ok);
+      int day=value.nextField(ptr).toInt(ok);
       startTime.setDate(QDate(year, month, day));
-      startTime.addHours(value.nextField(ptr).toInt());
-      startTime.addMinutes(value.nextField(ptr).toInt());
-      startTime.addSeconds(value.nextField(ptr).toDouble());
+      startTime.addHours(value.nextField(ptr).toInt(ok));
+      startTime.addMinutes(value.nextField(ptr).toInt(ok));
+      startTime.addSeconds(value.nextField(ptr).toDouble(ok));
     } else if(keyword=="SAMP_FREQ")
-      sampFreq=value.toDouble();
+      sampFreq=value.toDouble(ok);
     else if(keyword=="NDAT")
-      sampNum=value.toInt();
+      sampNum=value.toInt(ok);
     else if(keyword=="CH0_ID" ||
             keyword=="CH1_ID" ||
             keyword=="CH2_ID") {
       int index=keyword.mid(2, 1).toInt();
-      QString valueStr=value.toString();
+      QString valueStr=value.toStringBuffer();
       if(valueStr.contains('N', Qt::CaseInsensitive)) {
         comp[index]=Signal::North;
       } else if(valueStr.contains('E', Qt::CaseInsensitive)) {
@@ -1165,14 +1196,18 @@ bool SignalFile::loadSaf()
                 valueStr.contains('V', Qt::CaseInsensitive)) {
         comp[index]=Signal::Vertical;
       } else {
-        App::log(tr("Unrecognized component name for SAF format: \"%1\"\n").arg(value.toString()));
+        App::log(tr("Unrecognized component name for SAF format: \"%1\"\n").arg(value.toStringView()));
       }
     } else if(keyword=="# DATA CONVERSION FACTOR")
-      convFact=value.toDouble();
+      convFact=value.toDouble(ok);
     else if(keyword=="# GEOGRAPHICAL COORDINATES")
       p.fromString(value);
-    else if(line.left(6)=="####--")
+    else if(line.left(6)=="####--") {
       break;
+    }
+    if(!ok) {
+      App::log(tr("SAF format: error reading value '%1'\n").arg(value.toStringView()));
+    }
   }
   if(sampFreq==0.0) {
     App::log(tr("Loading SAF file: bad sampling frequency\n"));
@@ -1200,6 +1235,130 @@ bool SignalFile::loadSaf()
   return true;
 }
 
+#ifdef HAS_HDF5
+bool loadFebusHDF5Error(hid_t file, hid_t dset, hid_t space)
+{
+  TRACE;
+  if(space>=0) H5Sclose(space);
+  if(dset>=0) H5Dclose(dset);
+  if(file>=0) H5Fclose(file);
+  return false;
+}
+#endif
+
+bool SignalFile::loadFebusHDF5()
+{
+  TRACE;
+#ifdef HAS_HDF5
+  // TODO : not sure that it works under Windows with special character file names
+  hid_t file, dset, space;
+  int rank;
+
+  file=H5Fopen(_name.toUtf8().data(), H5F_ACC_RDONLY, H5P_DEFAULT);
+  if(file<0) {
+    App::log(tr("Cannot open file '%1'\n").arg(_name));
+    return false;
+  }
+
+  // Get dimension of strain dataset
+  dset=H5Dopen(file, "strain", H5P_DEFAULT);
+  if(dset<0) {
+    App::log(tr("No 'strain' dataset in file '%1'\n").arg(_name));
+    return loadFebusHDF5Error(file, -1, -1);
+  }
+  space=H5Dget_space(dset);
+  rank=H5Sget_simple_extent_ndims(space);
+  if(rank!=2) {
+    App::log(tr("'strain' dataset has rank %1 instead of 2 in file '%2'\n").arg(rank).arg(_name));
+    return loadFebusHDF5Error(file, dset, space);
+  }
+  hsize_t dims[2];
+  H5Sget_simple_extent_dims(space, dims, NULL);
+  H5Sclose(space);
+  H5Dclose(dset);
+
+  // Get times
+  if(dims[0]<1) {
+    App::log(tr("Time dimension is null in file '%1'\n").arg(_name));
+    return loadFebusHDF5Error(file, dset, space);
+  }
+  dset=H5Dopen(file, "time", H5P_DEFAULT);
+  if(dset<0) {
+    App::log(tr("No 'time' dataset in file '%1'\n").arg(_name));
+    return loadFebusHDF5Error(file, -1, -1);
+  }
+  space=H5Dget_space(dset);
+  rank=H5Sget_simple_extent_ndims(space);
+  if(rank!=1) {
+    App::log(tr("'time' dataset has rank %1 instead of 1 in file '%2'\n").arg(rank).arg(_name));
+    return loadFebusHDF5Error(file, dset, space);
+  }
+  hsize_t timeDim;
+  H5Sget_simple_extent_dims(space, &timeDim, NULL);
+  if(timeDim!=dims[0]) {
+    App::log(tr("Time dimension is not consistent with strain dimensions in file '%1'\n").arg(_name));
+    return loadFebusHDF5Error(file, dset, space);
+  }
+  double * times=new double[dims[0]];
+  H5Dread(dset, H5T_NATIVE_DOUBLE, H5S_ALL, H5S_ALL, H5P_DEFAULT, times);
+  double startSecond=times[0];
+  double samplingPeriod=(times[dims[0]-1]-startSecond)/(dims[0]-1.0);
+  delete [] times;
+  H5Sclose(space);
+  H5Dclose(dset);
+
+  // Get distances
+  if(dims[1]<1) {
+    App::log(tr("Distance dimension is null in file '%1'\n").arg(_name));
+    return loadFebusHDF5Error(file, dset, space);
+  }
+  dset=H5Dopen(file, "distance", H5P_DEFAULT);
+  if(dset<0) {
+    App::log(tr("No 'distance' dataset in file '%1'\n").arg(_name));
+    return loadFebusHDF5Error(file, -1, -1);
+  }
+  space=H5Dget_space(dset);
+  rank=H5Sget_simple_extent_ndims(space);
+  if(rank!=1) {
+    App::log(tr("'distance' dataset has rank %1 instead of 1 in file '%2'\n").arg(rank).arg(_name));
+    return loadFebusHDF5Error(file, dset, space);
+  }
+  hsize_t distanceDim;
+  H5Sget_simple_extent_dims(space, &distanceDim, NULL);
+  if(distanceDim!=dims[1]) {
+    App::log(tr("Distance dimension is not consistent with strain dimensions in file '%1'\n").arg(_name));
+    return loadFebusHDF5Error(file, dset, space);
+  }
+  double * distances=new double[dims[1]];
+  H5Dread(dset, H5T_NATIVE_DOUBLE, H5S_ALL, H5S_ALL, H5P_DEFAULT, distances);
+  H5Sclose(space);
+  H5Dclose(dset);
+
+  H5Fclose(file);
+
+  DateTime startTime(QDate(2000, 1, 1), 0, 0.0);
+  startTime.addSeconds(startSecond);
+  for(uint iSig=0; iSig<dims[1]; iSig++) {
+    Signal * newSignal=new Signal(_db);
+    newSignal->setFile(this);
+    newSignal->setNumberInFile(iSig);
+    newSignal->setOffsetInFile(dims[1]);
+    newSignal->setNSamples(dims[0]);
+    newSignal->setStartTime(startTime);
+    newSignal->setSamplingPeriod(samplingPeriod);
+    newSignal->setReceiver(Point(distances[iSig], 0.0, 0.0));
+    newSignal->setType(Signal::Waveform);
+    setSignalName(newSignal, QString::number(iSig+1), "", 1, shortName());
+    newSignal->setComponent(Signal::North);
+  }
+  delete [] distances;
+  return true;
+#else
+  App::log(tr("HDF5 not supported, check configuration options.\n"));
+  return false;
+#endif
+}
+
 bool SignalFile::loadAsciiOneColumn()
 {
   TRACE;
@@ -1244,7 +1403,7 @@ bool SignalFile::loadAscii()
   TRACE;
   QFile f(_name);
   if(!f.open(QIODevice::ReadOnly)) {
-    Message::warning(MSG_ID, tr( "Loading ASCII Columns" ), tr("Unable to open file %1").arg(_name), true);
+    Message::warning(MSG_ID, tr("Loading ASCII Columns"), tr("Unable to open file %1").arg(_name), true);
     return false;
   }
   // Parse header if it exists
@@ -1315,7 +1474,7 @@ void SignalFile::warnAsciiHeader()
 {
   TRACE;
   Message::information(MSG_ID, tr("Loading ASCII Columns"),
-                       tr("The ASCII format without header imply that you fill in "
+                       tr("The ASCII format without header implies that you fill in "
                           "the correct information yourself in a table. Choose menu "
                           "\"view/new table\" and change the SamplingPeriod (or "
                           "SamplingFrequency) to allow correct plotting in a graphic"), true);
@@ -1350,7 +1509,7 @@ bool SignalFile::loadFourier()
   }
   AsciiLineParser p(&buffer, colNum);
   int lineNumber=1;
-  QVector<double> frequencies;
+  VectorList<double> frequencies;
   p.readLine();
   frequencies.append(p.toDouble(0));
 
@@ -1411,16 +1570,16 @@ bool SignalFile::loadRD3()
   // open log file
   QFileInfo finfo(_name);
   QDir d(finfo.absolutePath());
-  QString logname=d.absoluteFilePath( "radarm.log" );
+  QString logname=d.absoluteFilePath("radarm.log");
   QFile flog(logname);
   bool IgnoreLog=false;
   while(!(flog.open(QIODevice::ReadOnly) || IgnoreLog)) {
-    if(Message::warning(MSG_ID, "Loading RD3 ...",
-                                "Unable to open log file.  Ignore ?", Message::yes(), Message::no())
+    if(Message::warning(MSG_ID, tr("Loading RD3 ..."),
+                        tr("Unable to open log file.  Ignore ?"), Message::yes(), Message::no())
         ==Message::Answer0)
       IgnoreLog=true;
     else {
-      QString fileName=Message::getOpenFileName("Open RD3 log file", "Log file (*.log)");
+      QString fileName=Message::getOpenFileName(tr("Open RD3 log file"), tr("Log file (*.log)"));
       flog.setFileName(fileName);
     }
   }
@@ -2000,7 +2159,7 @@ bool SignalFile::loadEfispec3D()
   int nSamples=f.size()/40;
 
   // Get sampling period from the first and the last blocks
-  // Avoid rounding errors notes when comparing two individual lines
+  // Avoid rounding errors noted when comparing two individual lines
   s >> val;
   double t1=Number::toDouble(val);
   f.skip((nSamples-2)*40);
@@ -2061,12 +2220,13 @@ void SignalFile::setSignalName(Signal * sig, QString stationName,
                                    QString sufix, int recNum, QString fileName)
 {
   TRACE;
-  if(GeopsyCoreEngine::instance()->preferences() ->stationNameFile())
+  if(GeopsyCoreEngine::instance()->preferences()->stationNameFile())
     sig->setName(stationName + sufix);
   else if(GeopsyCoreEngine::instance()->preferences() ->stationNameRxxx()) {
     sig->setName(QString::asprintf("R%03i", recNum));
-  } else
+  } else {
     sig->setName(fileName + sufix);
+  }
 }
 
 void SignalFile::removeFile()
@@ -2100,6 +2260,7 @@ void SignalFile::xml_writeChildren(XML_WRITECHILDREN_ARGS) const
 
 XMLMember SignalFile::xml_member(XML_MEMBER_ARGS)
 {
+  Q_UNUSED(context)
   Q_UNUSED(attributes)
   if(tag=="Signal") {
     ASSERT(_db==static_cast<SignalDatabase *>(context));
@@ -2123,24 +2284,24 @@ bool SignalFile::xml_setProperty(XML_SETPROPERTY_ARGS)
   bool ok=true;
   switch(memberID) {
   case 0:
-    setName(content.toString());
+    setName(content.toStringBuffer());
     return true;
   case 1:
-    setFormat(content.toString());
+    setFormat(content.toStringBuffer());
     if(format()==SignalFileFormat(SignalFileFormat::Unknown)) {
-      App::log(tr("Unkown format '%1' for file '%2'\n").arg(content.toString()).arg(name()) );
+      App::log(tr("Unkown format '%1' for file '%2'\n").arg(content.toStringView()).arg(name()));
       return false;
     } else {
       return true;
     }
   case 2:
-    _isOriginalFile=content.toBool(&ok);
+    _isOriginalFile=content.toBool(ok);
     return ok;
   case 3:
-    _size=content.toLongLong(&ok);
+    _size=content.toLongLong(ok);
     return ok;
   case 4:
-    _crc32=content.toUInt(&ok);
+    _crc32=content.toUInt(ok);
     return ok;
   default:
     return false;
