@@ -24,6 +24,16 @@
 **
 ***************************************************************************/
 
+// This include has not the same name on all platforms
+// See admin/customconfig for the definition of macros
+#ifdef HAS_HDF5
+#  if defined(HDF5_HDF5)
+#    include <hdf5.h>
+#  elif defined(HDF5_HDF5_SERIAL_HDF5)
+#    include <hdf5/serial/hdf5.h>
+#  endif
+#endif
+
 #include "SignalFileFormat.h"
 #include "CustomFileFormats.h"
 #include "AsciiSignalFormat.h"
@@ -183,6 +193,7 @@ QString SignalFileFormat::name() const
   case MiniSeed: return "MiniSeed";
   case Fourier: return "Fourier";
   case Efispec3D: return "Efispec3D";
+  case FebusHDF5: return "FebusHDF5";
   case Custom:
     if(_customFormat) {
       return _customFormat->name();
@@ -234,6 +245,7 @@ QString SignalFileFormat::caption() const
   case MiniSeed: return tr("Mini seed");
   case Fourier: return tr("Fourier spectrum");
   case Efispec3D: return "Efispec3D";
+  case FebusHDF5: return "Febus HDF5";
   case Custom:
     if(_customFormat) {
       return _customFormat->caption();
@@ -294,6 +306,7 @@ QString SignalFileFormat::filter() const
   case MiniSeed: return "*.mseed *.msd *";
   case Fourier: return "*.fourier";
   case Efispec3D: return "*.gpl";
+  case FebusHDF5: return "*.hd5";
   }
   return "*";
 }
@@ -348,6 +361,7 @@ QString SignalFileFormat::suffix() const
   case MiniSeed: return ".mseed";
   case Fourier: return ".fourier";
   case Efispec3D: return ".gpl";
+  case FebusHDF5: return ".hd5";
   }
   return QString();
 }
@@ -425,6 +439,9 @@ SignalFileFormat SignalFileFormat::fromName(QString n)
   case 'e':
     if(n=="efispec3d") return Efispec3D;
     break;
+  case 'f':
+    if(n=="febushdf5") return FebusHDF5;
+    break;
   case 'g':
     if(n=="gse2") return Gse2;
     else if(n=="geopsysignal") return GeopsySignal;
@@ -501,6 +518,9 @@ SignalFileFormat SignalFileFormat::fromCaptionFilter(QString cf)
   case '3':
     if(cf.startsWith(tr("rd3 ramac"))) return RD3;
     break;
+  case 'b':
+    if(cf.startsWith(tr("febus hdf5"))) return FebusHDF5;
+    break;
   case 'c':
     if(cf.startsWith(tr("sac"))) {
       if(cf.startsWith(tr("sac little endian"))) return SacLittleEndian;
@@ -521,9 +541,9 @@ SignalFileFormat SignalFileFormat::fromCaptionFilter(QString cf)
     if(cf.startsWith(tr("seg"))) {
       if(cf.startsWith(tr("seg-2"))) return Seg2;
       else if(cf.startsWith(tr("seg-d"))) return SegD;
-    } else if(cf.startsWith(tr("SEGY"))) {
-      if(cf.startsWith(tr("SEGY Little Endian"))) return SegYLittleEndian;
-      if(cf.startsWith(tr("SEGY Big Endian"))) return SegYBigEndian;
+    } else if(cf.startsWith(tr("segy"))) {
+      if(cf.startsWith(tr("segy Little Endian"))) return SegYLittleEndian;
+      if(cf.startsWith(tr("segy Big Endian"))) return SegYBigEndian;
     }
     break;
   case 'f':
@@ -615,7 +635,7 @@ SignalFileFormat SignalFileFormat::fromContent(QString fileName)
   if(str.indexOf("Arrival_times_file")>-1) {
     return Tomo;
   }
-  if(str.count()>=2 && str[0]==0x55 && str[1]==0x3A) {
+  if(str.size()>=2 && str[0].unicode()==0x55 && str[1].unicode()==0x3A) {
     return Seg2;
   }
   if(str.left(4)=="WID2") {
@@ -633,16 +653,24 @@ SignalFileFormat SignalFileFormat::fromContent(QString fileName)
   if(str.left(4)=="RIFF") {
     return Wav;
   }
-  // Test simple multi-column ascii file without header
-  bool ok;
-  while(!st.atEnd() && !str.isEmpty() && str[0]=='#') {
-    str=st.readLine();
+  // Test if SAC format
+  fmt=SACHeader::determineByteOrder(fileName);
+  if(fmt.id()!=Unknown) return fmt;
+  // Testing mini seed
+  if(MiniSeedVolume::isValid(fileName)) {
+    return MiniSeed;
+  } else {
+    QFileInfo fi(fileName);
+    QString s=fi.suffix();
+    if(s=="msd" || s=="mseed" || s=="miniseed") {
+      MiniSeedVolume::nonAsciiPathError(fileName);
+      return Unknown;
+    }
   }
-  QString field=str.trimmed().simplified().section(QRegExp("[ \t]"), 0, 0);
-  field.toDouble(&ok);
-  if(ok) return Ascii;
+  // Testing Febus HDF5
+  if(isFebusHDF5(fileName)) return FebusHDF5;
+  // Testing Guralp format (at the end because there is a risk of scanning the whole file)
   f.seek(0); // reset to begin of file
-  // Testing Guralp format
   App::freeze(true);
   GuralpCompressedBlock b;
   while(!f.atEnd()) {
@@ -658,21 +686,8 @@ SignalFileFormat SignalFileFormat::fromContent(QString fileName)
   }
   f.close();
   App::freeze(false);
-  // Test if SAC format
-  fmt=SACHeader::determineByteOrder(fileName);
-  if(fmt.id()!=Unknown) return fmt;
-  // Testing mini seed
-  if(MiniSeedVolume::isValid(fileName)) {
-    return MiniSeed;
-  } else {
-    QFileInfo fi(fileName);
-    QString s=fi.suffix();
-    if(s=="msd" || s=="mseed" || s=="miniseed") {
-      MiniSeedVolume::nonAsciiPathError(fileName);
-      return Unknown;
-    }
-  }
   // Testing PASSCAL SEGY (before SU because it is more strict)
+  // But PASSCAL SEGY may read the full file... so move it to the end
   fmt=PasscalSegYHeader::determineByteOrder(fileName, 1);
   if(fmt.id()!=Unknown) return fmt;
   // Testing SEGY
@@ -681,12 +696,22 @@ SignalFileFormat SignalFileFormat::fromContent(QString fileName)
   // Testing SU
   fmt=SEGYTraceHeader::determineByteOrderSU(fileName, 1);
   if(fmt.id()!=Unknown) return fmt;
+
   // Format still not identified, use suffix
   QFileInfo finfo(fileName);
   fmt=fromSuffix(finfo.suffix());
   if(fmt.id()!=Unknown) return fmt;
   // User custom formats
   fmt=GeopsyCoreEngine::instance()->customFileFormats()->fromContent(fileName);
+  if(fmt.id()!=Unknown) return fmt;
+  // Test simple multi-column ascii file without header
+  bool ok;
+  while(!st.atEnd() && !str.isEmpty() && str[0]=='#') {
+    str=st.readLine();
+  }
+  QString field=str.trimmed().simplified().section(QRegularExpression("[ \t]"), 0, 0);
+  field.toDouble(&ok);
+  if(ok) return Ascii;
   return fmt;
 }
 
@@ -725,6 +750,11 @@ SignalFileFormat SignalFileFormat::fromSuffix(QString suffix)
         fmt=Efispec3D;
       }
       break;
+    case 'h':
+      if(suffix=="hd5") {
+        fmt=FebusHDF5;
+      }
+      break;
     case 'm':
       if(suffix=="msd" || suffix=="mseed") {
         fmt=MiniSeed;
@@ -741,7 +771,7 @@ SignalFileFormat SignalFileFormat::fromSuffix(QString suffix)
       }
       break;
     case 's':
-      switch(suffix.count()) {
+      switch(suffix.size()) {
       case 2:
         if(suffix=="su" ) {
           #if Q_BYTE_ORDER==Q_BIG_ENDIAN
@@ -864,4 +894,40 @@ SignalFileFormat::Storage SignalFileFormat::storage() const
   }
 }
 
+bool SignalFileFormat::isFebusHDF5(const QString& fileName)
+{
+#ifdef HAS_HDF5
+  hid_t file, dset;
+
+  file=H5Fopen(fileName.toUtf8().data(), H5F_ACC_RDONLY, H5P_DEFAULT);
+  if(file<0) {
+    return false;
+  }
+  dset=H5Dopen(file, "strain", H5P_DEFAULT);
+  if(dset<0) {
+    H5Fclose(file);
+    return false;
+  }
+  H5Dclose(dset);
+  dset=H5Dopen(file, "time", H5P_DEFAULT);
+  if(dset<0) {
+    H5Fclose(file);
+    return false;
+  }
+  H5Dclose(dset);
+  dset=H5Dopen(file, "distance", H5P_DEFAULT);
+  if(dset<0) {
+    H5Fclose(file);
+    return false;
+  }
+  H5Dclose(dset);
+  H5Fclose(file);
+  return true;
+#else
+  Q_UNUSED(fileName)
+  App::log(1, tr("HDF5 not supported, check configuration options.\n"));
+  return false;
+#endif
+}
+
 } // namespace GeopsyCore
