@@ -76,6 +76,7 @@ public:
     Custom,
     Fourier,
     Efispec3D,
+    FebusHDF5,
     FormatCount  // Must be the last one, used to count the available file formats
   };
   enum Storage {Single, Multi};
@@ -105,6 +106,8 @@ public:
   static SignalFileFormat fromCaptionFilter(QString cf);
   static QList< QPair<QString, SignalFileFormat> > importList();
   static QList< QPair<QString, SignalFileFormat> > exportList();
+
+  static bool isFebusHDF5(const QString& fileName);
 private:
   Format _id;
   AbstractFileFormat * _customFormat;
@@ -126,6 +129,7 @@ private:
   case SignalFileFormat::Fourier: \
   case SignalFileFormat::FormatCount: \
   case SignalFileFormat::Efispec3D: \
+  case SignalFileFormat::FebusHDF5: \
   case SignalFileFormat::Unknown:
 
 } // namespace GeopsyCore
