@@ -116,7 +116,7 @@ namespace GeopsyCore {
     TRACE;
     _signals=subPool;
     if(name().isEmpty()) {
-      if(_signals.name().count()<40) { // Avoid long names like "Selected from..."
+      if(_signals.name().size()<40) { // Avoid long names like "Selected from..."
         setName(_signals.name());
       }
     } else {
@@ -164,16 +164,17 @@ namespace GeopsyCore {
     switch(memberID) {
     case 0: {
         if(!_ids) {   // Multiple <ids> tags are merge together
-          _ids=new QVector<int>;
+          _ids=new VectorList<int>;
         }
         static const QString sep=" \n\t\r";
         const QChar * ptr=0;
         StringSection f=content.nextField(ptr, sep, true);
+        bool ok=true;
         while(f.isValid()) {
-          _ids->append(f.toInt());
+          _ids->append(f.toInt(ok));
           f=content.nextField(ptr, sep, true);
         }
-        return true;
+        return ok;
       }
     default:
       return AbstractSignalGroup::xml_setProperty(memberID-1, tag, attributes, content, context);
@@ -201,7 +202,7 @@ namespace GeopsyCore {
     QFile f(dbPath.absoluteFilePath(name()+".group"));
     if(f.open(QIODevice::ReadOnly)) {
       if(!_ids) {
-        _ids=new QVector<int>;
+        _ids=new VectorList<int>;
       }
       QDataStream s(&f);
       if(dbVersion==1) {
@@ -227,7 +228,7 @@ namespace GeopsyCore {
     TRACE;
     if(_ids) {
       _signals.removeAll();
-      for(QVector<int>::iterator it=_ids->begin(); it!=_ids->end(); it++) {
+      for(VectorList<int>::iterator it=_ids->begin(); it!=_ids->end(); it++) {
         QHash<int, Signal *>::const_iterator itHash=ids.find(*it);
         if(itHash==ids.end()) {
           App::log(tr("Group '%1': unknow signal ID %2\n").arg(pathName()).arg(*it) );
