@@ -67,7 +67,7 @@ namespace GeopsyCore {
     XMLMember xml_member(XML_MEMBER_ARGS);
   private:
     SubSignalPool _signals;
-    QVector<int> * _ids;
+    VectorList<int> * _ids;
   };
 
 } // namespace GeopsyCore
