@@ -54,15 +54,24 @@ namespace GeopsyCore {
 
 
     int n=subPool->count();
+    if(n>10) {
+      _db=subPool->database();
+    } else {
+      _db=nullptr;
+    }
     QJSValue list, sig;
     list=_engine->newArray(n);
     _engine->globalObject().setProperty("signals", list);
-    for(int i=0; i<n; i++) {
-      SignalHeaderObject * obj=new SignalHeaderObject(subPool->at(i), this);
-      connect(obj, SIGNAL(beginSignalChange(Signal*)), this, SIGNAL(beginSignalChange(Signal*)));
-      connect(obj, SIGNAL(endSignalChange(Signal*)), this, SIGNAL(endSignalChange(Signal*)));
-      sig=_engine->newQObject(obj);
-      list.setProperty(i, sig);
+    if(_db) {
+      for(int i=0; i<n; i++) {
+        SignalHeaderObject * obj=new SignalHeaderObject(subPool->at(i), this);
+        if(n<10) {
+          connect(obj, SIGNAL(beginSignalChange(Signal*)), this, SIGNAL(beginSignalChange(Signal*)));
+          connect(obj, SIGNAL(endSignalChange(Signal*)), this, SIGNAL(endSignalChange(Signal*)));
+        }
+        sig=_engine->newQObject(obj);
+        list.setProperty(i, sig);
+      }
     }
   }
 
@@ -70,16 +79,24 @@ namespace GeopsyCore {
   {
     TRACE;
     APP_LOG(1, tr("Starting execution of header script...\n"))
+    if(_db) {
+      emit beginSignalChange(_db);
+    }
     QJSValue ret=_engine->evaluate(script);
+    bool retValue;
     if(ret.isError()) {
       App::log(tr("Uncaught exception at line %1:\n %2\n")
                        .arg(ret.property("lineNumber").toInt())
                        .arg(ret.toString()));
-      return false;
+      retValue=false;
     } else {
       APP_LOG(1, tr("Header script executed successfully.\n"))
-      return true;
+      retValue=true;
     }
+    if(_db) {
+      emit endSignalChange(_db);
+    }
+    return retValue;
   }
 
 } // namespace GeopsyCore
