@@ -76,7 +76,7 @@ namespace GeopsyCore {
     TRACE;
     if(_process) {
       bool ok=true;
-      DoubleSignal::SignalType t=DoubleSignal::type(signalType, &ok);
+      DoubleSignal::SignalType t=DoubleSignal::convertSignalType(signalType, ok);
       if(ok) {
         _process->fastFourierTransform(t);
       } else {
@@ -100,6 +100,16 @@ namespace GeopsyCore {
     }
   }
 
+  bool SignalProcessObject::saveDatabase(QString filePath)
+  {
+    TRACE;
+    if(_process) {
+      return _process->saveDatabase(filePath);
+    } else {
+      return false;
+    }
+  }
+
   QVariant SignalProcessObject::header(int signalIndex, QString dataIndex)
   {
     TRACE;
@@ -190,9 +200,14 @@ namespace GeopsyCore {
   {
     TRACE;
     if(_process) {
+      bool ok=true;
       FilterParameters param;
-      param.setMethod(method);
-      param.setBand(band);
+      param.setMethod(FilterParameters::convertMethod(method, ok));
+      param.setBand(FilterParameters::convertBand(band, ok));
+      if(!ok) {
+        App::log(tr("Bad filter method or band."));
+        return;
+      }
       param.setFrequencyRange(fmin, fmax);
       switch(param.method()) {
       case FilterParameters::Butterworth: {
