@@ -56,6 +56,7 @@ SignalProcessScript::SignalProcessScript(SignalProcess * process)
 
   _engine->globalObject().setProperty("fastFourierTransfrom", extension.property("fastFourierTransfrom"));
   _engine->globalObject().setProperty("exportFile", extension.property("exportFile"));
+  _engine->globalObject().setProperty("saveDatabase", extension.property("saveDatabase"));
   _engine->globalObject().setProperty("header", extension.property("header"));
   _engine->globalObject().setProperty("setHeader", extension.property("setHeader"));
   _engine->globalObject().setProperty("signalCount", extension.property("signalCount"));
@@ -79,6 +80,7 @@ SignalProcessScript::SignalProcessScript(SignalProcess * process)
   _engine->globalObject().setProperty("mergeStations", extension.property("mergeStations"));
   _engine->globalObject().setProperty("decimateAmplitude", extension.property("decimateAmplitude"));
   _engine->globalObject().setProperty("decimateTime", extension.property("decimateTime"));
+  _engine->globalObject().setProperty("gapsFromNaN", extension.property("gapsFromNaN"));
 
   _engine->globalObject().setProperty("waveletTransform", extension.property("waveletTransform"));
   _engine->globalObject().setProperty("stalta", extension.property("stalta"));
