@@ -45,12 +45,6 @@ SparseTimeRange::SparseTimeRange()
   _n2=1;
 }
 
-SparseTimeRange::SparseTimeRange(const SparseTimeRange& r)
-    : QVector<TimeRange>(r)
-{
-  _n2=r._n2;
-}
-
 SparseTimeRange::SparseTimeRange(const TimeRange& r)
 {
   _n2=1;
@@ -120,7 +114,7 @@ int SparseTimeRange::remove(int& index, const TimeRange& r)
     for(int i=index;i<count() && at(i).end()<r.end(_epsilon);i++) {
       nRemoved++;
     }
-    QVector<TimeRange>::remove(index, nRemoved);
+    VectorList<TimeRange>::remove(index, nRemoved);
     int lowerN2=_n2 >> 1;
     while(count()<lowerN2) {
       _n2=lowerN2;
@@ -534,25 +528,25 @@ void SparseTimeRange::add(const TimeRange& r, bool acceptOverlap)
 
 void SparseTimeRange::clear()
 {
-  QVector<TimeRange>::clear();
+  VectorList<TimeRange>::clear();
   _n2=1;
 }
 
 void SparseTimeRange::append(const TimeRange& r)
 {
-  QVector<TimeRange>::append(r);
+  VectorList<TimeRange>::append(r);
   if(count()==_n2) _n2=_n2 << 1;
 }
 
 void SparseTimeRange::insert(int before, const TimeRange& r)
 {
-  QVector<TimeRange>::insert(before, r);
+  VectorList<TimeRange>::insert(before, r);
   if(count()==_n2) _n2=_n2 << 1;
 }
 
 void SparseTimeRange::remove(int index)
 {
-  QVector<TimeRange>::remove(index);
+  VectorList<TimeRange>::remove(index);
   int lowerN2=_n2 >> 1;
   if(count()<lowerN2) _n2=lowerN2;
 }
@@ -645,13 +639,13 @@ void SparseTimeRange::printDebug() const
 /*!
   Split into continuous TimeRange with min/max length specifications.
 */
-QVector<TimeRange> SparseTimeRange::split(double minLength, double maxLength) const
+VectorList<TimeRange> SparseTimeRange::split(double minLength, double maxLength) const
 {
   TRACE;
   if(maxLength==0.0) {
     maxLength=std::numeric_limits<double>::infinity();
   }
-  QVector<TimeRange> res;
+  VectorList<TimeRange> res;
   for(const_iterator it=begin(); it!=end(); it++) {
     TimeRange r=*it;
     while(r.lengthSeconds()>maxLength) {
