@@ -54,7 +54,7 @@ SubSignalPool::SubSignalPool(const SubSignalPool& subPool)
 {
   TRACE;
   for(iterator it=begin(); it!=end(); ++it) {
-    ( *it) ->addReference();
+    (*it)->addReference();
   }
 }
 
@@ -293,7 +293,50 @@ void SubSignalPool::removeTrend()
   }
 }
 
-void SubSignalPool::subtractSignal(Signal * bysig)
+void SubSignalPool::signalOperationAdd(Signal *bysig)
+{
+  TRACE;
+  // Make sure all signals are in time series
+  fastFourierTransform(Signal::Waveform);
+  bool bySigIncludedInSubpool=false;
+  SubSignalPoolProcess cp(*this);
+  bysig->constLockSamples();
+  for(iterator it=begin(); it!=end(); ++it) {
+    Signal * sig=* it;
+    if(sig!=bysig) { // avoid bysig to zeroed, postponed to the end
+      if( !sig->warnReadOnlySamples()) {
+        sig->addSignal(bysig);
+      }
+    } else {
+      bySigIncludedInSubpool=true;
+    }
+    cp.next();
+  }
+  bysig->unlockSamples();
+  if(bySigIncludedInSubpool) { // Set it to 0
+    if(!bysig->warnReadOnlySamples()) {
+      bysig->setValue(0.0);
+    }
+  }
+}
+
+void SubSignalPool::signalOperationAdd(SubSignalPool * bySubPool)
+{
+  TRACE;
+  if(count()!=bySubPool->count())
+    return ;
+  // Make sure all signals are in time series
+  fastFourierTransform(Signal::Waveform);
+  for(int i=0; i < count(); ++i) {
+    Signal * sig=at(i);
+    Signal * bysig=bySubPool->at(i);
+    if(!sig->warnReadOnlySamples()) {
+      sig->addSignal(bysig);
+    }
+  }
+}
+
+void SubSignalPool::signalOperationSubtract(Signal *bysig)
 {
   TRACE;
   // Make sure all signals are in time series
@@ -320,7 +363,7 @@ void SubSignalPool::subtractSignal(Signal * bysig)
   }
 }
 
-void SubSignalPool::subtractSignals(SubSignalPool * bySubPool)
+void SubSignalPool::signalOperationSubtract(SubSignalPool * bySubPool)
 {
   TRACE;
   if(count()!=bySubPool->count())
@@ -503,14 +546,14 @@ bool SubSignalPool::mergeStations()
       }
       ++it;
     } else {
-      if( ! toMerge.merge()) return false;
+      if(!toMerge.merge()) return false;
       merged.addSignal(toMerge.first());
       toMerge.removeAll();
       samplingPeriod=0;
     }
   }
-  if( !toMerge.isEmpty()) {
-    if( ! toMerge.merge()) return false;
+  if(!toMerge.isEmpty()) {
+    if(!toMerge.merge()) return false;
     merged.addSignal(toMerge.first());
   }
   *this=merged;
@@ -782,6 +825,31 @@ void SubSignalPool::decimateTime(int factor)
   *this=decimatedSignals;
 }
 
+/*!
+  Generate random signals
+*/
+void SubSignalPool::random(double maxAmplitude, Random * generator)
+{
+  TRACE;
+  // Make sure all signals are in time series
+  fastFourierTransform(Signal::Waveform);
+
+  SignalDatabase * db=database();
+  Random * myGenerator;
+  if(generator) {
+    myGenerator=nullptr;
+  } else {
+    myGenerator=new Random;
+    generator=myGenerator;
+  }
+  GeopsyCoreEngine::instance()->setProgressMaximum(db, count()-1);
+  for(int i=0; i<count(); ++i) {
+    at(i)->random(maxAmplitude, generator);
+    GeopsyCoreEngine::instance()->setProgressValue(db, i);
+  }
+  delete myGenerator;
+}
+
 void SubSignalPool::fastFourierTransform(DoubleSignal::SignalType st)
 {
   TRACE;
@@ -820,10 +888,10 @@ void SubSignalPool::importTable(QString fileName)
   strItem=strLine.nextField(ptr, "\t" );
   bool doSamplingPeriod=false;
   while(strItem.isValid()) {
-    varItem=MetaDataFactory::instance()->index(strItem.toString());
+    varItem=MetaDataFactory::instance()->index(strItem.toStringBuffer());
     if(!varItem.isValid()) {
       Message::warning(MSG_ID, tr("Importing Table ..."),
-                       tr("Unrecognized meta data: '%1'").arg(strItem.toString()),
+                       tr("Unrecognized meta data: '%1'").arg(strItem.toStringView()),
                        Message::cancel());
       return;
     }
@@ -861,7 +929,7 @@ void SubSignalPool::importTable(QString fileName)
     strItem=strLine.nextField(ptr, "\t" );
     for(MetaDataFieldList::iterator itvar=varList.begin();itvar!=varList.end();++itvar) {
       if(itvar->id()!=MetaDataFactory::SamplingPeriod || doSamplingPeriod) {
-        sig->setHeader(*itvar, strItem.toString());
+        sig->setHeader(*itvar, strItem.toStringBuffer());
       }
       strItem=strLine.nextField(ptr, "\t" );
     }
@@ -890,7 +958,7 @@ void SubSignalPool::exportTable(QString fileName, const MetaDataFieldList& param
   for(itvar=param.begin();itvar!=param.end();++itvar) {
     s << MetaDataFactory::instance()->name(*itvar) << "\t";
   }
-  s << endl;
+  s << Qt::endl;
   for(iterator it=begin(); it!=end(); ++it) {
     Signal * sig=*it;
     for (itvar=param.begin(); itvar!=param.end(); ++itvar) {
@@ -904,7 +972,7 @@ void SubSignalPool::exportTable(QString fileName, const MetaDataFieldList& param
       }
       s << str << "\t";
     }
-    s << endl;
+    s << Qt::endl;
   }
 }
 
@@ -1229,7 +1297,7 @@ QHash<const SeismicEvent *, SubSignalPool *> SubSignalPool::associateSources()
     Signal * sig=at(i);
     sources=database()->seismicEvents()->events(sig);
     if(sources.isEmpty()) {
-      App::log(tr("No source found for signal %i\n").arg(sig->nameComponent()));
+      App::log(tr("No source found for signal %1\n").arg(sig->nameComponent()));
     }
     for(int i=sources.count()-1; i>=0; i--) {
       const SeismicEvent * source=sources.at(i);
@@ -1254,7 +1322,7 @@ QHash<const SeismicEvent *, SubSignalPool *> SubSignalPool::associateSources()
       distances.insert(src.distanceTo(subPool->at(i)->receiver()),
                        subPool->at(i));
     }
-    subPool->clear();
+    subPool->removeAll();
     QMap<double, Signal *>::iterator it;
     for(it=distances.begin(); it!=distances.end(); it++) {
       subPool->addSignal(it.value());
@@ -1510,10 +1578,12 @@ bool SubSignalPool::save(QString filePath, bool useOriginalBaseName, SignalFileF
       App::log(tr("Format %1 is currently not supported for export.\n").arg(format.name()) );
       return false;
     }
-    if(format.customFormat()->storage()==SignalFileFormat::Single) {
-      break;
+    // custom format with export capabilities of multiple signal in one file
+    if(format.customFormat()->storage()==SignalFileFormat::Multi) {
+      if(!exportFilePath(filePath, useOriginalBaseName, format)) return false;
     }
-    // Else custom format with export capabilities of multiple signal in one file
+    break;
+    // For multi signal formats
   case SignalFileFormat::Seg2:
   case SignalFileFormat::SuLittleEndian:
   case SignalFileFormat::SuBigEndian:
@@ -1529,20 +1599,7 @@ bool SubSignalPool::save(QString filePath, bool useOriginalBaseName, SignalFileF
   case SignalFileFormat::Wav:
   case SignalFileFormat::CityShark2:
   case SignalFileFormat::MiniSeed:
-    // For multi signal formats
     if(!exportFilePath(filePath, useOriginalBaseName, format)) return false;
-    if(useOriginalBaseName){
-      QFileInfo fi(filePath);
-      QString newFilePath=File::uniqueName(fi.fileName(), fi.path());
-      if(newFilePath!=filePath) {
-        if(Message::warning(MSG_ID, tr("Exporting signals"), tr("File %1 already exists, saving to %2?").arg(filePath).arg(newFilePath),
-                            Message::yes(), Message::no())==Message::Answer1) {
-          return false;
-        }
-        App::log(tr("File %1 already exists, saving to %2\n").arg(filePath).arg(newFilePath) );
-        filePath=newFilePath;
-      }
-    }
     break;
   case SignalFileFormat::SacLittleEndian:
   case SignalFileFormat::SacBigEndian:
@@ -1606,35 +1663,46 @@ bool SubSignalPool::save(QString filePath, bool useOriginalBaseName, SignalFileF
 bool SubSignalPool::exportFilePath(QString& filePath, bool useOriginalBaseName, const SignalFileFormat& format) const
 {
   TRACE;
-  if(!useOriginalBaseName) return true;
-  if(isEmpty()) {
-    Message::warning(MSG_ID, tr("Export %1").arg(format.caption()),
-                     tr("No signal to deduce a common file name, cannot use option 'original base name'." ), Message::cancel());
-    return false;
-  }
-  const_iterator it=begin();
-  SignalFile * file=(*it)->file();
-  if(!file) {
-    Message::warning(MSG_ID, tr("Export %1").arg(format.caption()),
-                     tr("Cannot deduce file name from temporary signals, cannot use option 'original base name'." ), Message::cancel());
-    return false;
-  }
-  QString fileName=file->shortName();
-  for(it++; it!=end(); it++) {
-    file=(*it)->file();
-    if(fileName!=file->shortName()) {
+  if(useOriginalBaseName) {
+    if(isEmpty()) {
       Message::warning(MSG_ID, tr("Export %1").arg(format.caption()),
-                           tr("No common file name, cannot use option 'original base name'.\n\n"
-                              "A solution is probably to split the list of signals to export by setting "
-                              "'maximum number of signals per file'."), Message::cancel());
+                       tr("No signal to deduce a common file name, cannot use option 'original base name'." ), Message::cancel());
       return false;
     }
-  }
-  if(format.suffix().isEmpty()) {
-    filePath+="/"+fileName;
-  } else {
-    QFileInfo fi(fileName);
-    filePath+="/"+fi.baseName()+format.suffix();
+    const_iterator it=begin();
+    SignalFile * file=(*it)->file();
+    if(!file) {
+      Message::warning(MSG_ID, tr("Export %1").arg(format.caption()),
+                       tr("Cannot deduce file name from temporary signals, cannot use option 'original base name'." ), Message::cancel());
+      return false;
+    }
+    QString fileName=file->shortName();
+    for(it++; it!=end(); it++) {
+      file=(*it)->file();
+      if(fileName!=file->shortName()) {
+        Message::warning(MSG_ID, tr("Export %1").arg(format.caption()),
+                             tr("No common file name, cannot use option 'original base name'.\n\n"
+                                "A solution is probably to split the list of signals to export by setting "
+                                "'maximum number of signals per file'."), Message::cancel());
+        return false;
+      }
+    }
+    if(format.suffix().isEmpty()) {
+      filePath+="/"+fileName;
+    } else {
+      QFileInfo fi(fileName);
+      filePath+="/"+fi.baseName()+format.suffix();
+    }
+    QFileInfo fi(filePath);
+    QString newFilePath=File::uniqueName(fi.fileName(), fi.path());
+    if(newFilePath!=filePath) {
+      if(Message::warning(MSG_ID, tr("Exporting signals"), tr("File %1 already exists, saving to %2?").arg(filePath).arg(newFilePath),
+                          Message::yes(), Message::no())==Message::Answer1) {
+        return false;
+      }
+      App::log(tr("File %1 already exists, saving to %2\n").arg(filePath).arg(newFilePath));
+      filePath=newFilePath;
+    }
   }
   return true;
 }
@@ -1948,6 +2016,7 @@ bool SubSignalPool::saveSegY(QString filePath, QDataStream::ByteOrder bo) const
   s.setFloatingPointPrecision(QDataStream::SinglePrecision);
   s.setByteOrder(bo);
   SEGYHeader hdr;
+  hdr.init();
   hdr.write(s);
   for(int i=0; i<count(); i++) {
     if(!at(i)->writeSegySu(s, i, false)) {
@@ -1971,20 +2040,26 @@ bool SubSignalPool::saveSac(QString filePath, bool useOriginalBaseName, QDataStr
     GeopsyCoreEngine::instance()->setProgressValue(db, i);
     Signal * sig=at(i);
     QString completefilePath;
-    if(useOriginalBaseName && sig->file()) {
-      QString tmp=sig->file()->shortName();
-      // Removes extension but not numbers like .009 found in Cityshark file names.
-      if(tmp.contains(QRegExp("\\.[a-zA-Z]+[0-9]*$"))) {
-        QFileInfo fi(tmp);
-        tmp=fi.completeBaseName();
+    if(useOriginalBaseName) {
+      if(sig->file() && sig->file()->format().storage()==SignalFileFormat::Single) {
+        QString tmp=sig->file()->shortName();
+        // Removes extension but not numbers like .009 found in Cityshark file names.
+        if(tmp.contains(QRegularExpression("\\.[a-zA-Z]+[0-9]*$"))) {
+          QFileInfo fi(tmp);
+          tmp=fi.completeBaseName();
+        }
+        QString compSuffix="_"+Signal::componentLetter(sig->component());
+        if(!tmp.endsWith(compSuffix)) {
+          tmp+=compSuffix;
+        }
+        tmp+=".sac";
+        completefilePath=File::uniqueName(tmp, filePath);
+      } else if(!sig->name().isEmpty()) {
+        QDir d(filePath);
+        completefilePath=d.absoluteFilePath(sig->name()+"_"+Signal::componentLetter(sig->component()));
       }
-      QString compSuffix="_"+Signal::componentLetter(sig->component());
-      if(!tmp.endsWith(compSuffix)) {
-        tmp+=compSuffix;
-      }
-      tmp+=".sac";
-      completefilePath=File::uniqueName(tmp,filePath);
-    } else {
+    }
+    if(completefilePath.isEmpty()) {
       if(n>1) {
         QFileInfo fi(filePath);
         completefilePath=File::uniqueName(fi.fileName(),fi.path());
@@ -2129,12 +2204,12 @@ bool SubSignalPool::saveWav(QString filePath) const
   double satFac=32768.0/maxAll; // avoid saturation and non integer values
   // Fill in header information
   WaveHeader wavinfo;
-  strncpy(wavinfo.chunkID, "RIFF", 4);
-  strncpy(wavinfo.format, "WAVE", 4);
-  strncpy(wavinfo.subchunk1ID, "fmt ", 4);
+  memcpy(wavinfo.chunkID, "RIFF", 4);
+  memcpy(wavinfo.format, "WAVE", 4);
+  memcpy(wavinfo.subchunk1ID, "fmt ", 4);
   wavinfo.subchunk1Size=16;
   wavinfo.audioFormat=1;
-  strncpy(wavinfo.subchunk2ID, "data", 4);
+  memcpy(wavinfo.subchunk2ID, "data", 4);
   wavinfo.bitsPerSample=16;
   wavinfo.numChannels=static_cast<qint16>(count());
   wavinfo.sampleRate=qRound(first()->samplingFrequency());
@@ -2274,43 +2349,44 @@ bool SubSignalPool::saveCityShark2(QString filePath) const
   QTextStream s(&f);
   // Some header information can be available in comments
   QString cmt=first()->metaData<Comments>().value();
-  QRegExp cmtGrep;
+  QRegularExpression cmtGrep;
+  QRegularExpressionMatch match;
   cmtGrep.setPattern("Station serial number *: *([0-9]+)");
-  cmtGrep.indexIn(cmt);
-  QString stationSerialNumber=cmtGrep.cap(1);
+  match=cmtGrep.match(cmt);
+  QString stationSerialNumber=match.captured(1);
   cmtGrep.setPattern("Station software version *: *([0-9]+)");
-  cmtGrep.indexIn(cmt);
-  QString stationSoftwareVersion=cmtGrep.cap(1);
+  match=cmtGrep.match(cmt);
+  QString stationSoftwareVersion=match.captured(1);
   cmtGrep.setPattern("Ending date *: *([0-9\\.]+)");
-  cmtGrep.indexIn(cmt);
-  QString endingDate=cmtGrep.cap(1);
+  match=cmtGrep.match(cmt);
+  QString endingDate=match.captured(1);
   cmtGrep.setPattern("Ending time *: *([0-9:\\.]+)");
-  cmtGrep.indexIn(cmt);
-  QString endingTime=cmtGrep.cap(1);
+  match=cmtGrep.match(cmt);
+  QString endingTime=match.captured(1);
   cmtGrep.setPattern("Recording duration *: *([0-9]+) *mn");
-  cmtGrep.indexIn(cmt);
-  QString duration=cmtGrep.cap(1);
+  match=cmtGrep.match(cmt);
+  QString duration=match.captured(1);
   cmtGrep.setPattern("Clipped samples *: *([0-9\\.]+) *%");
-  cmtGrep.indexIn(cmt);
-  double clippedSamples=cmtGrep.cap(1).toDouble();
+  match=cmtGrep.match(cmt);
+  double clippedSamples=match.captured(1).toDouble();
   cmtGrep.setPattern("Latitude *: *([0-9\\. NS]+)");
-  cmtGrep.indexIn(cmt);
-  QString latitude=cmtGrep.cap(1);
+  match=cmtGrep.match(cmt);
+  QString latitude=match.captured(1);
   cmtGrep.setPattern("Longitude *: *([0-9\\. EW]+)");
-  cmtGrep.indexIn(cmt);
-  QString longitude=cmtGrep.cap(1);
+  match=cmtGrep.match(cmt);
+  QString longitude=match.captured(1);
   cmtGrep.setPattern("Altitude *: *([0-9]+) *m");
-  cmtGrep.indexIn(cmt);
-  QString altitude=cmtGrep.cap(1);
+  match=cmtGrep.match(cmt);
+  QString altitude=match.captured(1);
   cmtGrep.setPattern("No. satellites *: *([0-9]+)");
-  cmtGrep.indexIn(cmt);
-  QString numSatellites=cmtGrep.cap(1);
+  match=cmtGrep.match(cmt);
+  QString numSatellites=match.captured(1);
   cmtGrep.setPattern("Maximum amplitude *: *([0-9 /]+)");
-  cmtGrep.indexIn(cmt);
-  QString maxAmplitude=cmtGrep.cap(1);
+  match=cmtGrep.match(cmt);
+  QString maxAmplitude=match.captured(1);
   cmtGrep.setPattern("Gain *: *([0-9]+)");
-  cmtGrep.indexIn(cmt);
-  int gain=cmtGrep.cap(1).toInt();
+  match=cmtGrep.match(cmt);
+  int gain=match.captured(1).toInt();
   DateTime startTime=first()->startTime();
   double countPervolt=CitySignal::conversionFactor(qRound(first()->samplingFrequency()), gain);
   // Note that conversion factor stored in the text header does not contain
@@ -2409,7 +2485,7 @@ bool SubSignalPool::saveSaf(QString filePath) const
       } else {
         if(!triplet.saveOneSaf(filePath)) return false;
       }
-      triplet.clear();
+      triplet.removeAll();
       samplingPeriod=sig->samplingPeriod();
       nSamp=sig->nSamples();
       startTime=sig->startTime();
@@ -2652,4 +2728,22 @@ DateTime SubSignalPool::lastTimePick(const QString& timePick) const
   return max;
 }
 
+VectorList<const SeismicEvent *> SubSignalPool::pickEvents(const PickParameters& param) const
+{
+  VectorList<const SeismicEvent *>  events;
+  for(SubSignalPool::const_iterator it=begin(); it!=end(); it++) {
+    const Signal * sig=*it;
+    events.append(sig->pickEvents(param));
+  }
+  return events;
+}
+
+void SubSignalPool::gapsFromNaN()
+{
+  for(SubSignalPool::iterator it=begin(); it!=end(); it++) {
+    Signal * sig=*it;
+    sig->gapsFromNaN();
+  }
+}
+
 } // namespace GeopsyCore
