@@ -34,6 +34,7 @@
 #include "GeoSignal.h"
 #include "SortKey.h"
 #include "TimeRangeParameters.h"
+#include "PickParameters.h"
 
 namespace GeopsyCore {
 
@@ -117,8 +118,10 @@ namespace GeopsyCore {
     // Signal processing
     void subtractValue(double val=0.0);
     void removeTrend();
-    void subtractSignal(Signal * bysig);
-    void subtractSignals(SubSignalPool * bySubPool);
+    void signalOperationAdd(Signal * bysig);
+    void signalOperationAdd(SubSignalPool * bySubPool);
+    void signalOperationSubtract(Signal * bysig);
+    void signalOperationSubtract(SubSignalPool * bySubPool);
     void filter(const FilterParameters& param);
     void waveletTransform(const MorletParameters& param);
     void shift(double dt);
@@ -138,11 +141,14 @@ namespace GeopsyCore {
     bool removeInstrumentalResponse(const InstrumentalResponse& sensor);
     void decimateAmplitude(int maxCount, double maxRef);
     void decimateTime(int factor);
+    void random(double maxAmplitude, Random * generator=nullptr);
     void fastFourierTransform(DoubleSignal::SignalType st);
     void discreteFourierTransform();
     void importTable(QString fileName);
     void exportTable(QString fileName, const MetaDataFieldList& param);
     void unglitch(double threshold);
+    void gapsFromNaN();
+    VectorList<const SeismicEvent *> pickEvents(const PickParameters& param) const;
     int checkDuplicateRays();
     void rotateComponents(Matrix3x3 rotMatrix);
     bool associate3Components();
