@@ -59,14 +59,17 @@ namespace GeopsyCore {
   {
     TRACE;
     delete _function;
+    if(windowFirstSample<windowLastSample) {
 #ifdef COMPATIBILITY_2_5_0
-    _function=new WindowFunction(windowLastSample-windowFirstSample+2, *_parameters);
+      _function=new WindowFunction(windowLastSample-windowFirstSample+2, *_parameters);
 #else
-    _function=new WindowFunction(windowLastSample-windowFirstSample+1, *_parameters);
+      _function=new WindowFunction(windowLastSample-windowFirstSample+1, *_parameters);
 #endif
-    ASSERT(windowFirstSample<=windowLastSample);
-    _function->setStartIndex(windowFirstSample);
-    _function->setSignalRange(signalFirstSample, signalLastSample);
+      _function->setStartIndex(windowFirstSample);
+      _function->setSignalRange(signalFirstSample, signalLastSample);
+    } else {
+      _function=nullptr;
+    }
   }
 
   void TaperDelegate::createFunction(double start, double end,
