@@ -45,6 +45,7 @@ namespace GeopsyCore {
                         double samplingFrequency, int nSamples);
     double correctionFactor() const {return _function->correctionFactor();}
 
+    bool isValid() const {return _function;}
     template<typename sampleType>
     void apply(sampleType samples) const;
 
@@ -103,7 +104,7 @@ namespace GeopsyCore {
   void TaperDelegate::apply(sampleType samples) const
   {
     TRACE;
-    const QVector<WindowFunction::Action>& actions=_function->actions();
+    const VectorList<WindowFunction::Action>& actions=_function->actions();
     int n=actions.count();
     int index;
     for(int i=0; i<n; i++) {
