@@ -76,7 +76,7 @@ TimeRange TimeRangeList::timeRange() const
   if(isEmpty()) return TimeRange();
   const_iterator it=begin();
   TimeRange globalRange=**it;
-  for(it++;it!=end();++it) {
+  for(it++; it!=end(); ++it) {
     const TimeRange& r=**it;
     if(r.start()<globalRange.start()) {
       globalRange.setStart(r.start());
@@ -117,15 +117,15 @@ void TimeRangeList::addBlanks(double frequency, const WindowingParameters& param
 }
 
 /*!
-  Add windows in \a tw time interval according to windowing parameters \a param and keep vectors \a keeps.
+  Add windows in \a r time interval according to windowing parameters \a param and keep vectors \a keeps.
 */
 void TimeRangeList::add(double frequency, const WindowingParameters& param, const SparseKeepSignal& keep,
                         const TimeRange& r)
 {
   TRACE;
   //App::log(tr("add time windows from %1 to %2\n").arg(r.start()).arg(r.end()) );
-  const QVector<KeepSignal *>& keeps=keep.keeps();
-  for(QVector<KeepSignal *>::const_iterator it=keeps.begin(); it!=keeps.end(); it++) {
+  const VectorList<KeepSignal *>& keeps=keep.keeps();
+  for(VectorList<KeepSignal *>::const_iterator it=keeps.begin(); it!=keeps.end(); it++) {
     const KeepSignal * keepSig=*it;
 
     double samplingPeriod=keepSig->samplingPeriod();
@@ -265,7 +265,7 @@ void TimeRangeList::add(double frequency, const WindowingParameters& param, cons
         if(winLength>=nMin) {
           TimeRange * newRange=newTimeRange(keepSig->startTime().shifted(winStart*samplingPeriod),
                                             winLength*samplingPeriod);
-          //App::log(tr("good win: start=%1 end=%2\n").arg(newRange->start()).arg(newRange->end()) << flush;
+          //App::log(tr("good win: start=%1 end=%2\n").arg(newRange->start()).arg(newRange->end()) << Qt::flush;
           append(newRange);
           App::log(_verbosityLevel, tr("Adding window from %1 to %2 s (duration %3 s).\n")
                                           .arg(newRange->start().toString())
@@ -289,18 +289,26 @@ void TimeRangeList::add(double frequency, const WindowingParameters& param, cons
   If not, the general add is used.
 */
 void TimeRangeList::add(double frequency, const WindowingParameters& param, const SparseKeepSignal& keep,
-                        const TimeRange& r, const SeismicEventTable * events)
+                        const QList<const SeismicEvent *>& events)
 {
   TRACE;
-  if(param.seismicEventTrigger()) {
-    double winMaxLen=param.maximumLength(frequency);
-    QList<const SeismicEvent *> list=events->events(r);
-    for(QList<const SeismicEvent *>::iterator it=list.begin(); it!=list.end(); it++) {
-      add(frequency, param, keep,
-          TimeRange((*it)->time().shifted(param.seismicEventDelay()), winMaxLen));
+  double winMaxLen=param.maximumLength(frequency);
+  // With PrimeFactorization::closestValue() the effective number of samples is adjusted (+ or -).
+  // It can generate a window larger than winMaxLen which will not be accepted if
+  // winMaxLen is passed strictly as it is. Hence, we multiply it by 1.5, 50% larger.
+  // Unless strong ovelap is chosen, it will generate only one window.
+  //winMaxLen*=1.5;
+  double duration;
+  for(QList<const SeismicEvent *>::const_iterator it=events.begin(); it!=events.end(); it++) {
+    const SeismicEvent * e=*it;
+    if(e->duration()<winMaxLen) {
+      duration=winMaxLen;
+    } else {
+      duration=e->duration();
     }
-  } else {
-    add(frequency, param, keep, r);
+    add(frequency, param, keep,
+        TimeRange(e->time().shifted(param.seismicEventDelay()),
+                  e->time().shifted(duration+param.seismicEventDelay())));
   }
 }
 
@@ -332,8 +340,8 @@ bool TimeRangeList::add(QTextStream& s, const QStringList& beginPatterns,
     }
     DateTime winStart, winEnd;
     bool ok;
-    QString startString=line.section(QRegExp("[ \t]"), 0, 0);
-    QString endString=line.section(QRegExp("[ \t]"), 1, 1);
+    QString startString=line.section(QRegularExpression("[ \t]"), 0, 0);
+    QString endString=line.section(QRegularExpression("[ \t]"), 1, 1);
     App::freeze(true);
     ok=winStart.fromString(startString);
     ok&=winEnd.fromString(endString);
@@ -363,7 +371,7 @@ bool TimeRangeList::add(QTextStream& s, const QStringList& beginPatterns,
 void TimeRangeList::add(const TimeRangeList& list)
 {
   TRACE;
-  for(const_iterator it=list.begin();it!=list.end();++it) {
+  for(const_iterator it=list.begin(); it!=list.end(); ++it) {
     append(cloneTimeRange(*it));
   }
 }
@@ -403,6 +411,7 @@ void TimeRangeList::inverse(double frequency, const WindowingParameters& param,
 {
   TRACE;
   SparseKeepSignal localKeep=keep;
+  localKeep.removeNullSignals();
   localKeep.initValues(1);
   blanksToKeep(localKeep, param.overlap());
   clear();
@@ -422,6 +431,7 @@ void TimeRangeList::blanksToKeep(SparseKeepSignal& keep, double overlap) const
   for(const_iterator it=begin();it!=end();++it) {
     const TimeRange& r=**it;
     double overlapLength=overlapRatio * r.lengthSeconds();
+    keep.removeNullSignals();
     keep.initValues(0, r.start().shifted(overlapLength), r.end().shifted(-overlapLength));
   }
   //GeopsyCoreEngine::instance()->showSignal(keep.keeps().at(0), "after", "blanksToKeep");
