@@ -35,7 +35,7 @@ namespace GeopsyCore {
 
 class WindowingParameters;
 class SparseKeepSignal;
-class SeismicEventTable;
+class SeismicEvent;
 
 class GEOPSYCORE_EXPORT TimeRangeList: private QList<TimeRange *>
 {
@@ -48,7 +48,7 @@ public:
   void add(double frequency, const WindowingParameters& param,
            const SparseKeepSignal& keep, const TimeRange& r);
   void add(double frequency, const WindowingParameters& param, const SparseKeepSignal& keep,
-           const TimeRange& r, const SeismicEventTable * events);
+           const QList<const SeismicEvent *>& events);
   void addBlanks(double frequency, const WindowingParameters& param,
                  const SparseKeepSignal& keep, const TimeRange& r);
   inline TimeRange& addOne(const TimeRange& r);
