@@ -56,8 +56,18 @@ namespace GeopsyCore {
     _badSampleThresholdValue=100.0;
     _badSampleTolerance=0.0;
     _badSampleGap=0.0;
+
     _rawSignalAntiTrigger.enabled=false;
+    _rawSignalAntiTrigger.shortLength=1.0;
+    _rawSignalAntiTrigger.longLength=30.0;
+    _rawSignalAntiTrigger.minimumThreshold=0.2;
+    _rawSignalAntiTrigger.maximumThreshold=2.5;
+
     _filterSignalAntiTrigger.enabled=false;
+    _filterSignalAntiTrigger.shortLength=1.0;
+    _filterSignalAntiTrigger.longLength=30.0;
+    _filterSignalAntiTrigger.minimumThreshold=0.2;
+    _filterSignalAntiTrigger.maximumThreshold=2.5;
 
     _seismicEventTrigger=false;
     _seismicEventDelay=-0.1;
@@ -254,7 +264,7 @@ namespace GeopsyCore {
         break;
       }
     }
-    App::log(tr("Unrecognized length type: %1\n").arg(l) );
+    App::log(tr("Unrecognized length type: %1\n").arg(l));
     return false;
   }
 
@@ -386,7 +396,7 @@ namespace GeopsyCore {
     }
     log+=prefix+"WINDOW_MAX_COUNT"+suffix+"="+QString::number(_maximumWindowCount)+"\n";
     log+="# Length of time windows are adjusted to avoid a prime number of samples which\n"
-         "# slows down the FFT computation. Usually a maximum prime 11 in the prime factorization\n"
+         "# slows down the FFT computation. Usually a maximum prime of 11 in the prime factorization\n"
          "# of the number of samples is a good compromise between the speed and the lenght inaccuracy\n"
          "# Leave as zero to allow any prime number factorization.\n";
     log+=prefix+"WINDOW_MAXIMUM_PRIME_FACTOR"+suffix+"="+QString::number(_maximumPrimeFactor)+"\n";
@@ -407,7 +417,7 @@ namespace GeopsyCore {
     }
     log+=prefix+"ANTI-TRIGGERING_ON_RAW_SIGNAL"+suffix+" (y/n)=";
     log+=_rawSignalAntiTrigger.enabled ? "y\n" : "n\n";
-    if(_filterSignalAntiTrigger.enabled) {
+    if(_rawSignalAntiTrigger.enabled) {
       if(_componentCount>0) {
         log+=prefix+"USED_RAW_COMPONENTS"+suffix+"=";
         log+=_rawComponent[0] ? "y" : "n";
@@ -556,14 +566,14 @@ namespace GeopsyCore {
       _rawSignalAntiTrigger.enabled=(value=="y");
       return true;
     case 9: {
-      LineParser p(value);
+        LineParser p(value);
         p.setDelimiters(",");
         if(_componentCount==0) {
           setComponentCount(p.count());
         }
         bool ok=true;
         for(int i=0; i<_componentCount; i++) {
-          _rawComponent[i]=(p.toString(i, ok)=="y" && ok);
+          _rawComponent[i]=(p.toString(i, ok).trimmed()=="y" && ok);
         }
       }
       return true;
@@ -580,7 +590,7 @@ namespace GeopsyCore {
       _rawSignalAntiTrigger.maximumThreshold=value.toDouble(&ok);
       return ok;
     case 14:
-      _rawSignalAntiTrigger.enabled=(value=="y");
+      _filterSignalAntiTrigger.enabled=(value=="y");
       return true;
     case 15: {
         LineParser p(value);
@@ -590,7 +600,7 @@ namespace GeopsyCore {
         }
         bool ok=true;
         for(int i=0; i<_componentCount; i++) {
-          _filterComponent[i]=(p.toString(i, ok)=="y" && ok);
+          _filterComponent[i]=(p.toString(i, ok).trimmed()=="y" && ok);
         }
       }
       return true;
@@ -624,7 +634,7 @@ namespace GeopsyCore {
       _seismicEventDelay=value.toDouble(&ok);
       return ok;
     case 29:
-      _maximumPrimeFactor=value.toInt(&ok);;
+      _maximumPrimeFactor=value.toInt(&ok);
       return ok;
     default:
       break;
