@@ -113,13 +113,14 @@ bool XMLSignal::xml_setProperty(XML_SETPROPERTY_ARGS)
 {
   TRACE;
   Q_UNUSED(attributes)
+  bool ok=true;
   switch(memberID) {
   case 0:
-    _database=GeopsyCoreEngine::instance()->database(content.toString());
+    _database=GeopsyCoreEngine::instance()->database(content.toStringBuffer());
     if(_database) return true; else return false;
   case 1:
-    _id=content.toInt();
-    return true;
+    _id=content.toInt(ok);
+    return ok;
   default:
     if(_sig) {
       return _sig->xml_setProperty(memberID-4, tag, attributes, content, context);
