@@ -65,7 +65,9 @@ AbstractToolWidget::~AbstractToolWidget()
   TRACE;
   Settings::setWidget(this, objectName(), false);
   delete [] _childrenList;
-  delete _tool;
+  if(_tool && !_tool->parent()) { // make sure that tool has a parent
+    _tool->setParent(this);
+  }
 }
 
 bool AbstractToolWidget::setSubPool(SubPoolWindow * subPoolWin)
@@ -110,7 +112,7 @@ void AbstractToolWidget::restoreFields()
   // At this stage, tool parameters have defaults values
   if(_tool) { // It may be null for old tools that are still converted
     ASSERT(_tool->parameters());
-    setParameters(_tool->parameters());
+    parametersToGui();
   }
   // Size is controlled by the parent widget
   parentWidget()->resize(parentWidget()->minimumSizeHint());
@@ -181,13 +183,14 @@ bool AbstractToolWidget::loadLogParameters(QString fileName)
 {
   TRACE;
   if(fileName.isEmpty()) {
-    fileName=Message::getOpenFileName(tr("Loading parameters in log file"),
-                                          tr("Log file (*.log)"));
+    fileName=Message::getOpenFileName(tr("Loading parameters"),
+                                          tr("Log file (*.log);"
+                                             "Parameter file (*.param)"));
   }
   if(fileName.length()>0) {
     QFile f(fileName);
     if(!f.open(QIODevice::ReadOnly)) {
-      Message::warning(MSG_ID, tr("Loading parameters in log file"),
+      Message::warning(MSG_ID, tr("Loading parameters"),
                            tr("Unable to open file for reading"), Message::cancel());
       return false;
     }
@@ -195,10 +198,9 @@ bool AbstractToolWidget::loadLogParameters(QString fileName)
     QStringList beginPatterns, endPatterns;
     beginPatterns << "# BEGIN PARAMETERS" << "### Parameters ###";
     endPatterns << "# END PARAMETERS" << "### End Parameters ###";
-    AbstractParameters * param=parameters();
-    if(param->load(s, beginPatterns, endPatterns)) {
-      updateAllFields(); // required?
-      setParameters(param);
+    parametersFromGui();
+    if(_tool->parameters()->load(s, beginPatterns, endPatterns)) {
+      parametersToGui();
       return true;
     }
   }
@@ -220,13 +222,12 @@ void AbstractToolWidget::saveLogParameters(QString fileName)
       return;
     }
     QTextStream s(&f);
-    s << "### Parameters ###" << endl;
-    AbstractParameters * param=parameters();
-    if(param) {
-      s << param->toString();
-      delete param;
-    }
-    s << "### End Parameters ###" << endl;
+    s << "### Parameters ###" << Qt::endl;
+    parametersFromGui();
+    AbstractParameters * param=_tool->parameters();
+    s << param->AbstractParameters::toString();
+    s << param->toString();
+    s << "### End Parameters ###" << Qt::endl;
   }
 }
 
