@@ -26,10 +26,13 @@
 ***************************************************************************/
 
 #include <SciFigs.h>
+
 #include "PickLayer.h"
 #include "SignalLayer.h"
 #include "PicksProperties.h"
 #include "PickToPick.h"
+#include "SubPoolWindow.h"
+#include "PickItem.h"
 
 namespace GeopsyGui {
 
@@ -38,7 +41,7 @@ const QString PickLayer::xmlPickLayerTag="PickLayer";
 REGISTER_GRAPHCONTENTLAYER(PickLayer, "PickLayer")
 
 PickLayer::PickLayer(SignalLayer * sig)
-    : GraphContentLayer(sig->graph())
+    : GraphContentsLayer(sig->graph())
 {
   TRACE;
   _sig=sig;
@@ -47,7 +50,7 @@ PickLayer::PickLayer(SignalLayer * sig)
 }
 
 PickLayer::PickLayer(AxisWindow * parent)
-    : GraphContentLayer(parent)
+    : GraphContentsLayer(parent)
 {
   TRACE;
   _sig=nullptr;
@@ -64,6 +67,7 @@ void PickLayer::initMembers()
   TRACE;
   _iSigPick=-1;
   _freePickNames=true;
+  _alterAllSteps=true;
 }
 
 Rect PickLayer::boundingRect() const
@@ -74,19 +78,48 @@ Rect PickLayer::boundingRect() const
 
 void PickLayer::paintText(const LayerPainterRequest& lp, double dotpercm)
 {
+  QMutexLocker ml(&_textPathsMutex);
+  _textPaths.clear();
+  const GraphContentsOptions& gc=lp.options();
+  double coef=dotpercm/SciFigsGlobal::screenResolution();
+  QFont scaledFont=lp.graphContents()->font();
+  if(coef!=1.0 && gc.printBitmap()) {
+    Font::scale(scaledFont, coef);
+  }
   if(_iSigPick>-1) {
-    QMutexLocker ml(&_textPathsMutex);
-    _textPaths.clear();
-    const GraphContentOptions& gc=lp.options();
-    double coef=dotpercm/SciFigsGlobal::screenResolution();
-    QFont scaledFont=lp.graphContent()->font();
-    if(coef!=1.0 && gc.printBitmap()) {
-      Font::scale(scaledFont, coef);
-    }
     scaledFont.setBold(true);
     QPainterPath p;
     p.addText(0, 0, scaledFont, tr("Setting \"%1\"").arg(_pickName));
     _textPaths.append(p);
+    scaledFont.setBold(false);
+  }
+  if(_sig && _sig->subPool()) {
+    Font::scale(scaledFont, 0.75);
+    int isigmin, isigmax;
+    SAFE_UNINITIALIZED(isigmin, 0);
+    SAFE_UNINITIALIZED(isigmax, 0);
+    _sig->visibleIndexRange(gc, isigmin, isigmax);
+    for(int iSig=isigmin; iSig<isigmax; ++iSig) {
+      const Signal * sig=_sig->subPool()->at(iSig);
+      if(!sig->isSpectrum()) {
+        const DateTime& tref=_sig->timeReference(sig);
+        // Events
+        if(_format.isVisible("events")) {
+          QList<const SeismicEvent *> events=sig->database()->seismicEvents()->events(sig);
+          for(QList<const SeismicEvent *>::iterator it=events.begin(); it!=events.end(); it++) {
+            const SeismicEvent * e=*it;
+            double tstart=tref.secondsTo(e->time());
+            double tend=tstart+e->duration();
+            if((tstart>gc.xVisMin() && tstart<gc.xVisMax()) ||
+               (tend>gc.xVisMin() && tend<gc.xVisMax())) {
+              QPainterPath p;
+              p.addText(0, 0, scaledFont, e->name());
+              _textPaths.append(p);
+            }
+          }
+        }
+      }
+    }
   }
 }
 
@@ -94,7 +127,7 @@ void PickLayer::paintData (const LayerPainterRequest& lp, QPainter& p, double do
 {
   TRACE;
   if(_sig && _sig->subPool()) {
-    const GraphContentOptions& gc=lp.options();
+    const GraphContentsOptions& gc=lp.options();
     int isigmin, isigmax;
     SAFE_UNINITIALIZED(isigmin, 0);
     SAFE_UNINITIALIZED(isigmax, 0);
@@ -102,27 +135,26 @@ void PickLayer::paintData (const LayerPainterRequest& lp, QPainter& p, double do
     int w=lp.size().width();
     int h=lp.size().height();
     // If time picking, add a comment in the bottom right corner
+    QMutexLocker ml(&_textPathsMutex);
+    QList<QPainterPath>::const_iterator itText=_textPaths.begin();
     if(_iSigPick>-1) {
-      QMutexLocker ml(&_textPathsMutex);
       p.setPen(Qt::red);
-      QList<QPainterPath>::const_iterator itText=_textPaths.begin();
       QRectF r=itText->boundingRect();
-      int baseLine=(int) round(-r.top());
+      int baseLine=qRound(-r.top());
       p.save();
       p.setRenderHints(QPainter::Antialiasing, true);
       p.setPen(Qt::NoPen);
       p.setBrush(Qt::red);
       p.translate(w - r.width() -10, h - r.height() - 10 + baseLine);
       p.setOpacity(0.7);
-      p.fillRect( -4, (int)r.top()-4, (int)r.width()+8, (int)r.height()+8, Qt::white);
+      p.fillRect(-4, (int)r.top()-4, (int)r.width()+8, (int)r.height()+8, Qt::white);
       p.fillRect(r, Qt::white);
       p.setOpacity(1);
-      p.drawPath( *itText);
-      p.setRenderHints(QPainter::Antialiasing, false);
+      p.drawPath(*(itText++));
       p.restore();
       _sig->highlightSignal(gc, p, w, _iSigPick, isigmin, isigmax);
     }
-    double pickSize;;
+    double pickSize;
     if(_sig->subPool()->count()==1) {
       pickSize=0.75*_sig->subPool()->at(0)->maximumAmplitude();
     } else {
@@ -133,21 +165,49 @@ void PickLayer::paintData (const LayerPainterRequest& lp, QPainter& p, double do
       const Signal * sig=_sig->subPool()->at(iSig);
       if(!sig->isSpectrum()) {
         const DateTime& tref=_sig->timeReference(sig);
+        double y0=_sig->signalY(iSig);
+        // Signal time picks
         QStringList picks=sig->metaData<TimePick>().names();
         for(QStringList::iterator it=picks.begin(); it!=picks.end(); it++) {
           QString pn=*it;
           if(_format.isVisible(pn)) {
             p.setPen(QPen(_format.color(pn), 2));
-            double y0=_sig->signalY(iSig);
             double t=tref.secondsTo(sig->metaData<TimePick>().value(pn));
-            if(t > gc.xVisMin() && t < gc.xVisMax()) {
-              QPoint p1=gc.r2s(t, y0 - pickSize);
+            if(t>gc.xVisMin() && t<gc.xVisMax()) {
+              QPoint p1=gc.r2s(t, y0-pickSize);
               QPoint p2(p1.x(), 0);
-              p2.setY(gc.yr2s(y0 + pickSize));
+              p2.setY(gc.yr2s(y0+pickSize));
               p.drawLine(p1, p2);
             }
           }
         }
+        // Events
+        if(_format.isVisible("events")) {
+          p.save();
+          p.setRenderHints(QPainter::Antialiasing, true);
+          QList<const SeismicEvent *> events=sig->database()->seismicEvents()->events(sig);
+          p.setPen(QPen(_format.color("events"), 2));
+          for(QList<const SeismicEvent *>::iterator it=events.begin(); it!=events.end(); it++) {
+            const SeismicEvent * e=*it;
+            double tstart=tref.secondsTo(e->time());
+            double tend=tstart+e->duration();
+            if((tstart>gc.xVisMin() && tstart<gc.xVisMax()) ||
+               (tend>gc.xVisMin() && tend<gc.xVisMax())) {
+              QPoint p1=gc.r2s(tstart, y0-pickSize);
+              QPoint p2(p1.x(), gc.yr2s(y0+pickSize));
+              QPoint p3(gc.xr2s(tend), p2.y());
+              p.drawLine(p1, p2);
+              p.drawLine(p2, p3);
+              p.save();
+              p.translate(p1);
+              p.setBrush(p.pen().color());
+              p.setPen(Qt::NoPen);
+              p.drawPath(*(itText++));
+              p.restore();
+            }
+          }
+          p.restore();
+        }
       }
     }
     if(isMouseTracking(Pick)) {
@@ -162,10 +222,10 @@ void PickLayer::paintData (const LayerPainterRequest& lp, QPainter& p, double do
 void PickLayer::toggleTrackingAction(bool checked, int id)
 {
   TRACE;
+  QAction * action=qobject_cast<QAction *>(sender());
+  if(!action) return;
   if(id==-1) {
-    QAction * a=qobject_cast<QAction *>(sender());
-    if(!a) return;
-    id=a->data().toInt();
+    id=action->data().toInt();
   }
   if(checked) {
     if(!isMouseTracking(id)) {
@@ -177,6 +237,7 @@ void PickLayer::toggleTrackingAction(bool checked, int id)
           mt.setRectangle(false);
           mt.setIdleCursor(QPixmap(":timepickcursor.png"), 4, 4);
         } else {
+          action->setChecked(false);
           return;
         }
         break;
@@ -256,6 +317,7 @@ bool PickLayer::setPick(const QString& pickName)
     if(!_freePickNames) {
       d->lockPickNames();
     }
+    d->setAlterAllSteps(_alterAllSteps);
     Settings::getWidget(d);
     if(d->exec()==QDialog::Rejected) {
       delete d;
@@ -263,6 +325,7 @@ bool PickLayer::setPick(const QString& pickName)
     }
     Settings::setWidget(d);
     _pickName=d->pickName();
+    _alterAllSteps=d->alterAllSteps();
     magnifier=d->magnifier();
     context=d->context();
     time=d->time();
@@ -285,14 +348,13 @@ bool PickLayer::mousePressEvent(QMouseEvent * e, int)
   TRACE;
   if(!_sig) return false;
   if(e->buttons() & Qt::LeftButton &&
-     !(e->modifiers() & (Qt::ControlModifier || Qt::ShiftModifier))) {
+     !(e->modifiers() & (Qt::ControlModifier | Qt::ShiftModifier))) {
     if(_iSigPick>-1) {
-      Signal& sig=*_sig->subPool()->at(_iSigPick);
-      TimePick& tp=sig.beginModifyMetaData<TimePick>();
-      DateTime refTime=graph()->xAxis()->timeReference();
-      tp.setValue(_pickName, refTime.shifted(graphContent()->options().xs2r(e->x())));
-      sig.endModifyMetaData(tp);
-      emit pickChanged(&sig, _pickName);
+#if(QT_VERSION>=QT_VERSION_CHECK(6, 0, 0))
+      setPick(e->position().x());
+#else
+      setPick(e->pos().x());
+#endif
       deepUpdate();
       return false;
     }
@@ -311,7 +373,7 @@ void PickLayer::mouseMoveEvent (const QPoint& pt, Qt::MouseButtons buttons, Qt::
   TRACE;
   if(!_sig) return;
   if(isMouseTracking(Pick)) {
-    const GraphContentOptions& gc=graphContent()->options();
+    const GraphContentsOptions& gc=graphContents()->options();
     deepUpdate();
     double m=gc.xs2r(pt.x());
     if(_iSigPick>-1) {
@@ -325,12 +387,7 @@ void PickLayer::mouseMoveEvent (const QPoint& pt, Qt::MouseButtons buttons, Qt::
           emit currentSignalChanged(sig, _iSigPick);
         }
         if(d<0.2) {
-          TimePick& tp=sig->beginModifyMetaData<TimePick>();
-          DateTime refTime=graph()->xAxis()->timeReference();
-          tp.setValue(_pickName, refTime.shifted(gc.xs2r(pt.x())));
-          sig->endModifyMetaData(tp);
-          sig->setHeaderModified(true);
-          emit pickChanged(sig, _pickName);
+          setPick(pt.x());
         }
       }
       if(sig->isSpectrum()) {
@@ -354,6 +411,47 @@ void PickLayer::mouseMoveEvent (const QPoint& pt, Qt::MouseButtons buttons, Qt::
   }
 }
 
+/*!
+  \a t is the x screen coordinate of the pick.
+*/
+void PickLayer::setPick(int t)
+{
+  TRACE;
+  const GraphContentsOptions& gc=graphContents()->options();
+  if(_alterAllSteps && _sig->subPoolWindow()) {
+    SignalProcess * process=_sig->subPoolWindow()->signalProcess();
+    if(process->stepCount()>0) {
+      int n=_sig->subPool()->count();
+      for(int i=process->stepCount()-1; i>=0; i--) {
+        const SubSignalPool * subPool=process->step(i);
+        if(subPool->count()==n) {
+          Signal * sig=subPool->at(_iSigPick);
+          TimePick& tp=sig->beginModifyMetaData<TimePick>();
+          DateTime refTime=_sig->timeReference(sig);
+          tp.setValue(_pickName, refTime.shifted(gc.xs2r(t)));
+          sig->endModifyMetaData(tp);
+          sig->setHeaderModified(true);
+          emit pickChanged(sig, _pickName);
+        } else {
+          App::log(tr("Number of signals changed during processing, signals cannot be traced back to the original.\n"
+                      "Time picks altered from step '%1'\n")
+                   .arg(process->steps().at(i+1)));
+          break;
+        }
+      }
+      return;
+    }
+  }
+  // else basic modification of subpool
+  Signal * sig=_sig->subPool()->at(_iSigPick);
+  TimePick& tp=sig->beginModifyMetaData<TimePick>();
+  DateTime refTime=_sig->timeReference(sig);
+  tp.setValue(_pickName, refTime.shifted(gc.xs2r(t)));
+  sig->endModifyMetaData(tp);
+  sig->setHeaderModified(true);
+  emit pickChanged(sig, _pickName);
+}
+
 bool PickLayer::keyPressEvent (QKeyEvent * e)
 {
   TRACE;
@@ -361,21 +459,33 @@ bool PickLayer::keyPressEvent (QKeyEvent * e)
   if(_iSigPick>-1) {
     switch (e->key()) {
     case Qt::Key_Up:
-      if(graphContent()->options().ay() < 0) {
+      if(graphContents()->options().ay()<0) {
         _iSigPick++;
-        if(_iSigPick >= (int) _sig->subPool()->count()) _iSigPick=0;
+        if(_iSigPick>=_sig->subPool()->count()) {
+          _iSigPick=0;
+        }
       } else {
-        if(_iSigPick==0) _iSigPick=_sig->subPool()->count() - 1; else _iSigPick--;
+        if(_iSigPick==0) {
+          _iSigPick=_sig->subPool()->count()-1;
+        } else {
+          _iSigPick--;
+        }
       }
       emit currentSignalChanged(_sig->subPool()->at(_iSigPick), _iSigPick);
       deepUpdate();
       return false;
     case Qt::Key_Down:
-      if(graphContent()->options().ay() > 0) {
+      if(graphContents()->options().ay()>0) {
         _iSigPick++;
-        if(_iSigPick >= (int) _sig->subPool()->count()) _iSigPick=0;
+        if(_iSigPick>=_sig->subPool()->count()) {
+          _iSigPick=0;
+        }
       } else {
-        if(_iSigPick==0) _iSigPick=_sig->subPool()->count() - 1; else _iSigPick--;
+        if(_iSigPick==0) {
+          _iSigPick=_sig->subPool()->count()-1;
+        } else {
+          _iSigPick--;
+        }
       }
       emit currentSignalChanged(_sig->subPool()->at(_iSigPick), _iSigPick);
       deepUpdate();
@@ -414,7 +524,7 @@ bool PickLayer::eventFilter(QObject *obj, QEvent *event)
   }
 }
 
-uint PickLayer::_tab=PropertyProxy::uniqueId();
+uint PickLayer::_tab=PropertyTab::uniqueId();
 
 /*!
   Setup property editor
@@ -446,12 +556,15 @@ void PickLayer::properties(PropertyWidget * w) const
   TRACE;
   if(w->id()==_tab) {
     QStringList names=TimePick::registeredNames();
+    w->setValue(PICKITEM_ATTRIBUTE_NAME, tr("Events"));
+    w->setValue(PICKITEM_ATTRIBUTE_VISIBLE, _format.isVisible("events"));
+    w->setValue(PICKITEM_ATTRIBUTE_COLOR, _format.color("events"));
+    int index=PICKITEM_ATTRIBUTE_COUNT;
     for(int i=0; i<names.count(); i++) {
-      int index=3*i;
-      w->setValue(index++, names.at(i));
-      QString pn=names.at(i);
+      const QString& pn=names.at(i);
+      w->setValue(index++, pn);
       w->setValue(index++, _format.isVisible(pn));
-      w->setValue(index, _format.color(pn));
+      w->setValue(index++, _format.color(pn));
     }
   }
 }
@@ -460,32 +573,45 @@ void PickLayer::setProperty(uint wid, int pid, QVariant val)
 {
   TRACE;
   if(wid==_tab) {
-    // Three properties per TimePick
-    int pickIndex=pid/3;
-    int pickAttribute=pid-3*pickIndex;
-    QStringList names=TimePick::registeredNames();
-    ASSERT(pickIndex>=0 && pickIndex<names.count());
-    QString pickName=names.at(pickIndex);
-    switch(pickAttribute) {
-    case 0:
-      // The color column is not editable, hence the active column is
-      // often the first one, generating a setData for the first column
-      // without any modification.
-      if(val.toString()!=pickName) {
-        if(Message::question(MSG_ID, tr("Renaming time picks"),
-                             tr("Do you want to rename time pick '%1' to '%2' for all signals?")
-                             .arg(pickName).arg(val.toString()),
-                             Message::yes(), Message::no())==Message::Answer0) {
-          TimePick::renamePick(pickName, val.toString());
+    if(pid<PICKITEM_ATTRIBUTE_COUNT) {
+      switch(pid) {
+      case PICKITEM_ATTRIBUTE_NAME:   // Name cannot be changed
+        break;
+      case PICKITEM_ATTRIBUTE_VISIBLE:
+        _format.setVisible("events", val.toBool());
+        break;
+      default:
+        _format.setColor("events", val.value<QColor>());
+        break;
+      }
+    } else {
+      // Three properties per TimePick
+      int pickIndex=pid/PICKITEM_ATTRIBUTE_COUNT-1;
+      int pickAttribute=pid-PICKITEM_ATTRIBUTE_COUNT*pickIndex;
+      QStringList names=TimePick::registeredNames();
+      ASSERT(pickIndex>=0 && pickIndex<names.count());
+      QString pickName=names.at(pickIndex);
+      switch(pickAttribute) {
+      case PICKITEM_ATTRIBUTE_NAME:
+        // The color column is not editable, hence the active column is
+        // often the first one, generating a setData for the first column
+        // without any modification.
+        if(val.toString()!=pickName) {
+          if(Message::question(MSG_ID, tr("Renaming time picks"),
+                               tr("Do you want to rename time pick '%1' to '%2' for all signals?")
+                               .arg(pickName).arg(val.toString()),
+                               Message::yes(), Message::no())==Message::Answer0) {
+            TimePick::renamePick(pickName, val.toString());
+          }
         }
+        break;
+      case PICKITEM_ATTRIBUTE_VISIBLE:
+        _format.setVisible(pickName, val.toBool());
+        break;
+      default:
+        _format.setColor(pickName, val.value<QColor>());
+        break;
       }
-      break;
-    case 1:
-      _format.setVisible(pickName, val.toBool());
-      break;
-    default:
-      _format.setColor(pickName, val.value<QColor>());
-      break;
     }
   }
   deepUpdate();
@@ -498,7 +624,7 @@ void PickLayer::xml_writeChildren(XML_WRITEPROPERTIES_ARGS) const
   if(scifigsContext->makeUp()) {
     _format.xml_save(s, context);
   }
-  GraphContentLayer::xml_writeProperties(s, context);
+  GraphContentsLayer::xml_writeProperties(s, context);
 }
 
 XMLMember PickLayer::xml_member(XML_MEMBER_ARGS)
@@ -508,7 +634,7 @@ XMLMember PickLayer::xml_member(XML_MEMBER_ARGS)
   if(scifigsContext->makeUp()) {
     if(tag=="PickFormat") return XMLMember(&_format);
   }
-  return GraphContentLayer::xml_member(tag, attributes, context);
+  return GraphContentsLayer::xml_member(tag, attributes, context);
 }
 
 // TODO: connect to signal layer if it exists
