@@ -226,7 +226,7 @@ Qt::ItemFlags SignalGroupItem::flags(const QModelIndex& index) const
              Qt::ItemIsDropEnabled;
     }
   } else {
-    return nullptr;
+    return Qt::NoItemFlags;
   }
 }
 
