@@ -35,7 +35,7 @@ const QString TimeWindowLayer::xmlTimeWindowLayerTag="TimeWindowLayer";
 REGISTER_GRAPHCONTENTLAYER(TimeWindowLayer, "TimeWindowLayer")
 
 TimeWindowLayer::TimeWindowLayer(AxisWindow * parent)
-    : GraphContentLayer(parent)
+    : GraphContentsLayer(parent)
 {
   TRACE;
   _sig=nullptr;
@@ -46,7 +46,7 @@ TimeWindowLayer::TimeWindowLayer(AxisWindow * parent)
 }
 
 TimeWindowLayer::TimeWindowLayer(SignalLayer * sig)
-    : GraphContentLayer(sig->graph())
+    : GraphContentsLayer(sig->graph())
 {
   TRACE;
   _sig=sig;
@@ -77,7 +77,7 @@ Rect TimeWindowLayer::boundingRect() const
   }
 }
 
-inline void TimeWindowLayer::paintTimeWindows(const GraphContentOptions& gc, QPainter& p,
+inline void TimeWindowLayer::paintTimeWindows(const GraphContentsOptions& gc, QPainter& p,
                                               const TimeWindowList& windows, const Signal * sig, int iSig) const
 {
   TRACE;
@@ -86,16 +86,18 @@ inline void TimeWindowLayer::paintTimeWindows(const GraphContentOptions& gc, QPa
   _sig->timeWindowY(gc, iSig, _size, wtop, wheight);
   const DateTime& tref=_sig->timeReference(sig);
   TimeRange gcLimits(tref.shifted(gc.xVisMin()), tref.shifted(gc.xVisMax()));
-  int *wleft, *wwidth;
   int n=windows.count();
   int i=0;
-  wleft=new int [n];
-  wwidth=new int [n];
-  p.setPen(QPen( Qt::NoPen));
-  p.setBrush(QBrush(QColor(200, 255, 193, 128)));
+  int * wleft=new int [n];
+  int * wwidth=new int [n];
+  QColor * wcolor=new QColor[n];
+
+  p.setPen(QPen(Qt::NoPen));
+  if(!_showColors) {
+    p.setBrush(QBrush(QColor(200, 255, 193, 128)));
+  }
   TimeRange sigRange=sig->timeRange().range();
   TimeRangeList::const_iterator it;
-  QColor col;
   // Painting is splitted in two parts to avoid changing the pen and the brush
   // for each time window. Screen coordinates of time window are cached.
   for(it=windows.begin(); it!=windows.end(); ++it) {
@@ -105,22 +107,33 @@ inline void TimeWindowLayer::paintTimeWindows(const GraphContentOptions& gc, QPa
       wleft[i]=gc.xr2s(tref.secondsTo(rLimits.start()));
       wwidth[i]=gc.xr2s(tref.secondsTo(rLimits.end()))-wleft[ i ];
       if(_showColors) {
-        guiColor(w.color(), col);
-        col.setAlpha(128);
-        p.setBrush(col);
+        guiColor(w.color(), wcolor[i]);
+        wcolor[i].setAlpha(128);
+        p.setBrush(wcolor[i]);
       }
       p.drawRect(wleft[i], wtop, wwidth[i], wheight);
       i++;
     }
   }
+  // Border of windows is drawn on top of the rectangle filling
   n=i;
-  p.setPen(QPen(QColor(152, 238, 77), 1, Qt::SolidLine));
-  p.setBrush(QBrush( Qt::NoBrush));
+  if(!_showColors) {
+    QColor c=p.brush().color().darker(105);
+    c.setAlpha(255);
+    p.setPen(QPen(c, 1, Qt::SolidLine));
+  }
+  p.setBrush(QBrush(Qt::NoBrush));
   for(i=0; i<n; i++) {
+    if(_showColors) {
+      QColor c=wcolor[i].darker(105);
+      c.setAlpha(255);
+      p.setPen(QPen(c, 1, Qt::SolidLine));
+    }
     p.drawRect(wleft[i], wtop, wwidth[i], wheight);
   }
   delete [] wleft;
   delete [] wwidth;
+  delete [] wcolor;
   p.restore();
 }
 
@@ -128,9 +141,9 @@ void TimeWindowLayer::paintData(const LayerPainterRequest& lp, QPainter& p, doub
 {
   TRACE;
   if(!_sig || !_sig->subPool()) return;
-  const GraphContentOptions& gc=lp.options();
+  const GraphContentsOptions& gc=lp.options();
   const SubSignalPool& subPool=*_sig->subPool();
-  QMap<const Signal *, const TimeWindowList *>::const_iterator it;
+  QMap<const Signal *, TimeWindowList *>::const_iterator it;
   int isigmin, isigmax;
   SAFE_UNINITIALIZED(isigmin, 0);
   SAFE_UNINITIALIZED(isigmax, 0);
@@ -212,22 +225,38 @@ bool TimeWindowLayer::trackRectangle(int id, double rx1, double ry1, double rx2,
 /*!
   Links signal \a sig to time window list \a l
 */
-void TimeWindowLayer::addTimeWindows(Signal * sig, const TimeWindowList * l)
+void TimeWindowLayer::addTimeWindows(Signal * sig, TimeWindowList * l)
 {
   TRACE;
   LayerLocker ll(this);
-  _windows.insert(sig, l);
+  addTimeWindowsInternal(sig, l);
 }
 
 /*!
   For convenience, links all signals of \a subPool to time window list \a l
 */
-void TimeWindowLayer::addTimeWindows(const SubSignalPool& subPool, const TimeWindowList * l)
+void TimeWindowLayer::addTimeWindows(const SubSignalPool& subPool, TimeWindowList * l)
 {
   TRACE;
   LayerLocker ll(this);
   for(SubSignalPool::const_iterator it=subPool.begin(); it!=subPool.end(); it++) {
-    _windows.insert(*it, l);
+    addTimeWindowsInternal(*it, l);
+  }
+}
+
+/*!
+  Links signal \a sig to time window list \a l
+*/
+void TimeWindowLayer::addTimeWindowsInternal(Signal * sig, TimeWindowList * l)
+{
+  TRACE;
+  QMap<const Signal *, TimeWindowList *>::iterator mapit;
+  mapit=_windows.find(sig);
+  if(_windowOwner && mapit!=_windows.end()) {
+    mapit.value()->add(*l);
+    delete l;
+  } else {
+    _windows.insert(sig, l);
   }
 }
 
@@ -236,7 +265,7 @@ void TimeWindowLayer::clearTimeWindows()
   TRACE;
   LayerLocker ll(this);
   if(_windowOwner) {
-    QMap<const Signal *, const TimeWindowList *>::iterator it;
+    QMap<const Signal *, TimeWindowList *>::iterator it;
     for(it=_windows.begin(); it!=_windows.end(); it++) {
       delete it.value();
     }
@@ -280,7 +309,7 @@ void TimeWindowLayer::xml_writeChildren(XML_WRITECHILDREN_ARGS) const
       att.add("signalIndex");
       QString& index=att.value(0);
       int n=subPool->count();
-      QMap<const Signal *, const TimeWindowList *>::const_iterator it;
+      QMap<const Signal *, TimeWindowList *>::const_iterator it;
       for(int i=0; i<n; i++) {
         it=_windows.find(subPool->at(i));
         if(it!=_windows.end()) {
@@ -301,7 +330,12 @@ XMLMember TimeWindowLayer::xml_member(XML_MEMBER_ARGS)
       const QString attID="signalIndex";
       XMLRestoreAttributeIterator it=attributes.find(attID);
       if(it!=attributes.end()) {
-        int signalIndex=it.value().toInt();
+        bool ok=true;
+        int signalIndex=it.value().toInt(ok);
+        if(!ok) {
+          App::log(tr("Bad signal index '%1'\n").arg(it.value().toStringView()));
+          return XMLMember(XMLMember::Unknown);
+        }
         if(!_xmlWindows) {
           _xmlWindows=new XMLTimeWindowList;
         }
@@ -309,7 +343,7 @@ XMLMember TimeWindowLayer::xml_member(XML_MEMBER_ARGS)
         _xmlWindows->_windows.insert(signalIndex, w);
         return XMLMember(w);
       } else {
-        App::log(tr("Missing signal index attribute\n") );
+        App::log(tr("Missing signal index attribute\n"));
         return XMLMember(XMLMember::Unknown);
       }
     } else if(tag=="signalLayerName") {
@@ -323,27 +357,28 @@ XMLMember TimeWindowLayer::xml_member(XML_MEMBER_ARGS)
       return  XMLMember(2);
     }
   }
-  return GraphContentLayer::xml_member(tag, attributes, context)+3;
+  return GraphContentsLayer::xml_member(tag, attributes, context)+3;
 }
 
 bool TimeWindowLayer::xml_setProperty(XML_SETPROPERTY_ARGS)
 {
   TRACE;
+  bool ok=true;
   switch(memberID) {
   case 0:
     if(!_xmlWindows) {
       _xmlWindows=new XMLTimeWindowList;
     }
-    _xmlWindows->_signalLayerName=content.toString();
+    _xmlWindows->_signalLayerName=content.toStringBuffer();
     return true;
   case 1:
-    _size=content.toDouble();
-    return true;
+    _size=content.toDouble(ok);
+    return ok;
   case 2:
-    _showColors=content.toBool();
-    return true;
+    _showColors=content.toBool(ok);
+    return ok;
   default:
-    return GraphContentLayer::xml_setProperty(memberID-3, tag, attributes, content, context);
+    return GraphContentsLayer::xml_setProperty(memberID-3, tag, attributes, content, context);
   }
 }
 
@@ -354,9 +389,9 @@ void TimeWindowLayer::xml_layerPolish(XML_POLISH_ARGS)
 {
   XMLSciFigs * scifigsContext=static_cast<XMLSciFigs *>(context);
   if(scifigsContext->data() && _xmlWindows) {
-    _sig=qobject_cast<SignalLayer *>(graphContent()->findLayer(SignalLayer::xmlSignalLayerTag,
+    _sig=qobject_cast<SignalLayer *>(graphContents()->findLayer(SignalLayer::xmlSignalLayerTag,
                                                                _xmlWindows->_signalLayerName));
-    QMap<int, const TimeWindowList *>::iterator it;
+    QMap<int, TimeWindowList *>::iterator it;
     if(_sig) {
       const SubSignalPool * subPool=_sig->subPool();
       for(it=_xmlWindows->_windows.begin(); it!=_xmlWindows->_windows.end(); it++) {
