@@ -37,7 +37,7 @@ namespace GeopsyGui {
 
 class SignalLayer;
 
-class GEOPSYGUI_EXPORT TimeWindowLayer : public GraphContentLayer
+class GEOPSYGUI_EXPORT TimeWindowLayer : public GraphContentsLayer
 {
   Q_OBJECT
   Q_PROPERTY(double size READ size WRITE setSize SCRIPTABLE true)
@@ -52,8 +52,8 @@ public:
   virtual const QString& xml_tagName() const {return xmlTimeWindowLayerTag;}
   static const QString xmlTimeWindowLayerTag;
 
-  void addTimeWindows(const SubSignalPool& subPool, const TimeWindowList * l);
-  void addTimeWindows(Signal * sig, const TimeWindowList * l);
+  void addTimeWindows(const SubSignalPool& subPool, TimeWindowList * l);
+  void addTimeWindows(Signal * sig, TimeWindowList * l);
   void clearTimeWindows();
 
   virtual Rect boundingRect() const;
@@ -79,11 +79,12 @@ signals:
 private:
   virtual void paintData(const LayerPainterRequest& lp, QPainter& p, double dotpercm) const;
 
-  inline void paintTimeWindows(const GraphContentOptions& gc, QPainter& p,
+  void addTimeWindowsInternal(Signal * sig, TimeWindowList * l);
+  inline void paintTimeWindows(const GraphContentsOptions& gc, QPainter& p,
                                const TimeWindowList& windows, const Signal * sig, int iSig) const;
 
   SignalLayer * _sig;
-  QMap<const Signal *, const TimeWindowList *> _windows;
+  QMap<const Signal *, TimeWindowList *> _windows;
 
   double _size;
   bool _showColors;
@@ -91,7 +92,7 @@ private:
 
   struct XMLTimeWindowList
   {
-    QMap<int, const TimeWindowList *> _windows;
+    QMap<int, TimeWindowList *> _windows;
     QString _signalLayerName;
   };
   XMLTimeWindowList * _xmlWindows;
