@@ -43,7 +43,7 @@ namespace HVCore {
     : AbstractTool(parent)
   {
     TRACE;
-    AbstractTool::setParameters(HVParameters());
+    setParameters(new HVParameters);
   }
 
   /*!
@@ -78,20 +78,6 @@ namespace HVCore {
     }
   }
 
-  bool AbstractHVTool::setParameters(const AbstractParameters& param)
-  {
-    TRACE;
-    const HVParameters * hvParam=dynamic_cast<const HVParameters *>(&param);
-    if(!hvParam) {
-      qDebug() << "Parameters are not HVParameters in AbstractHVTool::setParameters.";
-      return false;
-    }
-    if(!AbstractTool::setParameters(param)) {
-      return false;
-    }
-    return setLoop();
-  }
-
   ParallelTaskManager * AbstractHVTool::createLoop()
   {
     HVTaskManager * tm=new HVTaskManager(_stations);
@@ -122,6 +108,7 @@ namespace HVCore {
       _stations.at(i)->setSampling(keep);
     }
     // Set values of keep
+    keep->removeNullSignals();
     keep->initValues(1);
     for(int i=0; i<n; i++) {
       _stations.at(i)->setKeep(keep, parameters()->windowing(), i);
@@ -365,13 +352,15 @@ namespace HVCore {
     }
   }
 
-  bool AbstractHVTool::save(QDir outputDir)
+  bool AbstractHVTool::saveResults(const QString& outputDir)
   {
     TRACE;
+    QDir d(outputDir);
+    App::log(tr("Saving to '%1'...\n").arg(d.absolutePath()));
     int n=_stations.count();
     for(int i=0; i<n; i++) {
       AbstractStation * stat=_stations.at(i);
-      if(!stat->save(outputDir, *parameters())) {
+      if(!stat->save(d, *parameters())) {
         return false;
       }
     }
