@@ -110,6 +110,7 @@ namespace HVCore {
     SparseTimeRange sr=timeRange(r);
     SparseKeepSignal * keep=new SparseKeepSignal(sr);
     setSampling(keep);
+    keep->removeNullSignals();
     keep->initValues(1);
     setKeep(keep, param, stationIndex);
     return keep;
@@ -172,7 +173,7 @@ namespace HVCore {
   {
     TRACE;
     ColorMap map;
-    map.generateColorScale(_timeWindows.count(), ColorPalette::Hsv);
+    map.generate(0, _timeWindows.count()-1);
     for(int i=_timeWindows.count()-1; i>=0; i--) {
       _timeWindows.at(i).setColor(map.color(i));
     }
@@ -191,7 +192,7 @@ namespace HVCore {
     return false;
   }
 
-  void AbstractStation::changeColors(const QVector<int>* selCurves, const Color &col)
+  void AbstractStation::changeColors(const QList<int>* selCurves, const QGpCoreTools::Color &col)
   {
     TRACE;
     if(_windowsChanged) {
@@ -200,7 +201,7 @@ namespace HVCore {
                   "Re-process your windows before editing the spectra."));
       return;
     }
-    QVector<int>::const_iterator it;
+    QList<int>::const_iterator it;
     for(it=selCurves->begin(); it!=selCurves->end(); ++it) {
       _timeWindows.at(*it).setColor(col);
     }
@@ -305,6 +306,7 @@ namespace HVCore {
          "#\n"
          "# BEGIN PARAMETERS\n"
          "#\n";
+    s << param.AbstractParameters::toString();
     s << param.toString();
     s << "#\n"
          "# END PARAMETERS\n"
