@@ -99,7 +99,7 @@ namespace HVCore {
     int di=winIndex*frequencySampling().count();
     int n=frequencySampling().count();
     for(int i=0; i<n; i++) {
-      y[i+di]=curve.interpole(x[i]).y();
+      y[i+di]=curve.interpole(x[i], LogScale, LogScale).y();
     }
     _averageWindowLength.add(winLength);
   }
@@ -268,7 +268,10 @@ namespace HVCore {
   void CurveResults::setPeaks()
   {
     TRACE;
-    if(_windows->curveCount()==0) return;
+    if(_windows->curveCount()==0 ||
+       _average.isEmpty()) {
+      return;
+    }
     double minFreq, maxFreq;
     const double * x=_windows->x();
     int imax=averageMax(_average);
@@ -470,7 +473,7 @@ namespace HVCore {
       return false;
     }
     QTextStream s(&f);
-    s << log << flush;
+    s << log << Qt::flush;
     if(s.status()==QTextStream::WriteFailed) {
       App::log(tr("Error while writing to file '%1'\n").arg(fileName));
       return false;
@@ -513,10 +516,12 @@ namespace HVCore {
              .arg(p.mean())
              .arg(p.mean()/p.stddev())
              .arg(p.mean()*p.stddev());
-        s << QString("# f%1 amplitude\t%2\n").arg(index).arg(_average.interpole(p.mean()).y());
+        s << QString("# f%1 amplitude\t%2\n")
+             .arg(index)
+             .arg(_average.interpole(p.mean(), LogScale, LogScale).y());
       }
     }
-    s << QString("# Position\t%1\n").arg(coordinates().toString(20));
+    s << QString("# Position\t%1\n").arg(coordinates().toString('g', 20));
     s << QString("# Category\t%1\n").arg(category());
     // Write titles
     s << "# Frequency\tAverage\tMin\tMax\n";
@@ -550,29 +555,30 @@ namespace HVCore {
     _stddevHigh.clear();
     _peaks.clear();
     bool ok=true;
-    QRegExp fi("f([0-9]+)");
-    QVector<double> xValues;
+    QRegularExpression fi("f([0-9]+)");
+    VectorList<double> xValues;
+    QRegularExpressionMatch match;
     while(!s.atEnd()) {
       QString line=s.readLine();
       if(line.startsWith("#")) {
         if(line.startsWith("# GEOPSY output version", Qt::CaseInsensitive)) {
-          if(line.section(QRegExp("[ \t]"), 4, 4).toDouble()>1.1) {
+          if(line.section(QRegularExpression("[ \t]"), 4, 4).toDouble()>1.1) {
             App::log(tr("Loading results: bad version, expecting version 1.1"));
             return false;
           }
         } else if(line.startsWith("# Number of windows for f", Qt::CaseInsensitive)) {
-          if(fi.indexIn(line, 24)==24) {
-            int index=fi.cap(1).toInt();
+          if(line.indexOf(fi, 24, &match)==24) {
+            int index=match.captured(1).toInt();
             if(index>=_peaks.count()) {
               _peaks.resize(index+1);
             }
             _peaks[index].setWeight(line.section("=", 1, 1).toInt());
             _peaks[index].setValid(false);
           }
-        } else if(line.contains(QRegExp("# f[0-9]+ from windows"))) {
+        } else if(line.contains(QRegularExpression("# f[0-9]+ from windows"))) {
           double f=line.section("\t", 1, 1).toDouble();
-          if(fi.indexIn(line, 2)==2) {
-            int index=fi.cap(1).toInt();
+          if(line.indexOf(fi, 2, &match)==2) {
+            int index=match.captured(1).toInt();
             if(index>=_peaks.count()) {
               _peaks.resize(index+1);
             }
@@ -623,19 +629,24 @@ namespace HVCore {
     _windows->setColor(winIndex, col);
   }
 
-  void CurveResults::setWindowColor(const QVector<int>* selCurves, const Color& col)
+  void CurveResults::setWindowColor(const QList<int>* selCurves, const Color& col)
   {
     TRACE;
-    QVector<int>::const_iterator it;
+    QList<int>::const_iterator it;
     for(it=selCurves->begin(); it!=selCurves->end(); ++it) {
       _windows->setColor(*it, col);
     }
   }
 
-  void CurveResults::blackWindows(int, const QVector<int>* selCurves)
+  void CurveResults::blackWindows(int, const VectorList<int>* selCurves)
   {
     TRACE;
+#if(QT_VERSION>=QT_VERSION_CHECK(6, 0, 0))
     emit colorsToChange(selCurves, Qt::gray);
+#else
+    QList<int> l=selCurves->toList();
+    emit colorsToChange(&l, Qt::gray);
+#endif
   }
 
   /*!
@@ -644,7 +655,7 @@ namespace HVCore {
   void CurveResults::blackWindows(const Rect &rect)
   {
     TRACE;
-    QVector<int> selCurves;
+    QList<int> selCurves;
     int iminFreq=frequencySampling().index(rect.x1());
     int imaxFreq=frequencySampling().index(rect.x2());
     int ns=frequencySampling().count();
@@ -728,7 +739,7 @@ namespace HVCore {
              p.mean(),
              p.mean()/p.stddev(),
              p.mean()*p.stddev(),
-             _average.interpole(p.mean()).y());
+             _average.interpole(p.mean(), LogScale, LogScale).y());
     }
   }
 
@@ -749,9 +760,9 @@ namespace HVCore {
             .arg(p.mean()*p.stddev());
         str+=QString("\nA%1=%2 [%3, %4]")
              .arg(index)
-             .arg(_average.interpole(p.mean()).y())
-             .arg(_stddevLow.interpole(p.mean()).y())
-             .arg(_stddevHigh.interpole(p.mean()).y());
+             .arg(_average.interpole(p.mean(), LogScale, LogScale).y())
+             .arg(_stddevLow.interpole(p.mean(), LogScale, LogScale).y())
+             .arg(_stddevHigh.interpole(p.mean(), LogScale, LogScale).y());
       }
     }
     str+=tr("\nCategory: %1").arg(category());
@@ -778,7 +789,7 @@ namespace HVCore {
     Returns the peak frequency of the average computed on a selection of windows.
     Used for filtering windows according to Cox et al. 2020.
   */
-  double CurveResults::averagePeak(const QVector<bool>& selection, double minFreq, double maxFreq) const
+  double CurveResults::averagePeak(const VectorList<bool>& selection, double minFreq, double maxFreq) const
   {
     int iminFreq=frequencySampling().index(minFreq);
     int imaxFreq=frequencySampling().index(maxFreq);
