@@ -48,7 +48,7 @@ namespace HVCore {
   bool HVStation::save(int, QDir outputDir, const HVParameters& param)
   {
     TRACE;
-    QString fileName=_signals->originalSignals()->name();;
+    QString fileName=_signals->originalSignals()->name();
     fileName=outputDir.absoluteFilePath(fileName+".hv");
     return _results[0]->save(fileName, log(param));
   }
@@ -62,8 +62,8 @@ namespace HVCore {
   {
     AbstractResults * r=new CurveResults(this);
     r->setName(originalSignals()->name());
-    connect(r, SIGNAL(colorsToChange(const QVector<int>*, const Color&)),
-            this, SLOT(changeColors(const QVector<int>*, const Color&)));
+    connect(r, SIGNAL(colorsToChange(const QList<int>*, const QGpCoreTools::Color&)),
+            this, SLOT(changeColors(const QList<int>*, const QGpCoreTools::Color&)));
     return r;
   }
 
@@ -111,8 +111,8 @@ namespace HVCore {
       return false;
     }
     // Init with all available time windows
-    QVector<bool> selected(n);
-    QVector<double> f0(n);
+    VectorList<bool> selected(n);
+    VectorList<double> f0(n);
     for(int i=0; i<n; i++) {
       f0[i]=results->peak(i, param.minimumFrequency(), param.maximumFrequency());
       selected[i]=(f0[i]>0.0);
