@@ -84,7 +84,10 @@ namespace HVCore {
   }
 
   /*!
-    Return an horizontal spectrum in direction \a azimuth counted clockwise from North
+    Return an horizontal spectrum in direction \a azimuth in degrees counted clockwise from North
+
+    Order of components: Z, N, E (\sa StationSignals::addSignal())
+    processed(1) is North, processed(2) is East.
   */
   Curve<Point2D> HVStationSignals::horizontal(double azimuth, const HVParameters *param)
   {
@@ -109,7 +112,15 @@ namespace HVCore {
     }
     DoubleSignal *& psig=processed(iComp);
     psig->subtractValue();
-    psig->taper(param->tapering());
+    if(!psig->taper(param->tapering())) {
+      App::log(tr("Error applying taper, skipping\n"));
+    }
+    if(param->oversamplingFactor()>1.0) {
+      DoubleSignal * sigLarge=new DoubleSignal;
+      sigLarge->frequencyOverSample(param->oversamplingFactor(), psig);
+      delete psig;
+      psig=sigLarge;
+    }
     psig->fastFourierTransform(DoubleSignal::Spectrum);
     return true;
   }
