@@ -81,5 +81,17 @@ namespace HVCore {
     t->unlock();
   }
 
+  void HVWorker::polish(ParallelTask * t)
+  {
+    HVTask * hvt=static_cast<HVTask *>(t);
+    App::log(tr("Get statistics...\n"));
+    int n=hvt->station()->resultCount();
+    for(int i=0; i<n; i++) {
+      AbstractResults * r=hvt->station()->results(i);
+      r->setStatistics();
+      r->setPeaks();
+    }
+  }
+
 } // namespace HVCore
 
