@@ -94,7 +94,7 @@ namespace HVCore {
     int n=_grid->nx();
     double * curve=new double[n];
     for(int i=0; i<n; i++) {
-      curve[i]=log(hv.interpole(_grid->x(i)).y());
+      curve[i]=log(hv.interpole(_grid->x(i), LogScale, LogScale).y());
     }
     double * values=_gridAccess->lockRow(azimuthIndex);
     for(int i=0; i<n; i++) {
@@ -121,7 +121,7 @@ namespace HVCore {
   }
 
 
-  bool RotateResults::save(QString fileName, QString log) const
+  bool RotateResults::save(QString fileName, QString) const
   {
     TRACE;
     QFile f(fileName);
