@@ -34,7 +34,7 @@ namespace HVCore {
   class HVCORE_EXPORT SpectrumRotateTool : public AbstractHVTool
   {
   public:
-    SpectrumRotateTool(QObject * parent=nullptr);
+    SpectrumRotateTool(QObject * parent);
 
     bool setSubPool(SubSignalPool * subPool);
   protected:
