@@ -34,7 +34,7 @@ namespace HVCore {
   class HVCORE_EXPORT SpectrumTool : public AbstractHVTool
   {
   public:
-    SpectrumTool(QObject * parent=nullptr);
+    SpectrumTool(QObject * parent);
 
     bool setSubPool(SubSignalPool * subPool);
   protected:
