@@ -49,12 +49,12 @@ namespace HVGui {
     ~AbstractHVWidget();
 
     bool setSubPool(SubSignalPool * subPool);
-    virtual void refreshSignal(Signal * sig);
+    void endSignalChange(Signal * sig);
 
     AbstractHVTool * tool() {return static_cast<AbstractHVTool *>(_tool);}
     const AbstractHVTool * tool() const {return static_cast<const AbstractHVTool *>(_tool);}
   public slots:
-    void start();
+    void start(int threadCount=0);
     void stop();
   protected slots:
     void setCurrentDisplayStation();
@@ -79,26 +79,22 @@ namespace HVGui {
     void on_makeUpSummaryBrowse_clicked();
     void on_useMakeUpResults_toggled();
     void on_useMakeUpSummary_toggled();
+    void on_doOversampling_toggled();
     void on_doHighPass_toggled();
 
     void winParamChanged();
     void procParamChanged();
   protected:
     void setMakeUp();
-    void setRunning(bool r, const QString& message=QString());
     void removeHorizontalComponents();
     void removeRotateStep();
-    void getParameters(HVParameters& param) const;
-    void setParameters(const HVParameters& param);
+    void parametersToGui();
+    void parametersFromGui();
     void setWinParamChanged(bool c);
     void createResults(QString subPoolName);
     virtual void restoreFields();
     virtual void updateAllFields();
 
-    bool updateParameters();
-    void setParameters(const AbstractParameters * param);
-    AbstractParameters * parameters(AbstractParameters * param=nullptr) const;
-
     virtual AbstractResultSheet * createResultSheet()=0;
     virtual AbstractSummary * createSummary()=0;
     virtual void setLimits();
