@@ -129,7 +129,7 @@ void AbstractSummary::setResults(const QList<AbstractResults *>& results)
   }
   std::sort(cats.begin(), cats.end());
   unique(cats);
-  static const Pen defaultPen(Qt::black, 0, Qt::NoPen);
+  static const Pen defaultPen(Qt::black, 0, Pen::NoLine);
   static const Symbol defaultSymbol(Symbol::Circle, 2.5, Pen(Qt::black), Brush(Qt::NoBrush) );
   _categories.setTexts(cats, defaultPen, defaultSymbol);
 
@@ -203,10 +203,10 @@ void AbstractSummary::setAverageValues()
     min.yMultiply(sum2);
     PlotLine2D * l;
     l=static_cast<PlotLine2D *>(_averageLayer->addLine());
-    l->setPen(Pen(Qt::black, 0.6, Qt::DashLine));
+    l->setPen(Pen(Qt::black, 0.6, Pen::DashLine));
     l->setCurve(min);
     l=static_cast<PlotLine2D *>(_averageLayer->addLine());
-    l->setPen(Pen(Qt::black, 0.6, Qt::DashLine));
+    l->setPen(Pen(Qt::black, 0.6, Pen::DashLine));
     l->setCurve(max);
     l=static_cast<PlotLine2D *>(_averageLayer->addLine());
     l->setCurve(sum);
@@ -322,9 +322,9 @@ void AbstractSummary::setBubbleValues()
     break;
   }
 
-  QVector<double> * xBubble=new QVector<double>;
-  QVector<double> * yBubble=new QVector<double>;
-  QVector<double> * valBubble=new QVector<double>;
+  VectorList<double> * xBubble=new VectorList<double>;
+  VectorList<double> * yBubble=new VectorList<double>;
+  VectorList<double> * valBubble=new VectorList<double>;
   int n=_results.count();
   for(int i=0; i<n; i++) {
     CurveResults * res=_results.at(i);
@@ -366,7 +366,7 @@ QMap<double, CurveResults *> AbstractSummary::distance2Station()
     statList.append((*it)->coordinates());
   }
   // For each station I get its projection on the line (listed in the same order)
-  QVector<double> distances=statList.project();
+  VectorList<double> distances=statList.project();
   // Create a map to sort distances
   QMap<double, CurveResults *> dist2stat;
   for(int i=_results.count() - 1;i >= 0;i-- ) {
@@ -387,7 +387,7 @@ void AbstractSummary::createStackedGraph(double x, double y)
   _stackedLayer->setObjectName("Curves");
   PlotLine2D * line;
   line=new PlotLine2D;
-  line->setPen(Pen(Qt::SolidLine));
+  line->setPen(Pen(Pen::SolidLine));
   line->setSymbol(Symbol(Symbol::NoSymbol));
   _stackedLayer->setReferenceLine(line);
 }
@@ -406,7 +406,7 @@ void AbstractSummary::createAverageGraph(double x, double y)
   _averageLayer->setObjectName("Average");
   PlotLine2D * line;
   line=new PlotLine2D;
-  line->setPen(Pen(Qt::black, 0.6, Qt::SolidLine));
+  line->setPen(Pen(Qt::black, 0.6, Pen::SolidLine));
   line->setSymbol(Symbol(Symbol::NoSymbol));
   _averageLayer->setReferenceLine(line);
 }
@@ -423,7 +423,7 @@ void AbstractSummary::createSpectrumGridGraph(double x, double y)
 
   _spectrumGridPalette=new ColorMapWidget(nullptr);
   _spectrumGridPalette->setObjectName("SpectrumPalette");
-  _spectrumGridPalette->generateColorScale(20, ColorPalette::McNames, true);
+  _spectrumGridPalette->generate(0, 19, ColorPalette::defaultSequential, ColorPalette::Reversed);
   _spectrumGridPalette->setNumberPrecision(2);
   _spectrumGridPalette->setOrientation(Axis::West);
   _spectrumGridPalette->setTitle(_stackedLayer->graph()->yAxis()->title());
@@ -479,7 +479,7 @@ void AbstractSummary::createBubbleGraph(double x, double y)
 
   _bubblePalette=new ColorMapWidget(nullptr);
   _bubblePalette->setObjectName("BubblePalette");
-  _bubblePalette->generateColorScale(20, ColorPalette::McNames);
+  _bubblePalette->generate(0, 19);
   _bubblePalette->setNumberPrecision(2);
   _bubblePalette->setOrientation(Axis::West);
   _bubblePalette->setPrintXAnchor(x+16.5);
@@ -636,7 +636,7 @@ void AbstractSummary::setMapOptions()
     _categories=_mapOptions->categories();
     _mapShowBubbles=_mapOptions->showBubbles();
     setValues();
-    _bubbleLayer->graphContent()->deepUpdate();
+    _bubbleLayer->graphContents()->deepUpdate();
   }
 }
 
