@@ -92,7 +92,7 @@ CompatFunction::CompatFunction()
 /*!
   Don't forget to call deleteVectors(), x, y and dy are created here
 */
-CompatFunction::CompatFunction(QVector<double> * x, QVector<double> * y, QVector<double> * dy)
+CompatFunction::CompatFunction(VectorList<double> * x, VectorList<double> * y, VectorList<double> * dy)
 {
   TRACE;
   _x=x;
@@ -104,7 +104,7 @@ CompatFunction::CompatFunction(QVector<double> * x, QVector<double> * y, QVector
   sort();
 }
 
-CompatFunction::CompatFunction(QVector<Point>& f)
+CompatFunction::CompatFunction(VectorList<Point>& f)
 {
   TRACE;
   _n2=0;
@@ -121,8 +121,8 @@ CompatFunction::~CompatFunction()
 void CompatFunction::line(double x1, double y1, double x2, double y2)
 {
   TRACE;
-  _x=new QVector<double>(2);
-  _y=new QVector<double>(2);
+  _x=new VectorList<double>(2);
+  _y=new VectorList<double>(2);
   (*_x)[0]=x1;
   (*_y)[0]=y1;
   (*_x)[1]=x2;
@@ -135,12 +135,12 @@ void CompatFunction::line(double x1, double y1, double x2, double y2)
 
   Don't forget to call deleteVectors(), x, y and dy are allocated here
 */
-void CompatFunction::set(QVector<Point>& f)
+void CompatFunction::set(VectorList<Point>& f)
 {
   TRACE;
-  QVector<double> * x=new QVector<double>;
-  QVector<double> * y=new QVector<double>;
-  QVector<double> * dy=new QVector<double>;
+  VectorList<double> * x=new VectorList<double>;
+  VectorList<double> * y=new VectorList<double>;
+  VectorList<double> * dy=new VectorList<double>;
   for(int i=0;i<f.count();i++) {
     Point& p=f[i];
     x->append(p.x());
@@ -160,7 +160,7 @@ void CompatFunction::set(QVector<Point>& f)
 /*!
   Set vector of X values, size must be >1
 */
-void CompatFunction::setX(QVector<double> * x)
+void CompatFunction::setX(VectorList<double> * x)
 {
   TRACE;
   if(_y && (!x || _y->size()!=x->size())) {
@@ -175,7 +175,7 @@ void CompatFunction::setX(QVector<double> * x)
 /*!
   Set vector of Y values, size must equal to x size
 */
-void CompatFunction::setY(QVector<double> * y)
+void CompatFunction::setY(VectorList<double> * y)
 {
   TRACE;
   if(_x &&(!y || _x->size()!=y->size())) {
@@ -190,7 +190,7 @@ void CompatFunction::setY(QVector<double> * y)
 /*!
   Set vector of YErr values, size must equal to x size
 */
-void CompatFunction::setYErr(QVector<double> * yErr)
+void CompatFunction::setYErr(VectorList<double> * yErr)
 {
   TRACE;
   if(_x) {
@@ -215,7 +215,7 @@ void CompatFunction::setYErr(QVector<double> * yErr)
 /*!
   Set vector of ErrWeight values, size must equal to x size
 */
-void CompatFunction::setWeight(QVector<double> * w)
+void CompatFunction::setWeight(VectorList<double> * w)
 {
   TRACE;
   if(_x) {
@@ -245,10 +245,10 @@ void CompatFunction::addPoint(int atIndex, double x, double y, double z)
   TRACE;
   if(!_x || !_y) {
     deleteVectors();
-    _x=new QVector<double>;
-    _y=new QVector<double>;
-    _yErr=new QVector<double>;
-    _weight=new QVector<double>;
+    _x=new VectorList<double>;
+    _y=new VectorList<double>;
+    _yErr=new VectorList<double>;
+    _weight=new VectorList<double>;
     _n2=1;
     _isSorted=true;
   }
@@ -361,7 +361,7 @@ void CompatFunction::resize(int n, bool removeLast)
   TRACE;
   if(_x->size()>n && !removeLast) {
     int removeCount=_x->size()-n;
-    QVector<double>::iterator it=_x->begin();
+    VectorList<double>::iterator it=_x->begin();
     int i;
     for(i=0;i<removeCount;i++) it=_x->erase(it);
     it=_y->begin();
@@ -412,16 +412,16 @@ void CompatFunction::resample_ds(int n, double min, double max,bool isLog,bool i
   if(min<minX()) min=minX();
   if(max>maxX()) max=maxX();
   // Calculate the "distance" abscisse
-  QVector<double> * tmp_dist=new QVector<double>(_x->size());
+  VectorList<double> * tmp_dist=new VectorList<double>(_x->size());
   (*tmp_dist)[0]=0;
-  //cout << "********* original transformed values" << endl;
+  //cout << "********* original transformed values" << Qt::endl;
   int i;
   for(i=1;i<(int)_x->size();i++) {
     double deltaX,deltaY;
     deltaX=((*_x)[i]-(*_x)[i-1])/valX;
     deltaY=((*_y)[i]-(*_y)[i-1])/valY;
     (*tmp_dist)[i]=(*tmp_dist)[i-1]+sqrt(deltaX*deltaX+deltaY*deltaY);
-    //cout << i << " " << (*_x)[i] << " " << (*_y)[i] << " " << (*tmp_dist)[i] << endl;
+    //cout << i << " " << (*_x)[i] << " " << (*_y)[i] << " " << (*tmp_dist)[i] << Qt::endl;
   }
   // Calculate the distance of min and max, and constant step
   double distMax=interpole(max,find(max,_x),_x,tmp_dist);
@@ -434,14 +434,14 @@ void CompatFunction::resample_ds(int n, double min, double max,bool isLog,bool i
   double * tmp_weight=0; if(_weight) tmp_weight=new double[n];
   // Intepolate new values for _x, _y and _yErr
   double dist=distMin;
-  //cout << "DistMinMaxStep: " <<  distMin << " " << distMax << " " << cstStep << endl;
+  //cout << "DistMinMaxStep: " <<  distMin << " " << distMax << " " << cstStep << Qt::endl;
   for(i=0;i<n;i++,dist+=cstStep) {
     int iDist=find(dist,tmp_dist);
     tmp_x[i]=interpole(dist,iDist,tmp_dist,_x);
     tmp_y[i]=interpole(dist,iDist,tmp_dist,_y);
     if(tmp_yErr) tmp_yErr[i]=interpole(dist,iDist,tmp_dist,_yErr);
     if(tmp_weight) tmp_weight[i]=interpole(dist,iDist,tmp_dist,_weight);
-    //cout << i << " " << dist << " " << tmp_x[i] << " " << tmp_y[i] << endl;
+    //cout << i << " " << dist << " " << tmp_x[i] << " " << tmp_y[i] << Qt::endl;
   }
   delete tmp_dist;
   // resize original vectors
@@ -520,10 +520,10 @@ void CompatFunction::resample(int n, double min, double max,bool isLog,bool isIn
 /*!
   Resample the function at x defined by xModel (.x of xModel)
 */
-void CompatFunction::resample(QVector<Point>& xModel,double invalid_value, bool doInterpole)
+void CompatFunction::resample(VectorList<Point>& xModel,double invalid_value, bool doInterpole)
 {
   TRACE;
-  QVector<double> x(xModel.count());
+  VectorList<double> x(xModel.count());
   for(int i=0;i<xModel.count();i++) x[i]=xModel[i].x();
   resample(&x, invalid_value, doInterpole);
 }
@@ -531,7 +531,7 @@ void CompatFunction::resample(QVector<Point>& xModel,double invalid_value, bool
 /*!
   Resample the function at x defined by xModel (e.g. from another function)
 */
-void CompatFunction::resample(QVector<double> * xModel,double invalid_value, bool doInterpole)
+void CompatFunction::resample(VectorList<double> * xModel,double invalid_value, bool doInterpole)
 {
   TRACE;
   ASSERT(_isSorted);
@@ -630,18 +630,12 @@ void CompatFunction::removeInvalidValues(double invalidValue)
 {
   TRACE;
   ASSERT(_isSorted);
-  QVector<double>::iterator itx=_x->begin();
-  QVector<double>::iterator ity=_y->begin();
-  QVector<double>::iterator ityErr=0;
-  if(_yErr) ityErr=_yErr->begin();
-  QVector<double>::iterator itweight=0;
-  if(_weight) itweight=_weight->begin();
   for(int i=_x->count()-1;i>=0;i--) {
-    if(*(ity+i)==invalidValue) {
-      _x->erase(itx+i);
-      _y->erase(ity+i);
-      if(_yErr) _yErr->erase(ityErr+i);
-      if(_weight) _weight->erase(itweight+i);
+    if(_y->at(i)==invalidValue) {
+      _x->removeAt(i);
+      _y->removeAt(i);
+      if(_yErr) _yErr->removeAt(i);
+      if(_weight) _weight->removeAt(i);
     }
   }
 }
@@ -665,7 +659,7 @@ double CompatFunction::minY()
   TRACE;
   ASSERT(_isSorted);
   double val=std::numeric_limits<double>::infinity();
-  QVector<double>::iterator it;
+  VectorList<double>::iterator it;
   for(it=_y->begin();it!=_y->end();++it) if(*it<val) val=*it;
   return val;
 }
@@ -706,7 +700,7 @@ double CompatFunction::maxY()
   TRACE;
   ASSERT(_isSorted);
   double val=-std::numeric_limits<double>::infinity();
-  QVector<double>::iterator it;
+  VectorList<double>::iterator it;
   for(it=_y->begin();it!=_y->end();++it) if(*it>val) val=*it;
   return val;
 }
@@ -718,7 +712,7 @@ void CompatFunction::log10()
 {
   TRACE;
   ASSERT(_isSorted);
-  QVector<double>::iterator it;
+  VectorList<double>::iterator it;
   for(it=_x->begin();it!=_x->end();++it) *it=::log10(*it);
 }
 
@@ -729,7 +723,7 @@ void CompatFunction::exp10()
 {
   TRACE;
   ASSERT(_isSorted);
-  QVector<double>::iterator it;
+  VectorList<double>::iterator it;
   for(it=_x->begin();it!=_x->end();++it) *it=pow(10,*it);
 }
 
@@ -756,7 +750,7 @@ void CompatFunction::inverseX()
     for(i=0;i<=n;i++) tmp[n-i]=(*_weight)[i];
     for(i=0;i<=n;i++) (*_weight)[i]=tmp[i];
   }
-  delete tmp;
+  delete [] tmp;
 }
 
 void CompatFunction::inverseY(double invalidValue)
@@ -836,8 +830,8 @@ double CompatFunction::fitFactor(int index,double val)
   [indexInVector]
 */
 double CompatFunction::interpole(double val,int indexInVector,
-                              QVector<double> * inVector,
-                              QVector<double> * outVector)
+                              VectorList<double> * inVector,
+                              VectorList<double> * outVector)
 {
   TRACE;
   return (*outVector)[indexInVector-1]+
@@ -851,21 +845,21 @@ double CompatFunction::interpole(double val,int indexInVector,
   is always greater or equal to 1. Uses dichotomy, best for functions with
   more than 10 values. Never return a number less than 1
 */
-int CompatFunction::find(double val,QVector<double> * inVector)
+int CompatFunction::find(double val,VectorList<double> * inVector)
 {
   TRACE;
-  //cout << "******* Find " << val << endl;
+  //cout << "******* Find " << val << Qt::endl;
   //for(uint i=0;i<inVector->size();i++)
-  //  cout << i << " " << (*inVector)[i] << endl;
+  //  cout << i << " " << (*inVector)[i] << Qt::endl;
   if(!inVector) return 1;
-  QVector<double>& vect=*inVector;
+  VectorList<double>& vect=*inVector;
   if(val<=vect[0]) return 1;
   int lasti=(int)vect.size()-1;
   if(val>vect[lasti-1]) return lasti;
   int i=_n2;
   int step2=i >> 1;
   while(step2>0) {
-    //cout << i << " " << lasti << " " << step2 << " " << vect[i] << endl;
+    //cout << i << " " << lasti << " " << step2 << " " << vect[i] << Qt::endl;
     if(i>lasti) i-=step2;
     else if(val<=vect[i]) {
       if(val>vect[i-1]) break;
@@ -873,20 +867,20 @@ int CompatFunction::find(double val,QVector<double> * inVector)
     } else i+=step2;
     step2=step2 >> 1;
   }
-  //cout << "Returning " << i << endl;
+  //cout << "Returning " << i << Qt::endl;
   return i;
 }
 
 /*!
   Try to find modes by analysing first and second derivative
 */
-void CompatFunction::getModes(QVector<double>& mean,
-                           QVector<double>& stddev)
+void CompatFunction::getModes(VectorList<double>& mean,
+                           VectorList<double>& stddev)
 {
   TRACE;
   ASSERT(_isSorted);
-  QVector<double>& xvect=*_x;
-  QVector<double>& yvect=*_y;
+  VectorList<double>& xvect=*_x;
+  VectorList<double>& yvect=*_y;
   double d1,d2=(yvect[1]-yvect[0])/(xvect[1]-xvect[0]);
   double dd;
   dd=0;
@@ -933,8 +927,8 @@ int CompatFunction::closestMax(int starti)
 {
   TRACE;
   ASSERT(_isSorted);
-  QVector<double>& xvect=*_x;
-  QVector<double>& yvect=*_y;
+  VectorList<double>& xvect=*_x;
+  VectorList<double>& yvect=*_y;
   int n=xvect.size();
   int di;
   if(starti==0) {
@@ -961,7 +955,7 @@ int CompatFunction::closestMax(int starti)
 void CompatFunction::multiplyX(double value)
 {
   TRACE;
-  QVector<double>& xvect=*_x;
+  VectorList<double>& xvect=*_x;
   for(int i=0;i<xvect.size();i++)
     xvect[i]*=value;
   if(value<=0) sort();
@@ -970,8 +964,8 @@ void CompatFunction::multiplyX(double value)
 void CompatFunction::multiplyXbyY()
 {
   TRACE;
-  QVector<double>& xvect=*_x;
-  QVector<double>& yvect=*_y;
+  VectorList<double>& xvect=*_x;
+  VectorList<double>& yvect=*_y;
   for(int i=0;i<xvect.size();i++)
     xvect[i]*=yvect[i];
   sort();
@@ -985,8 +979,8 @@ void CompatFunction::multiplyXbyY()
 double CompatFunction::average()
 {
   TRACE;
-  QVector<double>& xvect=*_x;
-  QVector<double>& yvect=*_y;
+  VectorList<double>& xvect=*_x;
+  VectorList<double>& yvect=*_y;
   double sum=0, lastx, curx, lasty, cury;
   lastx=xvect[0];
   lasty=yvect[0];
@@ -1008,8 +1002,8 @@ double CompatFunction::average()
 double CompatFunction::stddev(double average)
 {
   TRACE;
-  QVector<double>& xvect=*_x;
-  QVector<double>& yvect=*_y;
+  VectorList<double>& xvect=*_x;
+  VectorList<double>& yvect=*_y;
   double sum=0, lastx, curx, lasty, cury;
   lastx=xvect[0];
   lasty=yvect[0];
