@@ -263,28 +263,28 @@ void CompatMultiModalData::reportToDataWeight(QDataStream& s, bool loadIt)
   }
 }
 
-QVector<double> * CompatMultiModalData::measurements(int iMode)
+VectorList<double> * CompatMultiModalData::measurements(int iMode)
 {
   ASSERT(iMode<_modesCount);
-  QVector<double> * list=new QVector<double>;
+  VectorList<double> * list=new VectorList<double>;
   double * values=_measurements[iMode];
   for(int i=0;i<_omegasCount;i++) list->push_back(values[i]);
   return list;
 }
 
-QVector<double> * CompatMultiModalData::stddev(int iMode)
+VectorList<double> * CompatMultiModalData::stddev(int iMode)
 {
   ASSERT(iMode<_modesCount);
-  QVector<double> * list=new QVector<double>;
+  VectorList<double> * list=new VectorList<double>;
   double * values=_stddev[iMode];
   for(int i=0;i<_omegasCount;i++) list->push_back(values[i]);
   return list;
 }
 
-QVector<double> * CompatMultiModalData::weight(int iMode)
+VectorList<double> * CompatMultiModalData::weight(int iMode)
 {
   ASSERT(iMode<_modesCount);
-  QVector<double> * list=new QVector<double>;
+  VectorList<double> * list=new VectorList<double>;
   double * values=_weight[iMode];
   for(int i=0;i<_omegasCount;i++) list->push_back(values[i]);
   return list;
@@ -313,6 +313,11 @@ bool CompatMultiModalData::insideDev(double devRatio, int iMode,
                                   Point2D * pDisp, int countPoints)
 {
   TRACE;
+#ifndef QT_NO_DEBUG
+  ASSERT(countPoints==_omegasCount);
+#else
+  Q_UNUSED(countPoints);
+#endif
   ASSERT(countPoints==_omegasCount);
   double * measurements=_measurements[iMode];
   double * stddev=_stddev[iMode];
