@@ -179,6 +179,34 @@ namespace QGpCoreMath {
     return sign*d;
   }
 
+  /*!
+    Converts an angle string with or without a suffix to a radian value
+  */
+  double Angle::fromString(QString angle)
+  {
+    bool fromDegrees=true;
+    angle=angle.toLower();
+    if(angle.endsWith("deg") || angle.endsWith(tr("deg"))) {
+      angle.chop(3);
+    } else if(angle.endsWith("°")) {
+      angle.chop(1);
+    } else if(angle.endsWith("rad") || angle.endsWith(tr("rad"))) {
+      angle.chop(3);
+      fromDegrees=false;
+    }
+    bool ok;
+    double a=angle.trimmed().toDouble(&ok);
+    if(!ok) {
+      App::log(tr("Error parsing angle '%1'\n").arg(angle));
+      return 0.0;
+    } else {
+      if(fromDegrees) {
+        a=degreesToRadians(a);
+      }
+      return a;
+    }
+  }
+
   /*!
     Maintains degrees and radians between 0 and 360, 0 and 2*pi, respectivelly.
   */
@@ -200,14 +228,14 @@ namespace QGpCoreMath {
     Returned angle is between -M_PI to M_PI.
     \a angle must be inside [0, 2*pi[
   */
-  double Angle::aroundZero(double angle)
+  double Angle::aroundZero(double radians)
   {
-    if(angle<=0.5*M_PI) {
-      return angle;
-    } else if(angle<1.5*M_PI) {
-      return angle-M_PI;
+    if(radians<=0.5*M_PI) {
+      return radians;
+    } else if(radians<1.5*M_PI) {
+      return radians-M_PI;
     } else {
-      return angle-2.0*M_PI;
+      return radians-2.0*M_PI;
     }
   }
 
@@ -245,6 +273,23 @@ namespace QGpCoreMath {
     return angle;
   }
 
+  double Angle::canonicalGradians(double angle)
+  {
+    TRACE;
+    if(angle<0.0) {
+      angle+=400.0;
+      while(angle<0.0) {
+        angle+=400.0;
+      }
+    } else if(angle>=400.0) {
+      angle-=400.0;
+      while(angle>=400.0) {
+        angle-=400.0;
+      }
+    }
+    return angle;
+  }
+
   /*!
     Return an angle difference \a a1 - \a a2 between -M_PI and M_PI
   */
@@ -253,9 +298,9 @@ namespace QGpCoreMath {
     TRACE;
     double diff=a1-a2;
     if(diff<-M_PI) {
-      diff+=2*M_PI;
+      diff+=2.0*M_PI;
     } else if(diff>M_PI) {
-      diff-=2*M_PI;
+      diff-=2.0*M_PI;
     }
     return diff;
   }
@@ -274,6 +319,20 @@ namespace QGpCoreMath {
     }
     return diff;
   }
+  /*!
+    Return an angle difference \a a1 - \a a2 between -200 and 200
+  */
+  double Angle::differenceGradians(double a1, double a2)
+  {
+    TRACE;
+    double diff=a1-a2;
+    if(diff<-200.0) {
+      diff+=400.0;
+    } else if(diff>200.0) {
+      diff-=400.0;
+    }
+    return diff;
+  }
 
   /*!
     \fn bool Angle::isInside(double angle, double min, double max)
@@ -283,4 +342,47 @@ namespace QGpCoreMath {
     \a min and \a max must be betwen -2*pi and 2*pi.
   */
 
+  void Angle::setValue(Mode m, double v)
+  {
+    switch(m) {
+    case Degrees:
+      setDegrees(v);
+      break;
+    case Radians:
+      setRadians(v);
+      break;
+    case Gradians:
+      setGradians(v);
+      break;
+    }
+  }
+
+  void Angle::setGeographicValue(Mode m, double v)
+  {
+    switch(m) {
+    case Degrees:
+      setGeographicDegrees(v);
+      break;
+    case Radians:
+      setGeographicRadians(v);
+      break;
+    case Gradians:
+      setGeographicGradians(v);
+      break;
+    }
+  }
+
+  double Angle::value(Mode m) const
+  {
+    switch(m) {
+    case Degrees:
+      break;
+    case Radians:
+      return radians();
+    case Gradians:
+      return gradians();
+    }
+    return degrees();
+  }
+
 } // namespace QGpCoreMath
