@@ -39,12 +39,11 @@ public:
   Circle(double x0=0.0, double y0=0.0, double r=0.0);
   Circle(const Point2D& c, double r);
   Circle(const Point2D& p1, const Point2D& p2, const Point2D& p3);
-  Circle(const Circle& o);
 
   const Point2D& center() const {return _c;}
   double radius() const {return _r;}
 
-  QVector<Point2D> intersect(const Circle& o) const;
+  VectorList<Point2D> intersect(const Circle& o) const;
   Point2D intersect(const Circle& o, bool& ok, const Circle& disc) const;
   double distanceTo(const Point2D& p) const;
   bool contains(const Point2D& p, double relativeTolerance=1.0) const;
