@@ -76,8 +76,10 @@ ColorMapData::~ColorMapData()
 void ColorMapData::setPalette(const ColorPalette& pal)
 {
   TRACE;
+  _palette=pal; // ColorPalette can have only one element
+                // We need at least 2, hence do resize
+                // after ColorPalette::operator=().
   resize(pal.count());
-  _palette=pal;
 }
 
 bool ColorMapData::operator==(const ColorMapData& o) const
@@ -87,7 +89,9 @@ bool ColorMapData::operator==(const ColorMapData& o) const
     int n1=count()-1;
     for(int i=0; i<n1; i++) {
       if(_upperValues[i]!=o._upperValues[i]) {
-        return false;
+        if(!isnan(_upperValues[i]) || !isnan(o._upperValues[i])) {
+          return false;
+        }
       }
     }
     return true;
@@ -109,6 +113,9 @@ void ColorMapData::resize(int n)
 {
   TRACE;
   if(!_upperValues || n!=count()) {
+    if(n<2) {
+      n=2;
+    }
     _palette.resize(n);
     if(_upperValues) {
       delete [] _upperValues;
