@@ -49,10 +49,10 @@ namespace QGpCoreMath {
 
     ColorPalette palette() const {return _palette;}
     void setPalette(const ColorPalette& pal);
-    inline void generateColorScale(int n, ColorPalette::Model m=ColorPalette::McNamesClip,
-                                   bool reversed=false, int transparency=255);
-    inline void generateGrayScale(int n, ColorPalette::Model m=ColorPalette::McNamesClip,
-                                  bool reversed=false, int transparency=255);
+    inline void generate(int imin, int imax, const QString& model,
+                         ColorPalette::Options options=ColorPalette::Continuous,
+                         quint16 transparency=COLOR_COMPONENT_MAX);
+    inline void toGray();
     void rgbInterpole(int imin, int imax) {_palette.rgbInterpole(imin, imax);}
     void hsvInterpole(int imin, int imax) {_palette.hsvInterpole(imin, imax);}
     void setWhiteTransparent(bool b) {_palette.setWhiteTransparent(b);}
@@ -80,18 +80,18 @@ namespace QGpCoreMath {
     int _n2;
   };
 
-  inline void ColorMapData::generateColorScale(int n, ColorPalette::Model m,
-                                               bool reversed, int transparency)
+  inline void ColorMapData::generate(int imin, int imax, const QString& model,
+                                     ColorPalette::Options options, quint16 transparency)
   {
-    resize(n);
-    _palette.generateColorScale(n, m, reversed, transparency);
+    if(imax>_palette.count()-1) {
+      resize(imax+1);
+    }
+    _palette.generate(imin, imax, model, options, transparency);
   }
 
-  inline void ColorMapData::generateGrayScale(int n, ColorPalette::Model m,
-                                              bool reversed, int transparency)
+  inline void ColorMapData::toGray()
   {
-    resize(n);
-    _palette.generateGrayScale(n, m, reversed, transparency);
+    _palette.toGray();
   }
 
 } // namespace QGpCoreMath
