@@ -27,6 +27,7 @@
 #include "ColorPalette.h"
 #include "Point.h"
 #include "DoubleMatrix.h"
+#include "ColorPaletteModels.h"
 
 namespace QGpCoreMath {
 
@@ -37,6 +38,13 @@ namespace QGpCoreMath {
     Full description of class still missing
   */
 
+  const QString ColorPalette::defaultSequential="batlow";
+  const QString ColorPalette::defaultSequentialWhite="batlowW";
+  const QString ColorPalette::defaultDiverging="vik";
+  const QString ColorPalette::defaultMultiSequential="bukavu";
+  const QString ColorPalette::defaultCyclic="vikO";
+  const QString ColorPalette::defaultCategorical="batlowS";
+
   /*!
     Description of constructor still missing
   */
@@ -94,8 +102,8 @@ namespace QGpCoreMath {
   void ColorPalette::resize(int n)
   {
     TRACE;
-    if(n<2) {
-      n=2;
+    if(n<1) {
+      n=1;
     }
     if(!_colors || n!=_n) {
       if(_colors) {
@@ -106,55 +114,73 @@ namespace QGpCoreMath {
     }
   }
 
-  void ColorPalette::generateColorScale(int n, Model m, bool reversed, int transparency)
+  /*!
+    Interpole color
+  */
+  Color ColorPalette::color(double index) const
   {
-    TRACE;
-    switch(m) {
-    case Hobi:
-      hobi(n, transparency);
-      break;
-    case McNames:
-      mcNames(n, n, transparency);
-      break;
-    case McNamesClip: // Avoid too dark colors
-      mcNames(n, n*5/4, transparency);
-      break;
-    case Hsv:
-      hsv(n, 255, 255, transparency);
-      break;
-    case Sardine:
-      sardineColorScale(n, transparency);
-      break;
-    case ColdHot:
-      coldHot(n, transparency);
-      break;
-    }
-    if(reversed) {
-      reverse();
-    }
+    int i0=qFloor(index);
+    double di=index-i0;
+    const Color& a=_colors[i0];
+    const Color& b=_colors[i0+1];
+    Color c;
+    c.setRed64(a.red64()*(1.0-di)+b.red64()*di);
+    c.setGreen64(a.green64()*(1.0-di)+b.green64()*di);
+    c.setBlue64(a.blue64()*(1.0-di)+b.blue64()*di);
+    return c;
   }
 
-  void ColorPalette::generateGrayScale(int n, Model m, bool reversed, int transparency)
+  void ColorPalette::generate(int imin, int imax, const QString& model,
+                              Options options, quint16 transparency)
   {
     TRACE;
-    sardineGrayScale(n, transparency);
-    // HSV or McNames do not have a linear monotonic luminance
-    // McNames was supposed to have this monotonic luminance, but not observed
-    /*switch(m) {
-    case McNames:
-      mcNames(n, transparency);
-      toGray();
-      break;
-    case Hsv:
-      hsv(n, 255, 255, transparency);
-      toGray();
-      break;
-    case Sardine:
-      sardineGrayScale(n, transparency);
-      break;
-    }*/
-    if(reversed) {
-      reverse();
+    if(imin<0) {
+      imin=0;
+    }
+    if(imax>=_n) {
+      resize(imax+1);
+    }
+    const ColorPalette * ref=ColorPaletteModels::instance()->palette(model);
+    int lastIndex=ref->count()-1;
+    if(options & Categorical) {
+      int index;
+      if(options & Reversed) {
+        for(int i=imin; i<=imax; i++) {
+          index=lastIndex-(i-imin);
+          while(index>=0) {
+            index+=ref->count();
+          }
+          _colors[i]=ref->color(lastIndex-(i-imin));
+          _colors[i].setAlpha64(transparency);
+        }
+      } else {
+        for(int i=imin; i<=imax; i++) {
+          index=i-imin;
+          while(index>lastIndex) {
+            index-=ref->count();
+          }
+          _colors[i]=ref->color(index);
+          _colors[i].setAlpha64(transparency);
+        }
+      }
+    } else {
+      double fac=lastIndex;
+      if(imax-imin>1) {
+        fac/=static_cast<double>(imax-imin);
+      } else {
+        fac=0.0;
+      }
+      if(options & Reversed) {
+        for(int i=imin; i<=imax; i++) {
+          _colors[i]=ref->color(lastIndex-qRound((i-imin)*fac));
+          _colors[i].setAlpha64(transparency);
+        }
+      } else {
+        for(int i=imin; i<=imax; i++) {
+          _colors[i]=ref->color(qRound((i-imin)*fac));
+          _colors[i].setAlpha64(transparency);
+        }
+      }
     }
   }
 
@@ -165,11 +191,10 @@ namespace QGpCoreMath {
   void ColorPalette::setWhiteTransparent(bool b)
   {
     TRACE;
-    int white=0x00FFFFFF;
     for(int i=0; i<_n; i++) {
       Color& c=_colors[i];
-      if(c.rgb()==white) {
-        c.setAlpha(b ? 0 : 0xFF);
+      if(c.isNearlyWhite()) {
+        c.setAlpha64(b ? 0x0000 : 0xFFFF);
       }
     }
   }
@@ -182,77 +207,27 @@ namespace QGpCoreMath {
     }
   }
 
-  void ColorPalette::reverse()
-  {
-    TRACE;
-    Color * nc=new Color[_n];
-    int n1=_n-1;
-    for(int i=0; i<_n; i++) {
-      nc[i]=_colors[n1-i];
-    }
-    delete [] _colors;
-    _colors=nc;
-  }
-
-  /*!
-    Implementation inherited from Sardine (D. Demanet).
-    It was the default color palette under Sardine
-  */
-  void ColorPalette::sardineColorScale(int n, int transparency)
-  {
-    TRACE;
-    resize(n);
-    if(_n==2) {
-      _colors[0]=Color(0, 0, 255, transparency);
-      _colors[1]=Color(255, 0, 0, transparency);
-    } else if(_n==3) {
-      _colors[0]=Color(0, 0, 255, transparency);
-      _colors[1]=Color(0, 255, 0, transparency);
-      _colors[2]=Color(255, 0, 0, transparency);
-    } else {
-      double x, r, g, b;
-
-      int n1=_n/3;
-      int n2=n1+(_n-n1)/2;
-      int i;
-      for(i=0; i<n1; i++) {
-        x=static_cast<double>(i)/static_cast<double>(n1);
-        r=0.;
-        g=pow(x, 0.3);
-        b=1.0-x*x;
-        _colors[i].setRgba(qRound(r*255.0), qRound(g*255.0), qRound(b*255.0), transparency);
-      }
-      for(i=n1; i<n2; i++) {
-        x=static_cast<double>(i-n1)/static_cast<double>(n2-n1);
-        r=pow(x, 0.3);
-        g=1.0;
-        b=0.0;
-        _colors[i].setRgba(qRound(r*255.0), qRound(g*255.0), qRound(b*255.0), transparency);
-      }
-      for(i=n2; i < _n; i++ ) {
-        x=static_cast<double>(i-n2)/static_cast<double>(n-n2-1);
-        r=1.0;
-        g=1.0-x*x;
-        b=0.0;
-        _colors[i].setRgba(qRound(r*255.0), qRound(g*255.0), qRound(b*255.0), transparency);
-      }
-    }
-  }
-
   /*!
     Implementation inherited from Sardine (D. Demanet).
     It was the default gray palette under Sardine
   */
-  void ColorPalette::sardineGrayScale(int n, int transparency)
+  void ColorPalette::sardineGrayScale(int imin, int imax)
   {
     TRACE;
-    resize(n);
-    double x, g;
-
-    for(int i=0; i<_n; i++) {
-      x=static_cast<double>(i)/static_cast<double>(n-1);
-      g=1.0-x*x;
-      _colors[i]=Color(qRound(g*255.0), qRound(g*255.0), qRound(g*255.0), transparency);
+    if(imin<0) {
+      imin=0;
+    }
+    if(imax>=_n) {
+      resize(imax+1);
+    }
+    double x;
+    double fac=1.0/static_cast<double>(imax-imin);
+    for(int i=imin; i<=imax; i++) {
+      x=static_cast<double>(i-imin)*fac;
+      x=1.0-x*x;
+      _colors[i].setRgba64(qRound(x*COLOR_COMPONENT_MAX),
+                           qRound(x*COLOR_COMPONENT_MAX),
+                           qRound(x*COLOR_COMPONENT_MAX), COLOR_COMPONENT_MAX);
     }
   }
 
@@ -261,81 +236,7 @@ namespace QGpCoreMath {
     TRACE;
     resize(n);
     for(int i=0; i<_n; i++) {
-      _colors[i].setHsva(qRound(static_cast<double>(i)*255.0/static_cast<double>(_n)), sat, value, transparency);
-    }
-  }
-
-  void ColorPalette::hobi(int n, int transparency)
-  {
-    TRACE;
-    resize(n);
-    int n2=_n >> 1;
-    _colors[0].setRgba(128, 128, 128, transparency);
-    _colors[n2].setRgba(255, 255, 0, transparency);
-    _colors[_n-1].setRgba(170, 0, 0, transparency);
-    hsvInterpole(0, n2);
-    hsvInterpole(n2, _n-1);
-  }
-
-  void ColorPalette::coldHot(int n, int transparency)
-  {
-    TRACE;
-    resize(n);
-    int n2=_n >> 1;
-    _colors[0].setRgba(0, 0, 255, transparency);
-    _colors[n2-1].setRgba(225, 225, 255, transparency);
-    if(n2 << 1==_n) {
-      _colors[n2].setRgba(255, 225, 225, transparency);
-      n2--;
-    } else {
-      _colors[n2].setRgba(255, 255, 255, transparency);
-      _colors[n2+1].setRgba(255, 225, 225, transparency);
-    }
-    _colors[_n-1].setRgba(255, 0, 0, transparency);
-    hsvInterpole(0, n2-1);
-    hsvInterpole(n2+1, _n-1);
-  }
-
-  /*!
-    Color palette proposed by
-    "An Effective Color Scale for Simultaneous Color and Gray-Scale Publications"
-    in IEEE SIGNAL PROCESSING MAGAZINE, JANUARY 2006, pp 82-87
-
-    To avoid last dark colors, n0 can be higher than n. The color palette is calculated on \a n0.
-  */
-  void ColorPalette::mcNames(int n, int n0, int transparency)
-  {
-    TRACE;
-    ASSERT(n0>=n);
-
-    resize(n);
-    Point rgb;
-    double p=2.0; // Number of cycles that occur over the range
-                  // Between 1.5 and 3.0, 2.0 used in paper
-    double t;
-    double f=sqrt(3)/(n0-1);
-    double fw=2.0/(n0-2);
-    double nw=(n0-3)*0.5+1.0;
-    double c1=2*M_PI/sqrt(3);
-    double c2=sqrt(3)*0.5;
-    double w;
-
-    Matrix3x3 blueRotation(3), greenRotation(3);
-    Angle blueAngle, greenAngle;
-    blueAngle.setRadians(asin(1/sqrt(3)));
-    greenAngle.setRadians(-M_PI*0.25);
-    blueRotation.rotation(ZAxis, blueAngle);
-    greenRotation.rotation(YAxis, greenAngle);
-
-    int di=n0-n;
-    for(int i=0; i<_n; i++) {
-      int i0=i+di;
-      t=f*i0;
-      w=(i==0 || i==_n-1) ? 0.0 : sqrt(3.0/8.0)*(1.0-fabs((i0-nw)*fw)); // TODO: use hyperbolic function
-      rgb=Point(t, w*cos(p*c1*(t-c2)), w*sin(p*c1*(t-c2)));
-      rgb=blueRotation*rgb;
-      rgb=greenRotation*rgb;
-      _colors[i].setRgba(qRound(rgb.x()*255.0), qRound(rgb.y()*255.0), qRound(rgb.z()*255.0), transparency);
+      _colors[i].setHsva(qRound(static_cast<double>(i)*65535.0/static_cast<double>(_n)), sat, value, transparency);
     }
   }
 
@@ -354,16 +255,16 @@ namespace QGpCoreMath {
     }
 
     Color& c1=_colors[imin];
-    r=c1.red();
-    g=c1.green();
-    b=c1.blue();
-    a=c1.alpha();
+    r=c1.red64();
+    g=c1.green64();
+    b=c1.blue64();
+    a=c1.alpha64();
 
     Color& c2=_colors[imax];
-    r2=c2.red();
-    g2=c2.green();
-    b2=c2.blue();
-    a2=c2.alpha();
+    r2=c2.red64();
+    g2=c2.green64();
+    b2=c2.blue64();
+    a2=c2.alpha64();
 
     dr=(r2-r)/static_cast<double>(imax-imin+1);
     dg=(g2-g)/static_cast<double>(imax-imin+1);
@@ -375,7 +276,7 @@ namespace QGpCoreMath {
       g+=dg;
       b+=db;
       a+=da;
-      _colors[i].setRgba(qRound(r), qRound(g), qRound(b), qRound(a));
+      _colors[i].setRgba64(qRound(r), qRound(g), qRound(b), qRound(a));
     }
   }
 
@@ -396,11 +297,11 @@ namespace QGpCoreMath {
 
     Color& c1=_colors[imin];
     c1.hsv(h1, s1, v1);
-    a1=c1.alpha();
+    a1=c1.alpha64();
 
     Color& c2=_colors[imax];
     c2.hsv(h2, s2, v2);
-    a2=c2.alpha();
+    a2=c2.alpha64();
 
     dh=static_cast<double>(h2-h1)/static_cast<double>(imax-imin+1);
     ds=static_cast<double>(s2-s1)/static_cast<double>(imax-imin+1);
@@ -423,10 +324,10 @@ namespace QGpCoreMath {
   QString ColorPalette::toString() const
   {
     TRACE;
-    QString s=_colors[0].name();
+    QString s=_colors[0].toString();
     for(int i=1; i<_n; i++) {
       s+=",";
-      s+=_colors[i].name();
+      s+=_colors[i].toString();
     }
     return s;
   }
@@ -437,8 +338,10 @@ namespace QGpCoreMath {
     QStringList l=s.split(",");
     if(l.count()>=2) {
       resize(l.count());
+      bool ok=true;
       for(int i=0; i<_n; i++) {
-        if(!_colors[i].setNamedColor(l.at(i))) {
+        _colors[i].fromString(l.at(i), ok);
+        if(!ok) {
           return false;
         }
       }
@@ -448,14 +351,15 @@ namespace QGpCoreMath {
     }
   }
 
-  ColorPalette ColorPalette::preference(const QString& name, int n, Model m)
+  ColorPalette ColorPalette::preference(const QString& name, int n, const QString& model,
+                                        Options options, quint16 transparency)
   {
     TRACE;
     QSettings& reg=CoreApplication::instance()->settings();
     reg.beginGroup("ColorPalettes");
     ColorPalette pal;
     if(!reg.contains(name) || !pal.fromString(reg.value(name).toString())) {
-      pal.generateColorScale(n, m);
+      pal.generate(0, n-1, model, options, transparency);
     }
     return pal;
   }
@@ -468,5 +372,9 @@ namespace QGpCoreMath {
     reg.setValue(name, pal.toString());
   }
 
+  ENUM_AS_STRING_BEGIN(ColorPalette, Option)
+  ENUM_AS_STRING_DATA_3(Categorical, Continuous, Reversed);
+  ENUM_AS_STRING_END
+
 } // namespace QGpCoreMath
 
