@@ -25,6 +25,7 @@
 ***************************************************************************/
 
 #include "ComplexStatisticalProxy.h"
+#include "IrregularGrid2D.h"
 
 namespace QGpCoreMath {
 
@@ -35,7 +36,7 @@ namespace QGpCoreMath {
     Full description of class still missing
   */
 
-  CURVEPROXY_BASICIMPLEMENTATIONS(ComplexStatisticalProxy)
+  CURVEPROXY_BASIC_IMPLEMENTATIONS(ComplexStatisticalProxy)
 
   QString ComplexStatisticalProxy::columnName(int col) const
   {
@@ -58,10 +59,10 @@ namespace QGpCoreMath {
     return QString();
   }
 
-  QVector<int> ComplexStatisticalProxy::savedColumns() const
+  VectorList<int> ComplexStatisticalProxy::savedColumns() const
   {
     TRACE;
-    QVector<int> l;
+    VectorList<int> l;
     l << 0 << 1 << 2 << 5 << 6;
     return l;
   }
@@ -125,10 +126,10 @@ namespace QGpCoreMath {
     return types;
   }
 
-  QVector<int> ComplexStatisticalProxy::defaultColumnFileTypes() const
+  VectorList<int> ComplexStatisticalProxy::defaultColumnFileTypes() const
   {
     TRACE;
-    QVector<int> l;
+    VectorList<int> l;
     l << 1 << 2 << 3 << 6 << 7 << 8;
     return l;
   }
@@ -187,5 +188,56 @@ namespace QGpCoreMath {
     return true;
   }
 
+  double ComplexStatisticalProxy::y(int sample, const CurvePointOptions * options) const
+  {
+    const ComplexStatisticalPoint& p=curve().constAt(sample);
+    return p.y(options);
+  }
+
+  void ComplexStatisticalProxy::setY(int sample, double value,
+                                     const CurvePointOptions * options)
+  {
+    ComplexStatisticalPoint& p=curve().constXAt(sample);
+    p.setY(value, options);
+  }
+
+  double ComplexStatisticalProxy::stddev(int sample) const
+  {
+    const ComplexStatisticalPoint& p=curve().constAt(sample);
+    return p.stddev();
+  }
+
+  void ComplexStatisticalProxy::setStddev(int sample, double value)
+  {
+    ComplexStatisticalPoint& p=curve().constXAt(sample);
+    p.setStddev(value);
+  }
+
+  double ComplexStatisticalProxy::weight(int sample) const
+  {
+    const ComplexStatisticalPoint& p=curve().constAt(sample);
+    return p.weight();
+  }
+
+  void ComplexStatisticalProxy::setWeight(int sample, double value)
+  {
+    ComplexStatisticalPoint& p=curve().constXAt(sample);
+    p.setWeight(value);
+  }
+
+  void ComplexStatisticalProxy::interpole(double x, double& y, double& dy,
+                                          const CurvePointOptions * options,
+                                          SamplingOptions xSampling,
+                                          SamplingOptions ySampling) const
+  {
+    const ComplexStatisticalPoint& p=curve().interpole(x, xSampling, ySampling);
+    y=p.y(options);
+    dy=p.stddev();
+  }
+
+  void ComplexStatisticalProxy::followMaximumX(IrregularGrid2D * grid, double min, double max) {
+    grid->followMaximumX<Curve<ComplexStatisticalPoint>, ComplexStatisticalPoint>(*_curve, min, max);
+  }
+
 } // namespace QGpCoreMath
 
