@@ -226,16 +226,20 @@ namespace QGpCoreMath {
     UtmZone zone;
     int nColumns=columnCount();
     int nRows=rowCount();
+    QString txt;
     for(int iRow=0; iRow<nRows; iRow++) {
       for(int iCol=0; iCol<nColumns; iCol++) {
         switch(type(iCol)) {
         case 15:
-          zone.fromString(text(iRow, iCol));
-          if(zone.isValid()) {
-            stat[zone]++;
-          } else {
-            Message::warning(MSG_ID, tr("Read utm zone"), tr("Bad UTM zone at line %1.")
-                                     .arg(lineNumber(iRow)), true);
+          txt=text(iRow, iCol);
+          if(!txt.isEmpty() && txt!="---") {
+            zone.fromString(txt);
+            if(zone.isValid()) {
+              stat[zone]++;
+            } else {
+              Message::warning(MSG_ID, tr("Read utm zone"), tr("Bad UTM zone at line %1.")
+                                       .arg(lineNumber(iRow)), true);
+            }
           }
           break;
         default:
