@@ -35,6 +35,23 @@ namespace QGpCoreMath {
     Full description of class still missing
   */
 
+  bool CurveProxy::isAbove(const CurveProxy * o, const CurvePointOptions * pointOptions,
+                           SamplingOptions xSampling, SamplingOptions ySampling) const
+  {
+    double yo, dyo;
+    bool matchingRange=false;
+    for(int i=sampleCount()-1; i>=0; i--) {
+      if(o->isInsideRange(x(i))) {
+         matchingRange=true;
+         o->interpole(x(i), yo, dyo, pointOptions, xSampling, ySampling);
+         if(y(i, pointOptions)<=yo) {
+           return false;
+         }
+      }
+    }
+    return matchingRange;
+  }
+
   /*!
     Returns the title for column \a col.
   */
@@ -57,7 +74,7 @@ namespace QGpCoreMath {
   void CurveProxy::save(QTextStream& s)
   {
     TRACE;
-    QVector<int> cols=savedColumns();
+    VectorList<int> cols=savedColumns();
     QString logTmp=log();
     logTmp.replace("\n","\n# ");
     s << "# Curve name:" << name() << "\n"
@@ -65,13 +82,13 @@ namespace QGpCoreMath {
          "# " << logTmp << "\n"
          "# End curve log\n"
          "# | ";
-    for(QVector<int>::iterator it=cols.begin();it!=cols.end();it++) {
+    for(VectorList<int>::iterator it=cols.begin();it!=cols.end();it++) {
       s << columnTitle(*it) << " | ";
     }
     s << "\n";
     int n=sampleCount();
     for(int i=0;i < n;i++ ) {
-      for(QVector<int>::iterator it=cols.begin();it!=cols.end();it++) {
+      for(VectorList<int>::iterator it=cols.begin();it!=cols.end();it++) {
         s << columnValue(i, *it).toString() << " ";
       }
       if(isValid(i)) {
