@@ -42,11 +42,10 @@ namespace QGpCoreMath {
   Description of constructor still missing
 */
 DirectionalSearch::DirectionalSearch()
+  : FunctionSearch(2)
 {
   TRACE;
   _precision[0]=0.001;
-  _nr=0;
-  _r=0;
   _cx=1.0;
   _sy=0.0;
 }
@@ -57,7 +56,6 @@ DirectionalSearch::DirectionalSearch()
 DirectionalSearch::~DirectionalSearch()
 {
   TRACE;
-  delete [] _r;
 }
 
 /*!
@@ -71,108 +69,95 @@ void DirectionalSearch::setAzimuth(double azimuth)
 }
 
 /*!
-  Init sampling in radius. setFunction() must be called before.
+  Set gridding along radius
 */
-void DirectionalSearch::setGrid(double minR, double maxR, double dR)
+void DirectionalSearch::setGrid(double min, double max, double step)
 {
   TRACE;
-  ASSERT(_function);
+  ASSERT(max-min>step); // At least 1 point
+  _step=step;
+  _min=min;
+  _count=qFloor((max-min)/step);
+}
 
-  int nr=(int)floor((maxR-minR)/dR+0.5)+1;
-  if(nr!=_nr) {
-    delete [] _r;
-    _r=new double [nr];
-    _nr=nr;
-  }
+inline void DirectionalSearch::setCurrentPosition(int i)
+{
+  double r=_min+_step*i;
+  _currentPosition[0]=_cx*r;
+  _currentPosition[1]=_sy*r;
 }
 
-/*!
-  Search current azimuth for its maximum and refine it
-*/
 void DirectionalSearch::globalMax(double absThres)
 {
   TRACE;
-  int maxi=0;
-  double val,maxVal=-std::numeric_limits<double>::infinity();
-  for(int i=0; i<_nr; i++) {
-    val=_function->value(Point2D(_cx*_r[i], _sy*_r[i]), i);
+  clearMaxima();
+  double val, maxVal=-std::numeric_limits<double>::infinity();
+  int maxk=0;
+  for(int k=0; k<_count; k++) {
+    setCurrentPosition(k);
+    val=value(_currentPosition);
     if(val>maxVal) {
       maxVal=val;
-      maxi=i;
+      maxk=k;
     }
   }
-  // Refine search by recursion and re-regridding
-  val=refineMax(lowLimit(maxi, _r),highLimit(maxi, _r, _nr), maxVal);
-  clearMaxima();
-  FunctionSearchMaximum * max=_function->createMaximum(val, _pos);
-  if(max) {
-    _maxima.append(max);
-    FunctionSearch::globalMax(absThres);
-  }
-}
-
-void DirectionalSearch::localMax(int nMax, double absThres, double relThres)
-{
-  TRACE;
-  double * map=new double [_nr];
-  for(int i=0; i<_nr; i++) {
-    map[i]=_function->value(Point2D(_cx*_r[i], _sy*_r[i]), i);
-  }
-  clearMaxima();
-  int nm=_nr-1;
-  for(int i=1;i<nm;i++) {
-    if(map[i-1]>0 && map[i]>map[i-1] &&
-       map[i+1]>0 && map[i]>map[i+1]) {
-      double val=refineMax(_r[i-1], _r[i+1], map[i]);
-      FunctionSearchMaximum * max=_function->createMaximum(val, _pos);
-      if(max) {
-        _maxima.append(max);
-      }
-    }
-  }
-  delete [] map;
-  FunctionSearch::localMax(nMax, absThres, relThres);
-}
-
-inline void DirectionalSearch::checkForMax(double r, double& maxVal, double& maxR)
-{
-  TRACE;
-  double val=_function->value(Point2D(_cx*r, _sy*r));
-  if(val>maxVal) {
-    maxVal=val;
-    maxR=r;
-  }
+  setCurrentPosition(maxk);
+  addMaximum(maxVal);
+  FunctionSearch::globalMax(absThres);
 }
 
 /*!
-  Refines the maximum of the grid in an area defined by radius limits.
-  return value of the refined maximum
+  Description still missing
 */
-double DirectionalSearch::refineMax(double minR, double maxR, double maxVal)
+void DirectionalSearch::localMax(int nMax, double absThres, double relThres)
 {
   TRACE;
-  double r=(minR+maxR)*0.5;
-  double dr=(maxR-minR)*0.5;
+  clearMaxima();
+  double previous, current, next;
+  setCurrentPosition(0);
+  previous=value(_currentPosition);
+  setCurrentPosition(1);
+  current=value(_currentPosition);
+  for(int k=2; k<_count; k++) {
+    setCurrentPosition(k);
+    next=value(_currentPosition);
+    if(current>next &&
+      current>previous) {
+      setCurrentPosition(k-1);
+      addMaximum(current);
+    }
+    previous=current;
+    current=next;
+  }
+  FunctionSearch::localMax(nMax, absThres, relThres);
+}
 
+/*!
+  Refines the maximum of the grid in an area defined by current position +/- one step.
+  Returns value of the refined maximum
+*/
+double DirectionalSearch::refineMax(double val)
+{
+  TRACE;
   double absPrecision;
   if(_relative[0]) {
-    absPrecision=fabs(_precision[0]*r);
+    absPrecision=fabs(_currentPosition[0]*_precision[0]);
+    if(absPrecision==0.0) { // Make sure that precision is not null
+      absPrecision=fabs(_precision[0]*(_currentPosition[0]+_step*0.5));
+    }
   } else {
     absPrecision=_precision[0];
   }
 
-  while(dr>absPrecision) {
-    dr*=0.5;
-
-    double r1=r-dr;
-    double r2=r+dr;
-
-    checkForMax(r1, maxVal, r);
-    checkForMax(r2, maxVal, r);
+  double step=_step;
+  while(step>absPrecision) {
+    step*=0.5;
+    _testPosition[0]=_testPosition[0]-step;
+    testForMax(val);
+    _testPosition[0]=_testPosition[0]+step;
+    testForMax(val);
   }
-  _pos.setX(_cx*r);
-  _pos.setY(_sy*r);
-  return maxVal;
+  return val;
 }
 
 } // namespace QGpCoreMath
