@@ -32,7 +32,6 @@
 
 #include "QGpCoreMathDLLExport.h"
 #include "Matrix.h"
-#include "Vector.h"
 #include "Segment.h"
 #include "MatrixIterator.h"
 
@@ -45,14 +44,15 @@ namespace QGpCoreMath {
     DoubleMatrix(int ndim) : Matrix<double>(ndim) {}
     DoubleMatrix(int nrow, int ncol) : Matrix<double>(nrow, ncol) {}
     DoubleMatrix(const Matrix<double> m) : Matrix<double>(m) {}
-    DoubleMatrix(const DoubleMatrix& m) : Matrix<double>(m) {}
 
     void rotation(int axis1, int axis2, const Angle& angle);
     void rotation3D(AxisType ax, const Angle& angle);
     void random(double min=0.0, double max=1.0);
+    double determinant() const;
     bool invert();
-    void singularValues(QVector<double>& values, DoubleMatrix * u=nullptr, DoubleMatrix * vt=nullptr) const;
-    QVector<double> symetricEigenValues(bool& ok) const;
+    void singularValues(VectorList<double>& values, DoubleMatrix * u=nullptr, DoubleMatrix * vt=nullptr) const;
+    VectorList<double> symetricEigenValues(bool& ok) const;
+    VectorList<Complex> eigenValues() const;
     DoubleMatrix leastSquare(const DoubleMatrix& b) const;
   };
 
@@ -66,7 +66,6 @@ namespace QGpCoreMath {
     inline void rotation(const Angle& angle);
     Matrix2x2 operator*(const Matrix2x2& m) const {return DoubleMatrix::operator*(m);}
     Matrix<double> operator*(const Matrix<double>& m) const {return DoubleMatrix::operator*(m);}
-    Vector<double> operator*(const Vector<double>& m) const {return DoubleMatrix::operator*(m);}
     inline Point2D operator*(const Point2D& p) const;
     double determinant() const;
   };
@@ -96,14 +95,13 @@ namespace QGpCoreMath {
 
     Matrix3x3 operator*(const Matrix3x3& m) const {return DoubleMatrix::operator*(m);}
     Matrix<double> operator*(const Matrix<double>& m) const {return DoubleMatrix::operator*(m);}
-    Vector<double> operator*(const Vector<double>& m) const {return DoubleMatrix::operator*(m);}
     inline Point operator*(const Point& p) const;
     Segment operator*(const Segment& s) const;
   };
 
   inline void Matrix3x3::rotation(AxisType ax, const Angle& angle)
   {
-    identity(0.0);
+    identity();
     DoubleMatrix::rotation3D(ax, angle);
   }
 
@@ -132,12 +130,11 @@ namespace QGpCoreMath {
     inline Point operator*(const Point& p) const;
     Segment operator*(const Segment& s) const;
     Matrix<double> operator*(const Matrix<double>& m) const {return DoubleMatrix::operator*(m);}
-    Vector<double> operator*(const Vector<double>& m) const {return DoubleMatrix::operator*(m);}
   };
 
   inline void Matrix4x4::rotation(AxisType ax, const Angle& angle)
   {
-    identity(0.0);
+    identity();
     DoubleMatrix::rotation3D(ax, angle);
   }
 
