@@ -90,6 +90,8 @@ namespace QGpCoreMath {
     Q_UNUSED(context)
     if(tag=="Document") {
       return XMLMember(&_document);
+    } else if(tag=="Folder") {
+      return XMLMember(_document.mainFolder());
     } else return XMLMember(XMLMember::Unknown);
   }
 
@@ -104,14 +106,15 @@ namespace QGpCoreMath {
     : XMLClass()
   {
     TRACE;
+    _visible=true;
   }
 
-  QList<NamedPoint> GoogleEarthKML::Document::points() const
+  void GoogleEarthKML::Document::collectPoints(QList<NamedPoint>& list) const
   {
     TRACE;
-    QList<NamedPoint> list;
-    _root.collectPoints(list);
-    return list;
+    if(_visible) {
+      _root.collectPoints(list);
+    }
   }
 
   void GoogleEarthKML::Document::xml_writeProperties(XML_WRITEPROPERTIES_ARGS) const
@@ -119,6 +122,7 @@ namespace QGpCoreMath {
     TRACE;
     Q_UNUSED(context)
     writeProperty(s, "name", _name);
+    writeProperty(s, "visibility", _visible ? "1" : "0");
     // TODO: complete support for style customization
     s << s.indent() << "<StyleMap id=\"msn_ylw-pushpin\">\n";
     s.incrementIndent();
@@ -185,8 +189,14 @@ namespace QGpCoreMath {
       return XMLMember(p);
     } else if(tag=="Folder") {
       return XMLMember(&_root);
-    } else if(tag=="name") return XMLMember(0);
-    else if(tag=="StyleMap" || tag=="Style") {
+    } else if(tag=="name") {
+      return XMLMember(0);
+    } else if(tag=="StyleMap" || tag=="Style") {
+      return XMLMember(XMLMember::Skip);
+    } else if(tag=="visibility") {
+      return XMLMember(1);
+    } else if(tag=="Snippet" ||
+              tag=="description") {
       return XMLMember(XMLMember::Skip);
     } else return XMLMember(XMLMember::Unknown);
   }
@@ -197,10 +207,14 @@ namespace QGpCoreMath {
     Q_UNUSED(attributes)
     Q_UNUSED(context)
     Q_UNUSED(tag)
+    bool ok=true;
     switch(memberID) {
     case 0:
-      _name=content.toString();
+      _name=content.toStringBuffer();
       return true;
+    case 1:
+      _visible=(content.toInt(ok)!=0);
+      return ok;
     default:
       return false;
     }
@@ -225,7 +239,7 @@ namespace QGpCoreMath {
   {
     TRACE;
     Q_UNUSED(context)
-    writeProperty(s, "coordinates", _coordinates.toString(20).replace(" ", ","));
+    writeProperty(s, "coordinates", _coordinates.toString('g', 20).replace(" ", ","));
   }
 
   XMLMember GoogleEarthKML::Point::xml_member(XML_MEMBER_ARGS)
@@ -234,6 +248,7 @@ namespace QGpCoreMath {
     Q_UNUSED(attributes)
     Q_UNUSED(context)
     if(tag=="coordinates") return XMLMember(0);
+    else if(tag=="gx:drawOrder") return XMLMember(XMLMember::Skip);
     else return XMLMember(XMLMember::Unknown);
   }
 
@@ -245,7 +260,7 @@ namespace QGpCoreMath {
     Q_UNUSED(tag)
     switch(memberID) {
     case 0: {
-        QString str=content.toString();
+        QString str=content.toStringBuffer();
         _coordinates.fromString(str.replace(",", " "));
       }
       return true;
@@ -264,6 +279,7 @@ namespace QGpCoreMath {
   GoogleEarthKML::Placemark::Placemark()
   {
     TRACE;
+    _visible=true;
   }
 
   void GoogleEarthKML::Placemark::xml_writeProperties(XML_WRITEPROPERTIES_ARGS) const
@@ -271,6 +287,7 @@ namespace QGpCoreMath {
     TRACE;
     Q_UNUSED(context)
     writeProperty(s, "name", _name);
+    writeProperty(s, "visibility", _visible ? "1" : "0");
     writeProperty(s, "styleUrl", "#msn_ylw-pushpin");
   }
 
@@ -285,10 +302,16 @@ namespace QGpCoreMath {
     TRACE;
     Q_UNUSED(attributes)
     Q_UNUSED(context)
-    if(tag=="name") return XMLMember(0);
-    else if(tag=="Point") {
+    if(tag=="name") {
+      return XMLMember(0);
+    } else if(tag=="Point") {
       return XMLMember(&_point);
-    } else if(tag=="LookAt" || tag=="styleUrl") {
+    } else if(tag=="visibility") {
+      return XMLMember(1);
+    } else if(tag=="LookAt" ||
+              tag=="styleUrl" ||
+              tag=="Snippet" ||
+              tag=="ExtendedData") {
       return XMLMember(XMLMember::Skip);
     } else {
       return XMLMember(XMLMember::Unknown);
@@ -301,10 +324,14 @@ namespace QGpCoreMath {
     Q_UNUSED(attributes)
     Q_UNUSED(context)
     Q_UNUSED(tag)
+    bool ok=true;
     switch(memberID) {
     case 0:
-      _name=content.toString();
+      _name=content.toStringBuffer();
       return true;
+    case 1:
+      _visible=(content.toInt(ok)!=0);
+      return ok;
     default:
       return false;
     }
@@ -317,9 +344,16 @@ namespace QGpCoreMath {
     Full description of class still missing
   */
 
+  GoogleEarthKML::Folder::Folder(Folder * parent)
+    : TreeContainer(parent)
+  {
+    _visible=true;
+  }
+
   GoogleEarthKML::Folder::~Folder()
   {
     TRACE;
+    qDeleteAll(_documents);
     qDeleteAll(_placemarks);
   }
 
@@ -336,8 +370,17 @@ namespace QGpCoreMath {
     for(const_iterator it=begin(); it!=end(); ++it) {
       static_cast<Folder *>(*it)->collectPoints(list);
     }
+    for(QList<Document *>::const_iterator it=_documents.begin(); it!=_documents.end(); ++it) {
+      Document * d=*it;
+      if(d->isVisible()) {
+        d->collectPoints(list);
+      }
+    }
     for(QList<Placemark *>::const_iterator it=_placemarks.begin(); it!=_placemarks.end(); ++it) {
-      list.append(NamedPoint((*it)->name(), (*it)->coordinates()));
+      Placemark * p=*it;
+      if(p->isVisible()) {
+        list.append(NamedPoint(p->name(), p->coordinates()));
+      }
     }
   }
 
@@ -346,11 +389,15 @@ namespace QGpCoreMath {
     TRACE;
     Q_UNUSED(context)
     writeProperty(s, "name", _name);
+    writeProperty(s, "visibility", _visible ? "1" : "0");
   }
 
   void GoogleEarthKML::Folder::xml_writeChildren(XML_WRITECHILDREN_ARGS) const
   {
     TRACE;
+    for(QList<Document *>::const_iterator it=_documents.begin(); it!=_documents.end(); ++it) {
+      (*it)->xml_save(s, context);
+    }
     for(QList<Placemark *>::const_iterator it=_placemarks.begin(); it!=_placemarks.end(); ++it) {
       (*it)->xml_save(s, context);
     }
@@ -362,13 +409,19 @@ namespace QGpCoreMath {
     TRACE;
     Q_UNUSED(attributes)
     Q_UNUSED(context)
-    if(tag=="name") return XMLMember(0);
-    else if(tag=="Folder") {
+    if(tag=="name") {
+      return XMLMember(0);
+    } else if(tag=="Folder") {
       return XMLMember(new Folder(this));
+    } else if(tag=="Document") {
+      _documents.append(new Document);
+      return XMLMember(_documents.last());
     } else if(tag=="Placemark") {
       Placemark * p=new Placemark;
       _placemarks.append(p);
       return XMLMember(p);
+    } else if(tag=="visibility") {
+      return XMLMember(1);
     } else if(tag=="open") return XMLMember(XMLMember::Skip);
     else return XMLMember(XMLMember::Unknown);
   }
@@ -379,10 +432,14 @@ namespace QGpCoreMath {
     Q_UNUSED(attributes)
     Q_UNUSED(context)
     Q_UNUSED(tag)
+    bool ok=true;
     switch(memberID) {
     case 0:
-      _name=content.toString();
+      _name=content.toStringBuffer();
       return true;
+    case 1:
+      _visible=(content.toInt(ok)!=0);
+      return ok;
     default:
       return false;
     }
