@@ -346,17 +346,21 @@ bool Grid3D<ValueType>::xml_setProperty(XML_SETPROPERTY_ARGS)
   Q_UNUSED(attributes)
   Q_UNUSED(context)
   Q_UNUSED(tag)
+  bool ok=true;
   switch(memberID) {
   case 0: _origin.fromString(content); return true;
   case 1:
-    _delta.fromString(content);
-    _invDelta.setX(1.0/_delta.x());
-    _invDelta.setY(1.0/_delta.y());
-    _invDelta.setZ(1.0/_delta.z());
-    return true;
-  case 2: _nx=content.toInt(); return true;
-  case 3: _ny=content.toInt(); return true;
-  case 4: _nz=content.toInt(); return true;
+    if(_delta.fromString(content)) {
+      _invDelta.setX(1.0/_delta.x());
+      _invDelta.setY(1.0/_delta.y());
+      _invDelta.setZ(1.0/_delta.z());
+      return true;
+    } else {
+      return false;
+    }
+  case 2: _nx=content.toInt(ok); return ok;
+  case 3: _ny=content.toInt(ok); return ok;
+  case 4: _nz=content.toInt(ok); return ok;
   }
   return false;
 }
@@ -387,8 +391,8 @@ QTextStream& operator>>(QTextStream& s, Grid3D<ValueType>& grd)
     str=s.readLine().trimmed(); line++;
   }
   if(str=="x y z val" ) {
-    QVector<Point> points;
-    QVector<ValueType> values;
+    VectorList<Point> points;
+    VectorList<ValueType> values;
     Point p;
     ValueType val;
     const QChar * ptr;
@@ -400,14 +404,30 @@ QTextStream& operator>>(QTextStream& s, Grid3D<ValueType>& grd)
       StringSection pStr(str);
       ptr=0;
       f=pStr.nextField(ptr);
-      if(f.isValid()) p.setX(f.toDouble()); else ok=false;
+      if(f.isValid()) {
+        p.setX(f.toDouble(ok));
+      } else {
+        ok=false;
+      }
       f=pStr.nextField(ptr);
-      if(f.isValid()) p.setY(f.toDouble()); else ok=false;
+      if(f.isValid()) {
+        p.setY(f.toDouble(ok));
+      } else {
+        ok=false;
+      }
       f=pStr.nextField(ptr);
-      if(f.isValid()) p.setZ(f.toDouble()); else ok=false;
+      if(f.isValid()) {
+        p.setZ(f.toDouble(ok));
+      } else {
+        ok=false;
+      }
       f=pStr.nextField(ptr);
-      if(f.isValid()) val=f.toDouble(); else ok=false;
-      if( !ok) {
+      if(f.isValid()) {
+        val=f.toDouble(ok);
+      } else {
+          ok=false;
+      }
+      if(!ok) {
         App::log(QCoreApplication::translate("Grid3D", "Wrong format at line %1, expected: float value\n").arg(line));
         return s;
       }
@@ -417,7 +437,7 @@ QTextStream& operator>>(QTextStream& s, Grid3D<ValueType>& grd)
     // Deduce nx, ny, nz, delta and origin from x, y and z vectors
     QMap<double,int> xMap, yMap, zMap;
     QMap<double,int>::iterator itMap;
-    for(QVector<Point>::iterator it=points.begin(); it!=points.end(); it++ ) {
+    for(VectorList<Point>::iterator it=points.begin(); it!=points.end(); it++ ) {
       itMap=xMap.find(it->x());
       if(itMap==xMap.end()) {
         xMap.insert(it->x(),0);
