@@ -41,7 +41,7 @@ namespace QGpCoreMath {
   /*!
     Copy constructor from a vector
   */
-  PointND::PointND(const QVector<double>& p)
+  PointND::PointND(const VectorList<double>& p)
   {
     ASSERT(p.count()>1);
     _x=p.at(0);
@@ -83,7 +83,7 @@ namespace QGpCoreMath {
     Returns the point as a string with space separation between coordinates.
     \a precision is the number of significant digits. \a format is 'g' or 'f'.
   */
-  QString PointND::toString(int precision, char format) const
+  QString PointND::toString(char format, int precision) const
   {
     TRACE;
     QString tmp;
@@ -100,16 +100,21 @@ namespace QGpCoreMath {
   {
     TRACE;
     const QChar * ptr=0;
+    bool ok=true;
     StringSection f;
     f=str.nextField(ptr);
-    if(f.isValid()) _x=f.toDouble(); else return false;
+    if(f.isValid()) {
+      _x=f.toDouble(ok);
+    } else {
+      return false;
+    }
     f=str.nextField(ptr);
     int i=0;
     while(f.isValid()) {
-      setY(i++, f.toDouble());
+      setY(i++, f.toDouble(ok));
       f=str.nextField(ptr);
     }
-    return true;
+    return ok;
   }
 
   double PointND::at(int index) const
