@@ -11,6 +11,7 @@
 #include "Angle.h"
 #include "AngleSearch.h"
 #include "AverageAngle.h"
+#include "BSpline.h"
 #include "BasicCurveProxy.h"
 #include "ChiSquareTest.h"
 #include "Circle.h"
@@ -18,6 +19,7 @@
 #include "ColorMap.h"
 #include "ColorMapData.h"
 #include "ColorPalette.h"
+#include "ColorPaletteModels.h"
 #include "ComplexExponential.h"
 #include "ComplexMPMatrix.h"
 #include "ComplexMatrix.h"
@@ -26,8 +28,11 @@
 #include "ConcentricSearch.h"
 #include "CoordinateFile.h"
 #include "Covariance.h"
+#include "CubicEquation.h"
+#include "CubicSpline.h"
 #include "Curve.h"
 #include "CurvePointOptions.h"
+#include "CurveProperties.h"
 #include "CurveProxy.h"
 #include "CurveSplitter.h"
 #include "DelaunayTriangulation.h"
@@ -35,14 +40,19 @@
 #include "DoubleMatrix.h"
 #include "Ellipse.h"
 #include "FrequencyBand.h"
+#include "FrequencyCurveProxy.h"
+#include "FunctionPlot.h"
 #include "FunctionSearch.h"
-#include "GaussDistribution.h"
+#include "FunctionSearchMaximum.h"
 #include "GaussianFrequencyBand.h"
+#include "GlobalRandom.h"
 #include "GoogleEarthKML.h"
 #include "Grid2D.h"
 #include "Grid3D.h"
 #include "GridParallelWriter.h"
-#include "GridSearch.h"
+#include "GridSearch1D.h"
+#include "GridSearch2D.h"
+#include "GridSearch3D.h"
 #include "GridSearchTest.h"
 #include "IrregularGrid2D.h"
 #include "IrregularGrid2DData.h"
@@ -52,8 +62,15 @@
 #include "Matrix.h"
 #include "MatrixIterator.h"
 #include "MatrixMultiply.h"
+#include "Misfit.h"
+#include "MultivariateNormalDistribution.h"
+#include "MultivariateStatistics.h"
 #include "NamedPoint.h"
+#include "NewtonOptimization1D.h"
+#include "NormalDistribution.h"
+#include "OptimizationBFGS.h"
 #include "Parallelepiped.h"
+#include "PeriodicStatistics.h"
 #include "PermutationVector.h"
 #include "Plane.h"
 #include "Point.h"
@@ -62,10 +79,15 @@
 #include "PointLocate.h"
 #include "PointND.h"
 #include "PointNDOptions.h"
+#include "Polygon.h"
+#include "Polynomial.h"
+#include "PolynomialFraction.h"
 #include "PrimeFactorization.h"
+#include "PrivateVector.h"
 #include "ProcessStatistics.h"
 #include "QGpCoreMathDLLExport.h"
 #include "Random.h"
+#include "RealStatisticalCurve.h"
 #include "RealStatisticalProxy.h"
 #include "Rect.h"
 #include "RootSolver.h"
@@ -84,6 +106,7 @@
 #include "Statistics.h"
 #include "Triangle.h"
 #include "TriangularMatrix.h"
+#include "TwiddleFactors.h"
 #include "UtmZone.h"
 #include "Value.h"
 #include "Vector.h"
