@@ -32,7 +32,7 @@
 #include <math.h>
 #include <QGpCoreTools.h>
 
-#include "GaussDistribution.h"
+#include "NormalDistribution.h"
 
 namespace QGpCoreMath {
 
@@ -50,7 +50,7 @@ public:
   inline int uniform(int min, int max);
   inline double uniform(double min, double max);
   double normal(double mean, double stddev);
-  double normal(GaussDistribution & gd) {return normal(gd.mean(),gd.stddev());}
+  double normal(NormalDistribution & gd) {return normal(gd.mean(),gd.stddev());}
   double ran2();
 
   QByteArray state() const;
