@@ -25,6 +25,7 @@
 ***************************************************************************/
 
 #include "RealStatisticalProxy.h"
+#include "IrregularGrid2D.h"
 
 namespace QGpCoreMath {
 
@@ -35,7 +36,10 @@ namespace QGpCoreMath {
     Full description of class still missing
   */
 
-  CURVEPROXY_BASICIMPLEMENTATIONS(RealStatisticalProxy)
+  CURVEPROXY_BASIC_IMPLEMENTATIONS(RealStatisticalProxy)
+  CURVEPROXY_ADVANCED_IMPLEMENTATIONS(RealStatisticalProxy,
+                                      Curve<RealStatisticalPoint>,
+                                      RealStatisticalPoint)
 
   QString RealStatisticalProxy::columnName(int col) const
   {
@@ -55,10 +59,10 @@ namespace QGpCoreMath {
     return QString();
   }
 
-  QVector<int> RealStatisticalProxy::savedColumns() const
+  VectorList<int> RealStatisticalProxy::savedColumns() const
   {
     TRACE;
-    QVector<int> l;
+    VectorList<int> l;
     l << 0 << 1 << 2 << 3;
     return l;
   }
@@ -103,10 +107,10 @@ namespace QGpCoreMath {
     return types;
   }
 
-  QVector<int> RealStatisticalProxy::defaultColumnFileTypes() const
+  VectorList<int> RealStatisticalProxy::defaultColumnFileTypes() const
   {
     TRACE;
-    QVector<int> l;
+    VectorList<int> l;
     l << 1 << 2 << 3 << 4 << 5;
     return l;
   }
@@ -154,32 +158,5 @@ namespace QGpCoreMath {
     return true;
   }
 
-  void RealStatisticalProxy::beginSplit(double maxX, SamplingOptions options, double maxErr, int minCount)
-  {
-    ASSERT(!_split);
-    _split=new QList<Curve<RealStatisticalPoint>>;
-    *_split=curve().split(maxX, options, maxErr, minCount);
-  }
-
-  int RealStatisticalProxy::splitCount() const
-  {
-    ASSERT(_split);
-    return _split->count();
-  }
-
-  void RealStatisticalProxy::getSplit(const CurveProxy * o, int index)
-  {
-    QList<Curve<RealStatisticalPoint>> * split;
-    split=static_cast<const RealStatisticalProxy *>(o)->_split;
-    ASSERT(split);
-    curve()=split->at(index);
-  }
-
-  void RealStatisticalProxy::endSplit()
-  {
-    delete _split;
-    _split=nullptr;
-  }
-
 } // namespace QGpCoreMath
 
