@@ -57,30 +57,20 @@ void Rect::operator*=(double fac)
 */
 void Rect::setLimits(double nx1, double ny1, double nx2, double ny2)
 {
-  TRACE;
-  double temp;
-  _x1=nx1;
-  _y1=ny1;
-  _x2=nx2;
-  _y2=ny2;
-  if(_x2<_x1) {
-    temp=_x2;
-    _x2=_x1;
-    _x1=temp;
+  if(nx1<nx2) {
+    _x1=nx1;
+    _x2=nx2;
+  } else {
+    _x1=nx2;
+    _x2=nx1;
   }
-  if(_y2<_y1) {
-    temp=_y2;
-    _y2=_y1;
-    _y1=temp;
+  if(ny1<ny2) {
+    _y1=ny1;
+    _y2=ny2;
+  } else {
+    _y1=ny2;
+    _y2=ny1;
   }
-  /*if(_x2-_x1<1e-10) { // avoid minuscule rectangles
-    _x2+=1e-10;
-    _x1-=1e-10;
-  }
-  if(_y2-_y1<1e-10) {
-    _y2+=1e-10;
-    _y1-=1e-10;
-  }*/
 }
 
 /*!
@@ -111,7 +101,34 @@ bool Rect::includes(const Point2D & p) const
 }
 
 /*!
-  Tests if the point is inside the speified area of the rectangle
+  Tests if the rectangle r is entirely and strictly inside the rectangle (excluding borders).
+*/
+bool Rect::strictIncludes(const Rect & r) const
+{
+  TRACE;
+  return (_x1<r._x1 && _y1<r._y1 && _x2>r._x2 && _y2>r._y2);
+}
+
+/*!
+  Tests if the point is strictly inside the rectangle (excluding borders).
+*/
+bool Rect::strictIncludes(const Point & p) const
+{
+  TRACE;
+  return (_x1<p.x() && p.x()<_x2 && _y1<p.y() && p.y()<_y2);
+}
+
+/*!
+  Tests if the point is strictly inside the rectangle (excluding borders).
+*/
+bool Rect::strictIncludes(const Point2D & p) const
+{
+  TRACE;
+  return (_x1<p.x() && p.x()<_x2 && _y1<p.y() && p.y()<_y2);
+}
+
+/*!
+  Tests if the point is inside the specified area of the rectangle
 */
 bool Rect::includes(const Point2D & p, Area inArea) const
 {
@@ -141,13 +158,37 @@ bool Rect::includes(const Point2D & p, Area inArea) const
 void Rect::add(double x, double y)
 {
   TRACE;
-  if(x!=1e99 && x!=-1e99) { // Compatibility with old files... can be removed in a few years
-    if((x>-std::numeric_limits<double>::infinity() && x<_x1) || _x1<=-std::numeric_limits<double>::infinity()) _x1=x;
-    if((x<std::numeric_limits<double>::infinity() && x>_x2) || _x2>=std::numeric_limits<double>::infinity()) _x2=x;
+  if(isfinite(x) && x!=1e99 && x!=-1e99) { // 1e99 is for compatibility with old files... can be removed in a few years
+    if(isfinite(_x1)) {
+      if(x<_x1) {
+        _x1=x;
+      }
+    } else {
+      _x1=x;
+    }
+    if(isfinite(_x2)) {
+      if(x>_x2) {
+        _x2=x;
+      }
+    } else {
+      _x2=x;
+    }
   }
-  if(y!=1e99 && y!=-1e99) { // Compatibility with old files... can be removed in a few years
-    if((y>-std::numeric_limits<double>::infinity() && y<_y1) || _y1<=-std::numeric_limits<double>::infinity()) _y1=y;
-    if((y<std::numeric_limits<double>::infinity() && y>_y2) || _y2>=std::numeric_limits<double>::infinity()) _y2=y;
+  if(isfinite(y) && y!=1e99 && y!=-1e99) { // 1e99 is for compatibility with old files... can be removed in a few years
+    if(isfinite(_y1)) {
+      if(y<_y1) {
+        _y1=y;
+      }
+    } else {
+      _y1=y;
+    }
+    if(isfinite(_y2)) {
+      if(y>_y2) {
+        _y2=y;
+      }
+    } else {
+      _y2=y;
+    }
   }
 }
 
@@ -272,7 +313,7 @@ void Rect::square()
 
 /*!
   Enlarges rectange by \a dx and \a dy in both direction. Add or multiply according to the scale type.
-  Inversed scales are considered like linear scales
+  Inverse scales are considered like linear scales
 */
 void Rect::enlarge(double dx, double dy, SamplingOptions xScale, SamplingOptions yScale)
 {
@@ -282,7 +323,7 @@ void Rect::enlarge(double dx, double dy, SamplingOptions xScale, SamplingOptions
     _x1 *= 1.0-dx;
     _x2 *= 1.0+dx;
     break;
-  case InversedScale:
+  case InverseScale:
     _x1=1.0/(1.0/_x1 + 1.0/dx);
     _x2=1.0/(1.0/_x2 - 1.0/dx);
     break;
@@ -296,7 +337,7 @@ void Rect::enlarge(double dx, double dy, SamplingOptions xScale, SamplingOptions
     _y1*=1.0-dy;
     _y2*=1.0+dy;
     break;
-  case InversedScale:
+  case InverseScale:
     _y1=1.0/(1.0/_y1 + 1.0/dy);
     _y2=1.0/(1.0/_y2 - 1.0/dy);
     break;
@@ -308,7 +349,7 @@ void Rect::enlarge(double dx, double dy, SamplingOptions xScale, SamplingOptions
 }
 
 /*!
-  Enlarges rectangle by width and height times \a ratio times in both directions.
+  Enlarges rectangle by width and height times \a ratio in both directions.
 */
 void Rect::enlarge(double ratio, SamplingOptions xScale, SamplingOptions yScale)
 {
@@ -316,28 +357,22 @@ void Rect::enlarge(double ratio, SamplingOptions xScale, SamplingOptions yScale)
   double s1, s2;
   switch(xScale) {
   case LogScale:
-    if(_x1<=0) {
+    if(_x1<=0.0) {
       _x1=1e-16;
     }
-    if(_x2<=0) {
+    if(_x2<=0.0) {
       _x2=1e-16;
     }
     s1=pow(_x2/_x1, ratio);
     _x1/=s1;
     _x2*=s1;
     break;
-  case InversedScale:
-    {
-      double t1=1/_x1;
-      double t2=1/_x2;
-      s1=ratio*(t1-t2);
-      _x1=1/(t1+s1);
-      _x2=1/(t2-s1);
-    }
-    /*s1=ratio*(_x2-_x1);
+  case InverseScale:
+    s1=ratio*(_x2-_x1);
     s2=_x1*_x2;
-    _x1=s2/(_x2+s1);
-    _x2=s2/(_x1-s1);*/
+    _x2=s2/(_x2+s1);
+    _x1=s2/(_x1-s1);
+    qSwap(_x1, _x2);
     break;
   default:
     s1=ratio*(_x2-_x1);
@@ -347,26 +382,27 @@ void Rect::enlarge(double ratio, SamplingOptions xScale, SamplingOptions yScale)
   }
   switch(yScale) {
   case LogScale:
-    if(_y1<=0) {
+    if(_y1<=0.0) {
       _y1=1e-16;
     }
-    if(_y2<=0) {
+    if(_y2<=0.0) {
       _y2=1e-16;
     }
     s1=pow(_y2/_y1, ratio);
     _y1/=s1;
     _y2*=s1;
     break;
-  case InversedScale:
+  case InverseScale:
     s1=ratio*(_y2-_y1);
     s2=_y1*_y2;
-    _y1=s2*_y1/(s2+s1*_y1);
-    _y2=s2*_y2/(s2+s1*_y2);
+    _y2=s2/(_y2+s1);
+    _y1=s2/(_y1-s1);
+    qSwap(_x1, _x2);
     break;
   default:
     s1=ratio*(_y2-_y1);
-    _y1 -= s1;
-    _y2 += s1;
+    _y1-=s1;
+    _y2+=s1;
     break;
   }
 }
@@ -491,20 +527,21 @@ bool Rect::xml_setProperty(XML_SETPROPERTY_ARGS)
   Q_UNUSED(tag)
   Q_UNUSED(attributes)
   Q_UNUSED(context)
-  double val=content.toDouble();
+  bool ok=true;
+  double val=content.toDouble(ok);
   switch(memberID) {
   case 0:
     _x1=val;
-    return true;
+    return ok;
   case 1:
     _y1=val;
-    return true;
+    return ok;
   case 2:
     _x2=val;
-    return true;
+    return ok;
   case 3:
     _y2=val;
-    return true;
+    return ok;
   default:
     return false;
   }
