@@ -50,36 +50,6 @@ namespace QGpCoreMath {
     _n=0;
   }
 
-  SamplingParameters::SamplingParameters(const SamplingParameters& o)
-    : AbstractParameters(o)
-  {
-    TRACE;
-    _minIndex=o._minIndex;
-    _min=o._min;
-    _max=o._max;
-    _step=o._step;
-    _scaleType=o._scaleType;
-    _stepType=o._stepType;
-    _n=o._n;
-  }
-
-  SamplingOptions SamplingParameters::options() const
-  {
-    TRACE;
-    SamplingOptions o;
-    switch(_scaleType) {
-    case Linear:
-      o=LinearScale;
-      break;
-    case Inversed:
-      o=LinearScale | InversedScale;
-      break;
-    case Log:
-      o=LogScale;
-    }
-    return o;
-  }
-
   /*!
     Set the number of samples according to the provided \a step
     Minimum, maximum and the type of sampling must be properly set.
@@ -133,7 +103,6 @@ namespace QGpCoreMath {
 
   void SamplingParameters::setCount()
   {
-    TRACE;
     if(_min<_max) {
       switch(_stepType) {
       case Step:
@@ -144,7 +113,7 @@ namespace QGpCoreMath {
             _minIndex=ceil(_min/_step);
             nd=1.0+floor(_max/_step)-_minIndex;
             break;
-          case Inversed:
+          case Inverse:
             _minIndex=floor(1.0/(_min*_step));
             nd=1.0+ceil(_minIndex-1.0/(_max*_step));
             break;
@@ -176,7 +145,7 @@ namespace QGpCoreMath {
             }
 #endif
             break;
-          case Inversed:
+          case Inverse:
             _step=(1.0/_min-1.0/_max)/static_cast<double>(_n-1);
             _minIndex=ceil(1.0/(_min*_step))-1;
             if(value(_n-1)>_max) { //Ensures that effective min and max are inside _min and _max
@@ -207,7 +176,7 @@ namespace QGpCoreMath {
           _step=(_max-_min)/static_cast<double>(_n-1);
           _minIndex=_min/_step;
           break;
-        case Inversed:
+        case Inverse:
           _step=(1.0/_min-1.0/_max)/static_cast<double>(_n-1);
           _minIndex=1.0/(_min*_step);
           break;
@@ -240,7 +209,6 @@ namespace QGpCoreMath {
 
   double SamplingParameters::value(int i) const
   {
-    TRACE;
     switch(_scaleType) {
     case Linear:
 #ifdef COMPATIBILITY_2_5_0
@@ -248,7 +216,7 @@ namespace QGpCoreMath {
 #else
       return _step*(i+_minIndex);
 #endif
-    case Inversed:
+    case Inverse:
       return 1.0/(_step*(_minIndex-i));
     case Log:
       break;
@@ -265,7 +233,6 @@ namespace QGpCoreMath {
   */
   int SamplingParameters::index(double val) const
   {
-    TRACE;
     int i;
     SAFE_UNINITIALIZED(i, 0);
     switch(_scaleType) {
@@ -276,7 +243,7 @@ namespace QGpCoreMath {
       i=qRound(val/_step)-_minIndex;
 #endif
       break;
-    case Inversed:
+    case Inverse:
       i=_minIndex-qRound(1.0/(val*_step));
       break;
     case Log:
@@ -295,10 +262,9 @@ namespace QGpCoreMath {
     return i;
   }
 
-  QVector<double> SamplingParameters::values() const
+  VectorList<double> SamplingParameters::values() const
   {
-    TRACE;
-    QVector<double> v(_n);
+    VectorList<double> v(_n);
     for(int i=0; i<_n; i++) {
       v[i]=value(i);
     }
@@ -323,89 +289,48 @@ namespace QGpCoreMath {
     }
   }
 
-  QString SamplingParameters::scaleType(ScaleType t)
+  /*!
+    Converts SamplingOptions to ScaleType
+  */
+  SamplingParameters::ScaleType SamplingParameters::scaleType(SamplingOptions s)
   {
+    if(s & LogScale) {
+      return Log;
+    }
+    if(s & InverseScale) {
+      return Inverse;
+    }
+    return Linear;
+  }
+
+  SamplingOptions SamplingParameters::samplingOptions(ScaleType t)
+  {
+    TRACE;
     switch(t) {
     case Linear:
       break;
+    case Inverse:
+      return LinearScale | InverseScale;
     case Log:
-      return "Log";
-    case Inversed:
-      return "Inversed";
+      return LogScale;
     }
-    return "Linear";
+    return LinearScale;
   }
 
-  SamplingParameters::ScaleType SamplingParameters::scaleType(QString t)
-  {
-    t=t.toLower();
-    if(t=="linear") {
-      return Linear;
-    } else if(t=="log") {
-      return Log;
-    } else if(t=="inversed") {
-      return Inversed;
-    } else {
-      App::log(tr("Bad sampling type '%1'.\n").arg(t));
-      return Linear;
-    }
-  }
+  ENUM_AS_STRING_BEGIN(SamplingParameters, ScaleType)
+  ENUM_AS_STRING_DATA_3(Inverse, Linear, Log);
+  ENUM_AS_STRING_SYNONYM("0", Log);
+  ENUM_AS_STRING_SYNONYM("1", Linear);
+  ENUM_AS_STRING_SYNONYM("Period", Inverse);
+  ENUM_AS_STRING_SYNONYM("Frequency", Linear);
+  ENUM_AS_STRING_SYNONYM("period", Inverse);   // Used for command line arguments
+  ENUM_AS_STRING_SYNONYM("frequency", Linear);
+  ENUM_AS_STRING_SYNONYM("log", Log);
+  ENUM_AS_STRING_END
 
-  /*!
-    Support old keywords for compatibility unlike the static function.
-  */
-  bool SamplingParameters::setScaleType(QString t, bool keepCount)
-  {
-    ScaleType s;
-    t=t.toLower();
-    if(t=="linear") {
-      s=Linear;
-    } else if(t=="log") {
-      s=Log;
-    } else if(t=="inversed") {
-      s=Inversed;
-    } else if(t=="0"){           // Compatibility
-      s=Log;
-    } else if(t=="1"){           // Compatibility
-      s=Linear;
-    } else if(t=="period"){      // Compatibility
-      s=Inversed;
-    } else if(t=="frequency") {  // Compatibility
-      s=Linear;
-    } else {
-      App::log(tr("Bad sampling type '%1'.\n").arg(t));
-      return false;
-    }
-    setScaleType(s, keepCount);
-    return true;
-  }
-
-  QString SamplingParameters::stepTypeString() const
-  {
-    switch(_stepType) {
-    case Count:
-      break;
-    case ExactCount:
-      return "ExactCount";
-    case Step:
-      return "Step";
-    }
-    return "Count";
-  }
-
-  void SamplingParameters::setStepType(QString t)
-  {
-    t=t.toLower();
-    if(t=="count") {
-      _stepType=Count;
-    } else if(t=="step") {
-      _stepType=Step;
-    } else if(t=="exactcount") {
-      _stepType=ExactCount;
-    } else {
-      App::log(tr("Bad step type '%1'.\n").arg(t) );
-    }
-  }
+  ENUM_AS_STRING_BEGIN(SamplingParameters, StepType)
+  ENUM_AS_STRING_DATA_3(Count, ExactCount, Step);
+  ENUM_AS_STRING_END
 
   int SamplingParameters::keywordCount(PARAMETERS_KEYWORDCOUNT_ARGS) const
   {
@@ -414,7 +339,6 @@ namespace QGpCoreMath {
 
   void SamplingParameters::collectKeywords(PARAMETERS_COLLECTKEYWORDS_ARGS)
   {
-    TRACE;
     int baseIndex=AbstractParameters::keywordCount();
     keywords.add(prefix+"MINIMUM"+suffix, this, baseIndex);
     keywords.add(prefix+"MAXIMUM"+suffix, this, baseIndex+1);
@@ -428,31 +352,32 @@ namespace QGpCoreMath {
 
   bool SamplingParameters::setValue(PARAMETERS_SETVALUE_ARGS)
   {
+    bool ok=true;
     switch(index-AbstractParameters::keywordCount()) {
     case 0:
-      setMinimum(value.toDouble());
-      return true;
+      setMinimum(value.toDouble(&ok));
+      return ok;
     case 1:
-      setMaximum(value.toDouble());
-      return true;
+      setMaximum(value.toDouble(&ok));
+      return ok;
     case 2:
       setCount(value.toInt());
       return true;
     case 3:     // Kept for compatibility
     case 7:
-      setScaleType(value);
+      setScaleType(convertScaleType(value, ok));
       setCount();
-      return true;
+      return ok;
     case 4:      // Kept for compatibility
       if(value=="y") {
-        setScaleType(Inversed);
+        setScaleType(Inverse);
       }
       return true;
     case 5:
-      setStep(value.toDouble());
-      return true;
+      setStep(value.toDouble(&ok));
+      return ok;
     case 6:
-      setStepType(value);
+      setStepType(convertStepType(value, ok));
       return true;
     default:
       break;
@@ -462,30 +387,28 @@ namespace QGpCoreMath {
 
   QString SamplingParameters::toString(PARAMETERS_TOSTRING_ARGS_IMPL) const
   {
-    TRACE;
     QString log;
     log+=prefix+"MINIMUM"+suffix+"="+QString::number(_min)+"\n";
     log+=prefix+"MAXIMUM"+suffix+"="+QString::number(_max)+"\n";
-    log+="# Either 'Linear', 'Log' or 'Inversed'\n";
-    log+=prefix+"SCALE_TYPE"+suffix+"="+scaleType(_scaleType)+"\n";
+    log+="# Either 'Linear', 'Log' or 'Inverse'\n";
+    log+=prefix+"SCALE_TYPE"+suffix+"="+convertScaleType(_scaleType)+"\n";
     log+="# Number of samples is either set to a fixed value ('Count') or through a step between samples ('Step')'\n";
-    log+=prefix+"STEP_TYPE"+suffix+"="+stepTypeString()+"\n";
+    log+=prefix+"STEP_TYPE"+suffix+"="+convertStepType(_stepType)+"\n";
     log+=prefix+"SAMPLES_NUMBER"+suffix+"="+QString::number(_n)+"\n";
     log+="# STEP=difference between two successive samples for 'linear' scales\n";
     log+="# STEP=ratio between two successive samples for 'log' scales\n";
-    log+="# STEP=difference between two successive inversed samples for 'inversed' scales\n";
+    log+="# STEP=difference between two successive inverse samples for 'inverse' scales\n";
     log+=prefix+"STEP"+suffix+"="+QString::number(_step)+"\n";
     return log;
   }
 
   QString SamplingParameters::toUserString() const
   {
-    TRACE;
     return tr("from %1 to %2 with %3 %4 samples (step=%5)")
         .arg(_n>1 ? value(0) : _min)
         .arg(_n>1 ? value(_n-1) : _max)
         .arg(_n)
-        .arg(scaleType(_scaleType))
+        .arg(convertScaleType(_scaleType))
         .arg(_step);
   }
 
@@ -502,20 +425,27 @@ namespace QGpCoreMath {
 
   bool SamplingParameters::isValidRange(bool log) const
   {
-    switch(_scaleType) {
-    case Log:
-    case Inversed:
-      if(_min<=0.0 || _max<=0.0) {
-        if(log) {
-          App::log(tr("Null or negative values not allowed for log and inversed scales\n"));
+    if(std::isfinite(_min) && std::isfinite(_max)) {
+      switch(_scaleType) {
+      case Log:
+      case Inverse:
+        if(_min<=0.0 || _max<=0.0) {
+          if(log) {
+            App::log(tr("Null or negative values not allowed for log and inverse scales\n"));
+          }
+          return false;
         }
-        return false;
+        break;
+      case SamplingParameters::Linear:
+        break;
       }
-      break;
-    case SamplingParameters::Linear:
-      break;
+      return true;
+    } else {
+      if(log) {
+        App::log(tr("Sampling with infinite limits\n"));
+      }
+      return false;
     }
-    return true;
   }
 
   /*!
@@ -523,7 +453,7 @@ namespace QGpCoreMath {
 
     TODO check linear and log
   */
-  bool SamplingParameters::bestFit(const QVector<double>& values)
+  bool SamplingParameters::bestFit(const VectorList<double>& values)
   {
     if(values.count()<3) {
       App::log(tr("Sampling best fit: a minimum of 3 values is required\n") );
@@ -580,7 +510,7 @@ namespace QGpCoreMath {
       setScaleType(Log);
       setStep(dLog0);
     } else {
-      setScaleType(Inversed);
+      setScaleType(Inverse);
       setStep(dInv0);
     }
     return isValidRange(true);
@@ -594,7 +524,7 @@ namespace QGpCoreMath {
   {
     if(isValid()) {
       if(_min<value(0)) {
-        if(_scaleType==Inversed) {
+        if(_scaleType==Inverse) {
           _minIndex++;
         } else {
           _minIndex--;
@@ -603,7 +533,7 @@ namespace QGpCoreMath {
         _min=value(0);
       }
       if(_max>value(_n-1)) {
-        if(_scaleType==Inversed) {
+        if(_scaleType==Inverse) {
           if(_minIndex>_n) { // Avoid division by 0
             _n++;
             _max=value(_n-1);
@@ -616,4 +546,28 @@ namespace QGpCoreMath {
     }
   }
 
+  /*!
+    Transforms into an equivalent linear scale.
+  */
+  void SamplingParameters::linearize()
+  {
+    switch(_scaleType) {
+    case Log:
+      _min=log(_min);
+      _max=log(_max);
+      _stepType=ExactCount;
+      setScaleType(Linear);
+      break;
+    case Inverse:
+      _min=1.0/_min;
+      _max=1.0/_max;
+      qSwap(_min, _max);
+      _stepType=ExactCount;
+      setScaleType(Linear);
+      break;
+    case Linear:
+      break;
+    }
+  }
+
 } // namespace QGpCoreMath
