@@ -35,33 +35,30 @@
 
 namespace QGpCoreMath {
 
-  enum SamplingOption {LinearScale=0, LogScale=1, InversedScale=2, Interpole=4};
+  enum SamplingOption {LinearScale=0, LogScale=1, InverseScale=2, Interpole=4};
   Q_DECLARE_FLAGS(SamplingOptions, SamplingOption)
 
   class QGPCOREMATH_EXPORT SamplingParameters: public AbstractParameters
   {
   public:
     SamplingParameters();
-    SamplingParameters(const SamplingParameters& o);
 
-    virtual AbstractParameters * clone() const {return new SamplingParameters(*this);}
+    AbstractParameters * clone() const {return new SamplingParameters(*this);}
 
-    enum ScaleType {Linear, Inversed, Log};
+    enum ScaleType {Linear, Inverse, Log};
     enum StepType {Step, Count, ExactCount};
 
+    ENUM_AS_STRING_DECL(ScaleType)
+    ENUM_AS_STRING_DECL(StepType)
+
     void setScaleType(ScaleType t, bool keepCount=false);
-    bool setScaleType(QString t, bool keepCount=false);
     ScaleType scaleType() const {return _scaleType;}
 
-    static ScaleType scaleType(QString t);
-    static QString scaleType(ScaleType t);
-
-    SamplingOptions options() const;
+    static ScaleType scaleType(SamplingOptions s);
+    static SamplingOptions samplingOptions(ScaleType t);
 
     void setStepType(StepType t) {_stepType=t; setCount();}
-    void setStepType(QString t);
     StepType stepType() const {return _stepType;}
-    QString stepTypeString() const;
 
     void setRange(double min, double max);
     void setMinimum(double m) {_min=m; setCount();}
@@ -80,19 +77,21 @@ namespace QGpCoreMath {
     bool isValid() const;
     bool isValidRange(bool log) const;
 
-    bool bestFit(const QVector<double>& values);
+    void linearize();
+
+    bool bestFit(const VectorList<double>& values);
 
     double value(int i) const;
     int index(double val) const;
-    QVector<double> values() const;
+    VectorList<double> values() const;
 
     QString toUserString() const;
 
-    virtual QString toString(PARAMETERS_TOSTRING_ARGS_DECL) const;
-    virtual void collectKeywords(PARAMETERS_COLLECTKEYWORDS_ARGS);
+    QString toString(PARAMETERS_TOSTRING_ARGS_DECL) const;
+    void collectKeywords(PARAMETERS_COLLECTKEYWORDS_ARGS);
   protected:
-    virtual int keywordCount(PARAMETERS_KEYWORDCOUNT_ARGS) const;
-    virtual bool setValue(PARAMETERS_SETVALUE_ARGS);
+    int keywordCount(PARAMETERS_KEYWORDCOUNT_ARGS) const;
+    bool setValue(PARAMETERS_SETVALUE_ARGS);
   private:
     void setCount();
 
