@@ -51,21 +51,6 @@ namespace QGpCoreMath {
     _scaleType=SamplingParameters::Linear;
   }
 
-  /*!
-    Description of constructor still missing
-  */
-  SmoothingParameters::SmoothingParameters(const SmoothingParameters& o)
-    : AbstractParameters(o),
-      _windowFunction(o._windowFunction)
-  {
-    TRACE;
-    _method=o._method;
-    _widthType=o._widthType;
-    _width=o._width;
-    _order=o._order;
-    _scaleType=o._scaleType;
-  }
-
   double SmoothingParameters::minimum(double x0) const
   {
     switch(_widthType) {
@@ -91,85 +76,13 @@ namespace QGpCoreMath {
     return x0+0.5*_width;
   }
 
-  QString SmoothingParameters::widthTypeString() const
-  {
-    switch(_widthType) {
-    case Constant:
-      break;
-    case Proportional:
-      return "Proportional";
-    case Log:
-      return "Log";
-    }
-    return "Constant";
-  }
+  ENUM_AS_STRING_BEGIN(SmoothingParameters, WidthType)
+  ENUM_AS_STRING_DATA_3(Constant, Log, Proportional);
+  ENUM_AS_STRING_END
 
-  void SmoothingParameters::setWidthType(const QString& t)
-  {
-    if(!t.isEmpty()) {
-      QString tl=t.toLower();
-      switch(tl[0].unicode()) {
-      case 'c':
-        if(tl=="constant") {
-          _widthType=Constant;
-          return;
-        }
-        break;
-      case 'l':
-        if(tl=="log") {
-          _widthType=Log;
-          return;
-        }
-        break;
-      case 'p':
-        if(tl=="proportional") {
-          _widthType=Proportional;
-        }
-      default:
-        break;
-      }
-    }
-    App::log(tr("Bad width type '%1'.\n").arg(t));
-  }
-
-  QString SmoothingParameters::methodString() const
-  {
-#ifdef SAVITZKY_GOLAY
-    switch(_method) {
-    case Function:
-      break;
-    case SavitzkyGolay:
-      return "SavitzkyGolay";
-    }
-#endif
-    return "Function";
-  }
-
-  void SmoothingParameters::setMethod(const QString& t)
-  {
-    if(!t.isEmpty()) {
-      QString tl=t.toLower();
-      switch(tl[0].unicode()) {
-      case 'f':
-        if(tl=="function") {
-          _method=Function;
-          return;
-        }
-        break;
-      case 's':
-        if(tl=="savitzkygolay") {
-#ifdef SAVITZKY_GOLAY
-          _method=SavitzkyGolay;
-#endif
-          return;
-        }
-        break;
-      default:
-        break;
-      }
-    }
-    App::log(tr("Bad method '%1'.\n").arg(t));
-  }
+  ENUM_AS_STRING_BEGIN(SmoothingParameters, Method)
+  ENUM_AS_STRING_DATA_2(Function, SavitzkyGolay);
+  ENUM_AS_STRING_END
 
   void SmoothingParameters::setWidthTypeCompatibility(const QString& t)
   {
@@ -257,8 +170,8 @@ namespace QGpCoreMath {
     bool ok=true;
     switch(index-AbstractParameters::keywordCount()) {
     case 0:
-      setWidthType(value);
-      return true;
+      _widthType=convertWidthType(value, ok);
+      return ok;
     case 1:
       setWidth(value.toDouble(&ok));
       return ok;
@@ -271,14 +184,14 @@ namespace QGpCoreMath {
       setWidthCompatibility(value.toDouble());
       return true;
     case 4:
-      setMethod(value);
-      return true;
+      _method=convertMethod(value, ok);
+      return ok;
     case 5:
       setOrder(value.toInt(&ok));
       return ok;
     case 6:
-      setScaleType(SamplingParameters::scaleType(value));
-      return true;
+      setScaleType(SamplingParameters::convertScaleType(value, ok));
+      return ok;
     default:
       break;
     }
@@ -289,11 +202,11 @@ namespace QGpCoreMath {
   {
     TRACE;
     QString log;
-    log+=prefix+"SMOOTHING_METHOD"+suffix+"="+methodString()+"\n";
-    log+=prefix+"SMOOTHING_WIDTH_TYPE"+suffix+"="+widthTypeString()+"\n";
+    log+=prefix+"SMOOTHING_METHOD"+suffix+"="+convertMethod(_method)+"\n";
+    log+=prefix+"SMOOTHING_WIDTH_TYPE"+suffix+"="+convertWidthType(_widthType)+"\n";
     log+=prefix+"SMOOTHING_WIDTH"+suffix+"="+QString::number(_width)+"\n";
-    log+="Describes the way values are summed: on a linear, log or inversed scale\n";
-    log+=prefix+"SMOOTHING_SCALE_TYPE"+suffix+"="+SamplingParameters::scaleType(scaleType())+"\n";
+    log+="# Describes the way values are summed: on a linear, log or inverse scale\n";
+    log+=prefix+"SMOOTHING_SCALE_TYPE"+suffix+"="+SamplingParameters::convertScaleType(scaleType())+"\n";
 #ifdef SAVITZKY_GOLAY
     log+=prefix+"SMOOTHING_ORDER"+suffix+"="+QString::number(_order)+"\n";
 #endif
