@@ -33,6 +33,7 @@
 #include "StatisticalValue.h"
 #include "ComplexPointOptions.h"
 #include "QGpCoreMathDLLExport.h"
+#include "SamplingParameters.h"
 
 namespace QGpCoreMath {
 
@@ -44,7 +45,6 @@ namespace QGpCoreMath {
     StatisticalPoint(double x, const numberType& y)
       : StatisticalValue<numberType>(y), _x(x) {}
 
-    inline void operator=(const StatisticalPoint<numberType>& o);
     inline void operator=(const StatisticalValue<numberType>& o);
 
     inline bool operator<(const StatisticalPoint<numberType>& p) const;
@@ -59,10 +59,12 @@ namespace QGpCoreMath {
 
     inline void interpole(double valX,
                           const StatisticalPoint<numberType>& p1,
-                          const StatisticalPoint<numberType>& p2);
+                          const StatisticalPoint<numberType>& p2,
+                          SamplingOptions xSampling,
+                          SamplingOptions ySampling);
 
     bool fromString(const StringSection& str);
-    QString toString(int precision=6, char format='g') const;
+    QString toString(char format='g', int precision=6) const;
   protected:
     void xml_writeProperties(XML_WRITEPROPERTIES_ARGS) const;
     XMLMember xml_member(XML_MEMBER_ARGS);
@@ -101,18 +103,12 @@ namespace QGpCoreMath {
     virtual const QString& xml_tagName() const {return xmlRealStatisticalPointTag;}
     static const QString xmlRealStatisticalPointTag;
 
-    inline void operator=(const RealStatisticalPoint& o);
     inline void operator=(const RealStatisticalValue& o);
 
     inline void setY(double v, const CurvePointOptions * options=nullptr);
     inline double y(const CurvePointOptions * options=nullptr) const;
   };
 
-  inline void RealStatisticalPoint::operator=(const RealStatisticalPoint& o)
-  {
-    StatisticalPoint<double>::operator=(o);
-  }
-
   inline void RealStatisticalPoint::operator=(const RealStatisticalValue& o)
   {
     StatisticalPoint<double>::operator=(o);
@@ -139,31 +135,17 @@ namespace QGpCoreMath {
     virtual const QString& xml_tagName() const {return xmlComplexStatisticalPointTag;}
     static const QString xmlComplexStatisticalPointTag;
 
-    inline void operator=(const ComplexStatisticalPoint& o);
     inline void operator=(const ComplexStatisticalValue& o);
 
     void setY(double v, const CurvePointOptions * options);
     double y(const CurvePointOptions * options) const;
   };
 
-  inline void ComplexStatisticalPoint::operator=(const ComplexStatisticalPoint& o)
-  {
-    StatisticalPoint<Complex>::operator=(o);
-  }
-
   inline void ComplexStatisticalPoint::operator=(const ComplexStatisticalValue& o)
   {
     StatisticalPoint<Complex>::operator=(o);
   }
 
-  template <class numberType>
-  inline void StatisticalPoint<numberType>::operator=(const StatisticalPoint<numberType>& o)
-  {
-    TRACE;
-    StatisticalValue<numberType>::operator=(o);
-    _x=o._x;
-  }
-
   template <class numberType>
   inline void StatisticalPoint<numberType>::operator=(const StatisticalValue<numberType>& o)
   {
@@ -186,12 +168,39 @@ namespace QGpCoreMath {
   template <class numberType>
   inline void StatisticalPoint<numberType>::interpole(double valX,
                                                       const StatisticalPoint<numberType>& p1,
-                                                      const StatisticalPoint<numberType>& p2)
+                                                      const StatisticalPoint<numberType>& p2,
+                                                      SamplingOptions xSampling,
+                                                      SamplingOptions ySampling)
   {
-    TRACE;
-    double factor=(valX-p1.x())/(p2.x()-p1.x());
     setX(valX);
-    this->setMean(p1.mean()+(p2.mean()-p1.mean())*factor);
+    double x1, x2;
+    numberType y1, y2;
+    if(xSampling & InverseScale) {
+      valX=1.0/valX;
+      x1=1.0/p1.x();
+      x2=1.0/p2.x();
+    } else if(xSampling & LogScale) {
+      valX=log(valX);
+      x1=log(p1.x());
+      x2=log(p2.x());
+    } else {
+      x1=p1.x();
+      x2=p2.x();
+    }
+    double factor=(valX-x1)/(x2-x1);
+    if(ySampling & InverseScale) {
+      y1=1.0/p1.mean();
+      y2=1.0/p2.mean();
+      this->setMean(1.0/(y1+(y2-y1)*factor));
+    } else if(ySampling & LogScale) {
+      y1=log(p1.mean());
+      y2=log(p2.mean());
+      this->setMean(exp(y1+(y2-y1)*factor));
+    } else {
+      y1=p1.mean();
+      y2=p2.mean();
+      this->setMean(y1+(y2-y1)*factor);
+    }
     this->setStddev(p1.stddev()+(p2.stddev()-p1.stddev())*factor);
     this->setWeight(p1.weight()+(p2.weight()-p1.weight())*factor);
   }
@@ -219,14 +228,15 @@ namespace QGpCoreMath {
   {
     TRACE;
     Q_UNUSED(context)
+    bool ok=true;
     switch(memberID) {
-    case 0: _x=content.toDouble(); return true;
+    case 0: _x=content.toDouble(ok); return ok;
     default: return StatisticalValue<numberType>::xml_setProperty(memberID-1, tag, attributes, content, context);
     }
   }
 
   template <class numberType>
-  QString StatisticalPoint<numberType>::toString(int precision, char format) const
+  QString StatisticalPoint<numberType>::toString(char format, int precision) const
   {
     TRACE;
     QString tmp;
@@ -249,18 +259,36 @@ namespace QGpCoreMath {
   {
     TRACE;
     const QChar * ptr=0;
+    bool ok=true;
     StringSection f;
     f=str.nextField(ptr);
-    if(f.isValid()) _x=f.toDouble(); else return false;
+    if(f.isValid()) {
+      _x=f.toDouble(ok);
+      if(!ok) {
+        return false;
+      }
+    } else {
+      return false;
+    }
     numberType tmp;
     if(str.nextNumber(tmp, ptr)) {
       StatisticalValue<numberType>::setMean(tmp);
     } else return false;
     f=str.nextField(ptr);
-    if(f.isValid()) StatisticalValue<numberType>::setStddev(f.toDouble()); else return false;
+    if(f.isValid()) {
+      StatisticalValue<numberType>::setStddev(f.toDouble(ok));
+      if(!ok) {
+        return false;
+      }
+    } else {
+      return false;
+    }
     f=str.nextField(ptr);
     if(f.isValid()) {
-      double w=f.toDouble();
+      double w=f.toDouble(ok);
+      if(!ok) {
+        return false;
+      }
       if(w==0.0) {
         StatisticalValue<numberType>::setValid(false);
         StatisticalValue<numberType>::setWeight(1.0);
