@@ -182,7 +182,7 @@ namespace QGpCoreMath {
       break;
     case WindowFunctionParameters::Tukey: {
         ASSERT(param.alpha()<=1.0);
-        ASSERT(param.alpha()>0.0);
+        ASSERT(param.alpha()>=0.0);
         double L=width+1.0;
         double al2=0.5*param.alpha()*L;
         int al2i=qCeil(al2);
@@ -264,14 +264,13 @@ namespace QGpCoreMath {
   double WindowFunction::value(double x, double x0, double xMin, double xMax,
                                const WindowFunctionParameters& param)
   {
-    double y;
-    if(x<xMin || x>xMax) {
-      y=0.0;
-    } else {
+    double y=0.0;
+    if(x>=xMin && x<=xMax) {
       double width;
       switch(param.shape()) {
       case WindowFunctionParameters::KonnoOhmachi:
       case WindowFunctionParameters::Rectangular:
+        SAFE_UNINITIALIZED(width, 0.0);
         break;
       default:
         width=x0-xMin;
@@ -434,9 +433,9 @@ namespace QGpCoreMath {
         }
         break;
       }
-    }
-    if(param.reversed()) {
-      y=1.0-y;
+      if(param.reversed()) {
+        y=1.0-y;
+      }
     }
     return y;
   }
@@ -448,7 +447,7 @@ namespace QGpCoreMath {
     for(int i=WindowFunctionParameters::Rectangular;
         i<=WindowFunctionParameters::KonnoOhmachi; i++) {
       param.setShape(static_cast<WindowFunctionParameters::Shape>(i));
-      App::log(tr("Testing %1...\n").arg(param.shapeString()));
+      App::log(tr("Testing %1...\n").arg(WindowFunctionParameters::convertShape(param.shape())));
       int width=50;
       WindowFunction f(width, param);
       double n1=width-1.0;
