@@ -42,11 +42,12 @@ namespace QGpCoreStat {
     HistogramReader();
     ~HistogramReader();
 
-    enum Action {Gui, Mean, Median, Mode, Grid, GaussMix, Plot, MaxFile, MinimumVelocity};
+    enum Action {Gui, Mean, Median, Mode, GaussMix, Plot, MaxFile, MinimumVelocity,
+                 Misfit, HistogramValues};
     enum MaxVariables {SlownessFrequency, AzimuthFrequency,
-                       EllipticityFrequency, EllipticityAbsFrequency,
-                       EllipticityDegFrequency, EllipticityDegInversedFrequency,
-                       EllipticityRadFrequency, EllipticityRadInversedFrequency,
+                       EllipticityFrequency, EllipticityAbsFrequency, EllipticityOppositeFrequency,
+                       EllipticityDegFrequency, EllipticityDegAbsFrequency, EllipticityDegOppositeFrequency,
+                       EllipticityRadFrequency, EllipticityRadAbsFrequency, EllipticityRadOppositeFrequency,
                        NoiseFrequency,
                        SlownessWaveNumber, SlownessWaveLength, SlownessPeriod, WaveNumberFrequency, WaveLengthFrequency,
                        FrequencyWaveNumber};
@@ -73,7 +74,7 @@ namespace QGpCoreStat {
     bool isEmpty() const {return _samples.isEmpty();}
 
     const SamplingParameters * xSampling() const {return _xSampling;}
-    const QVector<double>& xValues() const {return _xValues;}
+    const VectorList<double>& xValues() const {return _xValues;}
     bool xLogSampling() const {return _xLogSampling;}
     const SamplingParameters& ySampling() const {return _ySampling;}
 
@@ -81,13 +82,20 @@ namespace QGpCoreStat {
     double noiseThreshold() const {return _noiseThreshold;}
 
     const QString& exportMaxFileName() const {return _exportMaxFileName;}
+    Curve<Point2D> misfit(bool& ok) const;
   protected:
     virtual bool parse(QTextStream& s);
     virtual bool loadSamples(QTextStream& s, const QString& lastLine);
+    virtual void misfit(const QList<Curve<Point2D>>& curves, Curve<Point2D>& m,
+                        int * hitCount, double precision) const;
     void add(const Histogram2D::Sample& s) {_samples.append(s);}
-    bool setDefaultXLimits(const QVector<double>& x);
+    bool setDefaultXLimits(const VectorList<double>& x);
     bool setDefaultYLimits();
+    bool configureFKMaxFile(const QString& line);
+    void configureSPACMaxFile();
+    void configureCapMaxFile();
 
+    Action _action;
     struct ManualFlags {
       bool minimum:1;
       bool maximum:1;
@@ -106,18 +114,18 @@ namespace QGpCoreStat {
       };
       int flags;
     } _manual;
+  protected:
+    int _xColumn, _yColumn, _verticalNoiseColumn, _horizontalNoiseColumn,
+        _powerColumn, _ringColumn, _validColumn;
+    bool _angularEllipticity;
   private:
     Histogram2D::Sample transformSample(const Histogram2D::Sample& s);
-    bool configureFKMaxFile(const QString& line);
-    void configureSPACMaxFile();
-    void configureCapMaxFile();
 
-    Action _action;
     QString _exportMaxFileName;
     bool _ignoreStdin;
     bool _normalize;
     bool _xLogSampling;
-    int _xColumn, _yColumn, _noiseColumn, _powerColumn, _ringColumn, _validColumn;
+    bool _yPeriodic;
     double _yFactor;
     double _relativePowerThreshold;
     double _noiseThreshold;
@@ -125,12 +133,12 @@ namespace QGpCoreStat {
     QString _pattern;
     int _ring;
 
-    QVector<double> _xValues;
+    VectorList<double> _xValues;
     SamplingParameters * _xSampling;
     SamplingParameters _ySampling;
-    QVector<Histogram2D::Sample> _samples;
-    QString _xTitle, _xTitleInversedScale;
-    QString _yTitle, _yTitleInversedScale;
+    VectorList<Histogram2D::Sample> _samples;
+    QString _xTitle, _xTitleInverseScale;
+    QString _yTitle, _yTitleInverseScale;
     Scale::Type _xScaleType, _yScaleType;
 
     bool _ignoreValid;
