@@ -3,14 +3,17 @@
 
 // All headers of QGpCoreStat library
 
-#include "Densities.h"
+#include "GaussianMixtureDistribution.h"
+#include "GaussianMixtureEM.h"
+#include "GaussianMixtureLikelihood.h"
 #include "GaussianMixtureParameters.h"
 #include "Histogram.h"
 #include "Histogram2D.h"
-#include "HistogramDensities.h"
+#include "HistogramInversion.h"
 #include "HistogramReader.h"
-#include "Likelihood.h"
+#include "MultivariateHistogram.h"
 #include "QGpCoreStatDLLExport.h"
+#include "SampleClassificationParameters.h"
 #include "SampleFilter.h"
 
 #ifndef GP_EXPLICIT_LIBRARY_NAMESPACE
