@@ -38,7 +38,8 @@ namespace QGpCoreStat {
     Parse \a line
   */
   bool SampleFilter::Sample::read(const QString& line, int xColumn, int yColumn,
-                                  int noiseColumn, int powerColumn, int ringColumn,
+                                  int verticalNoiseColumn, int horizontalNoiseColumn,
+                                  int powerColumn, int ringColumn,
                                   int validColumn)
   {
     TRACE;
@@ -48,8 +49,11 @@ namespace QGpCoreStat {
     _frequency=lp.toDouble(1, ok);
     setX(lp.toDouble(xColumn, ok));
     setY(lp.toDouble(yColumn, ok));
-    if(noiseColumn>0) {
-      _noise=lp.toDouble(noiseColumn, ok);
+    if(verticalNoiseColumn>0) {
+      _verticalNoise=lp.toDouble(verticalNoiseColumn, ok);
+    }
+    if(horizontalNoiseColumn>0) {
+      _horizontalNoise=lp.toDouble(horizontalNoiseColumn, ok);
     }
     if(powerColumn>0) {
       _power=lp.toDouble(powerColumn, ok);
@@ -154,7 +158,7 @@ namespace QGpCoreStat {
     int n0=countValidSamples();
     for(int i=0; i<n; i++) {
       Sample& s=_samples[i];
-      if(s.noise()>threshold) {
+      if(s.verticalNoise()>threshold) {
         s.setValid(false);
       }
     }
@@ -246,10 +250,10 @@ namespace QGpCoreStat {
     }
   }
 
-  QVector<Histogram2D::Sample> SampleFilter::samples() const
+  VectorList<Histogram2D::Sample> SampleFilter::samples() const
   {
     TRACE;
-    QVector<Histogram2D::Sample> dest;
+    VectorList<Histogram2D::Sample> dest;
     int n=_samples.count();
     for(int i=0; i<n; i++) {
       const Sample& s=_samples.at(i);
