@@ -40,23 +40,25 @@ namespace QGpCoreStat {
     {
     public:
       inline Sample();
-      inline Sample(const Sample& s);
 
       void operator=(const Histogram2D::Sample& s) {Histogram2D::Sample::operator=(s);}
 
       bool read(const QString& line, int xColumn, int yColumn,
-                int noiseColumn, int powerColumn, int ringColumn,
+                int verticalNoiseColumn, int horizontalNoiseColumn,
+                int powerColumn, int ringColumn,
                 int validColumn);
 
      double time() const {return _time;}
      double frequency() const {return _frequency;}
-     double noise() const {return _noise;}
+     double verticalNoise() const {return _verticalNoise;}
+     double horizontalNoise() const {return _horizontalNoise;}
      double power() const {return _power;}
      int ring() const {return _ring;}
     private:
       double _time;
       double _frequency;
-      double _noise;
+      double _verticalNoise;
+      double _horizontalNoise;
       double _power;
       int _ring;
     };
@@ -76,14 +78,14 @@ namespace QGpCoreStat {
     static void showStatistics(int remaining, int original);
 
 
-    QVector<Histogram2D::Sample> samples() const;
-    typedef QVector<Sample>::iterator iterator;
+    VectorList<Histogram2D::Sample> samples() const;
+    typedef VectorList<Sample>::iterator iterator;
     iterator begin() {return _samples.begin();}
     iterator end() {return _samples.end();}
   private:
     void selectPower(int beginIndex, int endIndex, double minPower);
     static bool lessThan(const Sample& s1, const Sample& s2);
-    QVector<Sample> _samples;
+    VectorList<Sample> _samples;
   };
 
   inline SampleFilter::Sample::Sample()
@@ -91,21 +93,12 @@ namespace QGpCoreStat {
   {
     _time=0.0;
     _frequency=0.0;
-    _noise=0.0;
+    _verticalNoise=0.0;
+    _horizontalNoise=0.0;
     _power=0.0;
     _ring=0;
   }
 
-  inline SampleFilter::Sample::Sample(const Sample& s)
-    : Histogram2D::Sample(s)
-  {
-    _time=s._time;
-    _frequency=s._frequency;
-    _noise=s._noise;
-    _power=s._power;
-    _ring=s._ring;
-  }
-
 } // namespace QGpCoreStat
 
 #endif // SAMPLEFILTER_H
