@@ -83,6 +83,7 @@ namespace QGpCoreTools {
     virtual int totalKeywordCount(PARAMETERS_TOTALKEYWORDCOUNT_ARGS) const;
     bool parse(const QString& line, const KeywordMap * keywords=nullptr);
     bool setValues(const AbstractParameters& o);
+    void addValues(const AbstractParameters& o);
   protected:
     virtual int keywordCount(PARAMETERS_KEYWORDCOUNT_ARGS) const;
     virtual bool setValue(PARAMETERS_SETVALUE_ARGS);
@@ -95,7 +96,6 @@ namespace QGpCoreTools {
     public:
       ParameterValue() {}
       inline ParameterValue(const QString& key, const QString& value, const QString& unit);
-      inline ParameterValue(const ParameterValue& o);
 
       inline bool set(const KeywordMap& map) const;
     private:
@@ -105,7 +105,7 @@ namespace QGpCoreTools {
     };
 
     int _version;
-    QVector<ParameterValue> * _values;
+    VectorList<ParameterValue> * _values;
   };
 
 } // namespace QGpCoreTools
