@@ -55,7 +55,7 @@ namespace QGpCoreTools {
   The two parameters of a cache are its size in byte and the path of a temporary directory
   used for swapping if the requested memory for data exceed its size.
 */
-Cache::Cache() : _mutex(Mutex::Recursive)
+Cache::Cache()
 {
   TRACE;
   _loadedBytes=0;
@@ -71,6 +71,10 @@ Cache::Cache() : _mutex(Mutex::Recursive)
   \fn Cache::setSize(double nMegaBytes)
   Set the maximum number of mega bytes that can be allocated simultaneously. The default is 0.
 */
+void Cache::setSize(double nMegaBytes)
+{
+  _maxLoadedBytes=qRound64(nMegaBytes*MEGABYTES);
+}
 
 /*!
   Set the path where to swap. The default is the home directory.
@@ -79,16 +83,67 @@ void Cache::setSwapDir(const QDir& d)
 {
   TRACE;
   _swapDir=d;
-  if(_swapDir.exists()) { // clean file that might be left after a crash
-    QStringList filters;
-    filters << "cache_data_*";
-    QStringList cacheFiles=_swapDir.entryList(filters);
+
+  // Check that directory exist or create a new one
+  if(!_swapDir.exists()) {
+    if(!_swapDir.mkpath(_swapDir.absolutePath())) {
+      Message::critical(MSG_ID, tr("Initialize swap directory"),
+                        tr("Cannot create directory %1.")
+                        .arg(_swapDir.absolutePath()));
+      exit(2);
+    }
+  }
+
+  // Clean files that might be left after a crash (more than 10 days ago)
+  QDateTime deadLine=QDateTime::currentDateTime().addDays(-10);
+  QStringList filters;
+  QStringList cacheFiles;
+  filters << "pid_*";
+  cacheFiles=_swapDir.entryList(filters);
+  filters.clear();
+  filters << "cache_data_*";
+  for(QStringList::iterator itpid=cacheFiles.begin();itpid!=cacheFiles.end();itpid++) {
+    QDir d(_swapDir);
+    d.cd(*itpid);
+    bool keepIt=false;
+    QStringList cacheFiles=d.entryList(filters);
     for(QStringList::iterator it=cacheFiles.begin();it!=cacheFiles.end();it++) {
+      QFileInfo fi(d.absoluteFilePath(*it));
+      if(fi.lastModified()<deadLine) {
+        d.remove(*it);
+      } else {
+        keepIt=true;
+        break;
+      }
+    }
+    if(!keepIt) {
+      _swapDir.rmdir(*itpid);
+    }
+  }
+  // Eventually remove files left by crashes of old versions
+  cacheFiles=_swapDir.entryList(filters);
+  for(QStringList::iterator it=cacheFiles.begin();it!=cacheFiles.end();it++) {
+    QFileInfo fi(d.absoluteFilePath(*it));
+    if(fi.lastModified()<deadLine) {
       _swapDir.remove(*it);
     }
-  } else {
-    _swapDir.mkpath(_swapDir.absolutePath ());
   }
+
+  // Create the new swap dir for this application instance
+  int index=0;
+  QString baseSubDir="pid_"+QString::number(QCoreApplication::applicationPid());
+  QString subDir=baseSubDir;
+  while(_swapDir.exists(subDir)) {
+    subDir=baseSubDir+"_"+QString::number(index);
+    index++;
+  }
+  if(!_swapDir.mkdir(subDir)) {
+    Message::critical(MSG_ID, tr("Initialize swap directory"),
+                      tr("Cannot create directory %1.")
+                      .arg(_swapDir.absoluteFilePath(subDir)));
+    exit(2);
+  }
+  _swapDir.cd(subDir);
 }
 
 /*!
@@ -97,23 +152,52 @@ void Cache::setSwapDir(const QDir& d)
 void Cache::free()
 {
   TRACE;
-  free(_maxLoadedBytes);
+  QList<const CacheItem *> list;
+  // Get the unlocked items
+  for(QList<const CacheItem *>::iterator it=_allocatedList.begin();it!=_allocatedList.end();++it) {
+    const CacheItem * item=*it;
+    item->_adminLock.MUTEX_LOCK;
+    if(item->_dataLock.tryLockForWrite()) {
+      if(item->_lockCount<2) {  // Only the one of this try, hence not locked elsewhere
+        list.append(item);
+      } else {
+        item->_dataLock.unlock();
+      }
+    }
+    item->_adminLock.unlock();
+  }
+  // Free them
+  for(QList<const CacheItem *>::iterator it=list.begin();it!=list.end();++it) {
+    const CacheItem * item=*it;
+    item->free();
+    qint64 dataSize=item->dataSize();
+    _loadedBytes-=dataSize;
+    _allocatedList.removeOne(item);
+    item->_dataLock.unlock();
+    APP_LOG(6, tr("Freeing %1 Kb from item %2\t\tFree space=%3 Kb\n")
+            .arg(dataSize/1024.0)
+            .arg(item->debugName())
+            .arg(freeBytes()/1024.0));
+  }
 }
 
 /*!
-  Free items with priority lest than \a priority in order to obtain at least \a nBytes.
+  Free items to obtain at least \a nBytes.
 */
-bool Cache::free(double nBytes)
+bool Cache::free(qint64 nBytes)
 {
   TRACE;
-  double obtainedBytes=_maxLoadedBytes-_loadedBytes;
+  qint64 obtainedBytes=_maxLoadedBytes-_loadedBytes;
   do {
     const CacheItem * item=bestToFree();
     if(item) {
-      item->save(_swapDir);
+      if(!item->save(_swapDir)) {
+        humanInfo();
+        return false;
+      }
       item->_saved=true;
       item->free();
-      double dataSize=item->dataSize();
+      qint64 dataSize=item->dataSize();
       obtainedBytes+=dataSize;
       _loadedBytes-=dataSize;
       _allocatedList.removeOne(item);
@@ -121,10 +205,13 @@ bool Cache::free(double nBytes)
       APP_LOG(6, tr("Saving item %1\n"
                     "Freeing %2 Kb from item %3\t\tFree space=%4 Kb\n")
               .arg(item->debugName())
-              .arg(dataSize/1024)
+              .arg(dataSize/1024.0)
               .arg(item->debugName())
-              .arg(freeBytes()/1024));
-    } else return false;
+              .arg(freeBytes()/1024.0));
+    } else {
+      humanInfo();
+      return false;
+    }
   } while(obtainedBytes<nBytes);
   return true;
 }
@@ -152,10 +239,10 @@ void Cache::free(CacheItem * item, bool saveTemp)
     _allocatedList.removeOne(item);
     _mutex.unlock();
     APP_LOG(6, tr("Freeing %1 Kb from item %2. %3 still allocated\t\tfree space=%4 Kb\n")
-            .arg(static_cast<double>(item->dataSize())/1024)
+            .arg(item->dataSize()/1024.0)
             .arg(item->debugName())
             .arg(_allocatedList.count())
-            .arg(freeBytes()/1024))
+            .arg(freeBytes()/1024.0))
   }
 }
 
@@ -168,7 +255,7 @@ bool Cache::makeAvailable(const CacheItem * item)
 {
   TRACE;
   // Process low level allocation of data
-  double neededSize=static_cast<double>(item->dataSize());
+  qint64 neededSize=item->dataSize();
   QMutexLocker ml(&_mutex);
   if(neededSize>freeBytes()) {
     // Not enough space in cache
@@ -188,7 +275,7 @@ bool Cache::makeAvailable(const CacheItem * item)
       humanInfo();
       return false; // really not lucky, no more space
     }
-    // Perfect got memory free
+    // Perfect got free memory
   }
   if(item->allocate()) {
     _allocatedList.append(item);
@@ -196,20 +283,23 @@ bool Cache::makeAvailable(const CacheItem * item)
     ml.unlock();
     if(item->_saved) {
       APP_LOG(6, tr("Loading item %1\n").arg(item->debugName()))
-      item->load(_swapDir);
+      if(!item->load(_swapDir)) {
+        humanInfo();
+        return false;
+      }
       _swapDir.remove(item->swapFileName());
       item->_saved=false;
     }
     APP_LOG(6, tr("Allocating %1 Kbytes for item %2\t\tfree space=%3 Kb\n")
-            .arg(neededSize/1024)
+            .arg(neededSize/1024.0)
             .arg(item->debugName())
-            .arg(freeBytes()/1024))
+            .arg(freeBytes()/1024.0))
     return true;
   }
   // Impossible to allocate new memory, problem with your computer?
   QString msg=tr("Impossible to allocate new data of size %1: current used space: %2 Kb.\n\n")
                    .arg(neededSize)
-                   .arg(_loadedBytes * sizeof(double)/1024.0)+humanInfo();
+                   .arg(_loadedBytes/1024.0)+humanInfo();
   App::log(msg);
   CoreApplication::instance()->reportBug(Message::Warning, msg.toLatin1().data());
   return false;
@@ -218,11 +308,11 @@ bool Cache::makeAvailable(const CacheItem * item)
 /*!
   In all cases the data must be still allocated with its original size. This is not double checked.
 */
-bool Cache::enlarge(CacheItem * item, double finalSize)
+bool Cache::enlarge(CacheItem * item, qint64 finalSize)
 {
   TRACE;
   // Process low level allocation of data
-  double neededSize=finalSize - (double) item->dataSize();
+  qint64 neededSize=finalSize-item->dataSize();
   QMutexLocker ml(&_mutex);
   if(neededSize>freeBytes()) {
     // Not enough space in cache
