@@ -68,8 +68,8 @@ namespace QGpCoreTools {
     virtual qint64 dataSize() const=0;
     virtual bool allocate() const=0;
     virtual void free() const=0;
-    virtual void save(QDir& d) const=0;
-    virtual void load(QDir& d) const=0;
+    virtual bool save(QDir& d) const=0;
+    virtual bool load(QDir& d) const=0;
 
     inline QString swapFileName() const {return QString("cache_data_%1").arg(reinterpret_cast<qint64>(this), 0, 16);}
     virtual QString debugName() const {return swapFileName();}
