@@ -44,145 +44,139 @@ namespace QGpCoreTools {
     TRACE;
     switch(c) {
     case Qt::white:
-      _rgba=0xffffffff;
+    case Qt::color1:
+      _rgba=0xFFFFFFFFFFFFFFFF;
       break;
     case Qt::black:
-      _rgba=0xff000000;
+      _rgba=0xFFFF000000000000;
       break;
     case Qt::red:
-      _rgba=0xffff0000;
+      _rgba=0xFFFFFFFF00000000;
       break;
     case Qt::darkRed:
-      _rgba=0xff800000;
+      _rgba=0xFFFF800000000000;
       break;
     case Qt::green:
-      _rgba=0xff00ff00;
+      _rgba=0xFFFF0000FFFF0000;
       break;
     case Qt::darkGreen:
-      _rgba=0xff008000;
+      _rgba=0xFFFF000080000000;
       break;
     case Qt::blue:
-      _rgba=0xff0000ff;
+      _rgba=0xFFFF00000000FFFF;
       break;
     case Qt::darkBlue:
-      _rgba=0xff000080;
+      _rgba=0xFFFF000000008000;
       break;
     case Qt::cyan:
-      _rgba=0xff00ffff;
+      _rgba=0xFFFF0000FFFFFFFF;
       break;
     case Qt::darkCyan:
-      _rgba=0xff008080;
+      _rgba=0xFFFF000080008000;
       break;
     case Qt::magenta:
-      _rgba=0xffff00ff;
+      _rgba=0xFFFFFFFF0000FFFF;
       break;
     case Qt::darkMagenta:
-      _rgba=0xff800080;
+      _rgba=0xFFFF800000008000;
       break;
     case Qt::yellow:
-      _rgba=0xffffff00;
+      _rgba=0xFFFFFFFFFFFF0000;
       break;
     case Qt::darkYellow:
-      _rgba=0xff808000;
+      _rgba=0xFFFF800080000000;
       break;
     case Qt::gray:
-      _rgba=0xffa0a0a4;
+      _rgba=0xFFFFA000A000A400;
       break;
     case Qt::darkGray:
-      _rgba=0xff808080;
+      _rgba=0xFFFF800080008000;
       break;
     case Qt::lightGray:
-      _rgba=0xffc0c0c0;
+      _rgba=0xFFFFC000C000C000;
       break;
     case Qt::transparent:
-      _rgba=0x00000000;
-      break;
     case Qt::color0:
-      _rgba=0x00000000;
-      break;
-    case Qt::color1:
-      _rgba=0xffffffff;
+      _rgba=0x0000000000000000;
       break;
     }
   }
 
-  QString Color::name() const
+  /*!
+    Return color under format #AAAARRRRGGGGBBBB
+  */
+  QString Color::toString() const
   {
     TRACE;
     return QString("#%1%2%3%4")
-        .arg(alpha(), 2, 16, QChar('0'))
-        .arg(red(), 2, 16, QChar('0'))
-        .arg(green(), 2, 16, QChar('0'))
-        .arg(blue(), 2, 16, QChar('0'));
+        .arg(alpha64(), 4, 16, QChar('0'))
+        .arg(red64(), 4, 16, QChar('0'))
+        .arg(green64(), 4, 16, QChar('0'))
+        .arg(blue64(), 4, 16, QChar('0'));
   }
 
-  bool Color::setNamedColor(const QString& n)
+  void Color::fromString(const StringView& n, bool& ok)
   {
     TRACE;
-    bool ok[4];
-    memset(ok, true, 4);
     Color c;
-    switch(n.count()) {
+    switch(n.size()) {
     case 4:
-      c=Color(n.mid(1, 1).toInt(&ok[0], 16),
-              n.mid(2, 1).toInt(&ok[1], 16),
-              n.mid(3, 1).toInt(&ok[2], 16));
+      c.setRgba64(n.mid(1, 1).toUInt(ok ? &ok : nullptr, 16) << 12,
+                  n.mid(2, 1).toUInt(ok ? &ok : nullptr, 16) << 12,
+                  n.mid(3, 1).toUInt(ok ? &ok : nullptr, 16) << 12);
       break;
     case 5:
-      c=Color(n.mid(2, 1).toInt(&ok[0], 16),
-              n.mid(3, 1).toInt(&ok[1], 16),
-              n.mid(4, 1).toInt(&ok[2], 16),
-              n.mid(1, 1).toInt(&ok[3], 16));
+      c.setRgba64(n.mid(2, 1).toUInt(ok ? &ok : nullptr, 16) << 12,
+                  n.mid(3, 1).toUInt(ok ? &ok : nullptr, 16) << 12,
+                  n.mid(4, 1).toUInt(ok ? &ok : nullptr, 16) << 12,
+                  n.mid(1, 1).toUInt(ok ? &ok : nullptr, 16) << 12);
       break;
     case 7:
-      c=Color(n.mid(1, 2).toInt(&ok[0], 16),
-              n.mid(3, 2).toInt(&ok[1], 16),
-              n.mid(5, 2).toInt(&ok[2], 16));
+      c.setRgba64(n.mid(1, 2).toUInt(ok ? &ok : nullptr, 16) << 8,
+                  n.mid(3, 2).toUInt(ok ? &ok : nullptr, 16) << 8,
+                  n.mid(5, 2).toUInt(ok ? &ok : nullptr, 16) << 8);
       break;
     case 9:
-      c=Color(n.mid(3, 2).toInt(&ok[0], 16),
-              n.mid(5, 2).toInt(&ok[1], 16),
-              n.mid(7, 2).toInt(&ok[2], 16),
-              n.mid(1, 2).toInt(&ok[3], 16));
+      c.setRgba64(n.mid(3, 2).toUInt(ok ? &ok : nullptr, 16) << 8,
+                  n.mid(5, 2).toUInt(ok ? &ok : nullptr, 16) << 8,
+                  n.mid(7, 2).toUInt(ok ? &ok : nullptr, 16) << 8,
+                  n.mid(1, 2).toUInt(ok ? &ok : nullptr, 16) << 8);
       break;
     case 10: // 3 digits does not support alpha, cannot discriminate with 3 channels with 4 digits
-      c=Color(n.mid(1, 3).toInt(&ok[0], 16),
-              n.mid(4, 3).toInt(&ok[1], 16),
-              n.mid(7, 3).toInt(&ok[2], 16));
+      c.setRgba64(n.mid(1, 3).toUInt(ok ? &ok : nullptr, 16) << 4,
+                  n.mid(4, 3).toUInt(ok ? &ok : nullptr, 16) << 4,
+                  n.mid(7, 3).toUInt(ok ? &ok : nullptr, 16) << 4);
       break;
     case 13:
-      c=Color(n.mid(1, 4).toInt(&ok[0], 16),
-              n.mid(5, 4).toInt(&ok[1], 16),
-              n.mid(9, 4).toInt(&ok[2], 16));
+      c.setRgba64(n.mid(1, 4).toUInt(ok ? &ok : nullptr, 16),
+                  n.mid(5, 4).toUInt(ok ? &ok : nullptr, 16),
+                  n.mid(9, 4).toUInt(ok ? &ok : nullptr, 16));
       break;
     case 17:
-      c=Color(n.mid(5, 4).toInt(&ok[0], 16),
-              n.mid(9, 4).toInt(&ok[1], 16),
-              n.mid(13, 4).toInt(&ok[2], 16),
-              n.mid(1, 4).toInt(&ok[3], 16));
+      c.setRgba64(n.mid(5, 4).toUInt(ok ? &ok : nullptr, 16),
+                  n.mid(9, 4).toUInt(ok ? &ok : nullptr, 16),
+                  n.mid(13, 4).toUInt(ok ? &ok : nullptr, 16),
+                  n.mid(1, 4).toUInt(ok ? &ok : nullptr, 16));
       break;
     default:
-      ok[0]=false;
+      ok=false;
       break;
     }
-    for(int i=0; i<0; i++) {
-      if(!ok[i]) {
-        App::log(tr("Bad color name '%1'\n").arg(n) );
-        return false;
-      }
-    }
     *this=c;
-    return true;
   }
 
   /*!
     Same code as in QColor
+
+    Values are from 0 to 255.
   */
   void Color::setHsva(int h, int s, int v, int a)
   {
     TRACE;
+    a=a << 8;
     if(s==0 || h==360) { // achromatic case
-      setRgba(v, v, v, a);
+      v=v << 8;
+      setRgba64(v, v, v, a);
     }
     const double hp=h/60.0;
     const double sp=s/255.0;
@@ -240,29 +234,33 @@ namespace QGpCoreTools {
         break;
       }
     }
-    setRgba(qRound(rp*USHRT_MAX) >> 8, qRound(gp*USHRT_MAX) >> 8, qRound(bp*USHRT_MAX) >> 8, a);
+    setRgba64(qRound(rp*COLOR_COMPONENT_MAX),
+              qRound(gp*COLOR_COMPONENT_MAX),
+              qRound(bp*COLOR_COMPONENT_MAX), a);
   }
 
   /*!
     Same code as in QColor. Qcolor stores unsigned short values and
     scale them to return integers from 0 to 255 (saturation and value) and 360 (hue). This function
-    has exactly the same rounding errors as QColor ouput functions.
+    has exactly the same rounding errors as QColor output functions.
+
+    Values are from 0 to 255.
   */
   void Color::hsv(int& h, int& s, int& v) const
   {
     TRACE;
-    const double rp=red()/255.0;
-    const double gp=green()/255.0;
-    const double bp=blue()/255.0;
+    double rp=unit(red64());
+    double gp=unit(green64());
+    double bp=unit(blue64());
     double cmax, cmin;
     minMax(rp, gp, bp, cmin, cmax);
     const double delta=cmax-cmin;
     if(cmax==0) {
       s=0;
     } else {
-      s=qRound((delta/cmax)*USHRT_MAX) >> 8;
+      s=qRound((delta/cmax)*COLOR_COMPONENT_MAX) >> 8;
     }
-    v=qRound(cmax*USHRT_MAX) >> 8;
+    v=qRound(cmax*COLOR_COMPONENT_MAX) >> 8;
     double hp;
     if(delta==0) {
       h=-1;  // achromatic case, hue is undefined
@@ -284,7 +282,7 @@ namespace QGpCoreTools {
   double Color::gammaExpansion(double csrgb)
   {
     if(csrgb>0.04045) {
-      return pow((csrgb+0.0555)/1.055, 2.4);
+      return ::pow((csrgb+0.0555)/1.055, 2.4);
     } else {
       return csrgb/12.92;
     }
@@ -293,25 +291,32 @@ namespace QGpCoreTools {
   double Color::gammaCompression(double clinear)
   {
     if(clinear>0.0031308) {
-      return 1.055*pow(clinear, 1.0/2.4)-0.055;
+      return 1.055*::pow(clinear, 1.0/2.4)-0.055;
     } else {
       return 12.92*clinear;
     }
   }
 
+  double Color::unit(quint16 c)
+  {
+    return static_cast<double>(c)/static_cast<double>(COLOR_COMPONENT_MAX);
+  }
+
   /*!
     Source: https://en.wikipedia.org/wiki/Grayscale
   */
   void Color::toGray()
   {
     TRACE;
-    double rLinear=gammaExpansion(red()/255.0);
-    double gLinear=gammaExpansion(green()/255.0);
-    double bLinear=gammaExpansion(blue()/255.0);
+    double rLinear=gammaExpansion(unit(red64()));
+    double gLinear=gammaExpansion(unit(green64()));
+    double bLinear=gammaExpansion(unit(blue64()));
     double luminanceLinear=0.2126*rLinear+0.7152*gLinear+0.0722*bLinear;
-    int luminanceSrgb=qRound(gammaCompression(luminanceLinear)*255.0);
-    //qDebug() << luminanceSrgb/255.0;
-    setRgba(luminanceSrgb, luminanceSrgb, luminanceSrgb, alpha());
+    if(luminanceLinear>1.0) { // Observed values above 1 for Oslo palette
+      luminanceLinear=1.0;
+    }
+    quint16 luminanceSrgb=qRound(gammaCompression(luminanceLinear)*COLOR_COMPONENT_MAX);
+    setRgba64(luminanceSrgb, luminanceSrgb, luminanceSrgb, alpha64());
   }
 
   /*!
@@ -324,5 +329,29 @@ namespace QGpCoreTools {
     return v<128;
   }
 
+  /*!
+    Returns true if it is close to white
+  */
+  bool Color::isNearlyWhite() const
+  {
+    return red64()>64000 && green64()>64000 && blue64()>64000;
+  }
+
+  quint32 Color::argb32() const
+  {
+#if Q_BYTE_ORDER == Q_BIG_ENDIAN
+    quint32 c=((alpha32() << 0) |
+               (red32() << 8) |
+               (green32() << 16) |
+               (blue32() << 24));
+#else // little endian:
+    quint32 c=((alpha32() << 24) |
+               (red32() << 16) |
+               (green32() << 8) |
+               (blue32() << 0));
+#endif
+    return c;
+  }
+
 } // namespace QGpCoreTools
 
