@@ -67,11 +67,12 @@ bool ColumnTextDescription::xml_setProperty(XML_SETPROPERTY_ARGS)
   Q_UNUSED(tag)
   Q_UNUSED(attributes)
   Q_UNUSED(context)
+  bool ok=true;
   switch(memberID) {
-  case 0: _type=content.toInt(); return true;
-  case 1: _factor=content.toDouble(); return true;
-  case 2: _replaceRx=content.toString(); return true;
-  case 3: _replaceAfter=content.toString(); return true;
+  case 0: _type=content.toInt(ok); return ok;
+  case 1: _factor=content.toDouble(ok); return ok;
+  case 2: _replaceRx=content.toStringBuffer(); return true;
+  case 3: _replaceAfter=content.toStringBuffer(); return true;
   default: return false;
   }
 }
