@@ -129,7 +129,7 @@ namespace QGpCoreTools {
     delete _text;
   }
 
-  void ColumnTextParser::setTypes(const QVector<int>& types)
+  void ColumnTextParser::setTypes(const VectorList<int>& types)
   {
     TRACE;
     int n=types.count();
@@ -262,9 +262,9 @@ namespace QGpCoreTools {
     Lines start at 1, If \a i is 0, no limit on end line is set.
   */
 
-  QVector<int> ColumnTextParser::columnWidths(const QString& ws)
+  VectorList<int> ColumnTextParser::columnWidths(const QString& ws)
   {
-    QVector<int> wi;
+    VectorList<int> wi;
     QStringList wStrList=ws.split(",");
     for(QStringList::iterator it=wStrList.begin();it!=wStrList.end();it++) {
       wi.append(it->trimmed().toInt());
@@ -272,10 +272,10 @@ namespace QGpCoreTools {
     return wi;
   }
 
-  QString ColumnTextParser::columnWidths(const QVector<int>& wi)
+  QString ColumnTextParser::columnWidths(const VectorList<int>& wi)
   {
     QString ws;
-    QVector<int>::const_iterator it=wi.begin();
+    VectorList<int>::const_iterator it=wi.begin();
     if(it!=wi.end()) {
       ws=QString::number(*it);
       for(it++;it!=wi.end();it++) {
@@ -390,24 +390,24 @@ namespace QGpCoreTools {
     addSection(0); // add at least one section
     _mutex.unlock();
     if(!_text || !_text->seek(0)) return;
-    QRegExp * acceptRegExp, * rejectRegExp, * sectionLineRegExp, * sectionCellRegExp;
+    QRegularExpression * acceptRegExp, * rejectRegExp, * sectionLineRegExp, * sectionCellRegExp;
     if(_acceptPattern.isEmpty()) {
       acceptRegExp=nullptr;
     } else {
-      acceptRegExp=new QRegExp(_acceptPattern);
+      acceptRegExp=new QRegularExpression(_acceptPattern);
     }
     if(_rejectPattern.isEmpty()) {
       rejectRegExp=nullptr;
     } else {
-      rejectRegExp=new QRegExp(_rejectPattern);
+      rejectRegExp=new QRegularExpression(_rejectPattern);
     }
     if(_isSectionLinePattern) {
-      sectionLineRegExp=new QRegExp(_sectionLinePattern);
+      sectionLineRegExp=new QRegularExpression(_sectionLinePattern);
     } else {
       sectionLineRegExp=nullptr;
     }
     if(_isSectionCellPattern) {
-      sectionCellRegExp=new QRegExp(_sectionCellPattern);
+      sectionCellRegExp=new QRegularExpression(_sectionCellPattern);
     } else {
       sectionCellRegExp=nullptr;
     }
@@ -452,18 +452,18 @@ namespace QGpCoreTools {
     delete rejectRegExp;
   }
 
-  void ColumnTextParser::parseColumns(const QString& rowStr, QRegExp * sectionCellRegExp)
+  void ColumnTextParser::parseColumns(const QString& rowStr, QRegularExpression * sectionCellRegExp)
   {
     QStringList cols;
     if(_fixedWidth) {
       int pos=0;
-      for(QVector<int>::const_iterator it=_columnWidths.begin(); it!=_columnWidths.end();it++) {
+      for(VectorList<int>::const_iterator it=_columnWidths.begin(); it!=_columnWidths.end();it++) {
         if(_terminate.testAndSetOrdered(true, true)) return;
-        if(pos>=rowStr.count()) break;
+        if(pos>=rowStr.size()) break;
         cols.append(cellContent(cols.count(), rowStr.mid(pos, *it)));
         pos+=*it;
       }
-      if(pos<rowStr.count()) {
+      if(pos<rowStr.size()) {
         cols.append(cellContent(cols.count(), rowStr.mid(pos)));
       }
     } else {
@@ -476,12 +476,12 @@ namespace QGpCoreTools {
         if(cols.count()==lastColumnIndex) {
           colStrSec=rowStrSec.nextField(ptr, "");
           if(!colStrSec.isValid()) break;
-          cols.append(cellContent(cols.count(), colStrSec.toString()));
+          cols.append(cellContent(cols.count(), colStrSec.toStringBuffer()));
           break;
         } else {
           colStrSec=rowStrSec.nextField(ptr, _delimiters, !_acceptNullColumns);
           if(!colStrSec.isValid()) break;
-          cols.append(cellContent(cols.count(), colStrSec.toString()));
+          cols.append(cellContent(cols.count(), colStrSec.toStringBuffer()));
         }
       }
 
@@ -506,7 +506,7 @@ namespace QGpCoreTools {
   {
     QString rxStr=replaceRx(column);
     if(!rxStr.isEmpty()) {
-      QRegExp rx(rxStr);
+      QRegularExpression rx(rxStr);
       s.replace(rx, replaceAfter(column));
     }
     double fac=factor(column);
@@ -565,9 +565,15 @@ namespace QGpCoreTools {
       static const QString tmp("column");
       XMLRestoreAttributeIterator it=attributes.find(tmp);
       if(it!=attributes.end()) {
-        return XMLMember(&columnDescription(it.value().toInt()));
+        bool ok=true;
+        int c=it.value().toInt(ok);
+        if(!ok) {
+          App::log(tr("Bad column index for description: %1\n").arg(it.value().toStringView()));
+          return XMLMember(XMLMember::Unknown);
+        }
+        return XMLMember(&columnDescription(c));
       } else {
-        App::log(tr("No column index defined for description\n") );
+        App::log(tr("No column index defined for description\n"));
         return XMLMember(XMLMember::Unknown);
       }
     } else if(tag=="startLine") return XMLMember(0);
@@ -600,28 +606,29 @@ namespace QGpCoreTools {
     Q_UNUSED(tag)
     Q_UNUSED(attributes)
     Q_UNUSED(context)
+    bool ok=true;
     switch(memberID) {
-    case 0: _startLine=content.toInt(); return true;
-    case 1: _endLine=content.toInt(); return true;
-    case 2: _acceptPattern=content.toString(); return true;
-    case 3: _rejectPattern=content.toString(); return true;
-    case 4: _hasComments=content.toBool(); return true;
+    case 0: _startLine=content.toInt(ok); return ok;
+    case 1: _endLine=content.toInt(ok); return ok;
+    case 2: _acceptPattern=content.toStringBuffer(); return true;
+    case 3: _rejectPattern=content.toStringBuffer(); return true;
+    case 4: _hasComments=content.toBool(ok); return ok;
 
-    case 5: _fixedWidth=content.toBool(); return true;
-    case 6: _acceptNullColumns=content.toBool(); return true;
-    case 7: _delimiters=content.toString(); return true;
-    case 8: _maximumColumnCount=content.toInt(); return true;
-    case 9: _columnWidths=columnWidths(content.toString()); return true;
+    case 5: _fixedWidth=content.toBool(ok); return ok;
+    case 6: _acceptNullColumns=content.toBool(ok); return ok;
+    case 7: _delimiters=content.toStringBuffer(); return true;
+    case 8: _maximumColumnCount=content.toInt(ok); return ok;
+    case 9: _columnWidths=columnWidths(content.toStringBuffer()); return true;
 
-    case 10: _isSectionLinePattern=content.toBool(); return true;
-    case 11: _sectionLinePattern=content.toString(); return true;
-    case 12: _isSectionLineCount=content.toBool(); return true;
-    case 13: _sectionLineCount=content.toInt(); return true;
-    case 14: _isSectionRowCount=content.toBool(); return true;
-    case 15: _sectionRowCount=content.toInt(); return true;
-    case 16: _isSectionCellPattern=content.toBool(); return true;
-    case 17: _sectionCellColumn=content.toInt(); return true;
-    case 18: _sectionCellPattern=content.toString(); return true;
+    case 10: _isSectionLinePattern=content.toBool(ok); return ok;
+    case 11: _sectionLinePattern=content.toStringBuffer(); return true;
+    case 12: _isSectionLineCount=content.toBool(ok); return ok;
+    case 13: _sectionLineCount=content.toInt(ok); return ok;
+    case 14: _isSectionRowCount=content.toBool(ok); return ok;
+    case 15: _sectionRowCount=content.toInt(ok); return ok;
+    case 16: _isSectionCellPattern=content.toBool(ok); return ok;
+    case 17: _sectionCellColumn=content.toInt(ok); return ok;
+    case 18: _sectionCellPattern=content.toStringBuffer(); return true;
     default: return false;
     }
   }
