@@ -40,7 +40,9 @@ namespace QGpCoreTools {
 /*!
   Description of constructor still missing
 */
-CoreApplication::CoreApplication(int & argc, char ** argv, ApplicationHelp * ( *help) (), bool reportBugs  )
+CoreApplication::CoreApplication(int & argc, char ** argv,
+                                 ApplicationHelp * ( *help) (),
+                                 BugReportOptions bugReportOptions)
     : CoreApplicationPrivate(argc, argv), QCoreApplication(argc, argv)
 {
   // Qt application information
@@ -49,6 +51,8 @@ CoreApplication::CoreApplication(int & argc, char ** argv, ApplicationHelp * ( *
   setOrganizationName("geopsy");
   // Install message handler
   setMessageHandler(new Message);
+  // Init instalation directories
+  initInstallDirs();
   // load translation if necessary
   initTranslations();
 
@@ -64,6 +68,8 @@ CoreApplication::CoreApplication(int & argc, char ** argv, ApplicationHelp * ( *
     } else if(help && (arg=="--help" || arg=="-help" || arg=="-h")) {
       showHelp(i, argc, argv, help);
       ::exit(0);
+    } else if(arg=="-batch") {
+      setBatch(true);
     } else if(arg=="-args") {
       int max=50;
       if(checkOptionArg(i, argc, argv, false)) {
@@ -75,8 +81,10 @@ CoreApplication::CoreApplication(int & argc, char ** argv, ApplicationHelp * ( *
       // Need a fully constructed QCoreApplication
       printLibraryPaths();
       ::exit(0);
+    } else if(arg=="-warning-critical") {
+      bugReportOptions|=WarningAsError;
     } else if(arg=="--nobugreport" || arg=="-nobugreport") {
-      reportBugs=false;
+      bugReportOptions=NoBugReport;
     } else if(arg=="-rargs") {
       int index=0;
       if(checkOptionArg(i, argc, argv, false)) {
@@ -92,7 +100,7 @@ CoreApplication::CoreApplication(int & argc, char ** argv, ApplicationHelp * ( *
     argc=j;
   }
 
-  initInternalDebugger(reportBugs);
+  initInternalDebugger(bugReportOptions);
   checkAtomicOperations();
   // Application name and organisation are properly set, we can use settings
   updateArgumentLists();
