@@ -66,12 +66,16 @@ namespace QGpCoreTools {
     static QString authors();
     virtual bool hasGui() const=0;
 
-    static void checkBlocks(bool showLib, bool showUndeleted, const char * file=nullptr, int line=0);
+    enum BugReportOption {NoBugReport=0, ReportBugs=1, ReportDirectly=2,
+                          WarningAsError=4, NoUserInterruptReport=8};
+    Q_DECLARE_FLAGS(BugReportOptions, BugReportOption)
+
+    static bool checkBlocks(bool showLib, bool showUndeleted, const char * file=nullptr, int line=0);
     static bool isBlockDamaged(void* v, const char * file, int line);
     static void printBlockInfo(void * ptr, const char * file, int line);
     static void setMemoryVerbose(bool v);
 
-    static bool checkOptionArg(int& i, int argc, char ** argv, bool mandatory=true);
+    static bool checkOptionArg(int& i, int argc, char ** argv, bool mandatory=true, int optionIndex=-1);
     static bool checkRemainingArgs(int argc, char ** argv);
     static int toInt(int i, int optionIndex, char ** argv);
     static double toDouble(int i, int optionIndex, char ** argv);
@@ -80,7 +84,7 @@ namespace QGpCoreTools {
     static CoreApplicationPrivate * instance() {return _self;}
 
     void debugUserInterrupts(bool d);
-    static QString backTrace();
+    static QString backTrace(int maxDepth);
     static QString backTraceBug();
     static QString bugInfo(Message::Severity sev, const QString& msg);
     static QString appInfo();
@@ -132,6 +136,7 @@ namespace QGpCoreTools {
     static QString htmlBugReport(const QString& platform, const QString& email=QString(),
                                  const QString &userInfo=QString());
 
+    const VectorList<int>& cpuAffinities() {return _cpuAffinities;}
     int maximumThreadCount() const {return _maximumThreadCount;}
 
     QSettings& settings();
@@ -140,12 +145,14 @@ namespace QGpCoreTools {
     static void setArgumentList(int argc, char ** argv);
     static const QStringList& argumentList() {return _argumentList;}
   protected:
+    void setCPUAffinityList(int maxCoreCount);
     void setTerminalSize();
     void askForUserInterrupt();
     void setMessageHandler(Message * m);
     static QString constructorApplicationName();
     void destructorCleanUp();
-    void initInternalDebugger(bool reportBugs);
+    void initInternalDebugger(BugReportOptions options);
+    void initInstallDirs();
     void initTranslations();
     void checkAtomicOperations();
     virtual void setHelp(ApplicationHelp * h);
@@ -171,8 +178,10 @@ namespace QGpCoreTools {
     QStringList _errors;
     QList<GlobalObject *> _globalPointers;
     QList<QObject *> _plugins;
+    VectorList<int> _cpuAffinities;
     int _maximumThreadCount;
-    bool _reportBugs, _debugUserInterrupts, _warningAsError, _batch;
+    BugReportOptions _bugReportOptions;
+    bool _batch;
     QSettings * _settings, * _globalSettings;
 
     mutable int _terminalCols, _terminalRows;
