@@ -31,7 +31,6 @@
 #include <QtCore>
 
 #include "QGpCoreToolsDLLExport.h"
-#include "Color.h"
 
 // This include has not the same name on all platforms
 // See admin/customconfig for the definition of macros
@@ -58,20 +57,30 @@ inline QTextStream &flush(QTextStream &s) {s << ::flush; return s;}
 
 namespace QGpCoreTools {
 
-  // Redefine my own assert (assert even if QT_NO_DEBUG is defined)
-  #if !defined(ASSERT)
-  #ifndef NO_ASSERT
-  #  define ASSERT(cond) do {if(!(cond))qt_assert(#cond,__FILE__,__LINE__);} while(0)
-  #else
-  #  define ASSERT(cond)
-  #endif
-  #endif
+#if !defined(ASSERT)
+#ifndef QT_NO_DEBUG
+#  define ASSERT(cond) do {if(!(cond))qt_assert(#cond,__FILE__,__LINE__);} while(0)
+#else
+#  define ASSERT(cond)
+#endif
+#endif
+
+// Uncomment to generate an error for all TODOs
+#define TODO(message)
+//  ()
+
+#define TODO_WARNING \
+    App::log(tr("Dev work found at %1:%2, unstable behavior expected.\n") \
+        .arg(__FILE__) \
+        .arg(__LINE__)); \
+    qWarning("Dev work found at %s:%i, unstable behavior expected.\n", \
+        __FILE__, __LINE__)
 
   QGPCORETOOLS_EXPORT void skipOpenBlasMultiThreading();
 
-  // With gcc 4.1.2, I have a lot of unecessary warnings with -Wuninitialized
-  // Maybe gcc will do a better job in the future
-  #define SAFE_UNINITIALIZED(var,value) var=value;
+// With gcc 4.1.2, I have a lot of unecessary warnings with -Wuninitialized
+// Maybe gcc will do a better job in the future
+#define SAFE_UNINITIALIZED(var,value) var=value;
 
   template<typename T>
   inline void minMax(T v1, T v2, T v3, T& min, T& max)
@@ -101,8 +110,8 @@ namespace QGpCoreTools {
     }
   }
 
-  // Usefull for compatibility with old names of properties in XML files
-  #define DUMMY_PROPERTIES \
+// Usefull for compatibility with old names of properties in XML files
+#define DUMMY_PROPERTIES \
   public: \
     void setDummyProperty(const QString&) {} \
     void setDummyProperty(double) {} \
@@ -116,6 +125,39 @@ namespace QGpCoreTools {
 
   QGPCORETOOLS_EXPORT QString encodeToHtml(QString str);
 
+  // Interface class after unification of QVector and QList in Qt 6
+#if(QT_VERSION>=QT_VERSION_CHECK(6, 0, 0))
+#define VectorList QList
+#else
+#define VectorList QVector
+#endif
+
+// Incomplete API for StringView before 5.15.2
+#if(QT_VERSION>=QT_VERSION_CHECK(5, 15, 2))
+#define StringView QStringView
+#else
+#define StringView QString
+#endif
+
+  /*template <typename T>
+  class QGPCORETOOLS_EXPORT VectorList : public QList<T>
+  {
+  public:
+    VectorList() : QList<T>() {}
+    VectorList(int size) : QList<T>(size) {}
+    VectorList(int size, const T& value) : QList<T>(size, value) {}
+    VectorList(const QList<T>& o) : QList<T>(o) {}
+  };
+  template <typename T>
+  class QGPCORETOOLS_EXPORT VectorList : public QVector<T>
+  {
+  public:
+    VectorList() : QVector<T>() {}
+    VectorList(int size) : QVector<T>(size) {}
+    VectorList(int size, const T& value) : QVector<T>(size, value) {}
+    VectorList(const QVector<T>& o) : QVector<T>(o) {}
+  };*/
+
   template<typename T>
   void unique(QList<T>& list)
   {
@@ -184,6 +226,7 @@ namespace QGpCoreTools {
     }
   }
 
+#if(QT_VERSION<QT_VERSION_CHECK(6, 0, 0))
   template<typename T>
   void unique(QVector<T>& vector)
   {
@@ -251,27 +294,13 @@ namespace QGpCoreTools {
       vector=newVector;
     }
   }
+#endif
 
   inline bool lessThanLocalAwareCompareString(const QString& s1, const QString& s2)
   {
     return QString::localeAwareCompare(s1, s2)<0;
   }
 
-  // Return value of registerComparators is ignored because if the operators
-  // are not available at compile time an error is issued.
-  #define REGISTER_METATYPE(type) \
-  class type##InitMetaType \
-  { \
-  public: \
-    type##InitMetaType(); \
-  }; \
-  type##InitMetaType::type##InitMetaType() \
-  { \
-    qRegisterMetaType<type>(# type); \
-    QMetaType::registerComparators<type>(); \
-  } \
-  static type##InitMetaType instance##type##InitMetaType;
-
 } // namespace QGpCoreTools
 
 #endif // GLOBAL_H
