@@ -75,6 +75,30 @@ namespace QGpCoreTools {
     return locale->toString(val, format, precision);
   }
 
+  void Number::toOctaveFile(double val, const QString& fileName, const QString& variableName)
+  {
+    QFile f(fileName);
+    if(!f.open(QIODevice::Append)) {
+      App::log(tr("Cannot write to %1\n").arg(fileName));
+      return;
+    }
+    QTextStream s(&f);
+    s << variableName << "=" << QString::number(val, 'g', 20) << ";" << Qt::endl;
+    f.close();
+  }
+
+  void Number::toOctaveFile(const Complex& val, const QString& fileName, const QString& variableName)
+  {
+    QFile f(fileName);
+    if(!f.open(QIODevice::Append)) {
+      App::log(tr("Cannot write to %1\n").arg(fileName));
+      return;
+    }
+    QTextStream s(&f);
+    s << variableName << "=" << val.toString('g', 20) << ";" << Qt::endl;
+    f.close();
+  }
+
   /*!
     Convert a user string into a double value using type \a t.
     Current QLocale settings are taken into account.
@@ -99,7 +123,11 @@ namespace QGpCoreTools {
   double Number::toDouble(const QVariant& val, bool &ok, QLocale * locale)
   {
     TRACE;
+#if(QT_VERSION>=QT_VERSION_CHECK(6, 0, 0))
+    if(val.typeId()==QMetaType::Double) {
+#else
     if(val.type()==QVariant::Double) {
+#endif
       return val.toDouble();
     } else {
       return toDouble(val.toString(), ok, locale);
@@ -156,7 +184,7 @@ namespace QGpCoreTools {
     // log10(2)=0.301029995663981198
     // Precision for float mantissa is 1/2^23, look for power of 10 to multiply f so that
     // 1/2^23 stand after decimal point, to remove it by rounding.
-    double fac=pow(10.0,floor(0.301029995663981198*(22-exp)));
+    double fac=::pow(10.0,floor(0.301029995663981198*(22-exp)));
     return ::round(fac*f)/fac;
   }
 
@@ -309,7 +337,7 @@ namespace QGpCoreTools {
     if(maximum==1.0) {
       return ::round(val);
     } else {
-      double factor=pow(10.0, floor(log10(maximum)));
+      double factor=::pow(10.0, floor(log10(maximum)));
       return ::round(val/factor)*factor;
     }
   }
@@ -401,7 +429,11 @@ namespace QGpCoreTools {
   double Number::durationToSeconds(const QVariant& val, bool &ok, QLocale * locale)
   {
     TRACE;
+#if(QT_VERSION>=QT_VERSION_CHECK(6, 0, 0))
+    if(val.typeId()==QMetaType::Double) {
+#else
     if(val.type()==QVariant::Double) {
+#endif
       return val.toDouble();
     } else {
       return durationToSeconds(val.toString(), ok, locale);
@@ -415,7 +447,7 @@ namespace QGpCoreTools {
   {
     TRACE;
     const QChar * p=str.data();
-    int n=str.count();
+    int n=str.size();
     QString number;
     bool qok;
     int vali;
