@@ -87,6 +87,8 @@ namespace QGpCoreTools {
   ParallelLoop::ParallelLoop(QObject * parent)
     : QObject(parent)
   {
+    _threadCount=CoreApplication::instance()->maximumThreadCount();
+    _index=0;
   }
 
   ParallelLoop::~ParallelLoop()
@@ -94,10 +96,16 @@ namespace QGpCoreTools {
     TRACE;
     for(QMap<LoopWorker *,TaskInfo>::iterator it=_workers.begin(); it!=_workers.end(); it++) {
       it.key()->QThread::terminate();
-      delete (it.key());
+      delete(it.key());
     }
   }
 
+  /*!
+   \fn int ParallelLoop::progressCount() const
+
+   Interface with LoopProgressWidget. Returns the number of threads.
+  */
+
   void ParallelLoop::terminate()
   {
     TRACE;
@@ -122,11 +130,17 @@ namespace QGpCoreTools {
     }
   }
 
-  void ParallelLoop::waitFinished()
+  /*!
+    If \a ms is null, it waits for the termination of workers without
+    any time limit.
+  */
+  void ParallelLoop::waitFinished(int ms)
   {
-    while(!_workers.isEmpty()) {
+    int i=0;
+    while(!_workers.isEmpty() && (ms<=0 || i<ms)) {
       App::sleep(500);
       QCoreApplication::processEvents();
+      i+=500;
     }
   }
 
@@ -146,17 +160,25 @@ namespace QGpCoreTools {
     return w;
   }
 
+  void ParallelLoop::setThreadCount(int threadCount)
+  {
+    TRACE;
+    _threadCount=threadCount;
+    if(_threadCount<=0 || _threadCount>CoreApplication::instance()->maximumThreadCount()) {
+      _threadCount=CoreApplication::instance()->maximumThreadCount();
+    }
+  }
+
   /*!
     Start loop from \a iStart to \a iEnd-1
   */
   void ParallelLoop::start(int iStart, int iEnd, bool forceParallel)
   {
     TRACE;
-    int nThreads=idealThreadCount(iEnd-iStart+1);
     _index=iStart;
     LoopWorker * w;
     TaskInfo infos;
-    if(nThreads<=1 && !forceParallel) {
+    if(_threadCount<=1 && !forceParallel) {
       App::log(1, tr("Running loop without parallel threads\n"));
       w=newWorker(iEnd);
       if(w) {
@@ -167,9 +189,9 @@ namespace QGpCoreTools {
         workerFinished(w);
       }
     } else {
-      App::log(1, tr("Running loop with %1 parallel threads\n").arg(nThreads));
+      App::log(tr("Running loop with %1 parallel threads\n").arg(_threadCount));
       int affinityShift=0;
-      for(int i=0; i<nThreads; i++) {
+      for(int i=0; i<_threadCount; i++) {
         w=newWorker(iEnd);
         if(w) {
           infos.index=i;
@@ -177,11 +199,12 @@ namespace QGpCoreTools {
           w->setObjectName(QString("LoopWorker_%1").arg(_workers.count()));
           _workers.insert(w, infos);
           w->setIndex(&_index, &_indexMutex);
-          if(!Thread::cpuAffinities().isEmpty()) {
-            w->setAffinity(Thread::cpuAffinities().at(i-affinityShift));
+          const VectorList<int>& affinities=CoreApplication::instance()->cpuAffinities();
+          if(!affinities.isEmpty()) {
+            w->setAffinity(affinities.at(i-affinityShift));
             APP_LOG(2, tr("Assign affinity %1 to worker %2\n").arg(w->affinity()).arg(w->objectName()))
-            if(i==Thread::cpuAffinities().count()-1) {
-              affinityShift+=Thread::cpuAffinities().count();
+            if(i==affinities.count()-1) {
+              affinityShift+=affinities.count();
             }
           }
           w->start();
