@@ -26,6 +26,7 @@
 #include "CoreApplicationPrivate.h"
 #include "DateTime.h"
 #include "DynamicBuffer.h"
+#include "EnumAsString.h"
 #include "EventRestrictor.h"
 #include "ExpressionAction.h"
 #include "ExpressionActions.h"
@@ -46,6 +47,7 @@
 #include "MessageContext.h"
 #include "Mutex.h"
 #include "Number.h"
+#include "Option.h"
 #include "PackageInfo.h"
 #include "ParallelLoop.h"
 #include "ParallelTask.h"
@@ -64,6 +66,7 @@
 #include "SortedVector.h"
 #include "StandardStream.h"
 #include "StreamRedirection.h"
+#include "StringDiff.h"
 #include "StringSection.h"
 #include "StringStream.h"
 #include "Tar.h"
