@@ -48,46 +48,39 @@ Version::Version(int a, int b, int c, const QString& name)
   _releaseName=name;
 }
 
-Version::Version(const QString& v)
+bool Version::fromString(const StringView& v)
 {
   StringSection vs(v);
   bool ok=true;
   const QChar * ptr=nullptr;
-  _a=vs.nextField(ptr, ".").toInt(&ok);
+  _a=vs.nextField(ptr, ".").toInt(ok);
   if(!ok) {
     parseError(v);
     _b=0;
     _c=0;
-    return;
+    return ok;
   }
-  _b=vs.nextField(ptr, ".").toInt(&ok);
+  _b=vs.nextField(ptr, ".").toInt(ok);
   if(!ok) {
     parseError(v);
     _c=0;
-    return;
+    return ok;
   }
   // C not mandatory
-  _c=vs.nextField(ptr, "-", false).toInt(&ok);
+  _c=vs.nextField(ptr, "-", false).toInt(ok);
 
   StringSection rn=vs.nextField(ptr, " ");
   if(rn.isValid()) {
-    _releaseName=rn.toString();
+    _releaseName=rn.toStringBuffer();
   }
+  return true;
 }
 
-void Version::parseError(const QString& v)
+void Version::parseError(const StringView& v)
 {
   App::log(tr("error parsing version '%1'\n").arg(v));
 }
 
-void Version::operator=(const Version& v)
-{
-  _a=v._a;
-  _b=v._b;
-  _c=v._c;
-  _releaseName=v._releaseName;
-}
-
 bool Version::operator<(const Version& v) const
 {
   if(_a<v._a) return true;
