@@ -283,9 +283,9 @@ void XMLClass::writeChildren(XMLStream& s, QString name, const XMLSaveAttributes
   May be useful for classes that do not inherit QObject.
   Must be re-implemented in sub-classes
 */
-bool XMLClass::xml_inherits(const QString& tagName) const
+bool XMLClass::xml_inherits(const QString&) const
 {
-  return tagName=="XMLClass";
+  return false;
 }
 
 /*!
@@ -381,8 +381,8 @@ QString XMLClass::saveSpecChar(QString content)
       } else {
         cur.setEnd(ptr);
         cur.appendTo(dest);
-        //App::log("Content before replacements ---" << content << "---" << endl;
-        //App::log("Content after replacements ---" << dest << "---" << endl;
+        //App::log("Content before replacements ---" << content << "---" << Qt::endl;
+        //App::log("Content after replacements ---" << dest << "---" << Qt::endl;
         return dest;
       }
     case 0x0026:    // '&'
@@ -538,17 +538,12 @@ void XMLClass::qobject_writeProperties(const QObject * o, const XMLClass * xmlo,
   TRACE;
   Q_UNUSED(context)
   const QMetaObject * meta=o->metaObject();
-  // Ignore property with index 0 (objectName from QObject, replaced by objectName of the first base class from  library)
+  // Ignore property with index 0 (objectName from QObject, replaced by objectName of the first base class from library)
   int n=meta->propertyCount();
   for(int i=meta->indexOfProperty("objectName"); i<n; i++) {
     QMetaProperty prop=meta ->property(i);
     if(prop.isStored()) {
-      QVariant val=prop.read(o);
-      if(val.type()==QVariant::String) {
-        xmlo->writeProperty(s, prop.name(), val.toString());
-      } else {
-        xmlo->writeProperty(s, prop.name(), val.toString());
-      }
+      xmlo->writeProperty(s, prop.name(), prop.read(o).toString());
     }
   }
 }
@@ -562,7 +557,7 @@ XMLMember XMLClass::qobject_member(QObject * o, XML_MEMBER_ARGS)
   Q_UNUSED(attributes)
   Q_UNUSED(context)
   const QMetaObject * meta=o->metaObject();
-  int id=meta->indexOfProperty(tag.toString().toLatin1().data());
+  int id=meta->indexOfProperty(tag.toStringView().toLatin1().data());
   if(id==-1) {
     return XMLMember(XMLMember::Unknown);
   } else {
@@ -588,11 +583,15 @@ bool XMLClass::qobject_setProperty(QObject * o, XML_SETPROPERTY_ARGS)
     App::log(tr("read-only property : %1\n").arg(p.name()));
     return false;
   }
+#if(QT_VERSION>=QT_VERSION_CHECK(6, 0, 0))
+  if(p.typeId()==QMetaType::Bool) {
+#else
   if(p.type()==QVariant::Bool) {
+#endif
     QVariant v(content=="true" );
     return p.write(o, v);
   } else {
-    QVariant v(content.toString());
+    QVariant v(content.toStringBuffer());
     return p.write(o, v);
   }
 }
