@@ -54,7 +54,7 @@ public:
   const AutocorrRing& ring(int index) const {return _rings[index];}
   AutocorrRing& ring(int index) {return _rings[index];}
   int indexOf(const AutocorrRing& r) const {return _rings.indexOf(r);}
-  const QVector<AutocorrRing> * rings() const {return &_rings;}
+  const VectorList<AutocorrRing> * rings() const {return &_rings;}
 
   const QList<ModalCurve>& curves() const {return _curves;}
   QList<ModalCurve>& curves() {return _curves;}
@@ -69,7 +69,7 @@ protected:
   bool xml_polish(XML_POLISH_ARGS);
 private:
   QList<ModalCurve> _curves;
-  QVector<AutocorrRing> _rings;
+  VectorList<AutocorrRing> _rings;
 };
 
 } // namespace QGpCoreWave
