@@ -37,7 +37,7 @@ class QGPCOREWAVE_EXPORT AutocorrDispersion : private AutocorrEngine
 {
 public:
   void setRing(const AutocorrRing& r) {setVerticalRing(r);}
-  QVector<double> dispersion(double omega, double autocorr,
+  VectorList<double> dispersion(double omega, double autocorr,
                              double kmin, double kmax);
 
   double y(double k);
