@@ -61,10 +61,10 @@ QString AutocorrProxy::columnUnit(int col) const
   }
 }
 
-QVector<int> AutocorrProxy::savedColumns() const
+VectorList<int> AutocorrProxy::savedColumns() const
 {
   TRACE;
-  QVector<int> l;
+  VectorList<int> l;
   l << 0 << 2 << 3 << 4;
   return l;
 }
@@ -111,10 +111,10 @@ QStringList AutocorrProxy::columnFileTypes() const
   return types;
 }
 
-QVector<int> AutocorrProxy::defaultColumnFileTypes() const
+VectorList<int> AutocorrProxy::defaultColumnFileTypes() const
 {
   TRACE;
-  QVector<int> l;
+  VectorList<int> l;
   l << 1 << 3 << 4 << 5;
   return l;
 }
