@@ -42,14 +42,14 @@ QString DispersionProxy::columnName(int col) const
 {
   TRACE;
   switch(col) {
-    case 0: return tr("Frequency");
-    case 1: return tr("Period");
-    case 2: return tr("Slowness");
-    case 3: return tr("Velocity");
-    case 4: return tr("Wave length");
-    case 5: return tr("Stddev");
-    case 6: return tr("Weight");
-    default: return QString();
+  case 0: return tr("Frequency");
+  case 1: return tr("Period");
+  case 2: return tr("Slowness");
+  case 3: return tr("Velocity");
+  case 4: return tr("Wave length");
+  case 5: return tr("Stddev");
+  case 6: return tr("Weight");
+  default: return QString();
   }
 }
 
@@ -57,19 +57,19 @@ QString DispersionProxy::columnUnit(int col) const
 {
   TRACE;
   switch(col) {
-    case 0: return tr("Hz");
-    case 1: return tr("s");
-    case 2: return tr("s/m");
-    case 3: return tr("m/s");
-    case 4: return tr("m");
-    default: return QString();
+  case 0: return tr("Hz");
+  case 1: return tr("s");
+  case 2: return tr("s/m");
+  case 3: return tr("m/s");
+  case 4: return tr("m");
+  default: return QString();
   }
 }
 
-QVector<int> DispersionProxy::savedColumns() const
+VectorList<int> DispersionProxy::savedColumns() const
 {
   TRACE;
-  QVector<int> l;
+  VectorList<int> l;
   l << 0 << 2 << 5 << 6;
   return l;
 }
@@ -124,10 +124,10 @@ QStringList DispersionProxy::columnFileTypes() const
   return types;
 }
 
-QVector<int> DispersionProxy::defaultColumnFileTypes() const
+VectorList<int> DispersionProxy::defaultColumnFileTypes() const
 {
   TRACE;
-  QVector<int> types;
+  VectorList<int> types;
   types << 1 << 3 << 5 << 8 << 9;
   return types;
 }
