@@ -63,10 +63,10 @@ QString EllipticityProxy::columnUnit(int col) const
   }
 }
 
-QVector<int> EllipticityProxy::savedColumns() const
+VectorList<int> EllipticityProxy::savedColumns() const
 {
   TRACE;
-  QVector<int> l;
+  VectorList<int> l;
   l << 0 << 2 << 3 << 4;
   return l;
 }
@@ -124,10 +124,10 @@ QStringList EllipticityProxy::columnFileTypes() const
   return types;
 }
 
-QVector<int> EllipticityProxy::defaultColumnFileTypes() const
+VectorList<int> EllipticityProxy::defaultColumnFileTypes() const
 {
   TRACE;
-  QVector<int> types;
+  VectorList<int> types;
   types << 1 << 3 << 9 << 15 << 16;
   return types;
 }
