@@ -50,7 +50,7 @@ namespace QGpCoreWave {
     Set the index in vector \a x of each sample of the curve. Each sample of the curve must have its
     corresponding value in vector \a x.
   */
-  void MagnetoTelluricCurve::linkX(const ::QVector<double>& x)
+  void MagnetoTelluricCurve::linkX(const ::VectorList<double>& x)
   {
     TRACE;
     int n=count();
@@ -101,8 +101,8 @@ namespace QGpCoreWave {
     Q_UNUSED(attributes)
     Q_UNUSED(context)
     switch(memberID) {
-    case 0: _name=content.toString(); return true;
-    case 1: _log=content.toString(); return true;
+    case 0: _name=content.toStringBuffer(); return true;
+    case 1: _log=content.toStringBuffer(); return true;
     default: return false;
     }
   }
@@ -116,7 +116,7 @@ namespace QGpCoreWave {
 
     \a minMisfit is the square of the minimum misfit value that can be reached for each sample individualy.
   */
-  double MagnetoTelluricCurve::misfit(int& nValues, int& nData, const MagnetoTelluricFactory& f, MisfitType type, double minMisfit) const
+  double MagnetoTelluricCurve::misfit(int& nValues, int& nData, const MagnetoTelluricFactory& f, Misfit::Type type, double minMisfit) const
   {
     TRACE;
     double res=0.0;
