@@ -88,7 +88,7 @@ namespace QGpCoreWave {
 
   /*!
   */
-  void MagnetoTelluricFactory::setX(const QVector<double>& x)
+  void MagnetoTelluricFactory::setX(const VectorList<double>& x)
   {
     TRACE;
     _x << x;
@@ -118,8 +118,8 @@ namespace QGpCoreWave {
   {
     TRACE;
     double factor=2*M_PI;
-    for(QVector<double>::iterator it=_x.begin(); it!=_x.end(); it++ ) {
-      (*it) *= factor;;
+    for(VectorList<double>::iterator it=_x.begin(); it!=_x.end(); it++ ) {
+      (*it)*=factor;
     }
   }
 
@@ -140,19 +140,19 @@ namespace QGpCoreWave {
     Complex omegamu, omega;
     Complex kcurr, klow;
     Complex xi;
-    QVector<Complex> alpha;
+    VectorList<Complex> alpha;
     Complex adm;
     double d;
     double sigmacurr, sigmalow;
     int nx=_x.count();
     int nLayers=model.layerCount();
-    const QVector<double>& depths=model.depths();
-    const QVector<double>& resistivities=model.resistivities();
+    const VectorList<double>& depths=model.depths();
+    const VectorList<double>& resistivities=model.resistivities();
     for(int i=0; i<nx; i++) {
       omega.setIm(-_x.at(i));
       omegamu.setIm(-MAGNETIC_CONSTANT*_x.at(i));
       //printf("omegamu[%i]=%lf+i*%lf\n", i, omegamu.re(), omegamu.im());
-      alpha.fill(Complex::null, resistivities.count());
+      alpha.fill(Complex(), resistivities.count());
       if(nLayers<2) {
         sigmacurr=1.0/resistivities.last();
         kcurr=sqrt(omegamu * sigmacurr);
@@ -233,7 +233,7 @@ namespace QGpCoreWave {
       p.setY(options.toDouble(p.x(), _impedanceXY[i].value()));
       sOut << p << "\n";
     }
-    sOut << flush;
+    sOut << Qt::flush;
   }
 
   MagnetoTelluricCurve MagnetoTelluricFactory::curve() const
