@@ -36,7 +36,7 @@ namespace QGpCoreWave {
     Full description of class still missing
   */
 
-  CURVEPROXY_BASICIMPLEMENTATIONS(MagnetoTelluricProxy)
+  CURVEPROXY_BASIC_IMPLEMENTATIONS(MagnetoTelluricProxy)
 
   int MagnetoTelluricProxy::yAxisColumn() const
   {
@@ -111,10 +111,10 @@ namespace QGpCoreWave {
     return CurveProxy::columnTitle(col);
   }
 
-  QVector<int> MagnetoTelluricProxy::savedColumns() const
+  VectorList<int> MagnetoTelluricProxy::savedColumns() const
   {
     TRACE;
-    QVector<int> l;
+    VectorList<int> l;
     l << 0 << 6 << 7 << 8 << 9;
     return l;
   }
@@ -198,10 +198,10 @@ namespace QGpCoreWave {
     return types;
   }
 
-  QVector<int> MagnetoTelluricProxy::defaultColumnFileTypes() const
+  VectorList<int> MagnetoTelluricProxy::defaultColumnFileTypes() const
   {
     TRACE;
-    QVector<int> l;
+    VectorList<int> l;
     l << 1 << 7 << 8 << 9 << 10;
     return l;
   }
@@ -274,5 +274,57 @@ namespace QGpCoreWave {
     return true;
   }
 
+
+  double MagnetoTelluricProxy::y(int sample, const CurvePointOptions * options) const
+  {
+    const MagnetoTelluricPoint& p=curve().constAt(sample);
+    return p.y(options);
+  }
+
+  void MagnetoTelluricProxy::setY(int sample, double value,
+                                     const CurvePointOptions * options)
+  {
+    MagnetoTelluricPoint& p=curve().constXAt(sample);
+    p.setY(value, options);
+  }
+
+  double MagnetoTelluricProxy::stddev(int sample) const
+  {
+    const MagnetoTelluricPoint& p=curve().constAt(sample);
+    return p.stddev();
+  }
+
+  void MagnetoTelluricProxy::setStddev(int sample, double value)
+  {
+    MagnetoTelluricPoint& p=curve().constXAt(sample);
+    p.setStddev(value);
+  }
+
+  double MagnetoTelluricProxy::weight(int sample) const
+  {
+    const MagnetoTelluricPoint& p=curve().constAt(sample);
+    return p.weight();
+  }
+
+  void MagnetoTelluricProxy::setWeight(int sample, double value)
+  {
+    MagnetoTelluricPoint& p=curve().constXAt(sample);
+    p.setWeight(value);
+  }
+
+  void MagnetoTelluricProxy::interpole(double x, double& y, double& dy,
+                                       const CurvePointOptions * options,
+                                       SamplingOptions xSampling,
+                                       SamplingOptions ySampling) const
+  {
+    const MagnetoTelluricPoint& p=_curve->interpole(x, xSampling, ySampling);
+    y=p.y(options);
+    dy=p.stddev();
+  }
+
+  void MagnetoTelluricProxy::followMaximumX(IrregularGrid2D * grid, double min, double max) {
+    grid->followMaximumX<MagnetoTelluricCurve, MagnetoTelluricPoint>(*_curve, min, max);
+  }
+
 } // namespace QGpCoreWave
 
