@@ -38,33 +38,21 @@ namespace QGpCoreWave {
     Full description of class still missing
   */
 
-  /*!
-    Return a standard string for slowness \a s.
-  */
-  QString Mode::slowness(Slowness s)
-  {
-    TRACE;
-    switch (s) {
-    case Group:
-      return "Group";
-    case Phase:
-      break;
-    }
-    return "Phase";
-  }
+  ENUM_AS_STRING_BEGIN(Mode, Type)
+  ENUM_AS_STRING_DATA_3(Autocorr, Dispersion, Ellipticity);
+  ENUM_AS_STRING_END
 
-  /*!
-    Return slowness from a standard string \a s
-  */
-  Mode::Slowness Mode::slowness(QString s)
-  {
-    TRACE;
-    if(s=="Group") {
-      return Group;
-    } else {
-      return Phase;
-    }
-  }
+  ENUM_AS_STRING_BEGIN(Mode, Polarization)
+  ENUM_AS_STRING_DATA_5(Love, Radial, Rayleigh, Transverse, Vertical);
+  ENUM_AS_STRING_END
+
+  ENUM_AS_STRING_BEGIN(Mode, Slowness)
+  ENUM_AS_STRING_DATA_2(Group, Phase);
+  ENUM_AS_STRING_END
+
+  ENUM_AS_STRING_BEGIN(Mode, Value)
+  ENUM_AS_STRING_DATA_2(Absolute, Signed);
+  ENUM_AS_STRING_END
 
   /*!
     Return a user-friendly string for slowness \a s.
@@ -94,50 +82,6 @@ namespace QGpCoreWave {
     }
   }
 
-  /*!
-    Return a standard string for polarization \a p.
-  */
-  QString Mode::polarization(Polarization p)
-  {
-    TRACE;
-    switch (p) {
-    case Vertical:
-      break;
-    case Radial:
-      return "Radial";
-    case Rayleigh:
-      return "Rayleigh";
-    case Transverse:
-      return "Transverse";
-    case Love:
-      return "Love";
-    }
-    return "Vertical";
-  }
-
-  /*!
-    Return polarization from a standard string \a p.
-  */
-  Mode::Polarization Mode::polarization(QString p)
-  {
-    TRACE;
-    if(p.count()>2) {
-      switch(p[2].unicode()) {
-      case 'd':
-        return Radial;
-      case 'a':
-        return Transverse;
-      case 'v':
-        return Love;
-      case 'r':
-        return Vertical;
-      default:
-        break;
-      }
-    }
-    return Rayleigh;
-  }
-
   /*!
     Return a user-friendly string for polarization \a p.
   */
@@ -178,35 +122,6 @@ namespace QGpCoreWave {
     }
   }
 
-
-  /*!
-    Return a standard string for slowness \a s.
-  */
-  QString Mode::value(Value s)
-  {
-    TRACE;
-    switch (s) {
-    case Signed:
-      break;
-    case Absolute:
-      return "Absolute";
-    }
-    return "Signed";
-  }
-
-  /*!
-    Return slowness from a standard string \a s
-  */
-  Mode::Value Mode::value(QString s)
-  {
-    TRACE;
-    if(s=="Absolute") {
-      return Absolute;
-    } else {
-      return Signed;
-    }
-  }
-
   /*!
     Return a user-friendly string for slowness \a s.
   */
@@ -287,9 +202,9 @@ namespace QGpCoreWave {
   {
     TRACE;
     Q_UNUSED(context)
-    writeProperty(s,"value", value(_value));
-    writeProperty(s,"slowness", slowness(_slowness));
-    writeProperty(s,"polarization", polarization(_polarization));
+    writeProperty(s,"value", convertValue(_value));
+    writeProperty(s,"slowness", convertSlowness(_slowness));
+    writeProperty(s,"polarization", convertPolarization(_polarization));
     writeProperty(s,"ringIndex", _ringIndex);
     writeProperty(s,"index",_index);
   }
@@ -314,22 +229,23 @@ namespace QGpCoreWave {
     Q_UNUSED(tag)
     Q_UNUSED(attributes)
     Q_UNUSED(context)
+    bool ok=true;
     switch(memberID) {
     case 0:
-      _slowness=slowness(content.toString());
-      return true;
+      _slowness=convertSlowness(content.toStringView(), ok);
+      return ok;
     case 1:
-      _polarization=polarization(content.toString());
-      return true;
+      _polarization=convertPolarization(content.toStringView(), ok);
+      return ok;
     case 2:
-      _ringIndex=content.toInt();
-      return true;
+      _ringIndex=content.toInt(ok);
+      return ok;
     case 3:
-      _index=content.toInt();
-      return true;
+      _index=content.toInt(ok);
+      return ok;
     case 4:
-      _value=value(content.toString());
-      return true;
+      _value=convertValue(content.toStringView(), ok);
+      return ok;
     default:
       return false;
     }
