@@ -19,6 +19,7 @@
 #include "FactoryPoint.h"
 #include "FortranInterface.h"
 #include "GeophysicalModel.h"
+#include "KennettSH.h"
 #include "Love.h"
 #include "LoveFunction.h"
 #include "MagnetoTelluricCurve.h"
@@ -32,6 +33,7 @@
 #include "ModalRefine.h"
 #include "ModalStorage.h"
 #include "Mode.h"
+#include "OmnidirectionalArrayResponse.h"
 #include "Podvin2D.h"
 #include "Podvin3D.h"
 #include "Profile.h"
@@ -43,7 +45,6 @@
 #include "RefractionProxy.h"
 #include "Resistivity1DModel.h"
 #include "Seismic1DModel.h"
-#include "ShAmplification.h"
 #include "TheoreticalFK.h"
 #include "TheoreticalLinearFK.h"
 #include "TiltNode.h"
