@@ -249,7 +249,7 @@ void RefractionDippingModel::allocateData()
     \li 1   right thickness is forced to 0
 
 */
-void RefractionDippingModel::fromSeismic1DModel(const Seismic1DModel& ref, const QVector<double>& pitch,
+void RefractionDippingModel::fromSeismic1DModel(const Seismic1DModel& ref, const VectorList<double>& pitch,
                                                 Seismic1DModel::SlownessType slowType)
 {
   TRACE;
@@ -515,7 +515,7 @@ bool RefractionDippingModel::setValue(double& var, const StringSection& field, i
   TRACE;
   bool ok=true;
   if(field.isValid()) {
-    var=field.toDouble(&ok);
+    var=field.toDouble(ok);
     if(ok && var>0.0) {
       return true;
     } else {
@@ -569,9 +569,10 @@ bool RefractionDippingModel::fromStream(QTextStream& s, QString * comments)
   field=fields.nextField(ptr);
   if(field.isValid()) {
     bool ok=true;
-    _layerCount=field.toInt(&ok);
+    _layerCount=field.toInt(ok);
     if(!ok && !field.isEmpty()) { // Not a blank line but failed
-      App::log(tr("Tilted layered model: bad number of layers: \"%1\" interpreted as %2\n").arg(field.toString()).arg(_layerCount) );
+      App::log(tr("Tilted layered model: bad number of layers: \"%1\" interpreted as %2\n")
+                   .arg(field.toStringView()).arg(_layerCount) );
        _layerCount=0;
        return false;
     }
@@ -584,15 +585,20 @@ bool RefractionDippingModel::fromStream(QTextStream& s, QString * comments)
     buf=File::readLineNoComments(s, comments);
     fields.set(buf);
     fields.trimmed();
-    ptr=0;
+    ptr=nullptr;
+    bool ok=true;
     field=fields.nextField(ptr);
     if(field.isValid()) {
-      _xL=field.toDouble();
-    } else return false;
+      _xL=field.toDouble(ok);
+    } else {
+      return false;
+    }
     field=fields.nextField(ptr);
     if(field.isValid()) {
-      _xR=field.toDouble();
-    } else return false;
+      _xR=field.toDouble(ok);
+    } else {
+      return false;
+    }
     // read the data
     _depthL[0]=0.0;
     _depthR[0]=0.0;
@@ -609,20 +615,26 @@ bool RefractionDippingModel::fromStream(QTextStream& s, QString * comments)
       ptr=0;
       field=fields.nextField(ptr);
       if(i<_layerCount-1) {
-        if(!setValue(_depthL[i+1], field, i, tr("left thickness"), false) ) return false;
-        _depthL[i+1] += _depthL[i];
+        if(!setValue(_depthL[i+1], field, i, tr("left thickness"), false)) {
+          return false;
+        }
+        _depthL[i+1]+=_depthL[i];
       }
       field=fields.nextField(ptr);
       if(i<_layerCount-1) {
-        if(!setValue(_depthR[i+1], field, i, tr("right thickness"), false) ) return false;
-        _depthR[i+1] += _depthR[i];
-     }
+        if(!setValue(_depthR[i+1], field, i, tr("right thickness"), false)) {
+          return false;
+        }
+        _depthR[i+1]+=_depthR[i];
+      }
       field=fields.nextField(ptr);
-      if(!setValue(_slow[i], field, i, tr("V"), false) ) return false;
+      if(!setValue(_slow[i], field, i, tr("V"), false)) {
+        return false;
+      }
       // Switch to slowness
       _slow[i]=1/_slow[i];
     }
-    return true;
+    return ok;
   } else {
     _layerCount=0;
     return false;
@@ -675,7 +687,7 @@ void RefractionDippingModel::toStream(QTextStream& s) const
              .arg(1/_slow[i], 0, 'g', 20);
   s << str3.arg(0.0, 0, 'g', 20)
             .arg(0.0, 0, 'g', 20)
-            .arg(1/_slow[_layerCount-1], 0, 'g', 20) << flush;
+            .arg(1/_slow[_layerCount-1], 0, 'g', 20) << Qt::flush;
 }
 
 } // namespace QGpCoreWave
