@@ -35,7 +35,10 @@ namespace QGpCoreWave {
     Full description of class still missing
   */
 
-  CURVEPROXY_BASICIMPLEMENTATIONS(RefractionProxy)
+  CURVEPROXY_BASIC_IMPLEMENTATIONS(RefractionProxy)
+  CURVEPROXY_ADVANCED_IMPLEMENTATIONS(RefractionProxy,
+                                      RefractionCurve,
+                                      FactoryPoint)
 
   QString RefractionProxy::columnName(int col) const
   {
@@ -60,10 +63,10 @@ namespace QGpCoreWave {
     }
   }
 
-  QVector<int> RefractionProxy::savedColumns() const
+  VectorList<int> RefractionProxy::savedColumns() const
   {
     TRACE;
-    QVector<int> l;
+    VectorList<int> l;
     l << 0 << 1 << 2 << 3;
     return l;
   }
@@ -108,10 +111,10 @@ namespace QGpCoreWave {
     return types;
   }
 
-  QVector<int> RefractionProxy::defaultColumnFileTypes() const
+  VectorList<int> RefractionProxy::defaultColumnFileTypes() const
   {
     TRACE;
-    QVector<int> types;
+    VectorList<int> types;
     types << 1 << 3 << 4 << 5;
     return types;
   }
