@@ -42,10 +42,10 @@ public:
   CurveBrowserSmooth(QWidget * parent=nullptr);
 
   void setCurveLimits(double min, double max) {_curveMin=min; _curveMax=max;}
-  void setAxisNames(QString linearName, QString inversedName);
+  void setAxisNames(QString linearName, QString inverseName);
   void updateAllFields();
 private slots:
-  void on_inversedBut_toggled(bool);
+  void on_inverseBut_toggled(bool);
   void on_autoMin_clicked();
   void on_autoMax_clicked();
 private:
