@@ -42,11 +42,11 @@ namespace QGpGuiMath {
   REGISTER_GRAPHCONTENTLAYER(ImageLayer, "ImageLayer")
 
   ImageLayer::ImageLayer(AxisWindow * parent) :
-      GraphContentLayer(parent)
+      GraphContentsLayer(parent)
   {
     TRACE;
-    _scale.setX(1.0); // 1 pixel/cm
-    _scale.setY(-1.0); // 1 pixel/cm, reversed
+    _scale.setX(1.0);   // 1 pixel/cm
+    _scale.setY(-1.0);  // 1 pixel/cm, reversed
   }
 
   ImageLayer::~ImageLayer()
@@ -54,14 +54,22 @@ namespace QGpGuiMath {
     TRACE;
   }
 
+  QPoint ImageLayer::r2i(const Point2D& p) const
+  {
+    const GraphContents * gc=graphContents();
+    double dx=gc->constScaleX().r2a(p.x())-gc->constScaleX().r2a(_origin.x());
+    double dy=gc->constScaleY().r2a(p.y())-gc->constScaleY().r2a(_origin.y());
+    return QPoint(qRound(dx/_scale.x()), qRound(dy/_scale.y()));
+  }
+
   void ImageLayer::paintData(const LayerPainterRequest& lp, QPainter& p, double) const
   {
     TRACE;
     if(_trueImage.isNull()) {
       return;
     }
-    const GraphContentOptions& gc=lp.options();
-    // visRect in user units (i.e. inversed real for inversed scales)
+    const GraphContentsOptions& gc=lp.options();
+    // visRect in user units (i.e. inverse real for inverse scales)
     Rect visRect=gc.visibleRect();
     visRect=visRect.intersect(boundingRect());
     if(visRect.width()>0 && visRect.height()>0) {
@@ -69,14 +77,14 @@ namespace QGpGuiMath {
       QRect imRect(r2i(visRect.topLeft()), r2i(visRect.bottomRight()));
       QImage tmp=_trueImage.copy(imRect.normalized());
       if(lp.terminated()) return;
-      QMatrix matrix;
+      QTransform matrix;
       matrix.scale(gc.ax()*_scale.x(), gc.ay()*_scale.y());
       if(lp.terminated()) return;
       if(!tmp.isNull()) {
         int x, y;
         SAFE_UNINITIALIZED(x, 0.0)
         SAFE_UNINITIALIZED(y, 0.0)
-        // We must be back to real units (i.e. inverse for inversed scales)
+        // We must be back to real units (i.e. inverse for inverse scales)
         switch(gc.scaleX().type()) {
         case Scale::Linear:
         case Scale::Log:
@@ -88,8 +96,8 @@ namespace QGpGuiMath {
             x=gc.xr2s(visRect.x1());
           }
           break;
-        case Scale::Inversed:
-        case Scale::InversedLog:
+        case Scale::Inverse:
+        case Scale::InverseLog:
           if(gc.scaleX().isReversed()) {
             x=gc.xr2s(1.0/visRect.x2());
           } else {
@@ -108,8 +116,8 @@ namespace QGpGuiMath {
             y=gc.yr2s(visRect.y2());
           }
           break;
-        case Scale::Inversed:
-        case Scale::InversedLog:
+        case Scale::Inverse:
+        case Scale::InverseLog:
           if(gc.scaleX().isReversed()) {
             y=gc.yr2s(1.0/visRect.y1());
           } else {
@@ -125,9 +133,16 @@ namespace QGpGuiMath {
   Rect ImageLayer::boundingRect() const
   {
     TRACE;
-    double iWidth=_trueImage.width()*_scale.x();
-    double iHeight=_trueImage.height()*_scale.y();
-    return Rect(_origin.x(), _origin.y(), _origin.x()+iWidth, _origin.y()+iHeight);
+    if(!_trueImage.isNull()) {
+      const GraphContents * gc=graphContents();
+      double ax1=gc->constScaleX().r2a(_origin.x());
+      double ay1=gc->constScaleY().r2a(_origin.y());
+      double x2=gc->constScaleX().a2r(ax1+_trueImage.width()*_scale.x());
+      double y2=gc->constScaleY().a2r(ay1+_trueImage.height()*_scale.y());
+      return Rect(_origin.x(), _origin.y(), x2, y2);
+    } else {
+      return Rect();
+    }
   }
 
   void ImageLayer::loadImage(QString fileName)
@@ -152,7 +167,7 @@ namespace QGpGuiMath {
     } else {
       _trueImage=QImage();
     }
-    graphContent()->deepUpdate();
+    graphContents()->deepUpdate();
   }
 
   /*!
@@ -166,22 +181,24 @@ namespace QGpGuiMath {
     scaling(_references, _origin, _scale);
   }
 
-  void ImageLayer::scaling(const QList<ReferencePoint> ref, Point2D& origin, Point2D& scale)
+  void ImageLayer::scaling(const QList<ReferencePoint> ref, Point2D& origin, Point2D& scale) const
   {
     int n=ref.count();
     if(n>1) {
       Curve<Point2D> c(n);
       double a, b;
+      const Scale& xAxis=graphContents()->constScaleX();
       for(int i=0; i<n; i++) {
         const ReferencePoint& p=ref.at(i);
-        c.at(i)=Point2D(p.image().x(), p.real().x());
+        c.at(i)=Point2D(p.image().x(), xAxis.r2a(p.real().x()));
       }
       c.leastSquare(a, b);
       origin.setX(b);
       scale.setX(a);
+      const Scale& yAxis=graphContents()->constScaleY();
       for(int i=0; i<n; i++) {
         const ReferencePoint& p=ref.at(i);
-        c.at(i)=Point2D(p.image().y(), p.real().y());
+        c.at(i)=Point2D(p.image().y(), yAxis.r2a(p.real().y()));
       }
       c.leastSquare(a, b);
       origin.setY(b);
@@ -189,18 +206,6 @@ namespace QGpGuiMath {
     }
   }
 
-  bool ImageLayer::mouseReleaseEvent(QMouseEvent * e, int id)
-  {
-    TRACE;
-    switch(id) {
-    case Scale:
-      emit pointPicked(r2i(graphContent()->options().s2r(e->pos())));
-      return true;
-    default:
-      return false;
-    }
-  }
-
   void ImageLayer::toggleTrackingAction(bool checked, int id)
   {
     TRACE;
@@ -214,9 +219,6 @@ namespace QGpGuiMath {
         LayerMouseTracking mt(this);
         mt.setId(id);
         switch (id) {
-        case Scale:
-          mt.setIdleCursor(QPixmap(":scalecursor.png"), 4, 4);
-          break;
         case Histogram:
           mt.setIdleCursor(QPixmap(":histogramcursor.png"), 4, 4);
           mt.setRectangle(true);
@@ -326,7 +328,7 @@ namespace QGpGuiMath {
         pix=0xFFFFFFFF;
       }
     }
-    graphContent() ->deepUpdate();
+    graphContents() ->deepUpdate();
   }
 
   void ImageLayer::lowPassFilter(int hThres, int sThres, int vThres)
@@ -345,7 +347,7 @@ namespace QGpGuiMath {
           * image=0xFFFFFFFF;
       }
     }
-    graphContent() ->deepUpdate();
+    graphContents() ->deepUpdate();
   }
 
   void ImageLayer::highPassFilter(int hThres, int sThres, int vThres)
@@ -364,7 +366,7 @@ namespace QGpGuiMath {
           * image=0xFFFFFFFF;
       }
     }
-    graphContent() ->deepUpdate();
+    graphContents() ->deepUpdate();
   }
 
   void ImageLayer::redPassFilter()
@@ -380,10 +382,10 @@ namespace QGpGuiMath {
            qRed(pix) < qBlue(pix) )
         pix=0xFFFFFFFF;
     }
-    graphContent() ->deepUpdate();
+    graphContents() ->deepUpdate();
   }
 
-  uint ImageLayer::_tabImage=PropertyProxy::uniqueId();
+  uint ImageLayer::_tabImage=PropertyTab::uniqueId();
 
   /*!
     Setup property editor
@@ -446,7 +448,7 @@ namespace QGpGuiMath {
       loadImage();
       break;
     }
-    graphContent()->deepUpdate();
+    graphContents()->deepUpdate();
   }
 
   /*!
@@ -503,8 +505,8 @@ namespace QGpGuiMath {
     TRACE;
     Q_UNUSED(context)
     writeProperty(s, "name", _name);
-    writeProperty(s, "image", Point2D(_image).toString(5));
-    writeProperty(s, "real", _real.toString(20));
+    writeProperty(s, "image", Point2D(_image).toString('g', 5));
+    writeProperty(s, "real", _real.toString('g', 20));
   }
 
   XMLMember ImageLayer::ReferencePoint::xml_member(XML_MEMBER_ARGS)
@@ -531,17 +533,17 @@ namespace QGpGuiMath {
     Q_UNUSED(attributes)
     switch(memberID) {
     case 0:
-      _name=content.toString();
+      _name=content.toStringBuffer();
       return true;
     case 1: {
         Point2D p;
-        p.fromString(content.toString());
+        p.fromString(content.toStringView());
         _image.setX((int)round(p.x()));
         _image.setY((int)round(p.y()));
       }
       return true;
     case 2:
-      _real.fromString(content.toString());
+      _real.fromString(content.toStringView());
       return true;
     default:
       return false;
