@@ -35,7 +35,7 @@ namespace QGpGuiMath {
   class QGPGUIMATH_EXPORT RealStatisticalPlotProxy : public CurvePlotProxy
   {
   public:
-    void setCurve(AbstractLine * line, CurveProxy * proxy);
+    void setCurve(AbstractLine * line, CurveProxy * proxy) const;
   };
 
 } // namespace QGpGuiMath
