@@ -58,7 +58,7 @@ namespace QGpGuiMath {
     connect(orderEdit, SIGNAL(valueChanged(int)), this, SIGNAL(parametersChanged()));
 #endif
     connect(windowFunctionEdit, SIGNAL(parametersChanged()), this, SIGNAL(parametersChanged()));
-    connect(widthEdit, SIGNAL(valueChanged(const QString&)), this, SIGNAL(parametersChanged()));
+    connect(widthEdit, SIGNAL(valueChanged(double)), this, SIGNAL(parametersChanged()));
   }
 
   /*!
@@ -153,7 +153,7 @@ namespace QGpGuiMath {
       param.setScaleType(SamplingParameters::Log);
       break;
     case 2:
-      param.setScaleType(SamplingParameters::Inversed);
+      param.setScaleType(SamplingParameters::Inverse);
       break;
     }
   }
@@ -194,7 +194,7 @@ namespace QGpGuiMath {
     case SamplingParameters::Log:
       scaleTypeEdit->setCurrentIndex(1);
       break;
-    case SamplingParameters::Inversed:
+    case SamplingParameters::Inverse:
       scaleTypeEdit->setCurrentIndex(2);
       break;
     }
