@@ -41,7 +41,10 @@ namespace QGpGuiTools {
 /*!
   Description of constructor still missing
 */
-Application::Application(int & argc, char ** argv, ApplicationHelp * ( *help) (), bool reportBugs, bool setPath)
+Application::Application(int & argc, char ** argv,
+                         ApplicationHelp * ( *help) (),
+                         BugReportOptions bugReportOptions,
+                         bool setPath)
     : CoreApplicationPrivate(argc, argv, setPath),
 #if(QT_VERSION > QT_VERSION_CHECK(5, 0, 0))
       // Qt 5 no longer supports the GUIenabled flag
@@ -57,6 +60,8 @@ Application::Application(int & argc, char ** argv, ApplicationHelp * ( *help) ()
   // Install message handler
   setMessageHandler(new GuiMessage);
   setQuitOnLastWindowClosed(true);
+  // Init instalation directories
+  initInstallDirs();
   // load translation if necessary
   initTranslations();
   setBatch(false);    // Gui application are by default not in batch
@@ -93,8 +98,10 @@ Application::Application(int & argc, char ** argv, ApplicationHelp * ( *help) ()
         index=CoreApplication::toInt(i, i-1, argv);
       }
       ::exit(startArgumentList(index));
+    } else if(arg=="-warning-critical") {
+      bugReportOptions|=WarningAsError;
     } else if(arg=="--nobugreport" || arg=="-nobugreport") {
-      reportBugs=false;
+      bugReportOptions=NoBugReport;
     } else {
       argv[j++]=argv[i];
     }
@@ -104,7 +111,7 @@ Application::Application(int & argc, char ** argv, ApplicationHelp * ( *help) ()
     argc=j;
   }
 
-  initInternalDebugger(reportBugs);
+  initInternalDebugger(bugReportOptions);
   checkAtomicOperations();
   // Application name and organisation are properly set, we can use settings
   updateArgumentLists();
@@ -124,7 +131,7 @@ Application::~Application()
 
 bool Application::hasGui() const
 {
-#if defined(Q_OS_WIN) || defined(Q_OS_MAC)
+#if defined(Q_OS_WIN) || defined(Q_OS_DARWIN)
   return true;
 #else
   const char * display=getenv("DISPLAY");
