@@ -45,10 +45,10 @@ namespace QGpGuiWave {
     a->setReversedScale(true);
     // Force title with multiplication for units
     a->setTitle("Frequency (kHz)");
-    a->setTitleInversedScale("Period (ms)");
+    a->setTitleInverseScale("Period (ms)");
   }
 
-  void MagnetoTelluricPlotProxy::setCurve(AbstractLine * line, CurveProxy * proxy)
+  void MagnetoTelluricPlotProxy::setCurve(AbstractLine * line, CurveProxy * proxy) const
   {
     TRACE;
     static_cast<MagnetoTelluricProxy *>(proxy)->setCurve(&static_cast<MagnetoTelluricLine *>(line)->curve());
