@@ -35,9 +35,9 @@ namespace QGpGuiWave {
   class QGPGUIWAVE_EXPORT MagnetoTelluricPlotProxy : public CurvePlotProxy
   {
   public:
-    virtual void setXAxisProperties(Axis * a);
+    void setXAxisProperties(Axis * a);
 
-    virtual void setCurve(AbstractLine * line, CurveProxy * proxy);
+    void setCurve(AbstractLine * line, CurveProxy * proxy) const;
   };
 
 } // namespace QGpGuiWave
