@@ -58,7 +58,7 @@ namespace QGpGuiWave {
     a->setRange(0.0, 5.0);
   }
 
-  void ModalPlotProxy::setCurve(AbstractLine * line, CurveProxy * proxy)
+  void ModalPlotProxy::setCurve(AbstractLine * line, CurveProxy * proxy) const
   {
     TRACE;
     static_cast<ModalProxy *>(proxy)->setCurve(&static_cast<ModalLine *>(line)->curve());
