@@ -39,12 +39,24 @@ namespace SciFigs {
 
 const QString AbstractNameLine::xmlAbstractNameLineTag="NameLine";
 
-void AbstractNameLine::operator=(const AbstractNameLine& o)
+AbstractNameLine::AbstractNameLine(const AbstractNameLine& o)
+  : AbstractLine(o)
 {
+  TRACE;
   _textColor=o._textColor;
   _textDx=o._textDx;
   _textDy=o._textDy;
   _textOrientation=o._textOrientation;
+}
+
+void AbstractNameLine::operator=(const AbstractLine& o)
+{
+  const AbstractNameLine * co=dynamic_cast<const AbstractNameLine *>(&o);
+  ASSERT(co);
+  _textColor=co->_textColor;
+  _textDx=co->_textDx;
+  _textDy=co->_textDy;
+  _textOrientation=co->_textOrientation;
   AbstractLine::operator=(o);
 }
 
@@ -53,7 +65,7 @@ QString AbstractNameLine::toString(int index, const CurvePointOptions * options)
   TRACE;
   NamedPoint p=point(index, options);
   p.setName(name(index));
-  return p.toString(20);
+  return p.toString('g', 20);
 }
 
 bool AbstractNameLine::fromString(int index, const StringSection& str, const QChar *& ptr, const CurvePointOptions * options)
@@ -63,32 +75,31 @@ bool AbstractNameLine::fromString(int index, const StringSection& str, const QCh
   StringSection f;
   f=str.nextField(ptr);
   if(f.isValid()) {
-    setX(index, f.toDouble(&ok));
-    if(!ok) return false;
+    setX(index, f.toDouble(ok));
   } else {
     return false;
   }
   f=str.nextField(ptr);
   if(f.isValid()) {
-    setY(index, f.toDouble(&ok), options);
-    if(!ok) return false;
+    setY(index, f.toDouble(ok), options);
   } else {
     return false;
   }
   const QChar * oldPtr=ptr;
   f=str.nextField(ptr);
   if(f.isValid()) {
-    double z=f.toDouble(&ok);
+    double z=f.toDouble(ok);
     if(ok) { // Z is optional
       setZ(index, z, options);
       oldPtr=ptr;
     } else {
       setZ(index, 0.0, options);
       ptr=oldPtr;
+      ok=true;
     }
     f=str.nextField(ptr, "\r\n", false);
     if(f.isValid()) {
-      setName(index, f.toString());
+      setName(index, f.toStringBuffer());
     } else {
       setName(index, QString());
       ptr=oldPtr;
@@ -98,7 +109,7 @@ bool AbstractNameLine::fromString(int index, const StringSection& str, const QCh
     setName(index, QString());
     ptr=oldPtr;
   }
-  return true;
+  return ok;
 }
 
 void AbstractNameLine::xml_writeProperties(XML_WRITEPROPERTIES_ARGS) const
@@ -134,6 +145,7 @@ bool AbstractNameLine::xml_setProperty(XML_SETPROPERTY_ARGS)
 {
   TRACE;
   Q_UNUSED(tag)
+  bool ok=true;
   LineLayerContext * lineContext=static_cast<LineLayerContext *>(context);
   switch(memberID) {
   case 0: {
@@ -150,20 +162,20 @@ bool AbstractNameLine::xml_setProperty(XML_SETPROPERTY_ARGS)
     }
     return true;
   case 1:
-    _textDx=content.toDouble();
-    return true;
+    _textDx=content.toDouble(ok);
+    return ok;
   case 2:
-    _textDy=content.toDouble();
-    return true;
+    _textDy=content.toDouble(ok);
+    return ok;
   case 3:
-    _textOrientation=content.toDouble();
-    return true;
+    _textOrientation=content.toDouble(ok);
+    return ok;
   case 4: {
-      QColor col(content.toString());
-      _textColor=col;
-      return true;
+      Color c;
+      c.fromString(content.toStringView(), ok);
+      guiColor(c, _textColor);
+      return ok;
     }
-    return true;
   default:
     return AbstractLine::xml_setProperty(memberID-5, tag, attributes, content, context);
   }
