@@ -49,7 +49,7 @@ ActivityMonitor::ActivityMonitor(QWidget *parent, Qt::WindowFlags f)
   yAxis()->setEnabled(false);
   xAxis()->setRange(0.0,100.0);
   yAxis()->setRange(0.0,10.0);
-  graphContent()->setGridLines(true);
+  graphContents()->setGridLines(true);
   xAxis()->setAutoTicks(false);
   yAxis()->setAutoTicks(false);
   xAxis()->setMajorTicks(10.0);
@@ -91,7 +91,7 @@ void ActivityMonitor::measure()
   }
   // Remove first samples of the curve
   double min=xAxis()->minimum();
-  while(!curve.isEmpty() && curve.firstX()<min) {
+  while(!curve.isEmpty() && curve.constAt(0).x()<min) {
     curve.remove(0);
   }
   double maxY=curve.y(curve.maximumY(curve.count()-10));
