@@ -140,8 +140,8 @@ namespace SciFigs {
   {
     TRACE;
     switch(_currentAxis->scaleType()) {
-    case Scale::Inversed:
-    case Scale::InversedLog:
+    case Scale::Inverse:
+    case Scale::InverseLog:
       emit setProperty(MinimumValue, 1.0/_currentAxis->visibleMaximum());
       break;
     default:
@@ -155,8 +155,8 @@ namespace SciFigs {
   {
     TRACE;
     switch(_currentAxis->scaleType()) {
-    case Scale::Inversed:
-    case Scale::InversedLog:
+    case Scale::Inverse:
+    case Scale::InverseLog:
       emit setProperty(MaximumValue, 1.0/_currentAxis->visibleMinimum());
       break;
     default:
@@ -171,8 +171,8 @@ namespace SciFigs {
     TRACE;
     Rect r=_currentAxis->boundingRect();
     switch(_currentAxis->scaleType()) {
-    case Scale::Inversed:
-    case Scale::InversedLog:
+    case Scale::Inverse:
+    case Scale::InverseLog:
       switch (_currentAxis->orientation()) {
       case Axis::North:
       case Axis::South:
@@ -205,8 +205,8 @@ namespace SciFigs {
     TRACE;
     Rect r=_currentAxis->boundingRect();
     switch(_currentAxis->scaleType()) {
-    case Scale::Inversed:
-    case Scale::InversedLog:
+    case Scale::Inverse:
+    case Scale::InverseLog:
       switch (_currentAxis->orientation()) {
       case Axis::North:
       case Axis::South:
@@ -238,11 +238,11 @@ namespace SciFigs {
   {
     TRACE;
     switch (st) {
-    case Scale::Inversed:
+    case Scale::Inverse:
       return 1;
     case Scale::Log:
       return 2;
-    case Scale::InversedLog:
+    case Scale::InverseLog:
       return 3;
     case Scale::AbsoluteTime:
       return 4;
@@ -259,11 +259,11 @@ namespace SciFigs {
     TRACE;
     switch (index) {
     case 1:
-      return Scale::Inversed;
+      return Scale::Inverse;
     case 2:
       return Scale::Log;
     case 3:
-      return Scale::InversedLog;
+      return Scale::InverseLog;
     case 4:
       return Scale::AbsoluteTime;
     case 5:
