@@ -28,7 +28,7 @@
 
 #include "CircleViewer.h"
 #include "AxisWindow.h"
-#include "GraphContentLayerFactory.h"
+#include "GraphContentsLayerFactory.h"
 #include "XMLSciFigs.h"
 #include "LayerPainterRequest.h"
 #include "LayerLocker.h"
@@ -46,22 +46,15 @@ namespace SciFigs {
   REGISTER_GRAPHCONTENTLAYER(CircleViewer, "CircleViewer")
 
   CircleViewer::CircleViewer(AxisWindow * parent) :
-      GraphContentLayer(parent)
+      GraphContentsLayer(parent)
   {
     TRACE;
-    _lineWeight=0.05;
-  }
-
-  void CircleViewer::setLineWeight (double lw)
-  {
-    LayerLocker ll(this);
-    _lineWeight=lw;
   }
 
   /*!
     \a phi is the rotation angle of the main axis in radians (along \a a).
   */
-  void CircleViewer::set(int index, double x, double y, double a, double b, double phi, QColor col)
+  void CircleViewer::set(int index, double x, double y, double a, double b, double phi, const Pen& pen)
   {
     TRACE;
     Item& item=_items[index];
@@ -71,13 +64,13 @@ namespace SciFigs {
     ell.setMajorRadius(a);
     ell.setMinorRadius(b);
     ell.setOrientation(phi);
-    item._color=col;
+    item._pen=pen;
   }
 
   /*!
     \a phi is the rotation angle of the main axis in radians (along \a a).
   */
-  void CircleViewer::add(double x, double y, double a, double b, double phi, QColor col)
+  void CircleViewer::add(double x, double y, double a, double b, double phi, const Pen& pen)
   {
     TRACE;
     Item item;
@@ -86,7 +79,7 @@ namespace SciFigs {
     ell.setMajorRadius(a);
     ell.setMinorRadius(b);
     ell.setOrientation(phi);
-    item._color=col;
+    item._pen=pen;
     LayerLocker ll(this);
     _items.push_back(item);
   }
@@ -94,12 +87,13 @@ namespace SciFigs {
   /*!
     Add a circle from the text contained in \a Line
 
-    3 x y rx               black circle
-    4 x y rx ry            black ellipse
-    5 x y rx ry rot        black rotated ellipse
-    6 x y rx r g b         colored circle
-    7 x y rx ry r g b      colored ellipse
-    8 x y rx ry rot r g b  colored rotated ellipse
+    3  x y rx                   black circle
+    4  x y rx ry                black ellipse
+    5  x y rx ry rot            black rotated ellipse
+    6  x y rx r g b             colored circle
+    7  x y rx ry r g b          colored ellipse
+    8  x y rx ry rot r g b      colored rotated ellipse
+    10 x y rx ry rot r g b w s  colored rotated ellipse with line properties
   */
   bool CircleViewer::add(const QString& line)
   {
@@ -111,16 +105,17 @@ namespace SciFigs {
       return true;
     case 3: {
         double r=parser.toDouble(2, ok);
-        add(parser.toDouble(0, ok), parser.toDouble(1, ok), r, r, 0.0, Qt::black);
+        add(parser.toDouble(0, ok), parser.toDouble(1, ok), r, r, 0.0, Pen());
       }
       return ok;
     case 4:
       add(parser.toDouble(0, ok), parser.toDouble(1, ok),
-          parser.toDouble(2, ok), parser.toDouble(3, ok), 0.0, Qt::black);
+          parser.toDouble(2, ok), parser.toDouble(3, ok), 0.0, Pen());
       return ok;
     case 5:
       add(parser.toDouble(0, ok), parser.toDouble(1, ok),
-          parser.toDouble(2, ok), parser.toDouble(3, ok), parser.toDouble(4, ok)/180.0*M_PI,Qt::black);
+          parser.toDouble(2, ok), parser.toDouble(3, ok), parser.toDouble(4, ok)/180.0*M_PI,
+          Pen());
       return ok;
     case 6: {
         double r=parser.toDouble(2, ok);
@@ -149,6 +144,16 @@ namespace SciFigs {
             parser.toDouble(2, ok), parser.toDouble(3, ok), parser.toDouble(4, ok)/180.0*M_PI, c);
       }
       return ok;
+    case 10: {
+        QColor c;
+        c.setRgb(parser.toInt(5, ok),
+                 parser.toInt(6, ok),
+                 parser.toInt(7, ok));
+        add(parser.toDouble(0, ok), parser.toDouble(1, ok),
+            parser.toDouble(2, ok), parser.toDouble(3, ok), parser.toDouble(4, ok)/180.0*M_PI,
+            Pen(c, parser.toDouble(8, ok), Pen::convertLineStyle(parser.toString(9, ok), ok)));
+      }
+      return ok;
     default:
       App::log(tr("Error parsing circle (%1 already added): %2 columns encountered instead of 3, 4, 6 or 7.\n"
                   "\"%3\"\n").arg(count()).arg(parser.count()).arg(line));
@@ -156,7 +161,7 @@ namespace SciFigs {
     }
   }
 
-  void CircleViewer::insert(int index, double x, double y, double a, double b, double phi, QColor col)
+  void CircleViewer::insert(int index, double x, double y, double a, double b, double phi, const Pen& pen)
   {
     TRACE;
     Item item;
@@ -165,7 +170,7 @@ namespace SciFigs {
     ell.setMajorRadius(a);
     ell.setMinorRadius(b);
     ell.setOrientation(phi);
-    item._color=col;
+    item._pen=pen;
     LayerLocker ll(this);
     _items.insert(index, item);
   }
@@ -194,25 +199,21 @@ namespace SciFigs {
   void CircleViewer::paintData(const LayerPainterRequest& lp, QPainter& p, double dotpercm) const
   {
     TRACE;
-    const GraphContentOptions& gc=lp.options();
+    const GraphContentsOptions& gc=lp.options();
     Limits limits(gc);
     double startPhi, stopPhi;
-    int lineWeight=(int)floor(_lineWeight*dotpercm+0.5);
-    if(lineWeight<1) {
-      lineWeight=1;
-    }
     for(int i=0; i<_items.count(); i++) {
       if(lp.terminated()) return;
       const Item& item=_items[i];
       const QGpCoreMath::Ellipse& ell=item._ellipse;
       if(limits.polarLimits(ell, startPhi, stopPhi)) {
-        p.setPen(QPen(item._color, lineWeight));
-        int rx=abs((int)(ell.majorRadius()* gc.ax()));
-        int ry=abs((int)(ell.minorRadius()*gc.ay()));
+        p.setPen(item._pen.qpen(dotpercm));
+        int rx=abs(qFloor(ell.majorRadius()*gc.ax()));
+        int ry=abs(qFloor(ell.minorRadius()*gc.ay()));
         int orx=gc.xr2s(ell.center().x())-rx;
         int ory=gc.yr2s(ell.center().y())-ry;
-        int minphi=(int)floor(Angle::radiansToDegrees(startPhi)*16.0);
-        int dphi=(int)ceil(Angle::radiansToDegrees(stopPhi)*16.0)-minphi;
+        int minphi=qFloor(Angle::radiansToDegrees(startPhi)*16.0);
+        int dphi=qCeil(Angle::radiansToDegrees(stopPhi)*16.0)-minphi;
         //printf("Circle %i is plotted phi %lg %lg\n",i,startPhi,stopPhi);
         if(ell.orientation().isNull()) {
           p.drawArc(orx, ory, rx + rx, ry + ry, minphi, dphi);
@@ -248,7 +249,7 @@ namespace SciFigs {
     return r;
   }
 
-  CircleViewer::Limits::Limits(const GraphContentOptions& gc)
+  CircleViewer::Limits::Limits(const GraphContentsOptions& gc)
   {
     TRACE;
     // We call _a,_b,_c,_d the four corners of the visible area
@@ -334,9 +335,9 @@ namespace SciFigs {
 
   void CircleViewer::xml_writeProperties(XML_WRITEPROPERTIES_ARGS) const
   {
-    // TODO: have a more xml format for recording
+    TODO("have a more xml format for recording")
     TRACE;
-    GraphContentLayer::xml_writeProperties(s, context);
+    GraphContentsLayer::xml_writeProperties(s, context);
     XMLSciFigs * scifigsContext=static_cast<XMLSciFigs *>(context);
     if(scifigsContext->data()) {
       QString tmp;
@@ -346,7 +347,7 @@ namespace SciFigs {
       for(int i=0;i<n;i++) {
         const Item& item=_items[i];
         const QGpCoreMath::Ellipse& ell=item._ellipse;
-        const QColor& col=item._color;
+        const Pen& pen=item._pen;
         tmp+=s.indent();
         tmp+="  ";
         tmp+=QString::number(ell.center().x(),'g',10);
@@ -359,11 +360,15 @@ namespace SciFigs {
         tmp+=" ";
         tmp+=QString::number(ell.orientation().degrees(),'g',10);
         tmp+=" ";
-        tmp+=QString::number(col.red());
+        tmp+=QString::number(pen.color().red());
         tmp+=" ";
-        tmp+=QString::number(col.green());
+        tmp+=QString::number(pen.color().green());
         tmp+=" ";
-        tmp+=QString::number(col.blue());
+        tmp+=QString::number(pen.color().blue());
+        tmp+=" ";
+        tmp+=QString::number(pen.width());
+        tmp+=" ";
+        tmp+=Pen::convertLineStyle(pen.lineStyle());
         tmp+="\n";
       }
       tmp+=s.indent();
@@ -380,7 +385,7 @@ namespace SciFigs {
       if(tag=="data") return XMLMember(0);
       else if(tag=="nCircles") return XMLMember(1); // For compatibility
     }
-    return GraphContentLayer::xml_member(tag, attributes, context)+2;
+    return GraphContentsLayer::xml_member(tag, attributes, context)+2;
   }
 
   bool CircleViewer::xml_setProperty(XML_SETPROPERTY_ARGS)
@@ -394,7 +399,7 @@ namespace SciFigs {
         //if(n==0) return true;
         StringSection l=content.readLine(ptr);
         while(l.isValid()) {
-          if(!add(l.toString())) {
+          if(!add(l.toStringBuffer())) {
             App::log(tr("Error parsing circle (%1 already added), incomplete line\n").arg(count()) );
             return false;
           }
@@ -408,7 +413,7 @@ namespace SciFigs {
     default:
       break;
     }
-    return GraphContentLayer::xml_setProperty(memberID-2, tag, attributes, content, context);
+    return GraphContentsLayer::xml_setProperty(memberID-2, tag, attributes, content, context);
   }
 
 } // namespace SciFigs
