@@ -39,7 +39,7 @@ namespace SciFigs {
   \class ColorMapWidget ColorMapWidget.h
   \brief ColorMapWidget is used to draw colored palettes in a GraphicSheet.
 
-  Usually color palettes are properties of certain types of GraphContentLayer like GridPlot.
+  Usually color palettes are properties of certain types of GraphContentsLayer like GridPlot.
   It is convenient to add a visual palette below or together with a colored grid or to any plot
   using colors for plotting values (the pseudo third dimension). It is possible to export the
   palette property to a ".pal" file and to import it to a freshly created ColorMapWidget.
@@ -84,11 +84,11 @@ ColorMapWidget::ColorMapWidget(QWidget *parent, Qt::WindowFlags f) :
   w->yAxis()->setEnabled(false);
   w->xAxis()->setTitle(tr("Title"));
   w->xAxis()->setObjectName("colorMapAxis");
-  w->graphContent()->setGridLines(false);
+  w->graphContents()->setGridLines(false);
   // Grab all mouse events
   w->xAxis()->installEventFilter(this);
   w->yAxis()->installEventFilter(this);
-  w->graphContent()->installEventFilter(this);
+  w->graphContents()->installEventFilter(this);
   w->installEventFilter(this);
   connect(w->xAxis(), SIGNAL(orientationChanged()), this, SLOT(setOrientation()));
   w->xAxis()->setOrientationBlocked(false);
@@ -96,7 +96,7 @@ ColorMapWidget::ColorMapWidget(QWidget *parent, Qt::WindowFlags f) :
 
   _colorMapLayer=new ColorMapLayer(w);
   ColorMap pal;
-  pal.generateColorScale(20, ColorPalette::Hsv);
+  pal.generate(0, 19);
   pal.setValues(0, 1, SamplingParameters::Linear);
   _colorMapLayer->setColorMap(pal);
   w->xAxis()->setRange(0,1);
@@ -191,28 +191,32 @@ const ColorMap& ColorMapWidget::colorMap() const
   return _colorMapLayer->colorMap();
 }
 
-void ColorMapWidget::setColorCount(int n)
+void ColorMapWidget::generate(int imin, int imax, const QString& model,
+                              ColorPalette::Options options, quint16 transparency)
 {
   ColorMap map;
-  map.resize(n);
+  map.generate(imin, imax, model, options, transparency);
   _colorMapLayer->setColorMap(map);
   emit changed(map);
 }
 
-void ColorMapWidget::generateColorScale(int n, ColorPalette::Model m,
-                                        bool reversed, int transparency)
+void ColorMapWidget::generate(int imin, int imax, const QString& model,
+                              const QString& options, quint16 transparency)
 {
-  ColorMap map;
-  map.generateColorScale(n, m, reversed, transparency);
-  _colorMapLayer->setColorMap(map);
-  emit changed(map);
+  bool ok=true;
+  ColorPalette::Option opt=ColorPalette::convertOption(options, ok);
+  if(ok) {
+    generate(imin, imax, model, opt, transparency);
+  }
 }
 
-void ColorMapWidget::generateGrayScale(int n, ColorPalette::Model m,
-                                       bool reversed, int transparency)
+
+void ColorMapWidget::toGray()
 {
-  ColorMap map;
-  map.generateGrayScale(n, m, reversed, transparency);
+  // No interface to directly change the color map except setColorMap()
+  // Adding AbstractColorPalette to ColorMapLayer would multiply the number of open doors.
+  ColorMap map=_colorMapLayer->colorMap();
+  map.toGray();
   _colorMapLayer->setColorMap(map);
   emit changed(map);
 }
@@ -309,7 +313,13 @@ QMouseEvent * ColorMapWidget::convertMouseEvent(QObject * obj, QEvent * e, QWidg
   QWidget * w=static_cast<QWidget *>(obj);
   QMouseEvent * me=static_cast<QMouseEvent *>(e);
   return new QMouseEvent(me->type(),
+#if(QT_VERSION>=QT_VERSION_CHECK(6, 0, 0))
+                         w->mapTo(dest, me->position()),
+                         me->globalPosition(),
+#else
                          w->mapTo(dest, me->pos()),
+                         me->globalPos(),
+#endif
                          me->button(),
                          me->buttons(),
                          me->modifiers());
@@ -356,8 +366,8 @@ bool ColorMapWidget::eventFilter(QObject * obj, QEvent * e)
   return true;
 }
 
-uint ColorMapWidget::_category=PropertyProxy::uniqueId();
-uint ColorMapWidget::_tabColorMap=PropertyProxy::uniqueId();
+uint ColorMapWidget::_category=PropertyCategory::uniqueId();
+uint ColorMapWidget::_tabColorMap=PropertyTab::uniqueId();
 
 /*!
   Setup property editor
@@ -407,7 +417,7 @@ void ColorMapWidget::setProperty(uint wid, int pid, QVariant val)
     case ColorMapProperties::Map:
       setColorMap(val.value<ColorMap>());
       emit changed(colorMap());
-      _colorMapLayer->graphContent()->deepUpdate();
+      _colorMapLayer->graphContents()->deepUpdate();
       break;
     default:
       break;
