@@ -39,10 +39,10 @@ namespace SciFigs {
     ~FontScales() {}
 
     void add(GraphicObject * obj, double value);
-    const QVector<double>& values(GraphicObject * obj) const;
+    const VectorList<double>& values(GraphicObject * obj) const;
     double value(GraphicObject * obj) const {return values(obj).first();}
   private:
-    QHash<GraphicObject *, QVector<double>> _values;
+    QHash<GraphicObject *, VectorList<double>> _values;
   };
 
 } // namespace SciFigs
