@@ -209,35 +209,35 @@ namespace SciFigs {
     XMLRestoreAttributeIterator it=attributes.find(tmp);
     if(it!=attributes.end()) {
       if(scifigsContext->data()) {
-        GraphicObject * obj=GraphicObjectFactory::instance()->create(tag.toString());
+        GraphicObject * obj=GraphicObjectFactory::instance()->create(tag.toStringBuffer());
         if(obj) {
           obj->setRemovable(true);
           obj->setParent(this);
           sheet()->addObject(obj, false);
           return XMLMember(obj);
         } else {
-          App::log(tr("Unknown object type %1\n").arg(tag.toString()) );
+          App::log(tr("Unknown object type %1\n").arg(tag.toStringView()) );
           return XMLMember(XMLMember::Unknown);
         }
       } else {
         GraphicObjectList list=objects();
-        GraphicObject * obj=list.findObject(tag.toString(), it.value().toString());
+        GraphicObject * obj=list.findObject(tag.toStringBuffer(), it.value().toStringBuffer());
         if(obj) {
           return XMLMember(obj);
         } else {
-          obj=list.findObject(tag.toString(), nullptr);
+          obj=list.findObject(tag.toStringBuffer(), nullptr);
           if(obj) {
             if(Message::warning(MSG_ID,"Restore",
                                      tr("Cannot find an object of type %1 and named %2,\n"
                                         "but an object of type %3 and named %4 has been found.\n"
                                         "Do you want to restore properties to this object?").
-                                     arg(tag.toString()).arg(it.value().toString()).
-                                     arg(tag.toString()).arg(obj->objectName()),
+                                     arg(tag.toStringView()).arg(it.value().toStringView()).
+                                     arg(tag.toStringView()).arg(obj->objectName()),
                                      Message::yes(),Message::no(), true)==Message::Answer0) {
               return XMLMember(obj);
             } else return XMLMember(XMLMember::Unknown);
           } else {
-            App::log(tr("Cannot find an object of type %1\n").arg(tag.toString()) );
+            App::log(tr("Cannot find an object of type %1\n").arg(tag.toStringView()) );
             return XMLMember(XMLMember::Unknown);
           }
         }
