@@ -25,7 +25,7 @@
 ***************************************************************************/
 
 #include "HistogramLayer.h"
-#include "GraphContentLayerFactory.h"
+#include "GraphContentsLayerFactory.h"
 #include "LayerPainterRequest.h"
 #include "XMLSciFigs.h"
 #include "LayerLocker.h"
@@ -60,7 +60,7 @@ namespace SciFigs {
     TRACE;
   }
 
-  void HistogramLayer::drawCurve(const GraphContentOptions& gc, QPainter& p, double dotpercm, int ,
+  void HistogramLayer::drawCurve(const GraphContentsOptions& gc, QPainter& p, double dotpercm, int ,
                                  Rect& , const AbstractLine& line, int startAt, int endAt) const
   {
     TRACE;
