@@ -29,7 +29,7 @@
 
 #include <QGpCoreMath.h>
 
-#include "GraphContentLayer.h"
+#include "GraphContentsLayer.h"
 #include "SciFigsDLLExport.h"
 #include "LineLayer.h"
 
@@ -45,7 +45,7 @@ namespace SciFigs {
     const QString& xml_tagName() const {return xmlHistogramLayerTag;}
     static const QString xmlHistogramLayerTag;
   protected:
-    void drawCurve(const GraphContentOptions& gc, QPainter& p, double dotpercm, int h,
+    void drawCurve(const GraphContentsOptions& gc, QPainter& p, double dotpercm, int h,
                    Rect& r, const AbstractLine& line, int startAt, int endAt) const;
   };
 
