@@ -26,8 +26,11 @@
 ***************************************************************************/
 
 #include <QGpGuiTools.h>
+
 #include "LegendTableDelegate.h"
 #include "LegendTable.h"
+#include "LegendTableItem.h"
+#include "SciFigsGlobal.h"
 
 namespace SciFigs {
 
@@ -61,41 +64,39 @@ QWidget * LegendTableDelegate::createEditor(QWidget * parent, const QStyleOption
   TRACE;
   switch (column( index.column())) {
   case LegendTable::ColumnNull: return nullptr;
-  case LegendTable::ColumnText: {
-      QLineEdit * w=new QLineEdit(parent);
-      return w;
-    }
+  case LegendTable::ColumnText:
+    return createLineEdit(parent);
   case LegendTable::ColumnPenColor:
   case LegendTable::ColumnSymbolPenColor:
   case LegendTable::ColumnSymbolBrushColor:
   case LegendTable::ColumnTextColor:
-    return QItemDelegate::createEditor(parent, option, index);
+    return ItemDelegate::createEditor(parent, option, index);
   case LegendTable::ColumnPenWidth:
   case LegendTable::ColumnSymbolSize:
   case LegendTable::ColumnSymbolPenWidth: {
-      DoubleSpinBox * w=new DoubleSpinBox(parent);
+      DoubleSpinBox * w=createDoubleSpinBox(parent);
       w->setSingleStep(0.1);
       w->setMinimum(0.0);
       w->setMaximum(100.0);
-      connect(w, SIGNAL(valueChanged(double)), this, SLOT(commitWidget()) );
+      connect(w, SIGNAL(valueChanged(double)), this, SLOT(commitWidget()));
       return w;
     }
   case LegendTable::ColumnPenStyle:
   case LegendTable::ColumnSymbolPenStyle: {
-      QComboBox * w=new QComboBox(parent);
-      connect(w, SIGNAL(activated(int)), this, SLOT(commitWidget()) );
+      QComboBox * w=createComboBox(parent);
+      connect(w, SIGNAL(activated(int)), this, SLOT(commitWidget()));
       LegendTable::initPenStyles(w);
       return w;
     }
   case LegendTable::ColumnSymbolType: {
-      QComboBox * w=new QComboBox(parent);
-      connect(w, SIGNAL(activated(int)), this, SLOT(commitWidget()) );
+      QComboBox * w=createComboBox(parent);
+      connect(w, SIGNAL(activated(int)), this, SLOT(commitWidget()));
       LegendTable::initSymbolTypes(w);
       return w;
     }
   case LegendTable::ColumnSymbolBrushStyle: {
-      QComboBox * w=new QComboBox(parent);
-      connect(w, SIGNAL(activated(int)), this, SLOT(commitWidget()) );
+      QComboBox * w=createComboBox(parent);
+      connect(w, SIGNAL(activated(int)), this, SLOT(commitWidget()));
       LegendTable::initBrushStyles(w);
       return w;
     }
@@ -103,97 +104,11 @@ QWidget * LegendTableDelegate::createEditor(QWidget * parent, const QStyleOption
   return nullptr;
 }
 
-void LegendTableDelegate::setEditorData(QWidget *editor, const QModelIndex &index) const
-{
-  TRACE;
-  switch (column( index.column()) ) {
-  case LegendTable::ColumnNull: break;
-  case LegendTable::ColumnText: {
-      QLineEdit * w=qobject_cast<QLineEdit *>(editor);
-      ASSERT(w);
-      w->setText(index.model() ->data(index).toString());
-      w->selectAll();
-    }
-    break;
-  case LegendTable::ColumnPenColor:
-  case LegendTable::ColumnSymbolPenColor:
-  case LegendTable::ColumnSymbolBrushColor:
-  case LegendTable::ColumnTextColor:
-    QItemDelegate::setEditorData(editor, index);
-    break;
-  case LegendTable::ColumnPenWidth:
-  case LegendTable::ColumnSymbolSize:
-  case LegendTable::ColumnSymbolPenWidth: {
-      DoubleSpinBox * w=qobject_cast<DoubleSpinBox *>(editor);
-      ASSERT(w);
-      w->setValue(index.model() ->data(index).toDouble());
-      break;
-    }
-  case LegendTable::ColumnPenStyle:
-  case LegendTable::ColumnSymbolPenStyle:
-  case LegendTable::ColumnSymbolType:
-  case LegendTable::ColumnSymbolBrushStyle: {
-      QComboBox * w=qobject_cast<QComboBox *>(editor);
-      ASSERT(w);
-      w->setCurrentIndex(index.model()->data(index).toInt());
-      break;
-    }
-  }
-}
-
-void LegendTableDelegate::setModelData(QWidget *editor, QAbstractItemModel *model,
-                                           const QModelIndex &index) const
-{
-  TRACE;
-  switch (column( index.column()) ) {
-  case LegendTable::ColumnNull: break;
-  case LegendTable::ColumnText: {
-      QLineEdit * w=qobject_cast<QLineEdit *>(editor);
-      ASSERT(w);
-      if(w->isModified() && model->data(index)!=w->text()) {
-        model->setData(index, w->text());
-        emit dataChanged();
-      }
-    }
-    break;
-  case LegendTable::ColumnPenColor:
-  case LegendTable::ColumnSymbolPenColor:
-  case LegendTable::ColumnTextColor:
-  case LegendTable::ColumnSymbolBrushColor:
-    break;
-  case LegendTable::ColumnPenWidth:
-  case LegendTable::ColumnSymbolSize:
-  case LegendTable::ColumnSymbolPenWidth: {
-      DoubleSpinBox * w=qobject_cast<DoubleSpinBox *>(editor);
-      ASSERT(w);
-      QVariant oldValue=model->data(index);
-      if(oldValue!=w->value()) {
-        model->setData(index, w->value());
-        emit dataChanged();
-      }
-      break;
-    }
-  case LegendTable::ColumnPenStyle:
-  case LegendTable::ColumnSymbolPenStyle:
-  case LegendTable::ColumnSymbolType:
-  case LegendTable::ColumnSymbolBrushStyle: {
-      QComboBox * w=qobject_cast<QComboBox *>(editor);
-      ASSERT(w);
-      QVariant oldValue=model->data(index);
-      if(oldValue!=w->currentIndex()) {
-        model->setData(index, w->currentIndex());
-        emit dataChanged();
-      }
-      break;
-    }
-  }
-}
-
 QSize LegendTableDelegate::sizeHint (const QStyleOptionViewItem & option, const QModelIndex & index) const
 {
   TRACE;
   if(index.row()<2) {
-    return QItemDelegate::sizeHint(option, index);
+    return ItemDelegate::sizeHint(option, index);
   } else {
     switch (column( index.column()) ) {
     case LegendTable::ColumnNull:
@@ -215,15 +130,15 @@ QSize LegendTableDelegate::sizeHint (const QStyleOptionViewItem & option, const
     case LegendTable::ColumnSymbolBrushStyle:
       return QSize(30, 0);
     }
-    return QItemDelegate::sizeHint(option, index);
+    return ItemDelegate::sizeHint(option, index);
   }
 }
 
-void LegendTableDelegate::paint (QPainter * painter, const QStyleOptionViewItem & option, const QModelIndex & index) const
+void LegendTableDelegate::paint(QPainter * painter, const QStyleOptionViewItem & option, const QModelIndex & index) const
 {
   TRACE;
   if(index.row()<2) {
-    QItemDelegate::paint(painter, option, index);
+    ItemDelegate::paint(painter, option, index);
   } else {
     QPoint p=option.rect.center();
     switch (column( index.column()) ) {
@@ -232,40 +147,38 @@ void LegendTableDelegate::paint (QPainter * painter, const QStyleOptionViewItem
     case LegendTable::ColumnPenWidth:
     case LegendTable::ColumnSymbolSize:
     case LegendTable::ColumnSymbolPenWidth:
-      QItemDelegate::paint(painter, option, index);
+      ItemDelegate::paint(painter, option, index);
       break;
     case LegendTable::ColumnPenColor:
     case LegendTable::ColumnSymbolPenColor:
     case LegendTable::ColumnSymbolBrushColor:
     case LegendTable::ColumnTextColor: {
         drawBackground(painter, option, index);
-        QColor c=index.model() ->data(index).value<QColor>();
+        QColor c=index.model()->data(index).value<QColor>();
         painter->fillRect(p.x()-8, p.y()-8, 16, 16 , c);
       }
       break;
     case LegendTable::ColumnPenStyle:
     case LegendTable::ColumnSymbolPenStyle: {
         drawBackground(painter, option, index);
-        Qt::PenStyle s=(Qt::PenStyle) index.model() ->data(index).toInt();
-        painter->fillRect(p.x()-16, p.y()-8, 32, 16, Qt::white);
-        painter->setPen(QPen( Qt::black, 0, s) );
+        Pen pen(painter->pen().color(), 0.3);
+        pen.setLineStyle(LegendTable::penStyle(index.model()->data(index).toInt()));
+        painter->setPen(pen.qpen(SciFigsGlobal::screenResolution()));
         painter->drawLine(p.x()-16, p.y(), p.x()+16, p.y());
       }
       break;
     case LegendTable::ColumnSymbolType: {
         drawBackground(painter, option, index);
-        Symbol::Type t=(Symbol::Type) index.model() ->data(index).toInt();
-        painter->fillRect(p.x()-8, p.y()-8, 16, 16, Qt::white);
-        Symbol s(t, 3.5);
-        s.paint( *painter, QPointF(p.x()-1, p.y()-1));
+        Symbol::Type t=(Symbol::Type) index.model()->data(index).toInt();
+        Symbol s(t, 3.5, painter->pen().color());
+        s.paint(*painter, QPointF(p.x()-1, p.y()-1));
       }
       break;
     case LegendTable::ColumnSymbolBrushStyle: {
         drawBackground(painter, option, index);
-        Qt::BrushStyle s=(Qt::BrushStyle) index.model() ->data(index).toInt();
-        painter->fillRect(p.x()-8, p.y()-8, 16, 16, Qt::white);
-        painter->setPen(QPen( Qt::NoPen) );
-        painter->setBrush(QBrush( Qt::black, s) );
+        Qt::BrushStyle s=LegendTable::brushStyle(index.model()->data(index).toInt());
+        painter->setPen(QPen( Qt::NoPen));
+        painter->setBrush(QBrush(painter->pen().color(), s) );
         painter->drawRect(p.x()-8, p.y()-8, 16, 16);
       }
       break;
@@ -276,7 +189,7 @@ void LegendTableDelegate::paint (QPainter * painter, const QStyleOptionViewItem
 void LegendTableDelegate::colorClicked(const QModelIndex& index)
 {
   TRACE;
-  if(index.row()>2) {
+  if(index.row()>1) {
     switch (column(index.column())) {
     case LegendTable::ColumnNull:
     case LegendTable::ColumnText:
@@ -296,7 +209,7 @@ void LegendTableDelegate::colorClicked(const QModelIndex& index)
         c=QColorDialog::getColor(c, Application::activeWindow());
         if(c.isValid()) {
           const_cast<QAbstractItemModel *>(index.model())->setData(index, c);
-          emit dataChanged();
+          emit dataChanged(index, StringDiff());
         }
       }
       break;
@@ -304,14 +217,4 @@ void LegendTableDelegate::colorClicked(const QModelIndex& index)
   }
 }
 
-void LegendTableDelegate::commitWidget(QWidget * w)
-{
-  TRACE;
-  if(! w) {
-    w=qobject_cast<QWidget *>(sender());
-    ASSERT(w);
-  }
-  emit commitData(w);
-}
-
 } // namespace SciFigs
