@@ -232,9 +232,9 @@ void LegendWidget::adjustSize()
   }
 }
 
-uint LegendWidget::_category=PropertyProxy::uniqueId();
-uint LegendWidget::_tabLegend=PropertyProxy::uniqueId();
-uint LegendWidget::_tabFormat=PropertyProxy::uniqueId();
+uint LegendWidget::_category=PropertyCategory::uniqueId();
+uint LegendWidget::_tabLegend=PropertyTab::uniqueId();
+uint LegendWidget::_tabFormat=PropertyTab::uniqueId();
 
 /*!
   Setup property editor
@@ -250,7 +250,7 @@ void LegendWidget::addProperties(PropertyProxy * pp)
     pp->addReference(this);
   } else {
     LegendProperties * w=new LegendProperties;
-    w->setPropertySections(LegendTable::All);
+    w->setPropertySections(LegendTable::AllSections);
     pp->addTab(_tabLegend, tr("Legend"), w, this);
   }
   if(pp->setCurrentTab(_tabFormat)) {
@@ -380,19 +380,18 @@ XMLMember LegendWidget::xml_member(XML_MEMBER_ARGS)
 
 bool LegendWidget::xml_setProperty(XML_SETPROPERTY_ARGS)
 {
-  // TODO: why not usingg qobject properties? To avoid useless update/resize?
+  bool ok=true;
   switch(memberID) {
   case 0:
-    _font.fromString(content.toString());
-    return true;
+    return _font.fromString(content.toStringBuffer());
   case 1:
-    _title=content.toString();
+    _title=content.toStringBuffer();
     return true;
   case 2:
-    _lineSize=content.toDouble();
+    _lineSize=content.toDouble(ok);
     return true;
   case 3:
-    _adjustBox=content.toBool();
+    _adjustBox=content.toBool(ok);
     return true;
   default:
     return GraphicObject::xml_setProperty(memberID-4, tag, attributes, content, context);
