@@ -29,7 +29,7 @@
 #include "AxisWindow.h"
 #include "AutoAdjustScale.h"
 #include "AutoAdjustScaleProperties.h"
-#include "GraphContent.h"
+#include "GraphContents.h"
 #include "PlotLine2D.h"
 #include "LayerPainterRequest.h"
 #include "XMLSciFigs.h"
@@ -51,12 +51,13 @@ namespace SciFigs {
   {
     TRACE;
     _function=nullptr;
+    _functionValid=true;
     _sampling=1;
     _variables=X;
     _min=0.0;
     _max=0.0;
     PlotLine2D * line=new PlotLine2D;
-    line->setPen(Pen(Qt::black, 0.3, Qt::SolidLine));
+    line->setPen(Pen(Qt::black, 0.3, Pen::SolidLine));
     line->setSymbol(Symbol());
     setReferenceLine(line);
 
@@ -111,13 +112,13 @@ namespace SciFigs {
     case SamplingParameters::Log:
       a->setScaleType(Scale::Log);
       break;
-    case SamplingParameters::Inversed:
-      a->setScaleType(Scale::Inversed);
+    case SamplingParameters::Inverse:
+      a->setScaleType(Scale::Inverse);
       break;
     }
   }
 
-  uint LiveCurveLayer::_tab=PropertyProxy::uniqueId();
+  uint LiveCurveLayer::_tab=PropertyTab::uniqueId();
 
   /*!
     Setup property editor
@@ -173,8 +174,8 @@ namespace SciFigs {
   void LiveCurveLayer::paintData(const LayerPainterRequest& lp, QPainter& p, double dotpercm) const
   {
     TRACE;
-    const GraphContentOptions& gc=lp.options();
-    if(!_function) {
+    const GraphContentsOptions& gc=lp.options();
+    if(!_function || !_functionValid) {
       return;
     }
     PlotLine2D line=*static_cast<PlotLine2D *>(_referenceLine);
@@ -197,15 +198,13 @@ namespace SciFigs {
     drawCurve(gc, p, dotpercm, h, r, line, 0, line.count());
   }
 
-  Curve<Point2D> LiveCurveLayer::calculateCurve(const QSize& s, const GraphContentOptions& gc,
+  Curve<Point2D> LiveCurveLayer::calculateCurve(const QSize& s, const GraphContentsOptions& gc,
                                                 const LayerPainterRequest * lp) const
   {
     TRACE;
     int nx=s.width()/_sampling;
     Curve<Point2D> curve(nx);
 
-    double x,y;
-    SAFE_UNINITIALIZED(y, 0.0)
     int iStart=_sampling >> 1;
     int ixGrid0, ixGrid, dixGrid, ixEndGrid;
     if(graph()->xAxis()->isEffectivelyReversed()) {
@@ -219,28 +218,29 @@ namespace SciFigs {
     }
     ixGrid=ixGrid0;
     if(lp) {
-      lp->graphContent()->setProgressMaximum(s.width());
+      lp->graphContents()->setProgressMaximum(s.width());
     }
     for(int ix=iStart; ixGrid!=ixEndGrid; ix+=_sampling, ixGrid+=dixGrid) {
       if(lp && lp->terminated()) {
         return curve;
       }
-      x=gc.xs2r(ix);
+      double x=gc.xs2r(ix);
+      PrivateVector<double> vec(3, 0.0);
       switch(_variables) {
       case X:
-        y=_function->value(Point(x, 0.0, 0.0));
+        vec[0]=x;
         break;
       case Y:
-        y=_function->value(Point(0.0, x, 0.0));
+        vec[1]=x;
         break;
       case Z:
-        y=_function->value(Point(0.0, 0.0, x));
+        vec[2]=x;
         break;
       }
-      curve.at(ixGrid)=Point2D(x, y);
+      curve.at(ixGrid)=Point2D(x, _function->value(vec));
     }
     if(lp) {
-      lp->graphContent()->setProgressValue(s.height());
+      lp->graphContents()->setProgressValue(s.height());
     }
     return curve;
   }
@@ -248,12 +248,12 @@ namespace SciFigs {
   void LiveCurveLayer::xml_writeChildren(XML_WRITECHILDREN_ARGS) const
   {
     TRACE;
-    if(!_function) {
+    if(!_function || !_functionValid) {
       return;
     }
     // Calculate curve with current plot limits
     PlotLine2D line=*static_cast<PlotLine2D *>(_referenceLine);
-    line.setCurve(calculateCurve(graphContent()->size(), graphContent()->options()));
+    line.setCurve(calculateCurve(graphContents()->size(), graphContents()->options()));
 
     static const QString key("index");
     XMLSaveAttributes att;
