@@ -36,30 +36,34 @@ namespace SciFigs {
 class SCIFIGS_EXPORT NameLine : public AbstractNameLine
 {
 public:
-  virtual AbstractLine * clone() const;
-  void operator=(const NameLine& o);
+  NameLine() {}
+  NameLine(const NameLine& o);
 
-  virtual const QString& xml_tagName() const {return xmlNameLineTag;}
+  AbstractLine * clone() const;
+  void operator=(const AbstractLine& o);
+  bool canCopy(const AbstractLine& o) const;
+
+  const QString& xml_tagName() const {return xmlNameLineTag;}
   static const QString xmlNameLineTag;
 
-  virtual int count() const {return _curve.count();}
-  virtual void clear() {_curve.clear();}
-  virtual void append() {_curve.append(NamedPoint());}
-  virtual void insert(int index) {_curve.insert(index, NamedPoint());}
-  virtual void removeLast() {  _curve.remove(_curve.count()-1);}
-  virtual bool isSorted() const {return _curve.isSorted();}
-  virtual void checkSort() {_curve.checkSort();}
-  virtual void indexRange(double xMin, double xMax, int& indexMin, int& indexMax) const {
+  int count() const {return _curve.count();}
+  void clear() {_curve.clear();}
+  void append() {_curve.append(NamedPoint());}
+  void insert(int index) {_curve.insert(index, NamedPoint());}
+  void removeLast() {  _curve.remove(_curve.count()-1);}
+  bool isSorted() const {return _curve.isSorted();}
+  void checkSort() {_curve.checkSort();}
+  void indexRange(double xMin, double xMax, int& indexMin, int& indexMax) const {
     return _curve.indexRange(xMin, xMax, indexMin, indexMax);
   }
-  virtual Point point(int index, const CurvePointOptions *) const {return _curve.constAt(index);}
-  virtual QString name(int index) const {return _curve.constAt(index).name();}
-  virtual void setX(int index, double v) {_curve.setX(index, v);}
-  virtual void setY(int index, double v, const CurvePointOptions *) {_curve.setY(index, v);}
-  virtual void setZ(int index, double v, const CurvePointOptions *) {_curve.constXAt(index).setZ(v);}
-  virtual void setName(int index, QString n) {_curve.constXAt(index).setName(n);}
+  Point point(int index, const CurvePointOptions *) const {return _curve.constAt(index);}
+  QString name(int index) const {return _curve.constAt(index).name();}
+  void setX(int index, double v) {_curve.setX(index, v);}
+  void setY(int index, double v, const CurvePointOptions *) {_curve.setY(index, v);}
+  void setZ(int index, double v, const CurvePointOptions *) {_curve.constXAt(index).setZ(v);}
+  void setName(int index, QString n) {_curve.constXAt(index).setName(n);}
 
-  virtual QString toString(int index, const CurvePointOptions *) const {return _curve.constAt(index).toString(20);}
+  QString toString(int index, const CurvePointOptions *) const {return _curve.constAt(index).toString('g', 20);}
 
   const Curve<NamedPoint>& curve() const {return _curve;}
   Curve<NamedPoint>& curve() {return _curve;}
