@@ -41,7 +41,7 @@ PaintProgress::PaintProgress(QObject * parent)
 {
   _active=false;
   _updateRect.setWidth(1);  // Init the size of rectangle. If not initialized, the
-  _updateRect.setHeight(1); // update triggered by GraphContent::paintProgress()
+  _updateRect.setHeight(1); // update triggered by GraphContents::paintProgress()
                             // is never achieved.
 }
 
