@@ -92,16 +92,20 @@ bool ParallelBand::xml_setProperty(XML_SETPROPERTY_ARGS)
   Q_UNUSED(tag)
   Q_UNUSED(attributes)
   Q_UNUSED(context)
+  bool ok=true;
   switch(memberID) {
-  case 0: _minimum=content.toDouble(); return true;
-  case 1: _maximum=content.toDouble(); return true;
+  case 0: _minimum=content.toDouble(ok); return ok;
+  case 1: _maximum=content.toDouble(ok); return ok;
   case 2: {                 // Kept for compatibility
       Point2D p;
-      p.fromString(content);
-      _minimum=p.x();
-      _maximum=p.y();
+      if(p.fromString(content)) {
+        _minimum=p.x();
+        _maximum=p.y();
+        return true;
+      } else {
+        return false;
+      }
     }
-    return true;
   default:
     return false;
   }
