@@ -37,23 +37,27 @@ namespace SciFigs {
 class SCIFIGS_EXPORT PlotLine : public AbstractLine
 {
 public:
-  virtual AbstractLine * clone() const;
-  virtual void operator=(const PlotLine& o);
+  PlotLine() {}
+  PlotLine(const PlotLine& o);
 
-  virtual int count() const {return _curve.count();}
-  virtual void clear() {_curve.clear();}
-  virtual void append() {_curve.append(Point());}
-  virtual void insert(int index) {_curve.insert(index, Point());}
-  virtual void removeLast() {_curve.remove(_curve.count()-1);}
-  virtual bool isSorted() const {return _curve.isSorted();}
-  virtual void checkSort() {_curve.checkSort();}
-  virtual void indexRange(double xMin, double xMax, int& indexMin, int& indexMax) const {
+  AbstractLine * clone() const;
+  void operator=(const AbstractLine& o);
+  bool canCopy(const AbstractLine& o) const;
+
+  int count() const {return _curve.count();}
+  void clear() {_curve.clear();}
+  void append() {_curve.append(Point());}
+  void insert(int index) {_curve.insert(index, Point());}
+  void removeLast() {_curve.remove(_curve.count()-1);}
+  bool isSorted() const {return _curve.isSorted();}
+  void checkSort() {_curve.checkSort();}
+  void indexRange(double xMin, double xMax, int& indexMin, int& indexMax) const {
     return _curve.indexRange(xMin, xMax, indexMin, indexMax);
   }
-  virtual Point point(int index, const CurvePointOptions *) const {return _curve.constAt(index);}
-  virtual void setX(int index, double v) {_curve.setX(index, v);}
-  virtual void setY(int index, double v, const CurvePointOptions *) {_curve.setY(index, v);}
-  virtual void setZ(int index, double v, const CurvePointOptions *) {_curve.constXAt(index).setZ(v);}
+  Point point(int index, const CurvePointOptions *) const {return _curve.constAt(index);}
+  void setX(int index, double v) {_curve.setX(index, v);}
+  void setY(int index, double v, const CurvePointOptions *) {_curve.setY(index, v);}
+  void setZ(int index, double v, const CurvePointOptions *) {_curve.constXAt(index).setZ(v);}
 
   const Curve<Point>& curve() const {return _curve;}
   Curve<Point>& curve() {return _curve;}
