@@ -36,16 +36,31 @@ namespace SciFigs {
   Same as PlotLine excpet that Z(error) coordinate is not stored
 */
 
-AbstractLine * PlotLine2D::clone() const
+PlotLine2D::PlotLine2D(const PlotLine2D& o)
+  : AbstractLine(o)
 {
-  PlotLine2D * l=new PlotLine2D;
-  *l=*this;
-  return l;
+  TRACE;
+  _curve=o._curve;
 }
 
-void PlotLine2D::operator=(const PlotLine2D& o)
+AbstractLine * PlotLine2D::clone() const
 {
-  _curve=o._curve;
+  TRACE;
+  return new PlotLine2D(*this);
+}
+
+bool PlotLine2D::canCopy(const AbstractLine& o) const
+{
+  TRACE;
+  return dynamic_cast<const PlotLine2D *>(&o);
+}
+
+void PlotLine2D::operator=(const AbstractLine& o)
+{
+  TRACE;
+  const PlotLine2D * co=dynamic_cast<const PlotLine2D *>(&o);
+  ASSERT(co);
+  _curve=co->_curve;
   AbstractLine::operator=(o);
 }
 
@@ -73,7 +88,7 @@ void PlotLine2D::setCurve(  const Curve<Point2D>& curve, const Pen& pen, const S
 /*!
   Description still missing
 */
-void PlotLine2D::setCurve(QVector<double> * dataX, QVector<double> * dataY)
+void PlotLine2D::setCurve(VectorList<double> * dataX, VectorList<double> * dataY)
 {
   TRACE;
   int n;
