@@ -23,10 +23,10 @@
 #include "ExternalPlotLine2D.h"
 #include "Font.h"
 #include "FontScales.h"
-#include "GraphContent.h"
-#include "GraphContentLayer.h"
-#include "GraphContentLayerFactory.h"
-#include "GraphContentOptions.h"
+#include "GraphContents.h"
+#include "GraphContentsLayer.h"
+#include "GraphContentsLayerFactory.h"
+#include "GraphContentsOptions.h"
 #include "GraphicObject.h"
 #include "GraphicObjectFactory.h"
 #include "GraphicObjectGroup.h"
@@ -41,6 +41,7 @@
 #include "IrregularGrid2DPlot.h"
 #include "LayerLocker.h"
 #include "LayerMouseTracking.h"
+#include "LayerPicker.h"
 #include "Legend.h"
 #include "LegendItem.h"
 #include "LegendItemWidget.h"
@@ -86,8 +87,10 @@
 #include "XMLSciFigs.h"
 #include "XUniqueYColorLines.h"
 #include "XYColorLines.h"
+#include "XYColorLinesProperties.h"
 #include "XYColorPlot.h"
 #include "XYPlot.h"
+#include "XYPlotProperties.h"
 #include "XYValueLines.h"
 #include "XYValuePlot.h"
 #include "ui_AlignGridParameters.h"
@@ -96,8 +99,8 @@
 #include "ui_AxisScaleProperties.h"
 #include "ui_ColorMapProperties.h"
 #include "ui_ColorPaletteEditor.h"
-#include "ui_GraphContentFormatProperties.h"
-#include "ui_GraphContentLayerProperties.h"
+#include "ui_GraphContentsFormatProperties.h"
+#include "ui_GraphContentsLayerProperties.h"
 #include "ui_GraphicObjectGeometryProperties.h"
 #include "ui_GraphicObjectIdProperties.h"
 #include "ui_GraphicObjectPrintProperties.h"
