@@ -38,7 +38,11 @@ namespace SciFigs {
 
 const QString XMLSciFigs::xmlSciFigsTag="SciFigs";
 
+/*!
+  Never allocated with new
+*/
 XMLSciFigs::XMLSciFigs()
+ : XMLContext(false)
 {
   TRACE;
   _currentObject=nullptr;
@@ -189,7 +193,7 @@ void XMLSciFigs::xml_writeChildren(XML_WRITECHILDREN_ARGS) const
       att.add(key);
       _currentObject->xml_save(s, context, att);
       s.decrementIndent();
-      s << s.indent() << "</GraphicSheet>" << endl;
+      s << s.indent() << "</GraphicSheet>" << Qt::endl;
     } else {
       _currentObject->xml_save(s, context);
     }
@@ -206,11 +210,11 @@ XMLMember XMLSciFigs::xml_member(XML_MEMBER_ARGS)
   else if(tag=="type") return XMLMember(2);
   else if(_currentObject) {
     if(tag==_currentObject->xml_tagName() ||
-       _currentObject->xml_isValidTagName(tag.toString())) {
+       _currentObject->xml_isValidTagName(tag.toStringBuffer())) {
       return XMLMember(const_cast<XMLClass *>(_currentObject));
     } else {
-      Message::warning(MSG_ID, tr("Parsing Scifig XML"), tr("The XML information is for object of type %1. "
-                           "The expected type is %2.").arg(tag.toString()). arg(_currentObject->xml_tagName()),
+      Message::warning(MSG_ID, tr("Parsing Scifig XML"), tr("The XML information is for an object of type %1. "
+                           "The expected type is %2.").arg(tag.toStringView()). arg(_currentObject->xml_tagName()),
                            true);
       return XMLMember(XMLMember::Unknown);
     }
@@ -230,14 +234,14 @@ bool XMLSciFigs::xml_setProperty(XML_SETPROPERTY_ARGS)
     // left here to avoid error when reading old SciFigs files
     return true;
   case 1: {
-      Version v(content.toString());
+      Version v(content.toStringView());
       static const Version vRef(PackageInfo::package("SciFigs")->version());
       if(v>vRef) {
         App::log(tr("This file was generated by SciFigs %1, which is more recent\n"
                     "than your current version %2.\n"
-                    "Upgrading might be necessary.\n").arg(content.toString()).arg(vRef.toString()));
+                    "Upgrading might be necessary.\n").arg(content.toStringView()).arg(vRef.toString()));
       }
-      _currentFileVersion=content.toString();
+      _currentFileVersion=content.toStringBuffer();
       return true;
     }
   case 2: {
@@ -250,7 +254,7 @@ bool XMLSciFigs::xml_setProperty(XML_SETPROPERTY_ARGS)
         if(fileType==Data && _currentFile==Layer) { // Compatibility: before 20110106, layer is saved as data
           return true;
         }
-        App::log(tr("No information to restore from file type %1\n").arg(content.toString()) );
+        App::log(tr("No information to restore from file type %1\n").arg(content.toStringView()));
         return false;
       }
     }
