@@ -26,20 +26,31 @@
 ***************************************************************************/
 
 #include "XYPlotProperties.h"
+#include "ui_XYPlotProperties.h"
 #include "LegendTable.h"
 
 namespace SciFigs {
 
-XYPlotProperties::XYPlotProperties(QWidget * parent)
-    : PropertyWidget(parent)
-{
-  TRACE;
-  setupUi(this);
+  XYPlotProperties::XYPlotProperties(QWidget * parent)
+      : PropertyWidget(parent),
+        _ui(new Ui::XYPlotProperties)
+  {
+    TRACE;
+    _ui->setupUi(this);
 
-  addProperty(DotDiameter, dotDiameter);
-  addProperty(Symbol, symbol);
+    addProperty(DotDiameter, _ui->dotDiameter, _ui->dotDiameterLabel);
+    addProperty(Symbol, _ui->symbol, _ui->symbolLabel);
 
-  LegendTable::initSymbolTypes(symbol);
-}
+    LegendTable::initSymbolTypes(_ui->symbol);
+  }
+
+  void XYPlotProperties::removeSymbol()
+  {
+    delete _ui->symbol;
+    _ui->symbol=nullptr;
+    delete _ui->symbolLabel;
+    _ui->symbolLabel=nullptr;
+    removeProperty(Symbol);
+  }
 
 } // namespace SciFigs
