@@ -28,8 +28,8 @@
 #include "ColorMapProperties.h"
 #include "XMLSciFigs.h"
 #include "XYValuePlot.h"
-#include "GraphContent.h"
-#include "GraphContentLayerFactory.h"
+#include "GraphContents.h"
+#include "GraphContentsLayerFactory.h"
 #include "AxisWindow.h"
 #include "LayerPainterRequest.h"
 #include "LayerLocker.h"
@@ -53,7 +53,7 @@ XYValuePlot::XYValuePlot(AxisWindow * parent) :
 {
   TRACE;
   _values=0;
-  _colorMap.generateColorScale(20, ColorPalette::Hsv);
+  _colorMap.generate(0, 19);
 }
 
 XYValuePlot::~XYValuePlot()
@@ -72,7 +72,7 @@ void XYValuePlot::setColorMap(const ColorMap& map)
     LayerLocker ll(this);
     _colorMap=map;
     // This layer takes generally time to repaint (useless to repaint only this layer) 
-    graphContent()->deepUpdate();
+    graphContents()->deepUpdate();
     emit colorMapChanged(map);
   }
 }
@@ -104,7 +104,7 @@ void XYValuePlot::setLogColorMap(double minVal, double maxVal)
 /*!
   Set the pointer to value Data
 */
-void XYValuePlot::setValues(QVector<double> * val)
+void XYValuePlot::setValues(VectorList<double> * val)
 {
   TRACE;
   LayerLocker ll(this);
@@ -118,7 +118,7 @@ void XYValuePlot::paintData(const LayerPainterRequest& lp, QPainter& p, double d
   // Make a copy of current palette (mandatory for multi-thread, palette are implicitly shared
   // objects so deep copy probably is not occuring right now, only upon user request for modification)
   const ColorMap map=_colorMap;
-  const GraphContentOptions& gc=lp.options();
+  const GraphContentsOptions& gc=lp.options();
   p.setRenderHints(QPainter::Antialiasing, true);
   int count;
   double pointSize, halfPointSize;
@@ -139,7 +139,7 @@ void XYValuePlot::paintData(const LayerPainterRequest& lp, QPainter& p, double d
   }
 }
 
-uint XYValuePlot::_tabColorMap=PropertyProxy::uniqueId();
+uint XYValuePlot::_tabColorMap=PropertyTab::uniqueId();
 
 /*!
   Setup property editor
@@ -243,8 +243,8 @@ void XYValuePlot::xml_writeBinaryData(XML_WRITEBINARYDATA_ARGS) const
 {
   TRACE;
   XYPlot::xml_writeBinaryData(s, context);
-  QVector<double>::iterator it;
-  QVector<double>::iterator itEnd;
+  VectorList<double>::iterator it;
+  VectorList<double>::iterator itEnd;
 
   itEnd=_values->end();
   for(it=_values->begin();it!=itEnd;++it) s << *it;
@@ -255,10 +255,10 @@ bool XYValuePlot::xml_setBinaryData(XML_SETBINARYDATA_ARGS)
   TRACE;
   int n;
   if(XYPlot::xml_setBinaryData(s, context) && (n=count())>0) {
-    QVector<double>::iterator it;
-    QVector<double>::iterator itEnd;
+    VectorList<double>::iterator it;
+    VectorList<double>::iterator itEnd;
 
-    _values=new QVector<double>;
+    _values=new VectorList<double>;
     _values->resize(n);
     itEnd=_values->end();
     for(it=_values->begin();it!=itEnd;++it) s >> *it;
