@@ -27,23 +27,16 @@
 #ifndef LAUNCHTHREADDELEGATE_H
 #define LAUNCHTHREADDELEGATE_H
 
-#include <QItemDelegate>
+#include <QGpGuiTools.h>
 
-
-class LaunchThreadDelegate : public QItemDelegate
+class LaunchThreadDelegate : public ItemDelegate
 {
   Q_OBJECT
 public:
-  LaunchThreadDelegate(QObject *parent=0) : QItemDelegate(parent) {}
+  LaunchThreadDelegate(QObject *parent=0) : ItemDelegate(parent) {}
 
   QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option,
                          const QModelIndex &index) const;
-  void setEditorData(QWidget *editor, const QModelIndex &index) const;
-  void setModelData(QWidget *editor, QAbstractItemModel *model,
-                     const QModelIndex &index) const;
-  QSize sizeHint (const QStyleOptionViewItem & option, const QModelIndex & index) const;
-signals:
-  void dataChanged() const;
 };
 
 #endif // LAUNCHTHREADDELEGATE_H
