@@ -32,7 +32,7 @@
 #include "InversionThread.h"
 
 LaunchThreadItem::LaunchThreadItem(QObject * parent)
-    : QAbstractItemModel(parent)
+    : QAbstractTableModel(parent)
 {
   TRACE;
   MainWindow * w=WindowEnvironment::window(this);
@@ -96,13 +96,13 @@ int LaunchThreadItem::rowCount(const QModelIndex &parent) const
   return 0;
 }
 
-int LaunchThreadItem::columnCount(const QModelIndex & ) const
+int LaunchThreadItem::columnCount(const QModelIndex&) const
 {
   TRACE;
   return 7;
 }
 
-QVariant LaunchThreadItem::data(const QModelIndex &index, int role) const
+QVariant LaunchThreadItem::data(const QModelIndex& index, int role) const
 {
   TRACE;
   MainWindow * w=WindowEnvironment::window(this);
@@ -124,7 +124,7 @@ QVariant LaunchThreadItem::data(const QModelIndex &index, int role) const
   }
 }
 
-bool LaunchThreadItem::setData (const QModelIndex & index, const QVariant & value, int role)
+bool LaunchThreadItem::setData(const QModelIndex& index, const QVariant & value, int role)
 {
   TRACE;
   MainWindow * w=WindowEnvironment::window(this);
@@ -212,29 +212,16 @@ QVariant LaunchThreadItem::headerData(int section, Qt::Orientation orientation,
   }
 }
 
-QModelIndex LaunchThreadItem::parent (const QModelIndex &) const
-{
-  TRACE;
-  return QModelIndex();
-}
-
-QModelIndex LaunchThreadItem::index (int row, int column, const QModelIndex &) const
+QModelIndex LaunchThreadItem::index(int row, int column, const QModelIndex &) const
 {
   TRACE;
   MainWindow * w=WindowEnvironment::window(this);
-  // 2019-01-21
-  // One of the strange behavior under Windows, count() is apparently not called
-  // and this function is used with row==0 and an empty thread list
-#ifdef Q_OS_WIN
-  if(row<w->threads().count()) {
-#endif
-  InversionThread * t=w->threads().at(row);
-  return createIndex(row, column, t);
-#ifdef Q_OS_WIN
+  if(row>=0 && row<w->threads().count()) {
+    InversionThread * t=w->threads().at(row);
+    return createIndex(row, column, t);
   } else {
     return QModelIndex();
   }
-#endif
 }
 
 Qt::ItemFlags LaunchThreadItem::flags (const QModelIndex &) const
