@@ -27,11 +27,11 @@
 #ifndef LAUNCHTHREADTABLE_H
 #define LAUNCHTHREADTABLE_H
 
-#include <QTableView>
+#include <QGpGuiTools.h>
 
 #include "ModelThreadInfo.h"
 
-class LaunchThreadTable : public QTableView
+class LaunchThreadTable : public TableView
 {
   Q_OBJECT
 public:
