@@ -35,7 +35,7 @@
 class PSViewer;
 class TabNAModelsPlot;
 
-class NAModelsPlot : public GraphContentLayer
+class NAModelsPlot : public GraphContentsLayer
 {
   Q_OBJECT
   Q_PROPERTY(double dotDiameter READ dotDiameter WRITE setDotDiameter)
@@ -43,32 +43,26 @@ public:
   NAModelsPlot(AxisWindow * parent=nullptr);
   ~NAModelsPlot();
 
-  virtual const QString& xml_tagName() const;
+  const QString& xml_tagName() const;
   static const QString xmlNAModelsPlotTag;
 
-  virtual Rect boundingRect() const;
-  virtual void setParent(GraphContent * parent);
+  Rect boundingRect() const;
+  void setParent(GraphContents * parent);
 
   void setParamX(int px);
   void setParamY(int py);
   int paramX() const {return _paramX;}
   int paramY() const {return _paramY;}
-  // Diameter of point on plot (in cm)
   double dotDiameter() const {return _size;}
-  // Change diameter of point on plot (in cm)
   void setDotDiameter (double d) {_size=d;}
-  // Diameter of point on plot (in cm)
-  double dotDiameterMM() const {return _size*10.0;}
-  // Change diameter of point on plot (in cm)
-  void setDotDiameterMM (double d) {_size=d*0.1;}
 
-  virtual bool hasProperties() {return true;}
-  virtual void addProperties(PropertyProxy * pp);
-  virtual void removeProperties(PropertyProxy * pp);
-  virtual void properties(PropertyWidget * w) const;
-  virtual void setProperty(uint wid, int pid, QVariant val);
+  bool hasProperties() {return true;}
+  void addProperties(PropertyProxy * pp);
+  void removeProperties(PropertyProxy * pp);
+  void properties(PropertyWidget * w) const;
+  void setProperty(uint wid, int pid, QVariant val);
 protected:
-  virtual void paintData(const LayerPainterRequest& lp, QPainter& p, double dotpercm) const;
+  void paintData(const LayerPainterRequest& lp, QPainter& p, double dotpercm) const;
   void setAxisProperties(int paramIndex, Axis * axis);
 
   mutable PSViewer * _psViewer;
@@ -77,13 +71,17 @@ protected:
   static uint _tab;
 
   bool saveParameters() const;
-  virtual void xml_writeProperties(XML_WRITEPROPERTIES_ARGS) const;
-  virtual void xml_writeChildren(XML_WRITECHILDREN_ARGS) const;
-  virtual void xml_writeBinaryData(XML_WRITEBINARYDATA_ARGS) const;
-  virtual XMLMember xml_member(XML_MEMBER_ARGS);
-  virtual bool xml_setProperty(XML_SETPROPERTY_ARGS);
+  void xml_writeProperties(XML_WRITEPROPERTIES_ARGS) const;
+  void xml_writeChildren(XML_WRITECHILDREN_ARGS) const;
+  void xml_writeBinaryData(XML_WRITEBINARYDATA_ARGS) const;
+  XMLMember xml_member(XML_MEMBER_ARGS);
+  bool xml_setProperty(XML_SETPROPERTY_ARGS);
 private:
-  void paramValue(double& x, double& y, double& misfit, ModelThreadList::const_iterator it) const;
+  void paramValue(double& x, double& y, double& misfit,
+                  const InversionThread * t,
+                  const SetIndex& index) const;
+  void paramValue(double& x, double& y, double& misfit,
+                  ModelThreadList::const_iterator it) const;
 };
 
 #endif
