@@ -30,6 +30,7 @@
 
 #include <QGpGuiTools.h>
 #include <SciFigs.h>
+
 #include "PSViewer.h"
 #include "AddPlotParam.h"
 #include "NAModelsPlotProperties.h"
@@ -50,9 +51,9 @@ PSViewer::PSViewer(QWidget * parent) :
   TRACE;
   setAttribute(Qt::WA_DeleteOnClose, true);
   _childLayout=new QVBoxLayout(this);
-  _childLayout->setMargin(0);
+  _childLayout->setContentsMargins(0, 0, 0, 0);
   _childLayout->setSpacing(0);
-#ifndef Q_OS_MAC
+#ifndef Q_OS_DARWIN
   _menuBar=new QMenuBar(this);
   _childLayout->addWidget(_menuBar);
 #endif
@@ -62,7 +63,7 @@ PSViewer::PSViewer(QWidget * parent) :
 
   _colorMap=new ColorMapWidget(nullptr);
   _colorMap->setObjectName("Palette");
-  _colorMap->generateColorScale(20, ColorPalette::Hobi);
+  _colorMap->generate(0, 19);
   _colorMap->setNumberPrecision(2);
   _colorMap->setTitle("Misfit value");
   _colorMap->setValues(0, 1, SamplingParameters::Linear);
@@ -105,7 +106,7 @@ void PSViewer::addActions()
   m->setTitle(tr( "&File" ));
   _sheet.addFileActions(m, nullptr);
 
-#ifndef Q_OS_MAC
+#ifndef Q_OS_DARWIN
   _menuBar->addMenu(m);
 #endif
   _sheet.addMenu(m);
@@ -143,7 +144,7 @@ void PSViewer::addActions()
   connect(a, SIGNAL(triggered()), this, SLOT(select()) );
   m->addAction(a);
 
-#ifndef Q_OS_MAC
+#ifndef Q_OS_DARWIN
   _menuBar->addMenu(m);
 #endif
   _sheet.addMenu(m);
@@ -160,7 +161,7 @@ void PSViewer::addActions()
   connect(a, SIGNAL(triggered()), this, SLOT(addPlot()));
   m->addAction(a);
 
-#ifndef Q_OS_MAC
+#ifndef Q_OS_DARWIN
   _menuBar->addMenu(m);
 #endif
   _sheet.addMenu(m);
@@ -177,7 +178,7 @@ void PSViewer::addActions()
   connect(a, SIGNAL(triggered()), this, SLOT(setLimits()));
   m->addAction(a);
 
-#ifndef Q_OS_MAC
+#ifndef Q_OS_DARWIN
   _menuBar->addMenu(m);
 #endif
   _sheet.addMenu(m);
@@ -217,7 +218,7 @@ void PSViewer::addThreadData(InversionThread * models)
 void PSViewer::synchronize()
 {
   TRACE;
-  //App::log("Synchronize now" << endl;
+  printf("Synchronize now\n");
   lockPlots();
   ViewerThreadMap::iterator it;
   bool modelsTouched=false;
@@ -234,21 +235,25 @@ void PSViewer::synchronize()
     }
     if(iModel<end) {
       modelsTouched=true;
-      for( ; iModel<end; iModel++) {
-        if(isfinite(t->misfit(iModel))) {
-          _models.append(ModelThreadInfo(t, iModel));
-        }
+      while(iModel<end) {
+        _models.append(ModelThreadInfo(t, iModel));
+        iModel++;
       }
     }
     t->unlock();
   }
   if(modelsTouched) {
+    printf("models updated\n");
     lockDataModels();
+    printf("sort\n");
     std::sort(_models.begin(), _models.end());
+    printf("end sort\n");
     unlockDataModels();
+    printf("end models updated\n");
     _sheet.deepUpdate();
   }
   unlockPlots();
+  printf("end synchronize\n");
 }
 
 void PSViewer::setLimits()
@@ -267,14 +272,24 @@ void PSViewer::setLimits()
     lockDataModels();
     ModelThreadList::const_iterator it=_models.begin();
     if(it!=_models.end()) {
-      double minM=std::numeric_limits<double>::infinity(), maxM=-std::numeric_limits<double>::infinity();
-      double misfitValue;
-      SAFE_UNINITIALIZED(misfitValue, 0);
+      double minM, maxM, misfitValue;
+      do {
+        const ModelThreadInfo& modelInfo=*it;
+        misfitValue=it->thread()->misfit(modelInfo.index());
+        minM=misfitValue;
+        maxM=misfitValue;
+        it++;
+      } while(isinf(misfitValue) && it!=_models.end());
       for(; it!=_models.end(); ++it) {
         const ModelThreadInfo& modelInfo=*it;
         misfitValue=it->thread()->misfit(modelInfo.index());
-        if(misfitValue>maxM) maxM=misfitValue;
-        if(misfitValue<minM) minM=misfitValue;
+        if(!isinf(misfitValue)) {
+          if(misfitValue>maxM) {
+            maxM=misfitValue;
+          } else if(misfitValue<minM) {
+            minM=misfitValue;
+          }
+        }
       }
       if(misfitValue>0) {
         _colorMap->setValues(minM, maxM, SamplingParameters::Log);
@@ -345,7 +360,7 @@ AxisWindow * PSViewer::addPlot(int paramX, int paramY)
   w->setPrintHeight(6.0);
   _sheet.addObject(w);
   NAModelsPlot * plot=new NAModelsPlot(w);
-  connect(_colorMap, SIGNAL(changed(ColorMap)), w->graphContent(), SLOT(deepUpdate()));
+  connect(_colorMap, SIGNAL(changed(ColorMap)), w->graphContents(), SLOT(deepUpdate()));
   plot->setParamX(paramX);
   plot->setParamY(paramY);
   return w;
@@ -362,7 +377,7 @@ void PSViewer::fileOpenPS()
     _sheet.fileOpen(fileName);
     QList<NAModelsPlot *> plotList=_sheet.findChildren<NAModelsPlot>(Qt::FindChildrenRecursively);
     for(QList<NAModelsPlot *>::iterator it=plotList.begin(); it!=plotList.end(); ++it) {
-      connect(_colorMap, SIGNAL(changed(ColorMap)), (*it)->graphContent(), SLOT(deepUpdate()));
+      connect(_colorMap, SIGNAL(changed(ColorMap)), (*it)->graphContents(), SLOT(deepUpdate()));
     }
     QList<ColorMapWidget *> colorMapList=_sheet.findChildren<ColorMapWidget>(Qt::FindDirectChildrenOnly);
     for(QList<ColorMapWidget *>::iterator it=colorMapList.begin(); it!=colorMapList.end(); ++it) {
