@@ -57,6 +57,7 @@ public:
   void unlockPlots();
   void addThreadData(InversionThread * models);
   const ModelThreadList& modelList() const {return *_selectedModels;}
+  const ViewerThreadMap& threads() const {return _threads;}
   void lockDataModels();
   void unlockDataModels();
   const ColorMap * colorMap() const {return &_colorMap->colorMap();}
@@ -80,14 +81,14 @@ private:
   GraphicSheet _sheet;
   ColorMapWidget * _colorMap;
   QVBoxLayout* _childLayout;
-#ifndef Q_OS_MAC
+#ifndef Q_OS_DARWIN
   QMenuBar * _menuBar;
 #endif
 
   ViewerThreadMap _threads;
   ModelThreadList _models;
   ModelThreadList * _selectedModels;
-  QVector<QPair<double, double>> _selectedRange;
+  VectorList<QPair<double, double>> _selectedRange;
   SetIndex _minimumIndex, _maximumIndex;
 
   bool _saveParameters;
