@@ -32,21 +32,25 @@
 #include "ProcessStatus.h"
 #include "InversionThread.h"
 
-void ProcessStatusDelegate::paint (QPainter * painter, const QStyleOptionViewItem & option,
-                                   const QModelIndex & index) const
+void ProcessStatusDelegate::paint(QPainter * painter, const QStyleOptionViewItem & option,
+                                  const QModelIndex & index) const
 {
   TRACE;
   if(index.column()==0) {
     ProcessStatus * table=qobject_cast<ProcessStatus *>(QObject::parent());
     ASSERT(table);
     LegendItemDisplay item(table->legend().item(index.row()));
+    drawBackground(painter, option, index);
     item.setDisplayText(false);
     item.paint(*painter, SciFigsGlobal::screenResolution(), option.rect.x(), option.rect.y(),
                option.rect.width(), option.rect.height());
-  } else QItemDelegate::paint(painter, option, index);
+  } else {
+    ItemDelegate::paint(painter, option, index);
+  }
 }
 
-QSize ProcessStatusDelegate::sizeHint (const QStyleOptionViewItem & option, const QModelIndex & index) const
+QSize ProcessStatusDelegate::sizeHint(const QStyleOptionViewItem & option,
+                                      const QModelIndex & index) const
 {
   TRACE;
   if(index.column()==0) {
@@ -55,7 +59,9 @@ QSize ProcessStatusDelegate::sizeHint (const QStyleOptionViewItem & option, cons
     LegendItemDisplay item(table->legend().item(index.row()));
     item.setDisplayText(false);
     return item.sizeHint(option.font);
-  } else return QItemDelegate::sizeHint(option, index);
+  } else {
+    return ItemDelegate::sizeHint(option, index);
+  }
 }
 
 /*!
@@ -77,11 +83,11 @@ ProcessStatus::ProcessStatus(QWidget *parent, Qt::WindowFlags f)
   threadTable->resizeColumnsToContents();
   Settings::columnWidth(threadTable, "ProcessStatus");
 
-  _legend.generateColorScale(10);
+  _legend.generate(0, 9);
   _curveLayer=new LineLayer(historyGraph);
   PlotLine2D * line;
   line=new PlotLine2D;
-  line->setPen(Pen(Qt::black, 0.3, Qt::SolidLine));
+  line->setPen(Pen(Qt::black, 0.3, Pen::SolidLine));
   line->setSymbol(Symbol());
   _curveLayer->setReferenceLine(line);
 
@@ -177,7 +183,7 @@ void ProcessStatus::changeLegend()
   TRACE;
   Dialog * d=new Dialog(this);
   LegendProperties * dl=new LegendProperties(this);
-  dl->setPropertySections(LegendTable::All);
+  dl->setPropertySections(LegendTable::AllSections);
   d->setMainWidget(dl);
   dl->setLegend(_legend);
   dl->setReadOnlyText(true);
@@ -186,7 +192,7 @@ void ProcessStatus::changeLegend()
     Settings::setRect(d, "ProcessStatus::legend");
     _legend=dl->legend();
     updatePens();
-    historyGraph->graphContent() ->deepUpdate();
+    historyGraph->graphContents() ->deepUpdate();
   }
   delete d;
 }
@@ -325,7 +331,11 @@ QVariant StatusThreadItem::data(const QModelIndex &index, int role) const
 {
   TRACE;
   MainWindow * w=WindowEnvironment::window(this);
-  InversionThread * t=w->threads().at(index.row());
+  ThreadList threads=w->threads();
+  if(index.row()>=threads.count()) {
+    return QVariant();
+  }
+  InversionThread * t=threads.at(index.row());
   StatusThreadMap::iterator itInfo=_threads->find(t);
   StatusThreadInfo * tInfo;
   if(itInfo!=_threads->end()) {
@@ -366,20 +376,25 @@ QVariant StatusThreadItem::data(const QModelIndex &index, int role) const
     case 7:
       if(tInfo) {
         return tr("%1 m").arg(tInfo->nr);
+      } else {
+        return tr("? m");
       }
     case 8:
       if(tInfo) {
-        if(tInfo->deltaNModels > 0)
+        if(tInfo->deltaNModels>0) {
           return tr("%1 m/m").arg((double) tInfo->deltaNRejected/(double) tInfo->deltaNModels);
-        else
+        } else {
           return tr("%1 m").arg(tInfo->nRejected);
-      } else
+        }
+      } else {
         return tr("? m");
+      }
     case 9:
-      if(tInfo)
+      if(tInfo) {
         return tr("%1 m").arg(tInfo->nGiveUp);
-      else
+      } else {
         return tr("? m");
+      }
     default: return QVariant();
     }
   default:
