@@ -114,15 +114,15 @@ protected:
   void updatePens();
 };
 
-class ProcessStatusDelegate : public QItemDelegate
+class ProcessStatusDelegate : public ItemDelegate
 {
   Q_OBJECT
 public:
-  ProcessStatusDelegate(ProcessStatus * parent) : QItemDelegate(parent) {}
+  ProcessStatusDelegate(ProcessStatus * parent) : ItemDelegate(parent) {}
 
-  virtual void paint (QPainter * painter, const QStyleOptionViewItem & option,
-                       const QModelIndex & index) const;
-  virtual QSize sizeHint (const QStyleOptionViewItem & option, const QModelIndex & index) const;
+  void paint (QPainter * painter, const QStyleOptionViewItem & option,
+              const QModelIndex & index) const;
+  QSize sizeHint (const QStyleOptionViewItem & option, const QModelIndex & index) const;
 };
 
 #endif // QTBPROCESSSTATUS_H
