@@ -27,8 +27,9 @@
 #ifndef THREADLAUNCHER_H
 #define THREADLAUNCHER_H
 
-#include <QQueue>
+#include <QtCore>
 
+#include "InversionThread.h"
 #include "ui_ThreadLauncher.h"
 
 class ThreadLauncher : public QWidget, public Ui::ThreadLauncher
