@@ -139,7 +139,7 @@ int modeGui(int argc, char ** argv)
     return 2;
   }
 
-  SciFigsGlobal s;
+  SciFigsGlobal s(true);
   Application::instance()->setGuiMessage();
 
   QString pluginFile=MainWindow::pluginSelector(pluginTag, debugStream);
