@@ -191,6 +191,9 @@ QWidget * DCPlugin::createTargetWidget()
   TRACE;
   TargetListFrameWidget * targetFrame=new TargetListFrameWidget;
   _targetWidget=targetFrame->targetListWidget;
+  // Set default values
+  TargetList tl;
+  _targetWidget->setFrom(&tl);
   connect(_targetWidget, SIGNAL(targetChanged()), this, SLOT(setParamFromTargets()));
   return targetFrame;
 }
@@ -337,7 +340,7 @@ QWidget * DCPlugin::parentWidget(QObject * o)
   TRACE;
   QAction * a=qobject_cast<QAction *>(o);
   ASSERT(a);
-  return a->parentWidget();
+  return qobject_cast<QWidget *>(a->parent());
 }
 
 void DCPlugin::groundProfilesViewer()
