@@ -46,7 +46,7 @@ ParamProfileWidget::ParamProfileWidget(ParamGroundModelWidget * parent, Qt::Wind
 
   _frameLayout=new QVBoxLayout(frame);
   _frameLayout->setSpacing(1);
-  _frameLayout->setMargin(1);
+  _frameLayout->setContentsMargins(1, 1, 1, 1);
   // signals and slots connections
   connect(addLayerBut, SIGNAL(clicked()), this, SLOT(addLayer()));
   connect(delLayerBut, SIGNAL(clicked()), this, SLOT(deleteLayer()));
@@ -206,8 +206,7 @@ void ParamProfileWidget::setLayerIndex()
 int ParamProfileWidget::selectedIndex() const
 {
   TRACE;
-  int n=_frameLayout->count();
-  ASSERT(_nLayers==n);
+  ASSERT(_nLayers==_frameLayout->count());
   for(int i=0; i<_nLayers; i++) {
     if(layer(i)->isSelected()) {
       return i;
