@@ -62,6 +62,23 @@ TargetListWidget::TargetListWidget(QWidget *parent, Qt::WindowFlags f)
   refraVpSelect->setEnabled(false);
   refraVsSelect->setEnabled(false);
   magnetoTelluricSelect->setEnabled(false);
+
+  // Set misfit types
+  QStringList misfitTypes=Misfit::types();
+  dispMisfitType->addItems(misfitTypes);
+  dispMisfitType->setEnabled(false);
+  autocorrMisfitType->addItems(misfitTypes);
+  autocorrMisfitType->setEnabled(false);
+  ellCurveMisfitType->addItems(misfitTypes);
+  ellCurveMisfitType->setEnabled(false);
+  ellPeakMisfitType->addItems(misfitTypes);
+  ellPeakMisfitType->setEnabled(false);
+  refraVpMisfitType->addItems(misfitTypes);
+  refraVpMisfitType->setEnabled(false);
+  refraVsMisfitType->addItems(misfitTypes);
+  refraVsMisfitType->setEnabled(false);
+  magnetoTelluricMisfitType->addItems(misfitTypes);
+  magnetoTelluricMisfitType->setEnabled(false);
 }
 
 /*!
@@ -397,41 +414,49 @@ TargetList * TargetListWidget::targetList()
   tl->refractionVsTarget().setSelected(refraVsSelect->isChecked());
   tl->magnetoTelluricTarget().setSelected(magnetoTelluricSelect->isChecked());
 
+  bool ok=true;
   if(_dispWidget) {
     tl->dispersionTarget().setCurves(_dispWidget->curves());
     tl->dispersionTarget().setMisfitWeight(dispWeight->text().toDouble());
     tl->dispersionTarget().setMinimumMisfit(dispMinMisfit->text().toDouble());
+    tl->dispersionTarget().setMisfitType(Misfit::convertType(dispMisfitType->currentText(), ok));
   }
   if(_autocorrWidget) {
     tl->autocorrTarget().setCurves(_autocorrWidget->curves());
     tl->autocorrTarget().setMisfitWeight(autocorrWeight->text().toDouble());
     tl->autocorrTarget().setMinimumMisfit(autocorrMinMisfit->text().toDouble());
+    tl->autocorrTarget().setMisfitType(Misfit::convertType(autocorrMisfitType->currentText(), ok));
   }
   if(_ellCurveWidget) {
     tl->ellipticityCurveTarget().setCurves(_ellCurveWidget->curves());
     tl->ellipticityCurveTarget().setMisfitWeight(ellCurveWeight->text().toDouble());
     tl->ellipticityCurveTarget().setMinimumMisfit(ellCurveMinMisfit->text().toDouble());
+    tl->ellipticityCurveTarget().setMisfitType(Misfit::convertType(ellCurveMisfitType->currentText(), ok));
   }
   if(_ellPeakWidget) {
     tl->ellipticityPeakTarget().setValue(_ellPeakWidget->value());
     tl->ellipticityPeakTarget().setMinimumAmplitude(_ellPeakWidget->minimumAmplitude());
     tl->ellipticityPeakTarget().setMisfitWeight(ellPeakWeight->text().toDouble());
     tl->ellipticityPeakTarget().setMinimumMisfit(ellPeakMinMisfit->text().toDouble());
+    tl->ellipticityPeakTarget().setMisfitType(Misfit::convertType(ellPeakMisfitType->currentText(), ok));
   }
   if(_refraVpWidget) {
     tl->refractionVpTarget().setCurves(_refraVpWidget->curves());
     tl->refractionVpTarget().setMisfitWeight(refraVpWeight->text().toDouble());
     tl->refractionVpTarget().setMinimumMisfit(refraVpMinMisfit->text().toDouble());
+    tl->refractionVpTarget().setMisfitType(Misfit::convertType(refraVpMisfitType->currentText(), ok));
   }
   if(_refraVsWidget) {
     tl->refractionVsTarget().setCurves(_refraVsWidget->curves());
     tl->refractionVsTarget().setMisfitWeight(refraVsWeight->text().toDouble());
     tl->refractionVsTarget().setMinimumMisfit(refraVsMinMisfit->text().toDouble());
+    tl->refractionVsTarget().setMisfitType(Misfit::convertType(refraVsMisfitType->currentText(), ok));
   }
   if(_magnetoTelluricWidget) {
     tl->magnetoTelluricTarget().setCurves(_magnetoTelluricWidget->curves());
     tl->magnetoTelluricTarget().setMisfitWeight(magnetoTelluricWeight->text().toDouble());
     tl->magnetoTelluricTarget().setMinimumMisfit(magnetoTelluricMinMisfit->text().toDouble());
+    tl->magnetoTelluricTarget().setMisfitType(Misfit::convertType(magnetoTelluricMisfitType->currentText(), ok));
   }
   tl->validateTargets();
   return tl;
@@ -453,99 +478,90 @@ void TargetListWidget::setFrom(TargetList * tl)
     ASSERT(_dispWidget);
     _dispWidget->clear();
     _dispWidget->addCurves(tl->dispersionTarget().curves());
-    dispWeight->setText(QString::number(tl->dispersionTarget().misfitWeight()));
-    dispMinMisfit->setText(QString::number(tl->dispersionTarget().minimumMisfit()));
   } else {
     if(_dispWidget) _dispWidget->clear();
-    dispWeight->setText("1");
-    dispMinMisfit->setText("0");
     dispSelect->setChecked(false);
   }
+  dispWeight->setText(QString::number(tl->dispersionTarget().misfitWeight()));
+  dispMinMisfit->setText(QString::number(tl->dispersionTarget().minimumMisfit()));
+  dispMisfitType->setCurrentText(Misfit::convertType(tl->dispersionTarget().misfitType()));
 
   if(!tl->autocorrTarget().curves().isEmpty()) {
     on_autocorrSet_clicked();
     ASSERT(_autocorrWidget);
     _autocorrWidget->clear();
     _autocorrWidget->addCurves(tl->autocorrTarget().curves());
-    autocorrWeight->setText(QString::number(tl->autocorrTarget().misfitWeight()));
-    autocorrMinMisfit->setText(QString::number(tl->autocorrTarget().minimumMisfit()));
   } else {
     if(_autocorrWidget) _autocorrWidget->clear();
     autocorrSelect->setChecked(false);
-    autocorrWeight->setText("1");
-    autocorrMinMisfit->setText("0");
-    autocorrSelect->setChecked(false);
   }
+  autocorrWeight->setText(QString::number(tl->autocorrTarget().misfitWeight()));
+  autocorrMinMisfit->setText(QString::number(tl->autocorrTarget().minimumMisfit()));
+  autocorrMisfitType->setCurrentText(Misfit::convertType(tl->autocorrTarget().misfitType()));
 
   if(!tl->ellipticityCurveTarget().curves().isEmpty()) {
     on_ellCurveSet_clicked();
     ASSERT(_ellCurveWidget);
     _ellCurveWidget->clear();
     _ellCurveWidget->addCurves(tl->ellipticityCurveTarget().curves());
-    ellCurveWeight->setText(QString::number(tl->ellipticityCurveTarget().misfitWeight()));
-    ellCurveMinMisfit->setText(QString::number(tl->ellipticityCurveTarget().minimumMisfit()));
   } else {
     if(_ellCurveWidget) _ellCurveWidget->clear();
     ellCurveSelect->setChecked(false);
-    ellCurveWeight->setText("1");
-    ellCurveMinMisfit->setText("0");
-    ellCurveSelect->setChecked(false);
   }
+  ellCurveWeight->setText(QString::number(tl->ellipticityCurveTarget().misfitWeight()));
+  ellCurveMinMisfit->setText(QString::number(tl->ellipticityCurveTarget().minimumMisfit()));
+  ellCurveMisfitType->setCurrentText(Misfit::convertType(tl->ellipticityCurveTarget().misfitType()));
 
   if(tl->ellipticityPeakTarget().value().isValid()) {
     on_ellPeakSet_clicked();
     ASSERT(_ellPeakWidget);
     _ellPeakWidget->setValue(tl->ellipticityPeakTarget().value());
     _ellPeakWidget->setMinimumAmplitude(tl->ellipticityPeakTarget().minimumAmplitude());
-    ellPeakWeight->setText(QString::number(tl->ellipticityPeakTarget().misfitWeight()));
-    ellPeakMinMisfit->setText(QString::number(tl->ellipticityPeakTarget().minimumMisfit()));
   } else {
-    ellPeakWeight->setText("1");
-    ellPeakMinMisfit->setText("0");
     ellPeakSelect->setChecked(false);
   }
+  ellPeakWeight->setText(QString::number(tl->ellipticityPeakTarget().misfitWeight()));
+  ellPeakMinMisfit->setText(QString::number(tl->ellipticityPeakTarget().minimumMisfit()));
+  ellPeakMisfitType->setCurrentText(Misfit::convertType(tl->ellipticityPeakTarget().misfitType()));
 
   if( !tl->refractionVpTarget().curves().isEmpty()) {
     on_refraVpSet_clicked();
     ASSERT(_refraVpWidget);
     _refraVpWidget->clear();
     _refraVpWidget->addCurves(tl->refractionVpTarget().curves());
-    refraVpWeight->setText(QString::number(tl->refractionVpTarget().misfitWeight()));
-    refraVpMinMisfit->setText(QString::number(tl->refractionVpTarget().minimumMisfit()));
   } else {
     if(_refraVpWidget) _refraVpWidget->clear();
-    refraVpWeight->setText("1");
-    refraVpMinMisfit->setText("0");
     refraVpSelect->setChecked(false);
   }
+  refraVpWeight->setText(QString::number(tl->refractionVpTarget().misfitWeight()));
+  refraVpMinMisfit->setText(QString::number(tl->refractionVpTarget().minimumMisfit()));
+  refraVpMisfitType->setCurrentText(Misfit::convertType(tl->refractionVsTarget().misfitType()));
 
   if( !tl->refractionVsTarget().curves().isEmpty()) {
     on_refraVsSet_clicked();
     ASSERT(_refraVsWidget);
     _refraVsWidget->clear();
     _refraVsWidget->addCurves(tl->refractionVsTarget().curves());
-    refraVsWeight->setText(QString::number(tl->refractionVpTarget().misfitWeight()));
-    refraVsMinMisfit->setText(QString::number(tl->refractionVpTarget().minimumMisfit()));
   } else {
     if(_refraVsWidget) _refraVsWidget->clear();
-    refraVsWeight->setText("1");
-    refraVsMinMisfit->setText("0");
     refraVsSelect->setChecked(false);
   }
+  refraVsWeight->setText(QString::number(tl->refractionVpTarget().misfitWeight()));
+  refraVsMinMisfit->setText(QString::number(tl->refractionVpTarget().minimumMisfit()));
+  refraVsMisfitType->setCurrentText(Misfit::convertType(tl->refractionVpTarget().misfitType()));
 
   if( !tl->magnetoTelluricTarget().curves().isEmpty()) {
     on_magnetoTelluricSet_clicked();
     ASSERT(_magnetoTelluricWidget);
     _magnetoTelluricWidget->clear();
     _magnetoTelluricWidget->addCurves(tl->magnetoTelluricTarget().curves());
-    magnetoTelluricWeight->setText(QString::number(tl->magnetoTelluricTarget().misfitWeight()));
-    magnetoTelluricMinMisfit->setText(QString::number(tl->magnetoTelluricTarget().minimumMisfit()));
   } else {
     if(_magnetoTelluricWidget) _magnetoTelluricWidget->clear();
-    magnetoTelluricWeight->setText("1");
-    magnetoTelluricMinMisfit->setText("0");
     magnetoTelluricSelect->setChecked(false);
   }
+  magnetoTelluricWeight->setText(QString::number(tl->magnetoTelluricTarget().misfitWeight()));
+  magnetoTelluricMinMisfit->setText(QString::number(tl->magnetoTelluricTarget().minimumMisfit()));
+  magnetoTelluricMisfitType->setCurrentText(Misfit::convertType(tl->magnetoTelluricTarget().misfitType()));
 
   updateInfo();
 }
