@@ -77,10 +77,10 @@ bool MatlabTarget::xml_setProperty(XML_SETPROPERTY_ARGS)
   Q_UNUSED(attributes)
   Q_UNUSED(context)
   switch(memberID) {
-  case 0: _startup=content.toString(); return true;
-  case 1: _scriptPath=content.toString(); return true;
-  case 2: _initScript=content.toString(); return true;
-  case 3: _forwardScript=content.toString(); return true;
+  case 0: _startup=content.toStringBuffer(); return true;
+  case 1: _scriptPath=content.toStringBuffer(); return true;
+  case 2: _initScript=content.toStringBuffer(); return true;
+  case 3: _forwardScript=content.toStringBuffer(); return true;
   default: return false;
   }
 }
@@ -108,25 +108,25 @@ bool MatlabTarget::isOk(int nParams)
   engOutputBuffer(matlab, buffer, MATLAB_OUTPUT_BUFFER_SIZE);
   if(!_scriptPath.isEmpty()) {
     QString cmd="addpath('" + _scriptPath + "');";
-    App::log(cmd << endl;
+    App::log(cmd << Qt::endl;
     if(engEvalString( matlab, cmd.toLatin1().data())!=0) {
       App::log(tr("Error adding path '%1'.\n").arg(_scriptPath) );
-      if(buffer[0]!='\0') App::log(buffer+4 << endl;
+      if(buffer[0]!='\0') App::log(buffer+4 << Qt::endl;
       engClose(matlab);
       App::setStreamPrefix("");
       return false;
     }
   }
-  if(buffer[0]!='\0') App::log(buffer+4 << endl;
-  App::log(_initScript << endl;
+  if(buffer[0]!='\0') App::log(buffer+4 << Qt::endl;
+  App::log(_initScript << Qt::endl;
   if(engEvalString( matlab, _initScript.toLatin1().data())!=0) {
     App::log(tr("Error running initialization script '%1' in Matlab environment.\n").arg(_initScript) );
-    if(buffer[0]!='\0') App::log(buffer+4 << endl;
+    if(buffer[0]!='\0') App::log(buffer+4 << Qt::endl;
     engClose(matlab);
     App::setStreamPrefix("");
     return false;
   }
-  if(buffer[0]!='\0') App::log(buffer+4 << endl;
+  if(buffer[0]!='\0') App::log(buffer+4 << Qt::endl;
   mxArray * dinverModel=mxCreateDoubleMatrix(1, nParams, mxREAL);
   for(int i=0; i<nParams;i++) {
     mxGetPr(dinverModel)[i]=0.0;
@@ -146,15 +146,15 @@ bool MatlabTarget::isOk(int nParams)
     App::setStreamPrefix("");
     return false;
   }
-  App::log(_forwardScript << endl;
+  App::log(_forwardScript << Qt::endl;
   if(engEvalString( matlab, _forwardScript.toLatin1().data())!=0) {
     App::log(tr("Error running forward script '%1' in Matlab environment.\n").arg(_forwardScript) );
-    if(buffer[0]!='\0') App::log(buffer+4 << endl;
+    if(buffer[0]!='\0') App::log(buffer+4 << Qt::endl;
     engClose(matlab);
     App::setStreamPrefix("");
     return false;
   }
-  if(buffer[0]!='\0') App::log(buffer+4 << endl;
+  if(buffer[0]!='\0') App::log(buffer+4 << Qt::endl;
   mxArray * dinverMisfit=engGetVariable(matlab, "dinverMisfit" );
   if( ! dinverMisfit) {
     App::log(tr("Error retreiving variable 'dinverMisfit' from Matlab environment.\n") );
