@@ -25,7 +25,9 @@
 **
 ***************************************************************************/
 
+#include <QGpGuiTools.h>
 #include <SciFigs.h>
+#include <QGpGuiMath.h>
 
 #include "MainWindow.h"
 #include "figueVersion.h"
@@ -40,6 +42,7 @@ void createDots(GraphicSheet * sheet);
 void createCircles(GraphicSheet * sheet);
 void createBands(AxisType a, GraphicSheet * sheet);
 void createManyCurves(GraphicSheet * sheet);
+void createImage(GraphicSheet * sheet);
 void createText(GraphicSheet * sheet);
 
 ApplicationHelp * help();
@@ -53,6 +56,7 @@ static ExportOptions exportOptions;
 static int xColumn=0;
 static QList<int> yColumns, yerrColumns, nameColumns;
 static DateTime xTimeRef, yTimeRef;
+static QString layerName;
 
 // Global options
 static double dx0=0.0, dy0=0.0, dx=0.0, dy=0.0, maxX=0.0, maxY=0.0;
@@ -60,13 +64,13 @@ static double dxPage=0.0, dyPage=0.0, maxXPage=0.0, maxYPage=0.0;
 
 static MainWindow * mainWindow;
 
-void openPageFiles(int argc, char ** argv)
+void openFiles(int argc, char ** argv)
 {
   double x=dx0, y=dy0, xPage=maxXPage, yPage=maxYPage;
   QStringList fileList=CoreApplication::getFileList(argc, argv);
   for(QStringList::iterator it=fileList.begin();it!=fileList.end();it++) {
     App::log(tr("Opening file %1\n").arg(*it) );
-    mainWindow->sheet()->fileOpen( *it, x, y);
+    mainWindow->sheet()->fileOpen(*it, x, y);
     if(maxX>0.0) {
       x+=dx;
       if(x>=maxX) {
@@ -94,6 +98,15 @@ void openPageFiles(int argc, char ** argv)
       yPage+=dyPage+maxYPage;
     }
   }
+  if(!layerName.isEmpty() && fileList.count()==1 && fileList.first().endsWith(".layer")) {
+    GraphicObjectList objs=mainWindow->sheet()->objects();
+    if(objs.count()==1) {
+      GraphContents * gc=qobject_cast<AxisWindow *>(objs.first())->graphContents();
+      if(gc->layerCount()==1) {
+        gc->layer(0)->setObjectName(layerName);
+      }
+    }
+  }
 }
 
 int main(int argc, char ** argv)
@@ -102,7 +115,8 @@ int main(int argc, char ** argv)
   a.setConsoleMessage();
 
   // Options
-  enum StdinMode {PageFile, Curve, CurveName, ManyCurves, Grid, Dots, Circles, Text, BandsX, BandsY, ObjectCount};
+  enum StdinMode {PageFile, Curve, CurveName, ManyCurves, Grid, Dots, Circles,
+                   Image, Text, BandsX, BandsY, ObjectCount};
   StdinMode mode=PageFile;
   QString makeupSheetFile;
   QString deleteTag;
@@ -132,6 +146,8 @@ int main(int argc, char ** argv)
         mode=BandsX;
       } else if(arg=="-bands-y" || arg=="-by") {
         mode=BandsY;
+      } else if(arg=="-image" || arg=="-i") {
+        mode=Image;
       } else if(arg=="-text" || arg=="-t") {
         mode=Text;
       } else if(arg=="-x-column") {
@@ -143,7 +159,7 @@ int main(int argc, char ** argv)
       } else if(arg=="-y-columns") {
         Application::checkOptionArg(i, argc, argv);
         QString ycs=argv[i];
-        QStringList ycList=ycs.split(QRegExp(" *, *"));
+        QStringList ycList=ycs.split(QRegularExpression(" *, *"));
         QString yc;
         yColumns.clear();
         foreach(yc, ycList) {
@@ -161,7 +177,7 @@ int main(int argc, char ** argv)
       } else if(arg=="-yerr-columns") {
         Application::checkOptionArg(i, argc, argv);
         QString ycs=argv[i];
-        QStringList ycList=ycs.split(QRegExp(" *, *"));
+        QStringList ycList=ycs.split(QRegularExpression(" *, *"));
         QString yc;
         yerrColumns.clear();
         foreach(yc, ycList) {
@@ -191,7 +207,7 @@ int main(int argc, char ** argv)
       } else if(arg=="-name-columns") {
         Application::checkOptionArg(i, argc, argv);
         QString ycs=argv[i];
-        QStringList ycList=ycs.split(QRegExp(" *, *"));
+        QStringList ycList=ycs.split(QRegularExpression(" *, *"));
         QString yc;
         nameColumns.clear();
         foreach(yc, ycList) {
@@ -222,6 +238,9 @@ int main(int argc, char ** argv)
       } else if(arg=="-cpp") {
         Application::checkOptionArg(i, argc, argv);
         curvesPerPlot=atoi(argv[i] );
+      } else if(arg=="-layer-name") {
+        Application::checkOptionArg(i, argc, argv);
+        layerName=argv[i];
       } else if(arg=="-preserve-colormap-scale") {
         autoScaleColorMap=false;
       } else if(arg=="-dx") {
@@ -275,7 +294,11 @@ int main(int argc, char ** argv)
         if(reg->hasPluginList()) {
           QStringList libs=reg->pluginList();
           delete reg;
-          printf("%i plugins\n",libs.count());
+#if(QT_VERSION>=QT_VERSION_CHECK(6, 0, 0))
+          printf("%lli plugins\n", libs.count());
+#else
+          printf("%i plugins\n", libs.count());
+#endif
           SciFigsPlugin::loadPlugins(libs, true);
         } else {
           printf("No plugins, search for new plugins...\n");
@@ -314,19 +337,18 @@ int main(int argc, char ** argv)
     argc=j;
   }
 
-  SciFigsGlobal s;
+  SciFigsGlobal s(true);
   mainWindow=new MainWindow;
   mainWindow->setObjectName("figue");
   Settings::getRect(mainWindow, "figue");
 
-  openPageFiles(argc, argv);
-
+  openFiles(argc, argv);
 
   switch (mode) {
   case PageFile:
     break;
   case ObjectCount:
-    QTextStream(stdout) << mainWindow->sheet()->objects().count() << " objects" << endl;
+    QTextStream(stdout) << mainWindow->sheet()->objects().count() << " objects" << Qt::endl;
     delete mainWindow;
     return 0;
   case Curve:
@@ -360,11 +382,21 @@ int main(int argc, char ** argv)
   case BandsY:
     createBands(XAxis, mainWindow->sheet());
     break;
+  case Image:  // Mostly there to force linking with QGpGuiMath
+    createImage(mainWindow->sheet());
+    break;
   case Text:
     createText(mainWindow->sheet());
     break;
   }
 
+  if(mode==PageFile) {
+    exportOptions.selectObjects(mainWindow->sheet());
+    exportOptions.setLegend(mainWindow->sheet());
+    exportOptions.setColorMap(mainWindow->sheet());
+    exportOptions.addLayers(mainWindow->sheet());
+  }
+
   if(!makeupSheetFile.isEmpty()) {
     mainWindow->sheet()->restoreMakeUp(makeupSheetFile);
   }
@@ -374,14 +406,7 @@ int main(int argc, char ** argv)
   }
 
   if(!exportOptions.exportFile().isEmpty()) {
-    mainWindow->sheet()->exportFile(exportOptions.exportFile(),
-                                    exportOptions.exportFormat(),
-                                    exportOptions.dpi());
-    delete mainWindow;
-    return 0;
-  }
-
-  if(!exportOptions.exportFileGraph().isEmpty()) {
+    exportOptions.exportObjects(mainWindow->sheet());
     delete mainWindow;
     return 0;
   }
@@ -446,13 +471,20 @@ ApplicationHelp * help()
   h->addOption("-by, -bands-y","Reads \"min max value\" from stdin and draw bands parallel to y axis with color for value. "
                               "A ParallelBand layer is created. "
                               "Several plots are separated by blank lines or comments.");
+  h->addOption("-i, -image", "Create an image layer from stdin with format:\n"
+                            "  X Y [space for other properties in the future]\n"
+                            "  Text first line\n"
+                            "  ...\n"
+                            "  Text last line\n"
+                            "Several plots are separated by comment lines. If a line begins with '#', replace it by '\\#':\n"
+                            "  sed \"s/^#/\\\\#/g\"");
   h->addOption("-t, -text", "Create text labels from stdin with format:\n"
-                                   "  X Y [space for other properties in the future]\n"
-                                   "  Text first line\n"
-                                   "  ...\n"
-                                   "  Text last line\n"
-                                   "Several plots are separated by comment lines. If a line begins with '#', replace it by '\\#':\n"
-                                   "  sed \"s/^#/\\\\#/g\"");
+                            "  X Y [space for other properties in the future]\n"
+                            "  Text first line\n"
+                            "  ...\n"
+                            "  Text last line\n"
+                            "Several plots are separated by comment lines. If a line begins with '#', replace it by '\\#':\n"
+                            "  sed \"s/^#/\\\\#/g\"");
   h->addOption("-x-column <INDEX>", "For options '-c', '-mc', and '-cn', define the X column index (default=0).");
   h->addOption("-y-columns <INDEX>", "For options '-c', '-mc', and '-cn', define the Y column indexes (default=1). "
                                      "Several values separated by comas to plot several curves with the same X values");
@@ -461,6 +493,9 @@ ApplicationHelp * help()
   h->addOption("-value-column <INDEX>", "For options 'd', define the value column index (default=yColumn+1).");
   h->addOption("-name-columns <INDEX>", "For options '-c', '-mc', and '-cn', define the name column index (default=none). "
                                         "The number of indexes provided must be the same as in '-y-columns'.");
+  h->addOption("-layer-name <NAME>", "Sets name of the created layer.");
+  h->addOption("-x-abs-time-ref <REF>", "Specify the time reference for X axis with format 'yyyyMMddhhmmssz'.");
+  h->addOption("-y-abs-time-ref <REF>", "Specify the time reference for Y axis with format 'yyyyMMddhhmmssz'.");
   h->addGroup("Output","output");
   exportOptions.help(h);
   h->addOption("-cpp <n>","Number of curves per plot (option -c only).");
@@ -477,7 +512,7 @@ ApplicationHelp * help()
                                         "Seen 'gptime -h' for details about format definition.");
   h->addGroup("Merging pages","mergePage");
   h->addOption("-dx0 <DX>", "Adds DX shift when loading the first .page file");
-  h->addOption("-dy0 <DY>", "Adds DY shifts when loading the first .page file");
+  h->addOption("-dy0 <DY>", "Adds DY shift when loading the first .page file");
   h->addOption("-dx <DX>", "Adds DX shifts when loading various .page files");
   h->addOption("-dy <DY>", "Adds DY shifts when loading various .page files");
   h->addOption("-max-x <MAXX>", "Maximum value for X when loading various .page files (default=0, no maximum). "
@@ -517,33 +552,35 @@ void createText(GraphicSheet * sheet)
   CoreApplication::instance()->debugUserInterrupts(false);
   while(!sIn.atEnd()) {
     QString line=sIn.readLine();
-    if(line[0]=='\n' || line[0]=='#') {
-      TextEdit * t=new TextEdit;
-      t->setText(text);
-      t->setPrintXAnchor(x);
-      t->setPrintYAnchor(y);
-      sheet->addObject(t);
-      foreach(QString m,  exportOptions.makeupObjectFiles()) {
-        t->restoreMakeUp(m);
-      }
-      t->adjustSize();
-      text=QString();
-      properties=true;
-    } else {
-      if(properties) {
-        LineParser lp(line);
-        bool ok=true;
-        x=lp.toDouble(0, ok);
-        y=lp.toDouble(1, ok);
-        properties=false;
-      } else {
-        if(!text.isEmpty()) {
-          text+="\n";
+    if(!line.isEmpty()) {   // Does nothing for an empty line
+      if(line[0]=='\n' || line[0]=='#') {
+        TextEdit * t=new TextEdit;
+        t->setText(text);
+        t->setPrintXAnchor(x);
+        t->setPrintYAnchor(y);
+        sheet->addObject(t);
+        foreach(QString m,  exportOptions.makeupObjectFiles()) {
+          t->restoreMakeUp(m);
         }
-        if(line.startsWith("\\#")) {
-          text+=line.mid(1);
+        t->adjustSize();
+        text=QString();
+        properties=true;
+      } else {
+        if(properties) {
+          LineParser lp(line);
+          bool ok=true;
+          x=lp.toDouble(0, ok);
+          y=lp.toDouble(1, ok);
+          properties=false;
         } else {
-          text+=line;
+          if(!text.isEmpty()) {
+            text+="\n";
+          }
+          if(line.startsWith("\\#")) {
+            text+=line.mid(1);
+          } else {
+            text+=line;
+          }
         }
       }
     }
@@ -568,10 +605,6 @@ AxisWindow * createPlot()
   AxisWindow * w=new AxisWindow();
   w->setPrintXAnchor(1.0);
   w->setPrintYAnchor(1.0);
-  for(QStringList::const_iterator it=exportOptions.prependLayerFiles().begin();
-      it!=exportOptions.prependLayerFiles().end(); it++) {
-    w->graphContent()->prependLayers(*it);
-  }
   return w;
 }
 
@@ -583,13 +616,20 @@ void addPlot(GraphicSheet * sheet, AxisWindow * w, int iPlot)
   w->setPrintHeight(10.0);
   w->setRemovable(true);
   sheet->addObject(w);
-  for(QStringList::const_iterator it=exportOptions.appendLayerFiles().begin();
-      it!=exportOptions.appendLayerFiles().end(); it++) {
-    w->graphContent()->appendLayers(*it);
+  if(exportOptions.selectedObjects().isEmpty() ||
+     exportOptions.selectedObjects().contains(w->objectName())) {
+    for(QStringList::const_iterator it=exportOptions.appendLayerFiles().begin();
+        it!=exportOptions.appendLayerFiles().end(); it++) {
+      w->graphContents()->appendLayers(*it);
+    }
+    for(QStringList::const_iterator it=exportOptions.prependLayerFiles().begin();
+        it!=exportOptions.prependLayerFiles().end(); it++) {
+      w->graphContents()->prependLayers(*it);
+    }
   }
   w->setPrintXAnchor((iPlot%2)* w->printWidth()+1.0);
   w->setPrintYAnchor((iPlot/2)*w->printHeight()+1.0);
-  GraphContent * gc=w->graphContent();
+  GraphContents * gc=w->graphContents();
   r=gc->boundingRect();
   r.enlarge(0.05, gc->scaleX().sampling(), gc->scaleY().sampling());
   w->xAxis()->setRange(r.x1(), r.x2());
@@ -612,26 +652,22 @@ void addPlot(GraphicSheet * sheet, AxisWindow * w, int iPlot)
     w->restoreMakeUp(m);
   }
   sheet->moveObject(w);
-  if(!exportOptions.exportFileGraph().isEmpty()) {
-    w->exportFile(exportOptions.exportFileGraph(iPlot),
-                  exportOptions.exportFormat(),
-                  exportOptions.dpi());
-  }
 }
 
-LineLayer * createCurvePlot(Legend * legend)
+LineLayer * createCurvePlot(Legend& legend)
 {
   TRACE;
   AxisWindow * w=createPlot();
   LineLayer * plot=new LineLayer(w);
+  if(!layerName.isEmpty()) {
+    plot->setObjectName(layerName);
+  }
   plot->setReferenceLine(new PlotLine);
   int n=yColumns.count();
   for(int i=0; i<n; i++) {
     AbstractLine * line=plot->addLine();
-    if(legend) {
-      line->setPen(legend->pen(i));
-      line->setSymbol(legend->symbol(i));
-    }
+    line->setPen(legend.pen(i));
+    line->setSymbol(legend.symbol(i));
   }
   return plot;
 }
@@ -639,18 +675,16 @@ LineLayer * createCurvePlot(Legend * legend)
 void createCurve(GraphicSheet * sheet)
 {
   TRACE;
-  Legend * legend;
+  Legend legend;
   if(exportOptions.legendFile().isEmpty()) {
-    legend=nullptr;
+    legend.generate(0, 20, ColorPalette::defaultCategorical, ColorPalette::Categorical);
   } else {
-    legend=new Legend;
     XMLErrorReport xmler(XMLErrorReport::Read | XMLErrorReport::NoMessageBox);
     xmler.setTitle(tr("Load legend"));
     xmler.setFileName(exportOptions.legendFile());
     XMLSciFigs s;
-    if(!xmler.exec(s.restoreFile(exportOptions.legendFile(), legend, XMLSciFigs::Data))) {
-      delete legend;
-      legend=nullptr;
+    if(!xmler.exec(s.restoreFile(exportOptions.legendFile(), &legend, XMLSciFigs::Data))) {
+      return;
     }
   }
   // Create plot and a first curve
@@ -684,10 +718,8 @@ void createCurve(GraphicSheet * sheet)
         } else {
           for(int i=0; i<nColumns; i++) {
             AbstractLine * line=plot->addLine();
-            if(legend) {
-              line->setPen(legend->pen(iCurve+i));
-              line->setSymbol(legend->symbol(iCurve+i));
-            }
+            line->setPen(legend.pen(iCurve+i));
+            line->setSymbol(legend.symbol(iCurve+i));
             curve[i]=&static_cast<PlotLine *>(plot->line(iCurve+i))->curve();
           }
           iCurve+=nColumns;
@@ -712,24 +744,24 @@ void createCurve(GraphicSheet * sheet)
   }
   CoreApplication::instance()->debugUserInterrupts(true);
   delete [] buf;
-  delete legend;
   delete [] curve;
   addPlot(sheet, w, iPlot);
 }
 
-NameLineLayer * createCurveNamePlot(Legend * legend)
+NameLineLayer * createCurveNamePlot(Legend& legend)
 {
   TRACE;
   AxisWindow * w=createPlot();
   NameLineLayer * plot=new NameLineLayer(w);
+  if(!layerName.isEmpty()) {
+    plot->setObjectName(layerName);
+  }
   plot->setReferenceLine(new NameLine);
   int n=yColumns.count();
   for(int i=0; i<n; i++) {
     AbstractLine * line=plot->addLine();
-    if(legend) {
-      line->setPen(legend->pen(0) );
-      line->setSymbol(legend->symbol(0) );
-    }
+    line->setPen(legend.pen(0) );
+    line->setSymbol(legend.symbol(0) );
   }
   return plot;
 }
@@ -737,18 +769,16 @@ NameLineLayer * createCurveNamePlot(Legend * legend)
 void createCurveName(GraphicSheet * sheet)
 {
   TRACE;
-  Legend * legend;
+  Legend legend;
   if(exportOptions.legendFile().isEmpty()) {
-    legend=nullptr;
+    legend.generate(0, 20, ColorPalette::defaultCategorical, ColorPalette::Categorical);
   } else {
-    legend=new Legend;
     XMLErrorReport xmler(XMLErrorReport::Read | XMLErrorReport::NoMessageBox);
     xmler.setTitle(tr("Load legend"));
     xmler.setFileName(exportOptions.legendFile());
     XMLSciFigs s;
-    if(!xmler.exec(s.restoreFile(exportOptions.legendFile(), legend, XMLSciFigs::Data))) {
-      delete legend;
-      legend=nullptr;
+    if(!xmler.exec(s.restoreFile(exportOptions.legendFile(), &legend, XMLSciFigs::Data))) {
+      return;
     }
   }
   // Create plot and a first curve
@@ -782,10 +812,8 @@ void createCurveName(GraphicSheet * sheet)
         } else {
           for(int i=0; i<nColumns; i++) {
             AbstractLine * line=plot->addLine();
-            if(legend && iCurve<legend->count()) {
-              line->setPen(legend->pen(iCurve) );
-              line->setSymbol(legend->symbol(iCurve) );
-            }
+            line->setPen(legend.pen(iCurve) );
+            line->setSymbol(legend.symbol(iCurve) );
             curve[i]=&static_cast<NameLine *>(plot->line(iCurve+i))->curve();
           }
           iCurve+=nColumns;
@@ -811,7 +839,6 @@ void createCurveName(GraphicSheet * sheet)
   }
   CoreApplication::instance()->debugUserInterrupts(true);
   delete [] buf;
-  delete legend;
   delete [] curve;
   addPlot(sheet, w, iPlot);
 }
@@ -821,6 +848,9 @@ IrregularGrid2DPlot * createGridPlot(ColorMap * pal)
   TRACE;
   AxisWindow * w=createPlot();
   IrregularGrid2DPlot * plot=new IrregularGrid2DPlot(w);
+  if(!layerName.isEmpty()) {
+    plot->setObjectName(layerName);
+  }
   if(pal) {
     plot->setColorMap(*pal);
   }
@@ -835,7 +865,7 @@ void createGrid(GraphicSheet * sheet)
     pal=nullptr;
   } else {
     pal=new ColorMap;
-    pal->generateColorScale(20, ColorPalette::Hsv);
+    pal->generate(0, 19);
     XMLErrorReport xmler(XMLErrorReport::Read | XMLErrorReport::NoMessageBox);
     xmler.setTitle(tr("Load palette"));
     xmler.setFileName(exportOptions.colorMapFile());
@@ -877,6 +907,9 @@ XYValuePlot * createDotsPlot(ColorMap * pal)
   w->setPrintXAnchor(1.0);
   w->setPrintYAnchor(1.0);
   XYValuePlot * plot=new XYValuePlot(w);
+  if(!layerName.isEmpty()) {
+    plot->setObjectName(layerName);
+  }
   if(pal) {
     plot->setColorMap(*pal);
   }
@@ -888,7 +921,6 @@ class ValueDot : public Point2D
 {
 public:
   ValueDot() {_value=0.0;}
-  ValueDot(const ValueDot& o) : Point2D(o) {_value=o._value;}
 
   bool operator<(const ValueDot& o) const {
     return _value>o._value;
@@ -899,15 +931,15 @@ private:
   double _value;
 };
 
-void addDotPlot(QVector<ValueDot>& dots, XYValuePlot * plot, int iPlot,
+void addDotPlot(VectorList<ValueDot>& dots, XYValuePlot * plot, int iPlot,
                  GraphicSheet * sheet)
 {
   std::sort(dots.begin(), dots.end());
   AxisWindow * w=plot->graph();
-  QVector<double> * x=new QVector<double>;
-  QVector<double> * y=new QVector<double>;
-  QVector<double> * val=new QVector<double>;
-  for(QVector<ValueDot>::iterator it=dots.begin(); it!=dots.end(); it++) {
+  VectorList<double> * x=new VectorList<double>;
+  VectorList<double> * y=new VectorList<double>;
+  VectorList<double> * val=new VectorList<double>;
+  for(VectorList<ValueDot>::iterator it=dots.begin(); it!=dots.end(); it++) {
     ValueDot& d=*it;
     val->append(d.value());
     x->append(d.x());
@@ -932,7 +964,7 @@ void createDots(GraphicSheet * sheet)
     pal=nullptr;
   } else {
     pal=new ColorMap;
-    pal->generateColorScale(20, ColorPalette::Hsv);
+    pal->generate(0, 19);
     XMLErrorReport xmler(XMLErrorReport::Read | XMLErrorReport::NoMessageBox);
     xmler.setTitle(tr("Load palette"));
     xmler.setFileName(exportOptions.colorMapFile());
@@ -944,7 +976,7 @@ void createDots(GraphicSheet * sheet)
   }
   // Create plot
   XYValuePlot * plot=createDotsPlot(pal);
-  QVector<ValueDot> dots;
+  VectorList<ValueDot> dots;
   int iPlot=0;
   // Read stdin for dots until encountering a blank line
   int n=256;
@@ -991,6 +1023,9 @@ CircleViewer * createCirclePlot()
   TRACE;
   AxisWindow * w=createPlot();
   CircleViewer * plot=new CircleViewer(w);
+  if(!layerName.isEmpty()) {
+    plot->setObjectName(layerName);
+  }
   return plot;
 }
 
@@ -1034,6 +1069,9 @@ XYValueLines * createManyCurvesPlot(ColorMap * pal)
   TRACE;
   AxisWindow * w=createPlot();
   XYValueLines * plot=new XYValueLines(w, true);
+  if(!layerName.isEmpty()) {
+    plot->setObjectName(layerName);
+  }
   if(pal) {
     plot->setColorMap(*pal);
   }
@@ -1041,11 +1079,10 @@ XYValueLines * createManyCurvesPlot(ColorMap * pal)
 }
 
 // Temporary storage before sorting curve by decreasing value
-class ValueCurve : public QVector<Point2D>
+class ValueCurve : public VectorList<Point2D>
 {
 public:
   ValueCurve() {_value=0.0;}
-  ValueCurve(const ValueCurve& o) : QVector<Point2D>(o) {_value=o._value;}
 
   bool operator<(const ValueCurve& o) const {
     return _value>o._value;
@@ -1056,7 +1093,7 @@ private:
   double _value;
 };
 
-void addManyCurvePlot(QVector<ValueCurve>& curves, XYValueLines * plot, int iPlot,
+void addManyCurvePlot(VectorList<ValueCurve>& curves, XYValueLines * plot, int iPlot,
                       GraphicSheet * sheet, ConsoleProgress * progress)
 {
    if(progress) {
@@ -1068,9 +1105,9 @@ void addManyCurvePlot(QVector<ValueCurve>& curves, XYValueLines * plot, int iPlo
     progress->setCaption("Definitive storage... ");
     progress->setMaximum(curves.count());
   }
-  QVector<int> pointCounts;
-  QVector<Point2D> points;
-  QVector<double> val;
+  VectorList<int> pointCounts;
+  VectorList<Point2D> points;
+  VectorList<double> val;
   int n=curves.count();
   // Calculate capacity for points
   int totalCount=0;
@@ -1080,7 +1117,7 @@ void addManyCurvePlot(QVector<ValueCurve>& curves, XYValueLines * plot, int iPlo
     pointCounts.append(c.count());
     totalCount += c.count();
   }
-  // Low level transfer for maximum speed. Using QVector::operator+= was too slow
+  // Low level transfer for maximum speed. Using VectorList::operator+= was too slow
   points.resize(totalCount);
   Point2D * destPtr=points.data();
   for(int i=0; i<n; i++) {
@@ -1111,7 +1148,7 @@ void createManyCurves(GraphicSheet * sheet)
     pal=nullptr;
   } else {
     pal=new ColorMap;
-    pal->generateColorScale(20, ColorPalette::Hsv);
+    pal->generate(0, 19);
     XMLErrorReport xmler(XMLErrorReport::Read | XMLErrorReport::NoMessageBox);
     xmler.setTitle(tr("Load palette"));
     xmler.setFileName(exportOptions.colorMapFile());
@@ -1123,13 +1160,14 @@ void createManyCurves(GraphicSheet * sheet)
   }
   // Create plot
   XYValueLines * plot=createManyCurvesPlot(pal);
-  QVector<ValueCurve> curves(1);
+  VectorList<ValueCurve> curves(1);
   int iPlot=0;
   // Read stdin for points until encountering a blank line or comment
   ConsoleProgress progress;
   progress.setCaption("Loading curves... ");
   progress.setMaximum(0);
   QTextStream sIn(stdin);
+  bool ok=true;
   CoreApplication::instance()->debugUserInterrupts(false);
   while(!sIn.atEnd()) {
     QString str=sIn.readLine();
@@ -1137,7 +1175,6 @@ void createManyCurves(GraphicSheet * sheet)
       if(str[0]=='\n' || str[0]=='#') {
         if(curves.last().count()>0) {
           if(curves.count()==curvesPerPlot) {
-            qDebug() << "curvesPerPlot";
             addManyCurvePlot(curves, plot, iPlot, sheet, &progress);
             iPlot++;
             curves.clear();
@@ -1158,10 +1195,23 @@ void createManyCurves(GraphicSheet * sheet)
         StringSection f;
         f=content.nextField(ptr);
         double x, y;
-        if(f.isValid()) x=f.toDouble(); else break;
+        if(f.isValid()) {
+          x=f.toDouble(ok);
+        } else {
+          break;
+        }
         f=content.nextField(ptr);
-        if(f.isValid()) y=f.toDouble(); else break;
-        curves.last().append(Point2D(x,y));
+        if(f.isValid()) {
+          y=f.toDouble(ok);
+        } else {
+          break;
+        }
+        if(ok) {
+          curves.last().append(Point2D(x,y));
+        } else {
+          App::log(tr("Bad conversion to real after reading %1 points.\n").arg(curves.last().size()));
+          return;
+        }
       }
     }
   }
@@ -1181,6 +1231,9 @@ ParallelBands * createBandsPlot()
   TRACE;
   AxisWindow * w=createPlot();
   ParallelBands * plot=new ParallelBands(w);
+  if(!layerName.isEmpty()) {
+    plot->setObjectName(layerName);
+  }
   return plot;
 }
 
@@ -1192,7 +1245,7 @@ void createBands(AxisType a, GraphicSheet * sheet)
     map=nullptr;
   } else {
     map=new ColorMap;
-    map->generateColorScale(20, ColorPalette::Hsv);
+    map->generate(0, 19);
     XMLErrorReport xmler(XMLErrorReport::Read | XMLErrorReport::NoMessageBox);
     xmler.setTitle(tr("Load palette"));
     xmler.setFileName(exportOptions.colorMapFile());
@@ -1209,6 +1262,7 @@ void createBands(AxisType a, GraphicSheet * sheet)
   // Read stdin for bands until encountering a blank line
   int n=256;
   char * buf=new char[n];
+  bool ok=true;
   CoreApplication::instance()->debugUserInterrupts(false);
   while(!feof(stdin)) {
     File::readLine(buf, n, stdin);
@@ -1228,13 +1282,13 @@ void createBands(AxisType a, GraphicSheet * sheet)
       double min, max;
       Brush b(Qt::SolidPattern);
       if(f.isValid()) {
-        min=f.toDouble();
+        min=f.toDouble(ok);
       } else {
         continue;
       }
       f=content.nextField(ptr);
       if(f.isValid()) {
-        max=f.toDouble();
+        max=f.toDouble(ok);
       } else {
         continue;
       }
@@ -1242,10 +1296,14 @@ void createBands(AxisType a, GraphicSheet * sheet)
         f=content.nextField(ptr);
         if(f.isValid()) {
           QColor col;
-          guiColor(map->color(f.toDouble()), col);
+          guiColor(map->color(f.toDouble(ok)), col);
           b.setColor(col);
         }
       }
+      if(!ok) {
+        App::log(tr("Bad conversion to real after reading %1 bands.\n").arg(plot->count()));
+        return;
+      }
       plot->addBand(min, max, b);
     }
   }
@@ -1261,3 +1319,47 @@ void createBands(AxisType a, GraphicSheet * sheet)
   delete map;
   sheet->autoResizeContent();
 }
+
+
+ImageLayer * createImagePlot()
+{
+  TRACE;
+  AxisWindow * w=createPlot();
+  ImageLayer * plot=new ImageLayer(w);
+  if(!layerName.isEmpty()) {
+    plot->setObjectName(layerName);
+  }
+  return plot;
+}
+
+void createImage(GraphicSheet * sheet)
+{
+  TRACE;
+  // Create plot
+  ImageLayer * plot=nullptr;
+  int iPlot=0;
+  // Read stdin for image file names
+  int n=256;
+  char * buf=new char[n];
+  CoreApplication::instance()->debugUserInterrupts(false);
+  while(!feof(stdin)) {
+    File::readLine(buf, n, stdin);
+    if(buf[0]!='\n' && buf[0]!='#') {
+      AxisWindow * w=plot->graph();
+      addPlot(sheet, w, iPlot);
+      iPlot++;
+      plot=createImagePlot();
+      plot->loadImage(buf);
+    }
+  }
+  CoreApplication::instance()->debugUserInterrupts(true);
+  delete [] buf;
+  if(plot) {
+    AxisWindow * w=plot->graph();
+    addPlot(sheet, w, iPlot);
+    sheet->moveObject(w);
+  } else {
+    delete plot->graph();
+  }
+  sheet->autoResizeContent();
+}
