@@ -44,7 +44,7 @@ public:
 
   void addActions();
   void setMode(Mode m);
-  void select(const QRegExp& exp);
+  void select(const QRegularExpression& exp);
 public slots:
   void acceptDrop(const QPoint& pos, bool& ok);
   void getSelection(SubSignalPool& sel);
@@ -65,7 +65,7 @@ protected:
   virtual void mouseDoubleClickEvent (QMouseEvent * e);
 private:
   QList<AbstractSignalGroup *> getSelection(bool readWriteOnly, bool warn=false);
-  void select(AbstractSignalGroup * parent, const QRegExp& exp);
+  void select(AbstractSignalGroup * parent, const QRegularExpression& exp);
   inline SignalGroupItem * model() const;
 
   Mode _mode;
