@@ -37,7 +37,7 @@ class ComplexTableModel: public QAbstractTableModel
 public:
   ComplexTableModel(QObject * parent) : QAbstractTableModel(parent) {_values=0;}
 
-  void setValues(QVector<Complex> * v);
+  void setValues(VectorList<Complex> * v);
 
   virtual int rowCount(const QModelIndex &) const {return _values ? _values->count() : 0;}
   virtual int columnCount(const QModelIndex &) const {return 2;}
@@ -54,10 +54,10 @@ public:
   void beginResetModel() {QAbstractTableModel::beginResetModel();}
   void endResetModel() {QAbstractTableModel::endResetModel();}
 private:
-  QVector<Complex> * _values;
+  VectorList<Complex> * _values;
 };
 
-void ComplexTableModel::setValues(QVector<Complex> * v)
+void ComplexTableModel::setValues(VectorList<Complex> * v)
 {
   beginResetModel();
   _values=v;
