@@ -44,7 +44,6 @@
 #include "SortKeys.h"
 #include "SourceCoordinates.h"
 #include "StationCoordinates.h"
-#include "SubtractSignals.h"
 #include "ToolFactory.h"
 #include "ViewParamEditor.h"
 #include "WaveformConsole.h"
@@ -72,11 +71,14 @@ MainWindow::MainWindow(QWidget *parent, Qt::WindowFlags f)
   connect (this, SIGNAL(asyncIncreaseProgressValue(int)), this, SLOT(increaseProgressValue(int)), Qt::QueuedConnection);
   connect (this, SIGNAL(asyncShowMessage(QString)), this, SLOT(showMessage( QString) ), Qt::QueuedConnection);
 
+  QDockWidget::DockWidgetFeatures features=QDockWidget::DockWidgetClosable |
+                                           QDockWidget::DockWidgetMovable |
+                                           QDockWidget::DockWidgetFloatable;
   QDockWidget * gDock=new DockWidget(this);
   gDock->setObjectName("Groups");
   gDock->setWindowTitle(tr("Groups"));
-  gDock->setFeatures(QDockWidget::AllDockWidgetFeatures);
-  gDock->setAllowedAreas(Qt::LeftDockWidgetArea | Qt::RightDockWidgetArea);
+  gDock->setFeatures(features);
+  gDock->setAllowedAreas(Qt::AllDockWidgetAreas);
   _groupList=new GroupWidget(gDock);
   gDock->setWidget(_groupList);
   addDockWidget(Qt::LeftDockWidgetArea, gDock);
@@ -84,8 +86,8 @@ MainWindow::MainWindow(QWidget *parent, Qt::WindowFlags f)
   QDockWidget * fDock=new DockWidget(this);
   fDock->setObjectName("Files");
   fDock->setWindowTitle(tr("Files"));
-  fDock->setFeatures (QDockWidget::AllDockWidgetFeatures);
-  fDock->setAllowedAreas(Qt::LeftDockWidgetArea | Qt::RightDockWidgetArea);
+  fDock->setFeatures(features);
+  fDock->setAllowedAreas(Qt::AllDockWidgetAreas);
   _fileList=new FileView(fDock);
   fDock->setWidget(_fileList);
   addDockWidget(Qt::LeftDockWidgetArea, fDock);
@@ -94,9 +96,10 @@ MainWindow::MainWindow(QWidget *parent, Qt::WindowFlags f)
   QDockWidget * eDock=new DockWidget(this);
   eDock->setObjectName("Events");
   eDock->setWindowTitle(tr("Events"));
-  eDock->setFeatures (QDockWidget::AllDockWidgetFeatures);
-  eDock->setAllowedAreas(Qt::LeftDockWidgetArea | Qt::RightDockWidgetArea);
+  eDock->setFeatures (features);
+  eDock->setAllowedAreas(Qt::AllDockWidgetAreas);
   _eventList=new SeismicEventWidget(eDock);
+  connect(_eventList, SIGNAL(eventsChanged()), this, SLOT(updateGraphicEvents()));
   eDock->setWidget(_eventList);
   addDockWidget(Qt::LeftDockWidgetArea, eDock);
   tabifyDockWidget(fDock, eDock);
@@ -104,7 +107,7 @@ MainWindow::MainWindow(QWidget *parent, Qt::WindowFlags f)
   QDockWidget * cDock=new DockWidget(this);
   cDock->setObjectName("WaveformConsole");
   cDock->setWindowTitle(tr("Waveform console"));
-  cDock->setFeatures (QDockWidget::AllDockWidgetFeatures);
+  cDock->setFeatures (features);
   cDock->setAllowedAreas(Qt::AllDockWidgetAreas);
   _waveformConsole=new WaveformConsole (cDock);
   cDock->setWidget(_waveformConsole);
@@ -113,7 +116,7 @@ MainWindow::MainWindow(QWidget *parent, Qt::WindowFlags f)
   QDockWidget * logDock=new QDockWidget(this);
   logDock->setObjectName("Log");
   logDock->setWindowTitle(tr("Log"));
-  logDock->setFeatures (QDockWidget::AllDockWidgetFeatures);
+  logDock->setFeatures (features);
   logDock->setAllowedAreas(Qt::AllDockWidgetAreas);
   LogWidget * logs=new LogWidget(logDock);
   _log=logs->addView(QThread::currentThread(), tr("Messages"));
@@ -131,8 +134,9 @@ MainWindow::MainWindow(QWidget *parent, Qt::WindowFlags f)
   {
     GeopsyPluginSettings reg;
     liveUpdate->addPlugins(reg.pluginList());
-    statusBar()->addPermanentWidget(liveUpdate, 0);
   }
+  statusBar()->addPermanentWidget(liveUpdate, 0);
+  liveUpdate->getLatestVersions();
 
   _progressBar=new ProgressBar(statusBar());
   _progressBar->setMaximumWidth(100);
@@ -305,7 +309,7 @@ void MainWindow::openDB(QString fileName)
     }
   }
   if(fileName.isEmpty()) {
-    fileName=Message::getOpenFileName(tr("Open a database"),  tr("Geopsy database (*.gpy *.sdb)"));
+    fileName=Message::getOpenFileName(tr("Open a database"), tr("Geopsy database (*.gpy *.sdb)"));
   }
   if(fileName.isEmpty()) {
     return;
@@ -446,14 +450,18 @@ void MainWindow::closeEvent(QCloseEvent * event)
   }
 }
 
-void MainWindow::quit(bool force)
+void MainWindow::quit()
 {
   TRACE;
-  if(force || warnBeforeClear(tr("Quitting ..."))) {
-    if(closeAllSubWindowsFromAllTabs()) {
-      qApp->quit();
-    }
+#if(QT_VERSION<QT_VERSION_CHECK(6, 0, 0))
+  if(warnBeforeClear(tr("Quitting ..."))) {
+#endif
+  if(closeAllSubWindowsFromAllTabs()) {
+    qApp->quit();
   }
+#if(QT_VERSION<QT_VERSION_CHECK(6, 0, 0))
+  }
+#endif
 }
 
 void MainWindow::clearAll()
@@ -513,7 +521,6 @@ bool MainWindow::warnBeforeClear(QString action)
   } else if(Message::question(MSG_ID, action, tr("Are you sure?"), Message::no(), Message::yes())==Message::Answer0) {
     return false;
   }
-
   return true;
 }
 
@@ -859,6 +866,11 @@ void MainWindow::addEditActions()
   connect(a, SIGNAL(triggered()), this, SLOT(setReceivers()));
   m->addAction(a);
 
+  a=new QAction(tr("Add gaps from NaN"), this);
+  a->setStatusTip(tr("Add gaps when NaN values are encountered"));
+  connect(a, SIGNAL(triggered()), this, SLOT(gapsFromNaN()));
+  m->addAction(a);
+
   m->addSeparator();
 
   a=new QAction(tr("New group(s)"), this);
@@ -1005,7 +1017,7 @@ void MainWindow::sort()
   Settings::getWidget(d);
   if(d->exec()==QDialog::Accepted) {
     Settings::setWidget(d);
-    d->getKeys();
+    d->save();
     _subPoolWin->subPool().sort();
     _subPoolWin->subPoolUpdate();
   }
@@ -1028,7 +1040,7 @@ void MainWindow::setHeader()
 void MainWindow::setReceivers()
 {
   TRACE;
-  if(!_subPoolWin) return ;
+  if(!_subPoolWin) return;
   StationCoordinates * d=new StationCoordinates(this);
   Settings::getWidget(d);
   QString log;
@@ -1059,6 +1071,12 @@ void MainWindow::setReceivers()
   delete d;
 }
 
+void MainWindow::gapsFromNaN()
+{
+  if(!_subPoolWin) return;
+  _subPoolWin->subPool().gapsFromNaN();
+}
+
 void MainWindow::createNewGroup()
 {
   TRACE;
@@ -1280,3 +1298,16 @@ void MainWindow::exportSignal()
   }
   delete d;
 }
+
+void MainWindow::updateGraphicEvents()
+{
+  TRACE;
+  QList<MultiDocumentSubWindow *> windows=subWindowList();
+  for(QList<MultiDocumentSubWindow *>::iterator it=windows.begin(); it!=windows.end(); it++) {
+    GraphicWindow * g=qobject_cast<GraphicWindow *>((*it)->widget());
+    if(g) {
+      g->updateEvents();
+    }
+  }
+}
+
