@@ -39,7 +39,7 @@ MapWindow::MapWindow(QWidget* parent)
   TRACE;
   setObjectName("map");
   QVBoxLayout * l=new QVBoxLayout(this);
-  l->setMargin(1);
+  l->setContentsMargins(1, 1, 1, 1);
   _map=new ArrayMap(this);
   l->addWidget(_map);
   _map->setObjectName("map");
@@ -57,14 +57,14 @@ MapWindow::MapWindow(QWidget* parent)
   QAction * a=new QAction(tr("Select from &coordinates"), this);
   a->setToolTip(tr("Select stations that match with coordinates read from a file"));
   connect(a, SIGNAL(triggered(bool)), this, SLOT(selectFromCoordinates()));
-  _map->graphContent()->QWidget::addAction(a);
+  _map->graphContents()->QWidget::addAction(a);
 
   // Drag and drop to transfert signal selection
-  SigSelectionDnD * sigDnD=new SigSelectionDnD(_map->graphContent());
+  SigSelectionDnD * sigDnD=new SigSelectionDnD(_map->graphContents());
   connect(sigDnD,SIGNAL(selectionDropped(QWidget *, const SubSignalPool&)), this, SLOT(addSignals(QWidget *, const SubSignalPool&)));
   connect(sigDnD,SIGNAL(getSelection(SubSignalPool&)), this,SLOT(getSelection(SubSignalPool&)));
-  connect(_map->graphContent(),SIGNAL(mouseTrackingBegin()), sigDnD,SLOT(disableFilter()));
-  connect(_map->graphContent(),SIGNAL(mouseTrackingEnd()), sigDnD,SLOT(enableFilter()));
+  connect(_map->graphContents(),SIGNAL(mouseTrackingBegin()), sigDnD,SLOT(disableFilter()));
+  connect(_map->graphContents(),SIGNAL(mouseTrackingEnd()), sigDnD,SLOT(enableFilter()));
 
   // Make up
   if(GeopsyCoreEngine::instance()->preferences()->restoreMapMakeUp() &&
