@@ -38,6 +38,8 @@ public:
   ~SeismicEventWidget();
 
   void addActions() {eventView->addActions();}
+signals:
+  void eventsChanged();
 };
 
 #endif // SEISMICEVENTWIDGET_H
