@@ -105,7 +105,11 @@ bool SigSelectionDnD::dragMoveEvent(QDragMoveEvent * e)
   TRACE;
   if(_dropEnabled && e->mimeData()->hasFormat("geopsy/x-signal-selection") && e->source()!=_src) {
     bool ok=true;
+#if(QT_VERSION >= QT_VERSION_CHECK(6, 0, 0))
+    emit acceptDrop(e->position().toPoint(), ok);
+#else
     emit acceptDrop(e->pos(), ok);
+#endif
     if(ok) {
       e->acceptProposedAction();
     }
