@@ -50,12 +50,12 @@ signals:
   void getSelection(SubSignalPool& sel);
   void selectionDropped(QWidget * parent, const SubSignalPool& sel);
 protected:
-  virtual bool dragEnterEvent(QDragEnterEvent * e);
-  virtual bool dragMoveEvent(QDragMoveEvent * e);
-  virtual bool dropEvent(QDropEvent * e);
-  virtual bool mousePressEvent(QMouseEvent * e);
-  virtual bool mouseReleaseEvent(QMouseEvent * e);
-  virtual bool mouseMoveEvent(QMouseEvent * e);
+  bool dragEnterEvent(QDragEnterEvent * e);
+  bool dragMoveEvent(QDragMoveEvent * e);
+  bool dropEvent(QDropEvent * e);
+  bool mousePressEvent(QMouseEvent * e);
+  bool mouseReleaseEvent(QMouseEvent * e);
+  bool mouseMoveEvent(QMouseEvent * e);
 
   QWidget * _src;
   QPoint _mousePressPos;
