@@ -29,16 +29,13 @@
 
 #include <QGpGuiTools.h>
 
-class SignalTableDelegate : public QItemDelegate
+class SignalTableDelegate : public ItemDelegate
 {
 public:
-  SignalTableDelegate(QObject *parent=0) : QItemDelegate(parent) {}
+  SignalTableDelegate(QObject *parent=nullptr) : ItemDelegate(parent) {}
 
-  virtual QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem& option,
-                                const QModelIndex& index) const;
-  virtual void setEditorData(QWidget *editor, const QModelIndex& index) const;
-  virtual void setModelData(QWidget *editor, QAbstractItemModel * model,
-                            const QModelIndex& index) const;
+  QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem& option,
+                        const QModelIndex& index) const;
 };
 
 #endif // SIGNALTABLEDELEGATE_H
