@@ -32,11 +32,13 @@
 
 #define TOOLFACTORY_NPOPULAR 5
 
+class MainWindow;
+
 class ToolFactory : public QObject
 {
   Q_OBJECT
 public:
-  ToolFactory(QObject * parent=nullptr);
+  ToolFactory(MainWindow * parent);
   ~ToolFactory();
 
   void addActions(QWidget * w);
