@@ -50,6 +50,7 @@ static QString streamSelection;
 static qint16 serverPort=18000;
 
 int modeGroupList(int argc, char ** argv);
+int modeRecentDatabaseList(int argc, char ** argv);
 int modeGui(int argc, char ** argv, bool seedlinkView);
 int modeExport(int argc, char ** argv, QString exportFile);
 int modeWaveform(int argc, char ** argv, QString exportFile);
@@ -65,7 +66,7 @@ int main(int argc, char ** argv)
 {
   skipOpenBlasMultiThreading();
   // Basic options: selection of the main modes
-  enum Mode {Gui, Export, Waveform, GroupList, SeedlinkView};
+  enum Mode {Gui, Export, Waveform, GroupList, RecentDatabaseList, SeedlinkView};
   Mode mode=Gui;
   QString toolName, exportFile, waveformFile;
 
@@ -106,6 +107,13 @@ int main(int argc, char ** argv)
           groupName=argv[i];
         }
         mode=GroupList;
+      } else if(arg=="-recent-dbs") {
+        mode=RecentDatabaseList;
+      } else if(arg=="-import-dir") {
+        QString key=Message::filterKey(tr("Signal file (*)"));
+        CoreApplication a(argc, argv, help);
+        App::log(Settings::getPath(key)+"\n");
+        return 0;
       } else if(arg=="-server") {
         CoreApplication::checkOptionArg(i, argc, argv);
         mode=SeedlinkView;
@@ -160,6 +168,8 @@ int main(int argc, char ** argv)
   switch(mode) {
   case GroupList:
     return modeGroupList(argc, argv);
+  case RecentDatabaseList:
+    return modeRecentDatabaseList(argc, argv);
   case SeedlinkView:
   case Gui:
     break;
@@ -180,14 +190,18 @@ int modeGui(int argc, char ** argv, bool seedlinkView)
     return 2;
   }
 
-  SciFigsGlobal s;
+  SciFigsGlobal s(true);
   // Splash screen with licence
   GeopsyAbout * splash=new GeopsyAbout(nullptr, Qt::SplashScreen | Qt::WindowStaysOnTopHint);
   splash->setAttribute(Qt::WA_DeleteOnClose);
+  splash->show();
+#if(QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+  QRect rootRect=splash->screen()->geometry();
+#else
   QRect rootRect=QApplication::desktop()->geometry();
+#endif
   QPoint p=rootRect.center();
   splash->move(p.x()-splash->width()/2, p.y()-splash->height()/2);
-  splash->show();
   while(!splash->painted()) {
     qApp->processEvents(QEventLoop::ExcludeUserInputEvents);
   }
@@ -208,7 +222,7 @@ int modeGui(int argc, char ** argv, bool seedlinkView)
     w->database()->load(database, groupName, signalFiles, format, true);
   }
 
- int appReturn=qApp->exec();
+  int appReturn=qApp->exec();
   return appReturn;
 }
 
@@ -360,6 +374,25 @@ int modeGroupList(int argc, char ** argv)
   }
 }
 
+int modeRecentDatabaseList(int argc, char ** argv)
+{
+  CoreApplication a(argc, argv, help);
+
+  if(!CoreApplication::checkRemainingArgs(argc,argv)) {
+    return 2;
+  }
+  QStringList docs=Settings::getHistory("RecentDocuments");
+  for(QStringList::iterator it=docs.begin(); it!=docs.end(); ++it) {
+    QFileInfo fi(*it);
+    if(fi.exists()) {
+      App::log(fi.absoluteFilePath()+"\n");
+    } else {
+      Settings::removeHistory("RecentDocuments", *it);
+    }
+  }
+  return 0;
+}
+
 SignalFileFormat getExportFormat(QString fStr)
 {
   SignalFileFormat format=SignalFileFormat::fromName(fStr);
@@ -436,6 +469,8 @@ ApplicationHelp * help()
   h->addGroup("Geopsy","geopsy");
   h->addOption( "-import-format <FORMAT>", "Set file format for files to import (FILE1, FILE2,..., default=Automatic)." );
   h->addOption( "-db <FILE.gpy>", "Open database contained in FILE.gpy" );
+  h->addOption( "-recent-dbs", "Lists recently accessed databases." );
+  h->addOption( "-import-dir", "Returns the current directory for importing signal files." );
   h->addOption( "-group <GROUP>", "Use group of signals named GROUP" );
   h->addOption( "-groups [<PARENT>]", "List the groups available in current database. If PARENT is specified, the groups contained by PARENT are listed." );
   h->addOption( "-export-formats", "List the signal file formats Geopsy can export" );
@@ -467,7 +502,7 @@ ApplicationHelp * help()
   h->addOption("-debug-tools","Test available tools and exit." );
   h->addOption("-add-tool-path <PATH>","Add PATH to the list of paths to search for tools." );
   GeopsyCoreEngine gp;
-  ToolFactory tools;
+  ToolFactory tools(nullptr);
   tools.setHelp(h);
   return h;
 }
