@@ -29,7 +29,8 @@
 
 #include "FKTimeWindows.h"
 
-const Color FKTimeWindows::_highLightedColor(255, 166, 166);
+const Color FKTimeWindows::_highLightedColor(10, 255, 166, 166);
+
 /*!
 
 */
@@ -44,13 +45,14 @@ FKTimeWindows::FKTimeWindows(QWidget* parent)
   /*
     setup graph properties
   */
-  waveNumGrid->graphContent()->setGridLines(false);
+  waveNumGrid->graphContents()->setGridLines(false);
 
   _gridLayer=new LiveGridLayer(waveNumGrid);
   _gridLayer->setObjectName("grid");
+  _gridLayer->setFunction(new FKFunctionPlot);
   _gridLayer->setSampling(3);
-  _positiveMap.generateColorScale(20, ColorPalette::McNamesClip, true);
-  _positiveNegativeMap.generateColorScale(20, ColorPalette::ColdHot, false);
+  _positiveMap.generate(0, 19, ColorPalette::defaultSequential, ColorPalette::Reversed);
+  _positiveNegativeMap.generate(0, 19, ColorPalette::defaultDiverging, ColorPalette::Continuous);
   _gridLayer->setColorMap(_positiveMap);
 
   _curveLayer=new LiveCurveLayer(waveNumGrid);
@@ -67,7 +69,7 @@ FKTimeWindows::FKTimeWindows(QWidget* parent)
   _fkSlowLineLayer=new LineLayer(waveNumGrid);
   _fkSlowLineLayer->setObjectName("userSlownessLine");
   AbstractLine * line=new PlotLine2D;
-  line->setPen(Pen(Qt::black, 0.60, Qt::DashLine));
+  line->setPen(Pen(Qt::black, 0.60, Pen::DashLine));
   line->setSymbol(Symbol(Symbol::NoSymbol));
   _fkSlowLineLayer->setReferenceLine(line);
   _fkSlowLineLayer->addLine();
@@ -81,15 +83,15 @@ FKTimeWindows::FKTimeWindows(QWidget* parent)
   _fkPeaks->setObjectName("fkPeaks");
   line=new PlotLine2D;
   line->setPen(Pen(Qt::NoPen));
-  line->setSymbol(Symbol(Symbol::Cross, 2.0));
+  line->setSymbol(Symbol(Symbol::Cross, 2.0, Pen(Qt::red)));
   _fkPeaks->setReferenceLine(line);
   _fkPeaks->addLine();
 
-  connect(waveNumGrid->graphContent(), SIGNAL(mouseMoved( QPoint, Qt::MouseButtons, Qt::KeyboardModifiers) ),
+  connect(waveNumGrid->graphContents(), SIGNAL(mouseMoved( QPoint, Qt::MouseButtons, Qt::KeyboardModifiers) ),
            this, SLOT(currentVelocitySlowness(QPoint)));
   valueLabel->setText(QString());
-  connect(kxEdit, SIGNAL(valueChanged(const QString&)), this, SLOT(kxkyChanged()));
-  connect(kyEdit, SIGNAL(valueChanged(const QString&)), this, SLOT(kxkyChanged()));
+  connect(kxEdit, SIGNAL(valueChanged(double)), this, SLOT(kxkyChanged()));
+  connect(kyEdit, SIGNAL(valueChanged(double)), this, SLOT(kxkyChanged()));
   connect(blockSetScroll, SIGNAL(valueChanged(int)), this, SLOT(setCurrentBlockSet()));
 
   _timeWindows=nullptr;
@@ -113,13 +115,15 @@ void FKTimeWindows::viewKxCurve()
 {
   TRACE;
   waveNumGrid->xAxis()->setTitle("Wave number (rad/m)");
-  waveNumGrid->xAxis()->setTitleInversedScale("Wave length/(2*pi) (m/rad)");
+  waveNumGrid->xAxis()->setTitleInverseScale("Wave length/(2*pi) (m/rad)");
   waveNumGrid->xAxis()->setSizeType(Axis::AxisSize);
   waveNumGrid->yAxis()->setTitle("Power");
-  waveNumGrid->yAxis()->setTitleInversedScale("1/Power");
+  waveNumGrid->yAxis()->setTitleInverseScale("1/Power");
   waveNumGrid->yAxis()->setSizeType(Axis::AxisSize);
   waveNumGrid->yAxis()->setScaleType(Scale::Log);
   waveNumGrid->yAxis()->setNumberType('e');
+  waveNumGrid->yAxis()->setReversedScale(false);
+
   _curveLayer->setScale(SamplingParameters::Log);
 
   _gridLayer->setOpacity(0.0);
@@ -132,32 +136,56 @@ void FKTimeWindows::viewKxCurve()
 void FKTimeWindows::viewKxKyGrid()
 {
   TRACE;
-  waveNumGrid->xAxis()->setTitle("Wave number X (rad/m)");
-  waveNumGrid->xAxis()->setTitleInversedScale( "Wave length X/(2*pi) (m/rad)");
+  waveNumGrid->xAxis()->setTitle(tr("Wave number X (rad/m)"));
+  waveNumGrid->xAxis()->setTitleInverseScale(tr("Wave length X/(2*pi) (m/rad)"));
   waveNumGrid->xAxis()->setSizeType(Axis::Scaled);
-  waveNumGrid->yAxis()->setTitle("Wave number Y (rad/m)");
-  waveNumGrid->yAxis()->setTitleInversedScale("Wave length Y/(2*pi) (m/rad)");
+  waveNumGrid->yAxis()->setTitle(tr("Wave number Y (rad/m)"));
+  waveNumGrid->yAxis()->setTitleInverseScale(tr("Wave length Y/(2*pi) (m/rad)"));
   waveNumGrid->yAxis()->setSizeType(Axis::Scaled);
   waveNumGrid->yAxis()->setScaleType(Scale::Linear);
   waveNumGrid->yAxis()->setNumberType('f');
+  waveNumGrid->yAxis()->setReversedScale(false);
 
   _gridLayer->setOpacity(1.0);
   _curveLayer->setOpacity(0.0);
-  _fkMeshLayer->setOpacity(0.5);
+  _fkMeshLayer->setOpacity(0.05);
   _fkSlowCircleLayer->setOpacity(1.0);
   _fkSlowLineLayer->setOpacity(0.0);
 }
 
+void FKTimeWindows::viewMatrixGrid()
+{
+  TRACE;
+  waveNumGrid->xAxis()->setTitle(tr("Channel"));
+  waveNumGrid->xAxis()->setTitleInverseScale("");
+  waveNumGrid->xAxis()->setSizeType(Axis::AxisSize);
+  waveNumGrid->xAxis()->setScaleType(Scale::Linear);
+  waveNumGrid->xAxis()->setNumberType('f');
+  waveNumGrid->yAxis()->setTitle(tr("Channel"));
+  waveNumGrid->yAxis()->setTitleInverseScale("");
+  waveNumGrid->yAxis()->setSizeType(Axis::AxisSize);
+  waveNumGrid->yAxis()->setScaleType(Scale::Linear);
+  waveNumGrid->yAxis()->setNumberType('f');
+  waveNumGrid->yAxis()->setReversedScale(true);
+
+  _gridLayer->setOpacity(1.0);
+  _curveLayer->setOpacity(0.0);
+  _fkMeshLayer->setOpacity(0.0);
+  _fkSlowCircleLayer->setOpacity(0.0);
+  _fkSlowLineLayer->setOpacity(0.0);
+}
+
 void FKTimeWindows::viewKEllGrid()
 {
   TRACE;
   waveNumGrid->xAxis()->setTitle("Wave number X (rad/m)");
-  waveNumGrid->xAxis()->setTitleInversedScale("Wave length X/(2*pi) (m/rad)");
+  waveNumGrid->xAxis()->setTitleInverseScale("Wave length X/(2*pi) (m/rad)");
   waveNumGrid->xAxis()->setSizeType(Axis::AxisSize);
   waveNumGrid->yAxis()->setTitle("Ellipticity (deg)");
   waveNumGrid->yAxis()->setSizeType(Axis::AxisSize);
   waveNumGrid->yAxis()->setScaleType(Scale::Linear);
   waveNumGrid->yAxis()->setNumberType('f');
+  waveNumGrid->yAxis()->setReversedScale(false);
 
   _gridLayer->setOpacity(1.0);
   _curveLayer->setOpacity(0.0);
@@ -180,11 +208,10 @@ void FKTimeWindows::setTimeWindowLayer(TimeWindowLayer * twLayer)
 bool FKTimeWindows::setParameters(const ArraySelection * array, double frequency, FKParameters * param)
 {
   TRACE;
-  // Before changing anything to parameters, disable the grid plot (setComponent will reset it)
-  _gridLayer->setFunction(nullptr);
-  _curveLayer->setFunction(nullptr);
 
-  LayerLocker ll(_timeWindowLayer); // deleting process will affect the list of time windows
+  LayerLocker llt(_timeWindowLayer); // deleting process will affect the list of time windows
+  LayerLocker llg(_gridLayer);
+  LayerLocker llc(_curveLayer);
   delete _taskManager;
   delete _crossSpectrum;
   delete _timeWindows;
@@ -202,23 +229,25 @@ bool FKTimeWindows::setParameters(const ArraySelection * array, double frequency
   _timeWindows=new ArrayTimeWindows(&_taskManager->array(), _taskManager->keep(), param);
   _crossSpectrum->setTimeWindows(_timeWindows);
 
-  // Steering must use the array selection as FKCrossSpectrum
-  // Selection is changed by setParameters above
+  // Steering must use the array selection because FKCrossSpectrum
+  // selection is changed by setParameters above
   delete _gridCache;
   _gridCache=new FKCache(&_taskManager->array());
 
   App::log(tr("Current frequency: %1\n").arg(frequency));
   _timeWindows->setFrequency(frequency);
   _timeWindows->setWindows();
-  ll.unlock();
+  llt.unlock();
 
   setBlockSetList(param->blockAveraging());
 
   setPlotOptions();
   setPlotOption();
   setGrid(param);
-  on_vEdit_valueChanged("");
-  if(_timeWindowLayer) _timeWindowLayer->deepUpdate();
+  on_vEdit_valueChanged(0);
+  if(_timeWindowLayer) {
+    _timeWindowLayer->deepUpdate();
+  }
   return true;
 }
 
@@ -226,7 +255,7 @@ void FKTimeWindows::setKxCurveLimits()
 {
   if(_crossSpectrum && _curveLayer->opacity()>0.0) {
     double kmax=_crossSpectrum->parameters()->effectiveGridSize(_timeWindows->frequency().center());
-    AxisWindow * w=waveNumGrid->graphContent()->graph();
+    AxisWindow * w=waveNumGrid->graphContents()->graph();
     if(w->xAxis()->zoomEnabled()) {
       w->xAxis()->setRange(0.0, kmax);
     }
@@ -241,11 +270,20 @@ void FKTimeWindows::setKxKyGridLimits()
   }
 }
 
+void FKTimeWindows::setMatrixGridLimits(AbstractFKFunction * fk)
+{
+  if(fk->crossSpectrum() && _gridLayer->opacity()>0.0) {
+    int n=fk->crossSpectrum()->columnCount();
+    waveNumGrid->xAxis()->setRange(0.5, n+0.5);
+    waveNumGrid->yAxis()->setRange(0.5, n+0.5);
+  }
+}
+
 void FKTimeWindows::setKEllGridLimits()
 {
   if(_crossSpectrum && _gridLayer->opacity()>0.0) {
     double kmax=_crossSpectrum->parameters()->effectiveGridSize(_timeWindows->frequency().center());
-    AxisWindow * w=waveNumGrid->graphContent()->graph();
+    AxisWindow * w=waveNumGrid->graphContents()->graph();
     if(w->xAxis()->zoomEnabled()) {
       w->xAxis()->setRange(0.0, kmax);
     }
@@ -260,7 +298,6 @@ void FKTimeWindows::setKEllGridLimits()
 void FKTimeWindows::setPowerLimits()
 {
   TRACE;
-  _gridLayer->setValueFactor(1.0);
   _gridLayer->setForceRatio(true);
   _gridLayer->setForceMinimumValue(false);
   _gridLayer->setForceMaximumValue(false);
@@ -274,7 +311,6 @@ void FKTimeWindows::setPowerLimits()
 void FKTimeWindows::setEllipticityLimits()
 {
   TRACE;
-  _gridLayer->setValueFactor(180.0/M_PI);
   _gridLayer->setForceRatio(false);
   _gridLayer->setForceMinimumValue(false);
   _gridLayer->setForceMaximumValue(false);
@@ -285,10 +321,22 @@ void FKTimeWindows::setEllipticityLimits()
   }
 }
 
+void FKTimeWindows::setMatrixLimits()
+{
+  TRACE;
+  _gridLayer->setForceRatio(true);
+  _gridLayer->setForceMinimumValue(false);
+  _gridLayer->setForceMaximumValue(false);
+  _gridLayer->setScale(SamplingParameters::Log);
+  _gridLayer->setSymetric(false);
+  if(_gridLayer->autoAdjust()) {
+    _gridLayer->setColorMap(_positiveMap);
+  }
+}
+
 void FKTimeWindows::setPowerGradientLimits()
 {
   TRACE;
-  _gridLayer->setValueFactor(1.0);
   _gridLayer->setForceRatio(false);
   _gridLayer->setForceMinimumValue(false);
   _gridLayer->setForceMaximumValue(false);
@@ -302,7 +350,6 @@ void FKTimeWindows::setPowerGradientLimits()
 void FKTimeWindows::setPowerConcaveMaskLimits()
 {
   TRACE;
-  _gridLayer->setValueFactor(1.0);
   _gridLayer->setForceRatio(false);
   _gridLayer->setForceMinimumValue(true);
   _gridLayer->setForceMaximumValue(true);
@@ -323,7 +370,6 @@ void FKTimeWindows::setPowerConcaveMaskLimits()
 void FKTimeWindows::setPowerStepLimits()
 {
   TRACE;
-  _gridLayer->setValueFactor(1.0);
   _gridLayer->setForceRatio(false);
   _gridLayer->setForceMinimumValue(true);
   _gridLayer->setForceMaximumValue(true);
@@ -341,7 +387,6 @@ void FKTimeWindows::setPowerStepLimits()
 void FKTimeWindows::setPowerDirectionLimits()
 {
   TRACE;
-  _gridLayer->setValueFactor(1.0);
   _gridLayer->setForceRatio(false);
   _gridLayer->setForceMinimumValue(true);
   _gridLayer->setForceMaximumValue(true);
@@ -357,7 +402,6 @@ void FKTimeWindows::setPowerDirectionLimits()
 void FKTimeWindows::setPowerEllStepLimits()
 {
   TRACE;
-  _gridLayer->setValueFactor(180.0/M_PI);
   _gridLayer->setForceRatio(false);
   _gridLayer->setForceMinimumValue(true);
   _gridLayer->setForceMaximumValue(true);
@@ -390,12 +434,20 @@ void FKTimeWindows::setCurrentBlockSet()
   }
   LayerLocker ll(_timeWindowLayer);
   // Before changing anything to parameters, disable the grid plot
-  AbstractFKFunction * func;
+  AbstractFKFunction * func=nullptr;
+  FKFunctionPlot * funcPlot=nullptr;
   if(_gridLayer->opacity()>0.0) {
-    func=static_cast<AbstractFKFunction *>(_gridLayer->takeFunction());
+    funcPlot=static_cast<FKFunctionPlot *>(_gridLayer->takeFunction());
+    if(funcPlot) {
+      func=funcPlot->function();
+    }
   } else if(_curveLayer->opacity()>0.0) {
     func=static_cast<AbstractFKFunction *>(_curveLayer->takeFunction());
-  } else {
+  }
+  if(!func) {
+    if(funcPlot) {
+      _gridLayer->setFunction(funcPlot);
+    }
     return;
   }
   /*
@@ -405,39 +457,58 @@ void FKTimeWindows::setCurrentBlockSet()
   TimeWindowList& winList=_timeWindows->list();
   if(winList.isEmpty()) {
     _currentBlockSet=-1;
-    delete func;
+    if(funcPlot) {
+      _gridLayer->setFunctionValid(false);
+      _gridLayer->setFunction(funcPlot);
+    } else {
+      _curveLayer->setFunctionValid(false);
+      _curveLayer->setFunction(func);
+    }
     return ;
   }
   _currentBlockSet=blockSetScroll->value();
   if(_currentBlockSet<0 || _currentBlockSet>=_blockSetList.count()) {
     blockSetScroll->setValue(0);
-    delete func;
+    if(funcPlot) {
+      _gridLayer->setFunctionValid(false);
+      _gridLayer->setFunction(funcPlot);
+    } else {
+      _curveLayer->setFunctionValid(false);
+      _curveLayer->setFunction(func);
+    }
     return;
   }
   highLightWindows(winList);
+  currentTime->setText(winList.at(_currentBlockSet).start().toString(DateTime::defaultUserFormat));
   ll.unlock();
 
-  // crossSpectrum is modifying the index
-  if(_currentBlockSet>=0 && _currentBlockSet<_blockSetList.count()) {
-    const QVector<int>& blocks=_blockSetList.at(_currentBlockSet);
-    App::log(tr("Processing block set starting at %1\n")
-             .arg(winList.at(blocks.first()).start()
-                  .toString(DateTime::defaultUserFormat)));
-    if(_crossSpectrum->calculate(blocks, func)) {
-      if(_gridLayer->opacity()>0.0) {
-        _gridLayer->setFunction(func);
-      } else if(_curveLayer->opacity()>0.0) {
-        _curveLayer->setFunction(func);
-      }
+  const VectorList<int>& blocks=_blockSetList.at(_currentBlockSet);
+  App::log(tr("Processing block set starting at %1\n")
+           .arg(winList.at(blocks.first()).start()
+           .toString(DateTime::defaultUserFormat)));
+  if(_crossSpectrum->calculate(blocks, func)) {
+    if(funcPlot) {
+      _gridLayer->setFunctionValid(true);
     } else {
-      delete func;
+      _curveLayer->setFunctionValid(true);
     }
   } else {
-    delete func;
+    if(funcPlot) {
+      _gridLayer->setFunctionValid(false);
+    } else {
+      _curveLayer->setFunctionValid(false);
+    }
+  }
+  if(funcPlot) {
+    _gridLayer->setFunction(funcPlot);
+  } else {
+    _curveLayer->setFunction(func);
   }
 
   waveNumGrid->deepUpdate();
-  if(_timeWindowLayer) _timeWindowLayer->deepUpdate();
+  if(_timeWindowLayer) {
+    setTimeWindows();
+  }
   if(showPeaksEdit->isChecked()) {
     showFKPeaks();
   }
@@ -447,8 +518,8 @@ void FKTimeWindows::highLightWindows(TimeWindowList& winList)
 {
   TRACE;
   winList.resetColors();
-  QVector<int> blocks=_blockSetList.at(_currentBlockSet);
-  for(QVector<int>::const_iterator it=blocks.begin(); it!=blocks.end(); it++) {
+  VectorList<int> blocks=_blockSetList.at(_currentBlockSet);
+  for(VectorList<int>::const_iterator it=blocks.begin(); it!=blocks.end(); it++) {
     winList.at(*it).setColor(_highLightedColor);
   }
 }
@@ -463,39 +534,36 @@ void FKTimeWindows::setPlotOptions()
   case ArrayStations::Vertical:
     plotOption->clear();
     plotOption->addItem(tr("Rayleigh power"));
-    plotOption->addItem(tr("Rayleigh power gradient direction"));
+    plotOption->addItem(tr("Cross-spectral matrix"));
+    /*plotOption->addItem(tr("Rayleigh power gradient direction"));
     plotOption->addItem(tr("Rayleigh power concavity"));
-    plotOption->addItem(tr("Rayleigh power step direction"));
+    plotOption->addItem(tr("Rayleigh power step direction"));*/
     break;
   case ArrayStations::Horizontal:
     break;
   case ArrayStations::ThreeComponents:
     switch(param->processType()) {
-    case FKParameters::ActiveDS:
     case FKParameters::ActiveRTBF:
+    case FKParameters::ActiveConventionalRayleigh:
       plotOption->clear();
-      plotOption->addItem(tr("Wavenumber power"));
-      plotOption->addItem(tr("Imaginary residuals"));
-      break;
-    case FKParameters::ActiveConventional:
-      plotOption->clear();
-      plotOption->addItem(tr("Wavenumber power"));
-      plotOption->addItem(tr("Ellipticity power"));
+      plotOption->addItem(tr("Rayleigh power"));
+      plotOption->addItem(tr("Rayleigh ellipticity"));
+      plotOption->addItem(tr("Cross-spectral matrix"));
       break;
     default:
       plotOption->clear();
+      plotOption->addItem(tr("Rayleigh power at best ellipticity"));
+      plotOption->addItem(tr("Rayleigh best ellipticity"));
       plotOption->addItem(tr("Rayleigh power at fixed ellipticity"));
-      plotOption->addItem(tr("Rayleigh power gradient kx-ky direction at fixed ellipticity"));
+      plotOption->addItem(tr("Cross-spectral matrix"));
+      /*plotOption->addItem(tr("Rayleigh power gradient kx-ky direction at fixed ellipticity"));
       plotOption->addItem(tr("Rayleigh power gradient kx-ky at fixed ellipticity"));
       plotOption->addItem(tr("Rayleigh power gradient ell at fixed ellipticity"));
       plotOption->addItem(tr("Rayleigh power concavity at fixed ellipticity"));
       plotOption->addItem(tr("Rayleigh power k step length at fixed ellipticity"));
       plotOption->addItem(tr("Rayleigh power k step direction at fixed ellipticity"));
       plotOption->addItem(tr("Rayleigh power ell step at fixed ellipticity"));
-      plotOption->addItem(tr("Rayleigh power at best ellipticity"));
-      plotOption->addItem(tr("Rayleigh best ellipticity"));
-      plotOption->addItem(tr("Love power"));
-      plotOption->addItem(tr("Rayleigh power gradient"));
+      plotOption->addItem(tr("Rayleigh power gradient"));*/
       break;
     }
     break;
@@ -517,9 +585,6 @@ void FKTimeWindows::setPlotOption()
   if(!_crossSpectrum) {
     return;
   }
-  // Before changing anything to parameters, disable the grid plot
-  _gridLayer->setFunction(nullptr);
-  _curveLayer->setFunction(nullptr);
   if(_crossSpectrum->array().count()==0) { // Selection is empty (for active)
     return;
   }
@@ -528,65 +593,82 @@ void FKTimeWindows::setPlotOption()
   ArrayStations::Mode mode=_crossSpectrum->mode();
 
   AbstractFKFunction * fk=nullptr;
+  FKFunctionPlot * funcPlot=nullptr;
+
 
   switch(mode) {
   case ArrayStations::Vertical:
     ellipticity->setEnabled(false);
     fk=AbstractFKFunction::create(mode, param, _gridCache);
     switch(param->processType()) {
-    case FKParameters::ActiveDS:
     case FKParameters::ActiveRTBF:
+    case FKParameters::ActiveCapon:
     case FKParameters::ActiveConventional:
       viewKxCurve();
       setKxCurveLimits();
       _curveLayer->setFunction(fk);
       break;
     default:
+      funcPlot=static_cast<FKFunctionPlot *>(_gridLayer->takeFunction());
+      if(!funcPlot) {
+        return;
+      }
       switch(plotOption->currentIndex()) {
       case 0:
-        _gridLayer->setVariables(LiveGridLayer::CrossXY);
+        funcPlot->setMode(FKFunctionPlot::BeamPower);
+        viewKxKyGrid();
+        setKxKyGridLimits();
         setPowerLimits();
         break;
       case 1:
-        _gridLayer->setVariables(LiveGridLayer::GradXYDirection);
+        fk->setCrossSpectrum(_crossSpectrum); // required for setting axis limits
+        viewMatrixGrid();
+        setMatrixGridLimits(fk);
+        funcPlot->setMode(FKFunctionPlot::CrossSpectralMatrix);
+        setMatrixLimits();
+        break;
+      /*case 1:
+        funcPlot->setMode(FKFunctionPlot::GradientDirection);
         setPowerDirectionLimits();
         break;
       case 2:
-        _gridLayer->setVariables(LiveGridLayer::ConcavityXY);
+        funcPlot->setMode(FKFunctionPlot::Concavity);
         setPowerGradientLimits();
         break;
       case 3:
-        _gridLayer->setVariables(LiveGridLayer::StepDirectionXY);
+        funcPlot->setMode(FKFunctionPlot::StepDirection);
         setPowerDirectionLimits();
-        break;
+        break;*/
       }
-      viewKxKyGrid();
-      setKxKyGridLimits();
-      _gridLayer->setFunction(fk);
+      funcPlot->setFunction(fk);
+      _gridLayer->setFunction(funcPlot);
       break;
     }
     break;
   case ArrayStations::Horizontal:
     break;
   case ArrayStations::ThreeComponents:
+    funcPlot=static_cast<FKFunctionPlot *>(_gridLayer->takeFunction());
+    if(!funcPlot) {
+      return;
+    }
     switch(param->processType()) {
-    case FKParameters::ActiveDS:
     case FKParameters::ActiveRTBF:
       ellipticity->setEnabled(false);
-      _gridLayer->setVariables(LiveGridLayer::CrossXY);
+      funcPlot->setMode(FKFunctionPlot::BeamPower);
       fk=AbstractFKFunction::create(mode, param, _gridCache);
       viewKEllGrid();
       setKEllGridLimits();
       break;
-    case FKParameters::ActiveConventional:
+    case FKParameters::ActiveConventionalRayleigh:
       ellipticity->setEnabled(false);
       switch(plotOption->currentIndex()) {
       default:
       case 0:
-        _gridLayer->setVariables(LiveGridLayer::CrossXY);
+        funcPlot->setMode(FKFunctionPlot::BeamPower);
         break;
       case 1:
-        _gridLayer->setVariables(LiveGridLayer::InvCrossXY);
+        funcPlot->setMode(FKFunctionPlot::InverseBeamPower);
         break;
       }
       fk=AbstractFKFunction::create(mode, param, _gridCache);
@@ -594,75 +676,72 @@ void FKTimeWindows::setPlotOption()
       setKEllGridLimits();
       break;
     default:
+      fk=AbstractFKFunction::create(mode, param, _gridCache);
       switch(plotOption->currentIndex()) {
       case 0:
-      case 1:
-      case 2:
-      case 3:
-      case 4:
-      case 5:
-      case 6:
-      case 7:
-        ellipticity->setEnabled(true);
-        _gridLayer->setFixedVariable(Angle::degreesToRadians(ellipticity->value()));
-        fk=AbstractFKFunction::create(mode, param, _gridCache);
+        ellipticity->setEnabled(false);
+        funcPlot->setMode(FKFunctionPlot::BeamPower);
         viewKxKyGrid();
         setKxKyGridLimits();
-        switch(plotOption->currentIndex()) {
-        case 1:
+        setPowerLimits();
+        break;
+      case 1:
+        ellipticity->setEnabled(false);
+        funcPlot->setMode(FKFunctionPlot::Ellipticity);
+        viewKxKyGrid();
+        setKxKyGridLimits();
+        setEllipticityLimits();
+        break;
+      case 2:
+        ellipticity->setEnabled(true);
+        funcPlot->setFixedEllipticity(Angle::degreesToRadians(ellipticity->value()));
+        viewKxKyGrid();
+        setKxKyGridLimits();
+        funcPlot->setMode(FKFunctionPlot::FixedEllipticity);
+        setPowerLimits();
+        break;
+      case 3:
+        ellipticity->setEnabled(false);
+        fk->setCrossSpectrum(_crossSpectrum); // required for setting axis limits
+        viewMatrixGrid();
+        setMatrixGridLimits(fk);
+        funcPlot->setMode(FKFunctionPlot::CrossSpectralMatrix);
+        setMatrixLimits();
+        break;
+        /*switch(plotOption->currentIndex()) {
+        case 4:
           _gridLayer->setVariables(LiveGridLayer::GradXYDirection);
           setPowerDirectionLimits();
           break;
-        case 2:
+        case 5:
           _gridLayer->setVariables(LiveGridLayer::GradXYValue);
           setPowerLimits();
           break;
-        case 3:
+        case 6:
           _gridLayer->setVariables(LiveGridLayer::GradZvsXY);
           _gridLayer->setValueFactor(180.0/M_PI);
           setPowerGradientLimits();
           break;
-        case 4:
+        case 7:
           _gridLayer->setVariables(LiveGridLayer::ConcavityXY);
           setPowerGradientLimits();
           break;
-        case 5:
+        case 8:
           _gridLayer->setVariables(LiveGridLayer::StepLengthXY);
           setPowerLimits();
           break;
-        case 6:
+        case 9:
           _gridLayer->setVariables(LiveGridLayer::StepDirectionXY);
           setPowerDirectionLimits();
           break;
-        case 7:
-          _gridLayer->setVariables(LiveGridLayer::StepZ);
-          setPowerEllStepLimits();
-          break;
         default:
           _gridLayer->setVariables(LiveGridLayer::CrossXY);
           setPowerLimits();
           break;
-        }
-        break;
-      case 8:
-        ellipticity->setEnabled(false);
-        _gridLayer->setVariables(LiveGridLayer::Value_XYMaxZ);
-        fk=AbstractFKFunction::create(mode, param, _gridCache);
-        viewKxKyGrid();
-        setKxKyGridLimits();
-        setPowerLimits();
-        break;
-      case 9:
-        ellipticity->setEnabled(false);
-        _gridLayer->setVariables(LiveGridLayer::Z_XYMaxZ);
-        fk=AbstractFKFunction::create(mode, param, _gridCache);
-        viewKxKyGrid();
-        setKxKyGridLimits();
-        setEllipticityLimits();
-        break;
+        }*/
       case 10:
         ellipticity->setEnabled(false);
-        _gridLayer->setVariables(LiveGridLayer::CrossXY);
+        funcPlot->setMode(FKFunctionPlot::BeamPower);
         fk=AbstractFKFunction::create(mode, param, _gridCache);
         viewKxKyGrid();
         setKxKyGridLimits();
@@ -672,14 +751,17 @@ void FKTimeWindows::setPlotOption()
         fk=nullptr;
         break;
       }
-      _gridLayer->setFunction(fk);
       break;
     }
+    funcPlot->setFunction(fk);
+    _gridLayer->setFunction(funcPlot);
     break;
   }
 
   if(fk) {
     fk->setCrossSpectrum(_crossSpectrum);
+    // Initialization that require the virtual mechanism (e.g. allocation of power engine)
+    fk->initialize(*param);
     fk->setMaximumWavenumber(std::numeric_limits<double>::infinity()); // No limit for plot
     fk->setMaximumSlowness(std::numeric_limits<double>::infinity());
   } else {
@@ -690,7 +772,7 @@ void FKTimeWindows::setPlotOption()
   waveNumGrid->deepUpdate();
 }
 
-void FKTimeWindows::on_kEdit_valueChanged(const QString & )
+void FKTimeWindows::on_kEdit_valueChanged(double)
 {
   TRACE;
   if(!_timeWindows) {
@@ -700,7 +782,7 @@ void FKTimeWindows::on_kEdit_valueChanged(const QString & )
   vEdit->blockSignals(true);
   vEdit->setValue(2*M_PI*_timeWindows->frequency().center()/val);
   vEdit->blockSignals(false);
-  _fkSlowCircleLayer->set(0, 0, 0, val, val, 0.0, Qt::black);
+  _fkSlowCircleLayer->set(0, 0.0, 0.0, val, val, 0.0, Pen());
   _fkSlowCircleLayer->deepUpdate();
   AbstractLine * line=_fkSlowLineLayer->line(0);
   line->setX(0, val);
@@ -708,7 +790,7 @@ void FKTimeWindows::on_kEdit_valueChanged(const QString & )
   _fkSlowLineLayer->deepUpdate();
 }
 
-void FKTimeWindows::on_vEdit_valueChanged(const QString & )
+void FKTimeWindows::on_vEdit_valueChanged(double)
 {
   TRACE;
   if(!_timeWindows) {
@@ -719,7 +801,7 @@ void FKTimeWindows::on_vEdit_valueChanged(const QString & )
   kEdit->setValue(2*M_PI*_timeWindows->frequency().center()/val);
   kEdit->blockSignals(false);
   double k=2 * M_PI * _timeWindows->frequency().center()/val;
-  _fkSlowCircleLayer->set(0, 0, 0, k, k, 0.0, Qt::black);
+  _fkSlowCircleLayer->set(0, 0.0, 0.0, k, k, 0.0, Pen());
   _fkSlowCircleLayer->deepUpdate();
   AbstractLine * line=_fkSlowLineLayer->line(0);
   line->setX(0, k);
@@ -771,7 +853,7 @@ void FKTimeWindows::currentVelocitySlowness(QPoint mousePos)
   if(!_crossSpectrum || !_timeWindows) {
     return;
   }
-  Point2D p=waveNumGrid->graphContent()->options().s2r(mousePos);
+  Point2D p=waveNumGrid->graphContents()->options().s2r(mousePos);
   Point2D origin(0, 0);
 
   enum Propagation {Propagation1D, Propagation2D};
@@ -782,9 +864,10 @@ void FKTimeWindows::currentVelocitySlowness(QPoint mousePos)
   switch(mode) {
   case ArrayStations::Vertical:
     switch(param->processType()) {
-    case FKParameters::ActiveDS:
     case FKParameters::ActiveRTBF:
+    case FKParameters::ActiveConventionalRayleigh:
     case FKParameters::ActiveConventional:
+    case FKParameters::ActiveCapon:
       prop=Propagation1D;
       break;
     default:
@@ -795,7 +878,6 @@ void FKTimeWindows::currentVelocitySlowness(QPoint mousePos)
     break;
   case ArrayStations::ThreeComponents:
     switch(param->processType()) {
-    case FKParameters::ActiveDS:
     case FKParameters::ActiveRTBF:
       prop=Propagation1D;
       break;
@@ -811,21 +893,21 @@ void FKTimeWindows::currentVelocitySlowness(QPoint mousePos)
   case Propagation1D: {
       double kr=p.x();
       double sr=kr/(2.0*M_PI*_timeWindows->frequency().center());
-      velSlowLabel->setText(tr("Propagation at k=%1 rad/m, v=%2 m/s or s=%3 s/km" )
+      velSlowLabel->setText(tr("Propagation at k=%1 rad/m, v=%2 m/s or s=%3 s/m" )
                              .arg(kr, 0, 'g', 3)
                              .arg(1.0/sr, 0, 'f', 0)
-                             .arg(sr*1000.0, 0, 'g', 5) );
+                             .arg(sr, 0, 'g', 5) );
     }
     break;
   case Propagation2D: {
       double kr=p.distanceTo(origin);
-      double az=Angle::mathToGeographic(origin.azimuthTo(p));
+      double az=Angle::radiansToDegrees(Angle::mathToGeographic(origin.azimuthTo(p)));
       double sr=kr/(2.0*M_PI*_timeWindows->frequency().center());
-      velSlowLabel->setText(tr("Propagation towards %1 counted from North\nat k=%2 rad/m, v=%3 m/s or s=%4 s/km" )
+      velSlowLabel->setText(tr("Propagation towards %1 counted from North at k=%2 rad/m, v=%3 m/s or s=%4 s/m" )
                              .arg(az, 0, 'f', 4)
                              .arg(kr, 0, 'g', 3)
                              .arg(1.0/sr, 0, 'f', 0)
-                             .arg(sr*1000.0, 0, 'g', 5));
+                             .arg(sr, 0, 'g', 5));
     }
     break;
   }
@@ -836,7 +918,7 @@ void FKTimeWindows::setBlockSetList(const BlockAveragingParameters& param)
   TRACE;
   // List is not "exact" if the signal contains gaps and with overlap
   int stationCount=_crossSpectrum->stationCount();
-  QVector<int> blocks;
+  VectorList<int> blocks;
   _blockSetList.clear();
   int i=0;
   while(true) {
@@ -867,9 +949,8 @@ void FKTimeWindows::showFKPeaks()
   case ArrayStations::Vertical:
     fk=AbstractFKFunction::create(mode, param, _gridCache);
     switch(param->processType()) {
-    case FKParameters::ActiveDS:
     case FKParameters::ActiveRTBF:
-    case FKParameters::ActiveConventional:
+    case FKParameters::ActiveConventionalRayleigh:
       return;
     default:
       break;
@@ -879,29 +960,11 @@ void FKTimeWindows::showFKPeaks()
     return;
   case ArrayStations::ThreeComponents:
     switch(param->processType()) {
-    case FKParameters::ActiveDS:
     case FKParameters::ActiveRTBF:
-    case FKParameters::ActiveConventional:
+    case FKParameters::ActiveConventionalRayleigh:
       return;
     default:
-      switch(plotOption->currentIndex()) {
-      case 0:
-      case 1:
-      case 2:
-      case 3:
-      case 4:
-      case 5:
-      case 6:
-      case 7:
-      case 8:
-        fk=AbstractFKFunction::create(mode, param, _gridCache);
-        break;
-      case 9:
-        fk=AbstractFKFunction::create(mode, param, _gridCache);
-        break;
-      default:
-        return;
-      }
+      fk=AbstractFKFunction::create(mode, param, _gridCache);
       break;
     }
     break;
@@ -909,46 +972,119 @@ void FKTimeWindows::showFKPeaks()
   fk->setCrossSpectrum(_crossSpectrum);
   fk->setMaximumSlowness(param->maximumSlowness());
   fk->setMaximumWavenumber(param->effectiveGridSize(_timeWindows->frequency().center()));
+  fk->setGridStep(param->gridStep());
   fk->setTotalLimits(_timeWindows->frequency().squaredOmega());
+  fk->initialize(*param);
 
 
   LayerLocker ll(_fkPeaks);
   Curve<Point2D>& plot=static_cast<PlotLine2D *>(_fkPeaks->line(0))->curve();
   plot.clear();
-  double gridSize=param->effectiveGridSize(_timeWindows->frequency().center());
 
-  GridSearch * gs;
-  /*if(param->inversionMethod()==FKParameters::Gradient) {
-    FKGradientSearch * g=new FKGradientSearch();
-    g->setFunction(fk);
-    fk->setGrid(g, param->cacheGridStep(), param->gridStep(), param->effectiveGridSize());
-    gs=g;
-    gs->localMax(INT_MAX, 0.0, 0.0);
-  } else {*/
-    FKGridSearch * g=new FKGridSearch;
-    g->setFunction(fk);
-    fk->setGrid(g, param->gridStep(), gridSize);
-    gs=g;
-    if(fk->hasEllipticity()) {
-      gs->localMaxBest(INT_MAX, 0.0, 0.0);
-    } else {
-      gs->localMax(INT_MAX, 0.0, 0.0);
-    }
-  //}
+  FunctionSearch * search=fk->createSearch(*param);
+  int nMax=param->maximumPeakCount(_crossSpectrum->array().count());
+  if(nMax>1) {
+    search->localMax(nMax,
+                     param->absoluteThreshold(),
+                     param->relativeThreshold());
+  } else {
+    search->globalMax(param->absoluteThreshold());
+  }
 
   FunctionMaximaIterator it;
-  for(it=gs->begin(); it!=gs->end(); ++it) {
-    Point kell=(*it)->pos();
-    plot.append(kell);
-    double v=2.0*M_PI*_timeWindows->frequency().center()/Point2D(kell.x(), kell.y()).length();
-    App::log(tr("Peak at k=(%1, %2), e=%3 deg. v=%4, s=%5, az=%6 deg.\n")
-             .arg(kell.x()).arg(kell.y())
-             .arg(Angle::radiansToDegrees(kell.z()))
-             .arg(v)
-             .arg(1.0/v)
-             .arg(Angle::mathToGeographic(kell.azimuth())));
+  WaveNumberConverter conv(_timeWindows->frequency().center());
+  FKPeaks::Value value;
+  for(it=search->begin(); it!=search->end(); ++it) {
+    const FunctionSearchMaximum& m=**it;
+    const Vector<double>& k=m.position();
+    double slowness=conv.slowness(k);
+    if(slowness>param->minimumSlowness() &&
+       !fk->isOnLimit(k, conv.frequency())) {
+      Point2D kp(k[0], k[1]);
+      plot.append(kp);
+      fk->setAssociatedResults(k, m.value(), value);
+      App::log(tr("Peak at k=(%1, %2), xi=%3 deg. v=%4, s=%5, az=%6 deg., Rz/N=%7, Rh/N=%8, power=%9\n")
+               .arg(kp.x()).arg(kp.y())
+               .arg(value.ellipticity)
+               .arg(1.0/slowness)
+               .arg(slowness)
+               .arg(Angle::radiansToDegrees(Angle::mathToGeographic(kp.azimuth())))
+               .arg(value.verticalNoise)
+               .arg(value.horizontalNoise)
+               .arg(value.power));
+    } else {
+      App::log(tr("Peak on limit\n"));
+    }
   }
-  delete gs;
+  if(search->maximaCount()==1) {
+    const Vector<double>& kell=(*search->begin())->position();
+
+    kxEdit->blockSignals(true);
+    kyEdit->blockSignals(true);
+    if(!fk->isOnLimit(kell, conv.frequency())) {
+      kxEdit->setValue(kell[0]);
+      kyEdit->setValue(kell[1]);
+    } else {
+      kxEdit->setValue(0.0);
+      kyEdit->setValue(0.0);
+    }
+    kxEdit->blockSignals(false);
+    kyEdit->blockSignals(false);
+    kxkyChanged();
+  }
+  delete search;
 
   _fkPeaks->deepUpdate();
 }
+
+void FKTimeWindows::on_brightSpot_clicked()
+{
+  PrivateVector<double> k(3, 0.0);
+  k[0]=kxEdit->value();
+  k[1]=kyEdit->value();
+  if(k[0]==0.0 && k[1]==0.0) {
+    return;
+  }
+  FKFunctionPlot * funcPlot=static_cast<FKFunctionPlot *>(_gridLayer->takeFunction());
+  AbstractFKFunction * function=funcPlot->function();
+  double power=function->value(k);
+  FKPeaks::Value value;
+  function->setAssociatedResults(k, power, value);
+  value.power*=powerFactor->value()*0.01;
+  App::log(tr("Remove bright spot at k=(%1, %2) with xi= %3 deg, Rz/N %4, Rh/N %5, power %6\n")
+      .arg(k[0])
+      .arg(k[1])
+      .arg(value.ellipticity)
+      .arg(value.verticalNoise)
+      .arg(value.horizontalNoise)
+      .arg(value.power));
+  function->remove(k, value);
+  _gridLayer->setFunction(funcPlot);
+  waveNumGrid->deepUpdate();
+  if(showPeaksEdit->isChecked()) {
+    showFKPeaks();
+  }
+}
+
+/*!
+  Add all stations to time window layer
+*/
+void FKTimeWindows::setTimeWindows()
+{
+  TRACE;
+  if(_timeWindowLayer && _crossSpectrum) {
+    const ArraySelection& array=_crossSpectrum->array();
+    int nComp=array.array()->nComponents();
+    int n=array.count();
+    _timeWindowLayer->clearTimeWindows();
+    for(int i=0; i<n; i++) {
+      for(int iComp=0; iComp<nComp; iComp++ ) {
+        const SubSignalPool subPool=array.stationSignals(i)->originals(iComp);
+        for(SubSignalPool::const_iterator itSig=subPool.begin();itSig!=subPool.end(); itSig++) {
+          _timeWindowLayer->addTimeWindows(*itSig, &timeWindowList());
+        }
+      }
+    }
+  }
+  _timeWindowLayer->deepUpdate();
+}
