@@ -41,8 +41,7 @@ FKToolWidget::FKToolWidget(QWidget * parent) :
 
   _currentTestFrequency=0.0;
 
-  delete _tool;
-  _tool=new FKTool;
+  _tool=new FKTool(this);
   connect(tool(), SIGNAL(waveNumberGridReady()), this, SLOT(setWaveNumberGrid()));
   connect(tool(), SIGNAL(finished()), this, SLOT(finish()));
 
@@ -58,22 +57,22 @@ FKToolWidget::FKToolWidget(QWidget * parent) :
   connect(freqSamp, SIGNAL(parametersChanged()), this, SLOT(numFreqChanged()));
 
   connect(timeLimits, SIGNAL(parametersChanged()), this, SLOT(parametersChanged()));
-  connect(selectMinimumDurationEdit, SIGNAL(valueChanged(const QString&)), this, SLOT(parametersChanged()));
+  connect(selectMinimumDurationEdit, SIGNAL(valueChanged(double)), this, SLOT(parametersChanged()));
   connect(winParam, SIGNAL(parametersChanged()), this, SLOT(parametersChanged()));
 
   connect(blockAveraging, SIGNAL(parametersChanged()), this, SLOT(parametersChanged()));
 
-  connect(freqBandwidthEdit, SIGNAL(valueChanged(const QString&)), this, SLOT(parametersChanged()));
-  connect(oversamplingEdit, SIGNAL(valueChanged(const QString&)), this, SLOT(parametersChanged()));
-  connect(dampingFactorEdit, SIGNAL(valueChanged(const QString&)), this, SLOT(parametersChanged()));
-  connect(rotateStepCountEdit, SIGNAL(valueChanged(const QString&)), this, SLOT(parametersChanged()));
-  connect(minDistance, SIGNAL(valueChanged(const QString&)), this, SLOT(parametersChanged()));
-  connect(maxDistance, SIGNAL(valueChanged(const QString&)), this, SLOT(parametersChanged()));
+  connect(freqBandwidthEdit, SIGNAL(valueChanged(double)), this, SLOT(parametersChanged()));
+  connect(oversamplingEdit, SIGNAL(valueChanged(double)), this, SLOT(parametersChanged()));
+  connect(dampingFactorEdit, SIGNAL(valueChanged(double)), this, SLOT(parametersChanged()));
+  connect(rotateStepCountEdit, SIGNAL(valueChanged(int)), this, SLOT(parametersChanged()));
+  connect(minDistance, SIGNAL(valueChanged(double)), this, SLOT(parametersChanged()));
+  connect(maxDistance, SIGNAL(valueChanged(double)), this, SLOT(parametersChanged()));
 
-  connect(gridStepEdit, SIGNAL(valueChanged(const QString& )), this, SLOT(gridStepChanged()));
-  connect(gridSizeEdit, SIGNAL(valueChanged(const QString& )), this, SLOT(gridSizeChanged()));
-  connect(vminEdit, SIGNAL(valueChanged(const QString& )), this, SLOT(parametersChanged()));
-  connect(vmaxEdit, SIGNAL(valueChanged(const QString& )), this, SLOT(parametersChanged()));
+  connect(gridStepEdit, SIGNAL(valueChanged(double)), this, SLOT(gridStepChanged()));
+  connect(gridSizeEdit, SIGNAL(valueChanged(double)), this, SLOT(gridSizeChanged()));
+  connect(vminEdit, SIGNAL(valueChanged(double)), this, SLOT(parametersChanged()));
+  connect(vmaxEdit, SIGNAL(valueChanged(double)), this, SLOT(parametersChanged()));
 
   _outputFileChecked=false;
   _exportAllFKGrids=false;
@@ -83,6 +82,10 @@ FKToolWidget::FKToolWidget(QWidget * parent) :
   // Temporary deactivate gradient search
   inversionMethodEdit->setCurrentIndex(1);
   inversionMethodEdit->setEnabled(false);
+
+  // Add a menu to start button to adjust the numer of parallel jobs
+  detailedStatus->setButtons(startBut, stopBut);
+  connect(detailedStatus, SIGNAL(startJobs(int)), this, SLOT(start(int)));
 }
 
 FKToolWidget::~FKToolWidget()
@@ -143,8 +146,9 @@ void FKToolWidget::setWaveNumberGrid()
   }
 }
 
-bool FKToolWidget::checkParameters(FKParameters * param) const
+bool FKToolWidget::checkParameters() const
 {
+  const FKParameters * param=tool()->parameters();
   if(param->gridStep()>param->gridSize()) {
     Message::warning(MSG_ID,tr("FK parameters"),tr("Grid step must be less than grid size."), true);
     return false;
@@ -164,11 +168,9 @@ bool FKToolWidget::checkParameters(FKParameters * param) const
 void FKToolWidget::parametersChanged()
 {
   if(_fkBrowser && testBut->isChecked()) {
-    FKParameters * param=static_cast<FKParameters *>(parameters());
-    if(param) {
-      _fkBrowser->setParameters(tool()->array(), _currentTestFrequency, param);
-      setTimeWindowLayer(&_fkBrowser->timeWindowList());
-    }
+    parametersFromGui();
+    _fkBrowser->setParameters(tool()->array(), _currentTestFrequency, tool()->parameters());
+    _fkBrowser->setTimeWindows();
   }
 }
 
@@ -212,21 +214,29 @@ bool FKToolWidget::setSubPool(SubSignalPool * subPool)
       }
     }*/
     processTypeEdit->blockSignals(true);
-    switch (tool()->array()->components()) {
-    case StationSignals::AllComponent:
-      //processTypeEdit->addItem(tr("Passive Direct Steering"));
-      processTypeEdit->addItem(tr("Passive RTBF"));
-      processTypeEdit->addItem(tr("Passive RTBF Radial"));
-      processTypeEdit->addItem(tr("Passive conventional"));
-      //processTypeEdit->addItem(tr("Active RTBF"));
-      //processTypeEdit->addItem(tr("Active conventional"));
-      break;
-    case StationSignals::VerticalComponent:
-      processTypeEdit->addItem(tr("Passive HR"));
-      processTypeEdit->addItem(tr("Passive conventional"));
-      processTypeEdit->addItem(tr("Active HR"));
-      processTypeEdit->addItem(tr("Active conventional"));
-      break;
+    StationSignals::Components c=tool()->array()->components();
+    if(c==StationSignals::AllComponent) {
+      processTypeEdit->addItem(tr("Passive ARDS"));
+      processTypeEdit->addItem(tr("Passive ARTBF"));
+      processTypeEdit->addItem(tr("Passive RTBF (2018)"));
+      processTypeEdit->addItem(tr("Passive LDS3"));
+    }
+    if(c & StationSignals::HorizontalComponent) {
+      processTypeEdit->addItem(tr("Passive LDS2"));
+      processTypeEdit->addItem(tr("Passive Radial Capon"));
+      processTypeEdit->addItem(tr("Passive Transverse Capon"));
+      processTypeEdit->addItem(tr("Passive Radial Conventional"));
+      processTypeEdit->addItem(tr("Passive Transverse Conventional"));
+    }
+    if(c & StationSignals::VerticalComponent) {
+      processTypeEdit->addItem(tr("Passive Vertical Capon"));
+      processTypeEdit->addItem(tr("Passive Vertical Conventional"));
+      processTypeEdit->addItem(tr("Active Vertical Capon"));
+      processTypeEdit->addItem(tr("Active Vertical Conventional"));
+    }
+    if(c==StationSignals::AllComponent) {
+      processTypeEdit->addItem(tr("Active Rayleigh Conventional"));
+      processTypeEdit->addItem(tr("Active RTBF"));
     }
     processTypeEdit->blockSignals(false);
     return true;
@@ -235,28 +245,6 @@ bool FKToolWidget::setSubPool(SubSignalPool * subPool)
   }
 }
 
-/*!
-  Add all stations to time window layer
-*/
-void FKToolWidget::setTimeWindowLayer(TimeWindowList * winList)
-{
-  TRACE;
-  if(timeWindowLayer() && _fkBrowser && _fkBrowser->crossSpectrum()) {
-    const ArraySelection& array=_fkBrowser->crossSpectrum()->array();
-    int nComp=array.array()->nComponents();
-    int n=array.count();
-    timeWindowLayer()->clearTimeWindows();
-    for(int i=0; i<n; i++) {
-      for(int iComp=0; iComp<nComp; iComp++ ) {
-        const SubSignalPool subPool=array.at(i)->originals(iComp);
-        for(SubSignalPool::const_iterator itSig=subPool.begin();itSig!=subPool.end(); itSig++) {
-          timeWindowLayer()->addTimeWindows(*itSig, winList);
-        }
-      }
-    }
-  }
-}
-
 void FKToolWidget::test()
 {
   TRACE;
@@ -271,39 +259,31 @@ void FKToolWidget::test()
   GeopsyCoreEngine::instance()->showMessage(tool()->database(), tr("Signals are ready"));
 }
 
-void FKToolWidget::start()
+void FKToolWidget::start(int threadCount)
 {
   TRACE;
   if(subPoolLocked()) {
     return;
   }
-  // Get parameters from dialog box
-  FKParameters * param=static_cast<FKParameters *>(parameters());
-  if(!param) {
-    Message::warning(MSG_ID, tr("Starting"), tr("Error(s) found in parameters, check log."));
-    return;
-  }
-  param->setOutputBaseName(outputFileName());
-  if(!param->outputBaseName().isEmpty()) {
+  parametersFromGui();
+  QString fileName=outputFileName();
+  if(!fileName.isEmpty()) {
+    tool()->parameters()->setOutputBaseName(fileName);
     lockSubPool();
-    if(tool()->setParameters(*param)) {
+    if(tool()->setLoop()) {
       detailedStatus->setLoop(tool()->loop());
-      setRunning(true);
-      tool()->start();
+      tool()->start(threadCount, true);
     } else {
       unlockSubPool();
     }
   }
-  delete param;
 }
 
 void FKToolWidget::finish()
 {
   unlockSubPool();
-  FKParameters * param=static_cast<FKParameters *>(parameters());
-  tool()->results()->save(param->outputBaseName(), tool()->log());
-  delete param;
-  setRunning(false);
+  tool()->results()->save(tool()->parameters()->outputBaseName(), tool()->log());
+  detailedStatus->setRunning(false);
 }
 
 void FKToolWidget::stop()
@@ -312,28 +292,16 @@ void FKToolWidget::stop()
   tool()->stop();
 }
 
-AbstractParameters * FKToolWidget::parameters(AbstractParameters * param) const
+void FKToolWidget::parametersFromGui()
 {
   TRACE;
-  if(!param) {
-    param=new FKParameters;
-  }
-  getParameters(*static_cast<FKParameters *>(param));
-  if(!checkParameters(static_cast<FKParameters *>(param))) {
-    delete param;
-    return nullptr;
-  } else {
-    return param;
-  }
-}
+  FKParameters& param=*tool()->parameters();
 
-void FKToolWidget::getParameters(FKParameters& param) const
-{
-  TRACE;
   param.setProcessType(processType(processTypeEdit->currentIndex()));
   param.setInversionMethod(inversionMethod(inversionMethodEdit->currentIndex()));
-  // Store default parameters not accessible through GUI
-  param.setDefaultValues(param.processType(), param.inversionMethod());
+  // Store default fkparameters not accessible through GUI
+  param.setDefaultValues();
+  param.setValues(_loadedParameters);
 
   timeLimits->getParameters(param.timeLimits());
   param.setSelectDurationFactor(0.01*selectMinimumDurationEdit->value());
@@ -358,7 +326,7 @@ void FKToolWidget::getParameters(FKParameters& param) const
 
   param.setMaximumPeakCount(maxPeakCount->value());
   param.setAbsoluteThreshold(maxAbsoluteThres->value());
-  param.setRelativeThreshold(maxRelativeThres->value());
+  param.setRelativeThreshold(maxRelativeThres->value()*0.01);
 
   param.setMinimumDistance(minDistance->value());
   param.setMaximumDistance(maxDistance->value());
@@ -366,10 +334,12 @@ void FKToolWidget::getParameters(FKParameters& param) const
   param.setOutputBaseName(outputFileNameEdit->text());
 }
 
-void FKToolWidget::setParameters(const AbstractParameters * absparam)
+void FKToolWidget::parametersToGui()
 {
   TRACE;
-  const FKParameters& param=*static_cast<const FKParameters *>(absparam);
+  const FKParameters& param=*tool()->parameters();
+
+  _loadedParameters.addValues(param);
   timeLimits->setParameters(param.timeLimits());
   selectMinimumDurationEdit->setValue(100.0*param.selectDurationFactor());
   winParam->setParameters(param.windowing());
@@ -397,9 +367,9 @@ void FKToolWidget::setParameters(const AbstractParameters * absparam)
   vminEdit->setValue(1.0/param.maximumSlowness());
   vmaxEdit->setValue(1.0/param.minimumSlowness());
 
-  maxPeakCount->setValue(param.maximumPeakCount());
+  maxPeakCount->setValue(param.maximumPeakCount(0));
   maxAbsoluteThres->setValue(param.absoluteThreshold());
-  maxRelativeThres->setValue(param.relativeThreshold());
+  maxRelativeThres->setValue(param.relativeThreshold()*100.0);
 
   minDistance->setValue(param.minimumDistance());
   maxDistance->setValue(param.maximumDistance());
@@ -410,94 +380,130 @@ void FKToolWidget::setParameters(const AbstractParameters * absparam)
 FKParameters::ProcessType FKToolWidget::processType(int t) const
 {
   TRACE;
-  switch (tool()->array()->components()) {
-  case StationSignals::AllComponent:
+  StationSignals::Components c=tool()->array()->components();
+  if(c==StationSignals::AllComponent) {
     switch(t) {
     case 0:
+      return FKParameters::ARDS;
+    case 1:
+      return FKParameters::ARTBF;
+    case 2:
       return FKParameters::RTBF;
-    case 1:
-      return FKParameters::RTBFRadial;
-    case 2:
-      return FKParameters::Conventional;
-    //case 5:
-    //  return FKParameters::ActiveDS;
     case 3:
-      return FKParameters::ActiveRTBF;
-    case 4:
-      return FKParameters::ActiveConventional;
+      return FKParameters::LDS3;
     default:
+      t-=4;
       break;
     }
-    break;
-  case StationSignals::VerticalComponent:
-    switch(t) {
-    case 1:
-      return FKParameters::Conventional;
-    case 2:
-      return FKParameters::ActiveRTBF;
-    case 3:
-      return FKParameters::ActiveConventional;
-    default:
-      break;
-    }
-    break;
   }
-  return FKParameters::RTBF;
-  //return FKParameters::RDS;
+  if(c & StationSignals::HorizontalComponent) {
+    switch(t) {
+    case 0:
+      return FKParameters::LDS2;
+    case 1:
+      return FKParameters::CaponRadial;
+    case 2:
+      return FKParameters::CaponTransverse;
+    case 3:
+      return FKParameters::ConventionalRadial;
+    case 4:
+      return FKParameters::ConventionalTransverse;
+    default:
+      t-=5;
+      break;
+    }
+  }
+  if(c & StationSignals::VerticalComponent) {
+    switch(t) {
+    case 0:
+      return FKParameters::Capon;
+    case 1:
+      return FKParameters::Conventional;
+    case 2:
+      return FKParameters::ActiveCapon;
+    case 3:
+      return FKParameters::ActiveConventional;
+    default:
+      t-=4;
+      break;
+    }
+  }
+  if(c==StationSignals::AllComponent) {
+    switch(t) {
+    case 0:
+      return FKParameters::ActiveConventionalRayleigh;
+    case 1:
+      return FKParameters::ActiveRTBF;
+    default:
+      t-=2;
+      break;
+    }
+  }
+  return FKParameters::Capon;
 }
 
 int FKToolWidget::processType(FKParameters::ProcessType t) const
 {
   TRACE;
-  switch (tool()->array()->components()) {
-  case StationSignals::AllComponent:
+  int shift=0;
+  StationSignals::Components c=tool()->array()->components();
+  if(c==StationSignals::AllComponent) {
     switch(t) {
-    case FKParameters::RDS:
-    case FKParameters::RDSRefined:
-    case FKParameters::Omni:
-    case FKParameters::PoggiRadial:
-    case FKParameters::PoggiVertical:
-      break;
-    case FKParameters::RDSRadial:
-      return 0;
-    case FKParameters::RDSVertical:
-      return 0;
+    case FKParameters::ARDS:
+      return shift;
+    case FKParameters::ARTBF:
+      return shift+1;
     case FKParameters::RTBF:
-      return 0;
-    case FKParameters::RTBFRadial:
-      return 1;
-    case FKParameters::Conventional:
-      return 2;
-    case FKParameters::ActiveDS:
-      return 3;
-    case FKParameters::ActiveRTBF:
-      return 3;
-    case FKParameters::ActiveConventional:
-      return 4;
+      return shift+2;
+    case FKParameters::LDS3:
+      return shift+3;
+    default:
+      shift+=4;
+      break;
     }
-    break;
-  case StationSignals::VerticalComponent:
+  }
+  if(c & StationSignals::HorizontalComponent) {
     switch(t) {
-    case FKParameters::RDS:
-    case FKParameters::RDSRefined:
-    case FKParameters::Omni:
-    case FKParameters::PoggiRadial:
-    case FKParameters::PoggiVertical:
-    case FKParameters::RDSRadial:
-    case FKParameters::RDSVertical:
-    case FKParameters::RTBF:
-    case FKParameters::RTBFRadial:
+    case FKParameters::LDS2:
+      return shift;
+    case FKParameters::CaponRadial:
+      return shift+1;
+    case FKParameters::CaponTransverse:
+      return shift+2;
+    case FKParameters::ConventionalRadial:
+      return shift+3;
+    case FKParameters::ConventionalTransverse:
+      return shift+4;
+    default:
+      shift+=5;
       break;
-    case FKParameters::Conventional:
-      return 1;
-    case FKParameters::ActiveDS:
-      return 2;
-    case FKParameters::ActiveRTBF:
-      return 2;
-    case FKParameters::ActiveConventional:
-      return 3;
     }
-    break;
+  }
+  if(c & StationSignals::VerticalComponent) {
+    switch(t) {
+    case FKParameters::Capon:
+      return shift;
+    case FKParameters::Conventional:
+      return shift+1;
+    case FKParameters::ActiveCapon:
+      return shift+2;
+    case FKParameters::ActiveConventional:
+      return shift+3;
+    default:
+      shift+=4;
+      break;
+    }
+    if(c==StationSignals::AllComponent) {
+      switch(t) {
+      case FKParameters::ActiveConventionalRayleigh:
+        return shift;
+      case FKParameters::ActiveRTBF:
+        return shift+1;
+      default:
+        shift+=2;
+        break;
+      }
+    }
   }
   return 0;
 }
@@ -586,85 +592,91 @@ void FKToolWidget::on_freqScroll_valueChanged(int index)
   parametersChanged();
 }
 
-void FKToolWidget::on_testFrequency_valueChanged(const QString&)
+void FKToolWidget::on_testFrequency_valueChanged(double)
 {
   TRACE;
   _currentTestFrequency=testFrequency->value();
 }
 
-void FKToolWidget::setRunning(bool r, const QString& message)
+void FKToolWidget::on_processTypeEdit_activated(int index)
 {
   TRACE;
-  startBut->setEnabled(!r);
-  stopBut->setEnabled(r);
-  if(r) {
-    if(message.isEmpty()) {
-      mainStatus->setText(tr("Running..."));
-    } else {
-      mainStatus->setText(message);
+  if(Message::question(MSG_ID, tr("Default values"),
+                       tr("Do you want to reset to the default values for processing '%1'?")
+                       .arg(processTypeEdit->itemText(index)),
+                       Message::yes(), Message::no(), true)==Message::Answer0) {
+    parametersFromGui();
+    FKParameters * param=tool()->parameters();
+    if(!_gridStepTouched) {
+      param->setGridStep(0.0);
     }
-  } else {
-    mainStatus->setText(tr("Not running"));
+    if(!_gridSizeTouched) {
+      param->setGridSize(0.0);
+    }
+    param->setDefaultValues();
+    processTypeEdit->blockSignals(true);
+    parametersToGui();
+    processTypeEdit->blockSignals(false);
   }
 }
 
 void FKToolWidget::on_processTypeEdit_currentIndexChanged(int index)
 {
   TRACE;
-  bool threeComp=tool()->array()->components()==StationSignals::AllComponent;
   FKParameters::ProcessType t=processType(index);
   switch(t) {
-  case FKParameters::RDS:
-  case FKParameters::RDSRefined:
+  case FKParameters::ARDS:
+  case FKParameters::SensorOrientation:
+  case FKParameters::RDSSingle:
+  case FKParameters::LDS2:
+  case FKParameters::LDS3:
   case FKParameters::Omni:
-  case FKParameters::RDSRadial:
-  case FKParameters::RDSVertical:
     dampingFactorEdit->setEnabled(true);
-    srcRecDistance->setEnabled(false);
     rotateStepCountEdit->setEnabled(false);
+    srcRecDistance->setEnabled(false);
     break;
+  case FKParameters::Undefined:
+  case FKParameters::Capon:
+    dampingFactorEdit->setEnabled(true);
+    rotateStepCountEdit->setEnabled(false);
+    srcRecDistance->setEnabled(false);
+    break;
+  case FKParameters::CaponRadial:
+  case FKParameters::CaponTransverse:
   case FKParameters::RTBF:
-  case FKParameters::RTBFRadial:
+  case FKParameters::ARTBF:
+  case FKParameters::RTBFFixedEll:
   case FKParameters::PoggiRadial:
   case FKParameters::PoggiVertical:
     dampingFactorEdit->setEnabled(true);
-    rotateStepCountEdit->setEnabled(threeComp);
+    rotateStepCountEdit->setEnabled(true);
     srcRecDistance->setEnabled(false);
     break;
   case FKParameters::Conventional:
     dampingFactorEdit->setEnabled(false);
-    rotateStepCountEdit->setEnabled(threeComp);
+    rotateStepCountEdit->setEnabled(false);
+    srcRecDistance->setEnabled(false);
+    break;
+  case FKParameters::ConventionalRadial:
+  case FKParameters::ConventionalTransverse:
+  case FKParameters::ConventionalRayleigh:
+    dampingFactorEdit->setEnabled(false);
+    rotateStepCountEdit->setEnabled(true);
     srcRecDistance->setEnabled(false);
     break;
-  case FKParameters::ActiveDS:
   case FKParameters::ActiveRTBF:
+  case FKParameters::ActiveCapon:
     dampingFactorEdit->setEnabled(true);
     rotateStepCountEdit->setEnabled(false);
     srcRecDistance->setEnabled(true);
     break;
   case FKParameters::ActiveConventional:
+  case FKParameters::ActiveConventionalRayleigh:
     dampingFactorEdit->setEnabled(false);
     rotateStepCountEdit->setEnabled(false);
     srcRecDistance->setEnabled(true);
     break;
   }
-  if(Message::question(MSG_ID, tr("Default values"),
-                       tr("Do you want to reset to the default values for processing '%1'?")
-                       .arg(processTypeEdit->itemText(index)),
-                       Message::yes(), Message::no(), true)==Message::Answer0) {
-    FKParameters param;
-    getParameters(param);
-    if(!_gridStepTouched) {
-      param.setGridStep(0.0);
-    }
-    if(!_gridSizeTouched) {
-      param.setGridSize(0.0);
-    }
-    param.setDefaultValues(param.processType(), param.inversionMethod());
-    processTypeEdit->blockSignals(true);
-    setParameters(&param);
-    processTypeEdit->blockSignals(false);
-  }
   parametersChanged();
 }
 
