@@ -156,7 +156,7 @@ void ToolNR::t0Apply()
     grid.setGrid(_shots[0]->receivers()->first()->samplingPeriod());
     grid.function()->setTimeLimits(timeLimits);
     grid.function()->setReceiverRange(minRecIndex, maxRecIndex);
-    grid.globalMax();
+    grid.globalMax(0.0);
     shifts[i]=grid.bestShift();
   }
   // Caluclate the average shift
