@@ -42,7 +42,7 @@ public:
   void createObjects(const SubSignalPool* subPool);
   void setWindowTitle(QString title) {GraphicSheetMenu::setWindowTitle(title);}
 private:
-  QVector<IrregularGrid2DPlot *> _gridLayers;
+  VectorList<IrregularGrid2DPlot *> _gridLayers;
 };
 
 #endif
