@@ -38,6 +38,7 @@ int main(int argc, char ** argv)
 {
   CoreApplication a(argc, argv, help);
 
+  a.setStreamPrefix("gpcoord: ");
   // Options
   CoordReader reader;
   if(reader.setOptions(argc, argv) &&
@@ -65,6 +66,7 @@ ApplicationHelp * help()
                                      "See option '-lookup' for FILE format.");
   h->addOption("-azimuth","Input must be X1 Y1 [Z1] X2 Y2 [Z2]. Output is in degrees from north (Y axis).");
   h->addOption("-azimuth-geo","Input must be LONG1 LAT1 [Z1] LONG2 LAT2 [Z2]. Output is in degrees from north.");
+  h->addOption("-azimuth-lookup FILE","Input must be NAME1 NAME2. Output is in degrees clockwise from north.");
   h->addOption("-from-geo","Input must be LONG LAT [Z [NAME]] in degrees (Z in meters). Output in rectangular coordinates X Y Z (m). "
                            "Option -reference must be supplied.");
   h->addOption("-to-geo","Input must be X Y [Z [NAME]] in meters. Output geographical coordinates LONG LAT Z in degrees. "
@@ -92,13 +94,20 @@ ApplicationHelp * help()
   h->addOption("-reference LONG LAT","Set geographical coordinates at origin of rectangular coordinates (0,0).");
   h->addOption("-translate TX TY","Input must be X Y [Z [NAME]]. Translates by vection (TX,TY).");
   h->addOption("-rotate ANGLE","Input must be X Y [Z [NAME]]. Rotates around origin (0,0) counterclockwise with ANGLE in degrees.");
+  h->addOption("-project FILE","Input must be X Y DELTA. Projects intput points on polygon defined by FILE. Format of FILE is the same as -lookup."
+                               "After projection, moves point along the polygon by DELTA (can be + or -).");
+  h->addOption("-invert-trans-rot REF_FILE","Input must be X Y [Z] NAME. Invert the translation and rotation required to match the input with REF_FILE. "
+                                            "See option '-lookup' for REF_FILE format.");
   h->addOption("-average","Input must be X Y [Z] from a fixed station. Output X Y [Z]. Coordinates can be lat/long or "
                           "cartesian.");
   h->addOption("-lookup FILE","Return the coordinates of points referenced by their names. "
                               "Input must be NAME. Output X Y [Z] NAME. FILE must contains "
                               "points with format X Y Z NAME");
-  h->addOption("-localize X Y","Input must be DISTANCE AZIMUTH from reference point X Y. Output are X Y of points shifted from "
-                               "reference point by DISTANCE and AZIMUTH. X Y are the rectangular coordinates of the reference point");
+  h->addOption("-localize X Y [Z]","Input must be DISTANCE H_ANGLE [[V_ANGLE] NAME]. Output are the coordinates of points shifted from reference point by oblique DISTANCE, horizontal H_ANGLE and vertical V_ANGLE. "
+                                "X Y Z are the rectangular coordinates of the reference point. If V_ANGLE is not provided, Z is ignored. This option can be used with measurements made with a total station.");
+  h->addOption("-line-move FILE","Input must be NAME1 NAME2 DISTANCE NAME. The coordinates of a point shifted from point NAME1 to "
+                                 "NAME2 by DISTANCE. NAME1 and NAME2 are found in FILE. See option '-lookup' for FILE format. "
+                                 "DISTANCE can be negative. New point is named NAME.");
   h->addOption("-trig-dist FILE","Triangulate from known distances to at least two reference points. "
                                  "Input must be NAME DISTANCE. Output X Y DX DY. FILE must contains the "
                                  "reference points with format X Y [Z] NAME");
@@ -106,10 +115,36 @@ ApplicationHelp * help()
                                "Input must be NAME AZIMUTH. Output X Y DX DY. FILE must contains the "
                                "reference points with format X Y [Z] NAME");
   h->addOption("-from-distances","Input must be NAME1 NAME2 DISTANCE. Output are X Y of named points (see -origin and -north).");
-  h->addOption("-circle RADIUS N [I0]","Generate a set of N coordinates distributed on a circle of RADIUS, plus a center at 0 0. "
-               "Coordinates are named starting at index I0 (0 by default).");
-  h->addOption("-array-limits", "Computes Kmin and Kmax for the input coordinates X Y [Z NAME].");
   h->addOption("-no-progress","Hides progress information through terminal");
+  h->addGroup("Array", "array");
+  h->addOption("-array-limits", "Computes Kmin and Kmax for the input coordinates X Y [Z NAME].");
+  h->addOption("-array-pattern DIR", "Computes the array theoretical pattern in direction DIR in degrees counted clockwise from north.\n"
+                                     "The value and the first two derivatives are output. Use -translate to move the center to something else than the origin.");
+  h->addOption("-circles","Generate a set of sensors distributed on circles. "
+                          "The radius provided by -radius is the maximum radius.");
+  h->addOption("-triangles","Generate a set of nested triangles. "
+                            "The radius provided by -radius is the maximum radius.");
+  h->addOption("-random","Generate a set of N coordinates randomly distributed inside a circle of RADIUS. "
+                                                     "The smallest distance between two staions is MIN_DISTANCE. Coordinates are named starting at index I0 (0 by default).");
+  h->addOption("-markov-chain","Generate a set of N coordinates randomly distributed inside a circle of RADIUS using a Markov chain with N_STEPS. "
+                                                                   "The smallest distance between two staions is MIN_DISTANCE. Coordinates are named starting at index I0 (0 by default).");
+  h->addOption("-circle-grid","Generate a set of N coordinates aligned on a grid inside a circle of RADIUS. "
+                                             "Coordinates are named starting at index I0 (0 by default).");
+  h->addOption("-random-grid-circle RADIUS N ERR [I0]","Generate a set of N coordinates nearly (random maximum error ERR) aligned on a grid inside a circle of RADIUS. "
+                                                        "Coordinates are named starting at index I0 (0 by default).");
+  h->addOption("-size N", "Number of sensors (default=15).");
+  h->addOption("-radius R", "Maximum distance from origin (default=100).");
+  h->addOption("-first-index I0", "Index of the first sensor (default=0). If it is greater than 0, no sensor at origin is generated (only for circles or triangles).");
+  h->addOption("-circle-count NC", "Number of circles (default=2).");
+  h->addOption("-radius-factor RF", "Radius factor betwen successive circles (default=3).");
+  h->addOption("-minimum-distance D", "Minimum distance between sensors (default=R/ceil(sqrt(N))).");
+  h->addOption("-step-count NS", "Number of Markov-chain steps (default=2).");
+  h->addOption("-maximum-step S", "Maximum length of Markov-chain steps (default=R/ceil(sqrt(N))).");
+  h->addOption("-maximum-deviation E", "Maximum deviation from grid postion for -random-grid (default=R/ceil(sqrt(N)).");
+  h->addOption("-center X Y", "Set center of array to X, Y\n");
+  h->addOption("-add-sensors FILE", "Add sensors before the generation. Modifies sensors generation for random placement only.");
+  h->addOption("-add-include-polygon FILE", "When generating stations of an array, accept only stations inside polygon defined in FILE. Format of FILE is the same as -lookup.");
+  h->addOption("-add-exclude-polygon FILE", "When generating stations of an array, accept only stations outside polygon defined in FILE. Format of FILE is the same as -lookup.");
   h->addGroup("from distance", "fromdistance");
   h->addOption("-stddev VALUE","The estimated standard deviation of distance measurements (default=1cm).");
   h->addOption("-origin NAME","Sets point named NAME as the origin of the relative coordinates, solves translation ambiguity (see -from-distances).");
@@ -120,5 +155,14 @@ ApplicationHelp * help()
   h->addOption("-posterior-precision VALUE","Sets precision of posterior localizations (default=0.05m).");
   h->addOption("-cluster-count N", "Aggregate robust quads using N random combinations (default=500).");
   h->addOption("-out MODE","Sets output mode: none, mean, raw, ellipse, clusters (default=mean). Several modes can be combined.");
+  h->addGroup("Angle", "angle");
+  h->addOption("-degrees", "Input angles are degrees (default).");
+  h->addOption("-radians", "Input angles are radians.");
+  h->addOption("-gradians", "Input angles are gradians (or gon).");
+  h->addGroup("Inversion", "inversio ");
+  h->addOption("-report <NAME>","Output generated models to NAME file.");
+  h->addOption("-ns0 <NS0>","Number of initial models (default=50).");
+  h->addOption("-ns <NS>","Number of models generated (default=2500).");
+  h->addOption("-nr <NR>","Number of best cells (default=50).");
   return h;
 }
