@@ -42,16 +42,18 @@
 CurveReader::CurveReader()
     : ArgumentStdinReader()
 {
-  TRACE;
   _mode=None;
   _nResample=100;
   _minX=-std::numeric_limits<double>::infinity();
   _maxX=std::numeric_limits<double>::infinity();
+  _minY=-std::numeric_limits<double>::infinity();
+  _maxY=std::numeric_limits<double>::infinity();
   _dx=1;
+  _dy=1;
   _xValue=0.0;
   _columnIndex=1;
   _samplingType=LinearScale;
-  _misfitType=L2_Normalized;
+  _misfitType=Misfit::L2_Normalized;
   _misfitMin=0.0;
   _misfitDof=1;
   _logBase=10.0;
@@ -59,6 +61,15 @@ CurveReader::CurveReader()
   _splitMaxX=1.2;
   _splitMaxErr=1e-4;
   _splitMinCount=4;
+  _curveCount=0;
+  _cubicSpline=nullptr;
+  _bSpline=nullptr;
+}
+
+CurveReader::~CurveReader()
+{
+  delete _cubicSpline;
+  delete _bSpline;
 }
 
 bool CurveReader::setOptions(int& argc, char ** argv)
@@ -119,7 +130,9 @@ bool CurveReader::setOptions(int& argc, char ** argv)
         _mode=MinValue;
       } else if(arg=="-value") {
         CoreApplication::checkOptionArg(i, argc, argv);
-        _mode=FunctionValue;
+        if(_mode==None) {
+          _mode=FunctionValue;
+        }
         _xValue=CoreApplication::toDouble(i, i-1, argv);
       } else if(arg=="-merge-replace") {
         CoreApplication::checkOptionArg(i, argc, argv);
@@ -131,6 +144,14 @@ bool CurveReader::setOptions(int& argc, char ** argv)
         _referenceFile=argv[i];
       } else if(arg=="-minmax") {
         _mode=MinMax;
+      } else if(arg=="-mean") {
+        _mode=Mean;
+      } else if(arg=="-stddev") {
+        _mode=Stddev;
+      } else if(arg=="-stddev-inf") {
+        _mode=StddevInf;
+      } else if(arg=="-stddev-sup") {
+        _mode=StddevSup;
       } else if(arg=="-misfit") {
         CoreApplication::checkOptionArg(i, argc, argv);
         _mode=Misfit;
@@ -153,28 +174,114 @@ bool CurveReader::setOptions(int& argc, char ** argv)
         CoreApplication::checkOptionArg(i, argc, argv);
         _mode=Multiply;
         _multiplyFactor=CoreApplication::toDouble(i, i-1, argv);
-      } else if(arg=="-function") {
+      } else if(arg=="-function-1d" || arg=="-function") {
         CoreApplication::checkOptionArg(i, argc, argv);
-        _mode=ParseFunction;
+        _mode=ParseFunction1D;
         _functionText=argv[i];
+      } else if(arg=="-function-2d") {
+        CoreApplication::checkOptionArg(i, argc, argv);
+        _mode=ParseFunction2D;
+        _functionText=argv[i];
+      } else if(arg=="-cubic-spline") {
+        if(_cubicSpline) {
+          App::log(tr("gpcurve: only one option '-cubic-spline' allowed.\n"));
+          return false;
+        }
+        _mode=CubicSplineMode;
+        int splineOption=i;
+        double x;
+        VectorList<double> y(1);
+        _referenceCurve.clear();
+        while(true) {
+          if(!CoreApplication::checkOptionArg(i, argc, argv, false)) {
+            break;
+          }
+          x=CoreApplication::toDouble(i, splineOption, argv);
+          if(!CoreApplication::checkOptionArg(i, argc, argv, false)) {
+            App::log(tr("gpcurve: an even number of arguments is required for option '-cubic-spline'.\n"));
+            return false;
+          }
+          y.first()=CoreApplication::toDouble(i, splineOption, argv);
+          _referenceCurve.append(PointND(x, y));
+        }
+        if(_referenceCurve.count()<2) {
+          App::log(tr("gpcurve: at least two knots are required for option '-cubic-spline'.\n"));
+          return false;
+        }
+        _cubicSpline=new CubicSpline (_referenceCurve.count());
+        for(int i=_referenceCurve.count()-1; i>=0; i--) {
+          _cubicSpline->setKnot(i, _referenceCurve.constAt(i).point2D(nullptr));
+        }
+        _cubicSpline->init();
+      } else if(arg=="-b-spline") {
+        if(_bSpline) {
+          App::log(tr("gpcurve: only one option '-b-spline' allowed.\n"));
+          return false;
+        }
+        _mode=BSplineMode;
+        int splineOption=i;
+        CoreApplication::checkOptionArg(i, argc, argv, true);
+        double n=CoreApplication::toInt(i, splineOption, argv);
+        if(n<0) {
+          App::log(tr("gpcurve: degree must greater or equal to 0 for option '-b-spline'.\n"));
+          return false;
+        }
+        double x;
+        VectorList<double> y(1);
+        _referenceCurve.clear();
+        while(true) {
+          if(!CoreApplication::checkOptionArg(i, argc, argv, false)) {
+            break;
+          }
+          x=CoreApplication::toDouble(i, splineOption, argv);
+          if(!CoreApplication::checkOptionArg(i, argc, argv, false)) {
+            App::log(tr("gpcurve: an odd number of arguments is required for option '-b-spline'.\n"));
+            return false;
+          }
+          y.first()=CoreApplication::toDouble(i, splineOption, argv);
+          _referenceCurve.append(PointND(x, y));
+        }
+        if(_referenceCurve.isEmpty()) {
+          App::log(tr("gpcurve: at least one control point is required for option '-b-spline'.\n"));
+          return false;
+        }
+        _bSpline=new BSpline (_referenceCurve.count(), n);
+        for(int i=_referenceCurve.count()-1; i>=0; i--) {
+          _bSpline->setControlPoint(i, _referenceCurve.constAt(i).point2D(nullptr));
+        }
       } else if(arg=="-misfit-type") {
         CoreApplication::checkOptionArg(i, argc, argv);
-        _misfitType=RealStatisticalValue::misfitType(argv[i] );
+        QString t(argv[i]);
+        bool ok=true;
+        _misfitType=Misfit::convertType(t, ok);
+        if(!ok) {
+          App::log(tr("gpcurve: bad misfit type '%1'\n").arg(argv[i]));
+          return false;
+        }
       } else if(arg=="-misfit-min") {
         CoreApplication::checkOptionArg(i, argc, argv);
         _misfitMin=atof(argv[i] );
       } else if(arg=="-misfit-dof") {
         CoreApplication::checkOptionArg(i, argc, argv);
         _misfitDof=atoi(argv[i] );
-      } else if(arg=="-min") {
+      } else if(arg=="-min-x" || arg=="min") {
         CoreApplication::checkOptionArg(i, argc, argv);
         _minX=CoreApplication::toDouble(i, i-1, argv);
-      } else if(arg=="-max") {
+      } else if(arg=="-max-x" || arg=="max") {
         CoreApplication::checkOptionArg(i, argc, argv);
         _maxX=CoreApplication::toDouble(i, i-1, argv);
       } else if(arg=="-dx") {
         CoreApplication::checkOptionArg(i, argc, argv);
         _dx=CoreApplication::toDouble(i, i-1, argv);
+      } else if(arg=="-min-y") {
+        CoreApplication::checkOptionArg(i, argc, argv);
+        _minY=CoreApplication::toDouble(i, i-1, argv);
+      } else if(arg=="-max-y") {
+        CoreApplication::checkOptionArg(i, argc, argv);
+        _maxY=CoreApplication::toDouble(i, i-1, argv);
+      } else if(arg=="-dy") {
+        CoreApplication::checkOptionArg(i, argc, argv);
+        _dy=CoreApplication::toDouble(i, i-1, argv);
       } else if(arg=="-angles") {
         _mode=Angles;
       } else if(arg=="-split") {
@@ -194,8 +301,8 @@ bool CurveReader::setOptions(int& argc, char ** argv)
         _mode=Extrapolate;
       } else if(arg=="-sampling") {
         CoreApplication::checkOptionArg(i, argc, argv);
-        if(strcmp(argv[i],"inversed")==0) {
-          _samplingType=InversedScale;
+        if(strcmp(argv[i],"inverse")==0) {
+          _samplingType=InverseScale;
         } else if(strcmp(argv[i],"linear")==0) {
           _samplingType=LinearScale;
         } else if(strcmp(argv[i],"log")==0) {
@@ -212,13 +319,27 @@ bool CurveReader::setOptions(int& argc, char ** argv)
       argv[j++]=argv[i];
     }
   }
-  if(j < argc) {
+  if(j<argc) {
     argv[j]=nullptr;
     argc=j;
   }
   return true;
 }
 
+bool CurveReader::isInputCurveRequired() const
+{
+  TRACE;
+  switch(_mode) {
+  case ParseFunction1D:
+  case ParseFunction2D:
+  case BSplineMode:
+    return false;
+  default:
+    break;
+  }
+  return true;
+}
+
 bool CurveReader::parse(QTextStream& s)
 {
   TRACE;
@@ -226,13 +347,13 @@ bool CurveReader::parse(QTextStream& s)
   Curve<PointND> curve;
   QString comments;
   while(curve.fromStream(s, &comments)) {
-    sOut << comments << flush;
+    sOut << comments << Qt::flush;
     if(!exec(curve)) {
       return false;
     }
     comments.clear();
   }
-  sOut << comments << flush;
+  sOut << comments << Qt::flush;
   return exec(curve);
 }
 
@@ -244,6 +365,8 @@ bool CurveReader::exec(Curve<PointND>& curve)
     App::log(tr("At least 2 samples are required to define a curve\n") );
     return false;
   }
+  _curveCount++;
+  int firstIndex=0, lastIndex=curve.count()-1;
   switch(_mode) {
   case ResampleExtrapole:
   case Resample:
@@ -251,12 +374,13 @@ bool CurveReader::exec(Curve<PointND>& curve)
   case CutInterpole:
   case Smooth:
     curve.sort();
-    // const must be passed to Curve to avoid reset of sorted flag
+    curve.firstValid(firstIndex);
+    curve.lastValid(lastIndex);
     if(_minX==-std::numeric_limits<double>::infinity()) {
-      _minX=const_cast<const Curve<PointND>&>(curve).firstX();
+      _minX=curve.constAt(firstIndex).x();
     }
     if(_maxX==std::numeric_limits<double>::infinity()) {
-      _maxX=const_cast<const Curve<PointND>&>(curve).lastX();
+      _maxX=curve.constAt(lastIndex).x();
     }
     break;
   default:
@@ -265,7 +389,8 @@ bool CurveReader::exec(Curve<PointND>& curve)
   PointNDOptions pointOptions(_columnIndex-1);
   switch(_mode) {
   case None:
-  case ParseFunction:
+  case ParseFunction1D:
+  case ParseFunction2D:
     break;
   case ResampleExtrapole:
     curve.resample(_nResample, _minX, _maxX, _samplingType);
@@ -274,11 +399,13 @@ bool CurveReader::exec(Curve<PointND>& curve)
   case Resample: {
       // _minX and _maxX can be set by the user to any value, not linked to actual range of curve
       // To avoid extrapolation we want to keep the original range of the curve
-      double minOriginalX=const_cast<const Curve<PointND>&>(curve).firstX();
-      double maxOriginalX=const_cast<const Curve<PointND>&>(curve).lastX();
+      curve.firstValid(firstIndex);
+      curve.lastValid(lastIndex);
+      double minOriginalX=curve.constAt(firstIndex).x();
+      double maxOriginalX=curve.constAt(lastIndex).x();
       curve.resample(_nResample, _minX, _maxX, _samplingType);
       curve.cut(minOriginalX, maxOriginalX, LinearScale);
-      sOut << curve.toString();
+      sOut << curve.toString('g', 20);
     }
     break;
   case Cut:
@@ -292,8 +419,8 @@ bool CurveReader::exec(Curve<PointND>& curve)
       case LogScale:
         s.setScaleType(SamplingParameters::Log);
         break;
-      case InversedScale:
-        s.setScaleType(SamplingParameters::Inversed);
+      case InverseScale:
+        s.setScaleType(SamplingParameters::Inverse);
         break;
       default:
         s.setScaleType(SamplingParameters::Linear);
@@ -324,7 +451,7 @@ bool CurveReader::exec(Curve<PointND>& curve)
   case MinValue: {
       int i=curve.minimumY(0, &pointOptions);
       ASSERT(i>-1);
-      sOut << curve.constAt(i).toString(20) << "\n";
+      sOut << curve.constAt(i).toString('g', 20) << "\n";
     }
     break;
   case MaxIndex:
@@ -333,7 +460,7 @@ bool CurveReader::exec(Curve<PointND>& curve)
   case MaxValue: {
       int i=curve.maximumY(0, &pointOptions);
       ASSERT(i>-1);
-      sOut << curve.constAt(i).toString(20) << "\n";
+      sOut << curve.constAt(i).toString('g', 20) << "\n";
     }
     break;
   case LocalMin: {
@@ -341,7 +468,7 @@ bool CurveReader::exec(Curve<PointND>& curve)
       while(i>=0) {
         sOut << i << " "
              << curve.y(i, &pointOptions) << " "
-             << 2.0*curve.y(i, &pointOptions)/(curve.y(i-1, &pointOptions)+curve.y(i+1, &pointOptions)) << ::endl;
+             << 2.0*curve.y(i, &pointOptions)/(curve.y(i-1, &pointOptions)+curve.y(i+1, &pointOptions)) << Qt::endl;
         i=curve.localMinimumY(i, &pointOptions);
       }
     }
@@ -349,7 +476,7 @@ bool CurveReader::exec(Curve<PointND>& curve)
   case LocalMinIndex: {
       int i=curve.localMinimumY(0, &pointOptions);
       while(i>=0) {
-        sOut << i << ::endl;
+        sOut << i << Qt::endl;
         i=curve.localMinimumY(i, &pointOptions);
       }
     }
@@ -357,7 +484,7 @@ bool CurveReader::exec(Curve<PointND>& curve)
   case LocalMinValue: {
       int i=curve.localMinimumY(0, &pointOptions);
       while(i>=0) {
-        sOut << curve.y(i, &pointOptions) << ::endl;
+        sOut << curve.y(i, &pointOptions) << Qt::endl;
         i=curve.localMinimumY(i, &pointOptions);
       }
     }
@@ -367,7 +494,7 @@ bool CurveReader::exec(Curve<PointND>& curve)
       while(i>=0) {
         sOut << i << " "
              << curve.y(i, &pointOptions) << " "
-             << 2.0*curve.y(i, &pointOptions)/(curve.y(i-1, &pointOptions)+curve.y(i+1, &pointOptions)) << ::endl;
+             << 2.0*curve.y(i, &pointOptions)/(curve.y(i-1, &pointOptions)+curve.y(i+1, &pointOptions)) << Qt::endl;
         i=curve.localMaximumY(i, &pointOptions);
       }
     }
@@ -375,7 +502,7 @@ bool CurveReader::exec(Curve<PointND>& curve)
   case LocalMaxIndex: {
       int i=curve.localMaximumY(0, &pointOptions);
       while(i>=0) {
-        sOut << i << ::endl;
+        sOut << i << Qt::endl;
         i=curve.localMaximumY(i, &pointOptions);
       }
     }
@@ -383,14 +510,24 @@ bool CurveReader::exec(Curve<PointND>& curve)
   case LocalMaxValue: {
       int i=curve.localMaximumY(0, &pointOptions);
       while(i>=0) {
-        sOut << curve.y(i, &pointOptions) << ::endl;
+        sOut << curve.y(i, &pointOptions) << Qt::endl;
         i=curve.localMaximumY(i, &pointOptions);
       }
     }
     break;
   case FunctionValue:
     curve.sort();
-    sOut << curve.interpole(_xValue).toString(20) << "\n";
+    sOut << curve.interpole(_xValue, LinearScale, LinearScale).toString('g', 20) << "\n";
+    break;
+  case CubicSplineMode:
+    curve.sort();
+    for(int i=0;i<curve.count();i++) {
+      const PointND& p=curve.constAt(i);
+      sOut << QString::number(p.x(), 'g', 20) << " "
+           << QString::number(_cubicSpline->value(p.x()), 'g', 20) << "\n";
+    }
+    break;
+  case BSplineMode:
     break;
   case MergeReplace: {
       loadReference();
@@ -398,9 +535,9 @@ bool CurveReader::exec(Curve<PointND>& curve)
         const PointND& p=curve.constAt(i);
         int index=_referenceCurve.indexAfter(p.x());
         if(index<_referenceCurve.count() && _referenceCurve.x(index)==p.x()) {
-          sOut << _referenceCurve.constAt(index).toString(20) << "\n";
+          sOut << _referenceCurve.constAt(index).toString('g', 20) << "\n";
         } else {
-          sOut << p.toString(20) << "\n";
+          sOut << p.toString('g', 20) << "\n";
         }
       }
     }
@@ -409,7 +546,7 @@ bool CurveReader::exec(Curve<PointND>& curve)
       loadReference();
       for(int i=0;i<curve.count();i++) {
         const PointND& p=curve.constAt(i);
-        sOut << p.toString(20) << " " << _referenceCurve.interpole(p.x()).toString(20) << "\n";
+        sOut << p.toString('g', 20) << " " << _referenceCurve.interpole(p.x(), LinearScale, LinearScale).toString('g', 20) << "\n";
       }
     }
     break;
@@ -423,13 +560,15 @@ bool CurveReader::exec(Curve<PointND>& curve)
         double step=c.minimumStep(_samplingType);
         int n;
         if(_samplingType & LogScale) {
-          n=1+qRound(log(c.interpole(max).x()/c.interpole(min).x())/log(step));
+          n=1+qRound(log(c.interpole(max, LinearScale, LinearScale).x()
+                         /c.interpole(min, LinearScale, LinearScale).x())/log(step));
         } else {
-          n=1+qRound(c.interpole(max).x()-c.interpole(min).x()/step);
+          n=1+qRound(c.interpole(max, LinearScale, LinearScale).x()
+                     -c.interpole(min, LinearScale, LinearScale).x()/step);
         }
         c.resample(n, min, max, _samplingType);
         sOut << "# split " << i << ": " << c.count() << " samples\n";
-        sOut << c.toString(20);
+        sOut << c.toString('g', 20);
       }
     }
     break;
@@ -470,6 +609,38 @@ bool CurveReader::exec(Curve<PointND>& curve)
       }
     }
     break;
+  case Mean: {
+      if(_minCurve.count()==0) {
+        _minCurve=curve;
+      } else {
+        if(_minCurve.count()!=curve.count() ||
+           _minCurve.constAt(0).count()!=curve.constAt(0).count()) {
+          App::log(tr("Curves must have exactly the same sampling.\n") );
+          return false;
+        }
+        _minCurve.ySum(curve);
+      }
+    }
+    break;
+  case Stddev:
+  case StddevInf:
+  case StddevSup: {
+      if(_minCurve.count()==0) {
+        _minCurve=curve;
+        _maxCurve=curve;
+        _maxCurve.ySquare();
+      } else {
+        if(_minCurve.count()!=curve.count() ||
+           _minCurve.constAt(0).count()!=curve.constAt(0).count()) {
+          App::log(tr("Curves must have exactly the same sampling.\n") );
+          return false;
+        }
+        _minCurve.ySum(curve);
+        curve.ySquare();
+        _maxCurve.ySum(curve);
+      }
+    }
+    break;
   case Derivative:
     if(curve.count()<3) {
       App::log(tr("At least 3 samples per curve are required to calculate derivative\n") );
@@ -516,35 +687,37 @@ bool CurveReader::exec(Curve<PointND>& curve)
       int nData=0, nValues =0;
       for(int i=0;i<curve.count();i++) {
         const PointND& p=curve.constAt(i);
-        PointND r=_referenceCurve.interpole(p.x());
+        PointND r=_referenceCurve.interpole(p.x(), LinearScale, LinearScale);
         RealStatisticalValue sv(r.y(0), r.y(1));
         RealValue v(p.y(0));
         sum += sv.misfit(nValues, nData, v, _misfitType, _misfitMin);
       }
       switch(_misfitType) {
-      case L1:
-      case L1_Normalized:
-      case L1_LogNormalized:
-      case L1_NormalizedBySigmaOnly:
+      case Misfit::L1:
+      case Misfit::L1_Normalized:
+      case Misfit::L1_LogNormalized:
+      case Misfit::L1_NormalizedBySigmaOnly:
         sOut << sum/curve.count() << "\n";
         break;
-      case RMS:
+      case Misfit::RMS:
         sOut << sqrt(sum/curve.count()) << "\n";
         break;
-      case L2:
-      case L2_Normalized:
-      case L2_LogNormalized:
-      case L2_NormalizedBySigmaOnly:
+      case Misfit::L2:
+      case Misfit::L2_Inverse:
+      case Misfit::L2_Normalized:
+      case Misfit::L2_LogNormalized:
+      case Misfit::L2_NormalizedBySigmaOnly:
         sOut << sqrt(sum) << "\n";
         break;
-      case Akaike:
+      case Misfit::Akaike:
         sOut << curve.count()*log(sqrt(sum/curve.count()))+2.0*_misfitDof << "\n";
         break;
-      case AkaikeFewSamples:
+      case Misfit::AkaikeFewSamples:
         sOut << curve.count()*log(sqrt(sum/curve.count()))
                +2.0*_misfitDof+(2.0*_misfitDof*(_misfitDof+1.0))/(curve.count()-_misfitDof-1.0) << "\n";
         break;
-      case Determinant:
+      case Misfit::Determinant:
+      case Misfit::TypeCount:
         ASSERT(false);
       }
     }
@@ -573,7 +746,7 @@ bool CurveReader::exec(Curve<PointND>& curve)
     sOut << curve.toString();
     break;
   }
-  sOut << flush;
+  sOut << Qt::flush;
   return true;
 }
 
@@ -611,33 +784,6 @@ bool CurveReader::loadReference()
   return true;
 }
 
-void CurveReader::generateFunction() const
-{
-  TRACE;
-  QTextStream sOut(stdout);
-  QJSEngine engine;
-  QJSValue global=engine.globalObject();
-  QJSValue result;
-  if(_functionText.contains("return")) {
-    result=engine.evaluate("function f(x) {"+_functionText+";}");
-  } else {
-    result=engine.evaluate("function f(x) {return "+_functionText+";}");
-  }
-  if(result.isError()) {
-    App::log(tr("Uncaught exception at line %1: %2\n")
-                     .arg(result.property("lineNumber").toInt())
-                     .arg(result.toString()));
-    return;
-  }
-  QJSValue f=global.property("f");
-  for(double x=_minX;x<=_maxX;x+=_dx) {
-    QJSValueList args;
-    args << x;
-    sOut << QString("%1 %2\n").arg(x, 0, 'g', 16).arg(f.call(args).toNumber(), 0, 'g', 16);
-  }
-  sOut << flush;
-}
-
 bool CurveReader::terminate()
 {
   TRACE;
@@ -649,8 +795,122 @@ bool CurveReader::terminate()
          << "# Max\n"
          << _maxCurve.toString();
     break;
+  case Mean:
+    _minCurve.yMultiply(1.0/static_cast<double>(_curveCount));
+    sOut << "# Mean\n"
+         << _minCurve.toString();
+    break;
+  case Stddev: {
+      _minCurve.yMultiply(_minCurve);
+      _minCurve.yMultiply(1.0/static_cast<double>(_curveCount));
+      _maxCurve.ySubtract(_minCurve);
+      _maxCurve.yMultiply(1.0/static_cast<double>(_curveCount-1));
+      _maxCurve.ySqrt();
+      sOut << "# Stddev\n"
+           << _maxCurve.toString();
+    }
+    break;
+  case StddevInf: {
+      Curve<PointND> curve(_minCurve);
+      curve.yMultiply(1.0/static_cast<double>(_curveCount));
+      _minCurve.yMultiply(curve);
+      _maxCurve.ySubtract(_minCurve);
+      _maxCurve.yMultiply(1.0/static_cast<double>(_curveCount-1));
+      _maxCurve.ySqrt();
+      curve.ySubtract(_maxCurve);
+      sOut << "# Stddev inf\n"
+           << curve.toString();
+    }
+    break;
+  case StddevSup: {
+      Curve<PointND> curve(_minCurve);
+      curve.yMultiply(1.0/static_cast<double>(_curveCount));
+      _minCurve.yMultiply(_minCurve);
+      _minCurve.yMultiply(1.0/static_cast<double>(_curveCount));
+      _maxCurve.ySubtract(_minCurve);
+      _maxCurve.yMultiply(1.0/static_cast<double>(_curveCount-1));
+      _maxCurve.ySqrt();
+      curve.ySum(_maxCurve);
+      sOut << "# Stddev sup\n"
+           << curve.toString();
+    }
+    break;
   default:
     break;
   }
   return true;
 }
+
+
+bool CurveReader::execNoInputCurveModes() const
+{
+  TRACE;
+  QTextStream sOut(stdout);
+  switch(_mode) {
+  case ParseFunction1D: {
+      QJSEngine engine;
+      QJSValue global=engine.globalObject();
+      QJSValue result;
+      if(_functionText.contains("return")) {
+        result=engine.evaluate("function f(x) {"+_functionText+";}");
+      } else {
+        result=engine.evaluate("function f(x) {return "+_functionText+";}");
+      }
+      if(result.isError()) {
+        App::log(tr("Uncaught exception at line %1: %2\n")
+                         .arg(result.property("lineNumber").toInt())
+                         .arg(result.toString()));
+        return false;
+      }
+      QJSValue f=global.property("f");
+      for(double x=_minX;x<=_maxX;x+=_dx) {
+        QJSValueList args;
+        args << x;
+        sOut << QString("%1 %2\n").arg(x, 0, 'g', 16).arg(f.call(args).toNumber(), 0, 'g', 16);
+      }
+      sOut << Qt::flush;
+    }
+    break;
+  case ParseFunction2D: {
+      QJSEngine engine;
+      QJSValue global=engine.globalObject();
+      QJSValue result;
+      if(_functionText.contains("return")) {
+        result=engine.evaluate("function f(x,y) {"+_functionText+";}");
+      } else {
+        result=engine.evaluate("function f(x,y) {return "+_functionText+";}");
+      }
+      if(result.isError()) {
+        App::log(tr("Uncaught exception at line %1: %2\n")
+                         .arg(result.property("lineNumber").toInt())
+                         .arg(result.toString()));
+        return false;
+      }
+      sOut << "x y val\n";
+      QJSValue f=global.property("f");
+      for(double y=_minY;y<=_maxY;y+=_dy) {
+        for(double x=_minX;x<=_maxX;x+=_dx) {
+          QJSValueList args;
+          args << x << y;
+          sOut << QString("%1 %2 %3\n").arg(x, 0, 'g', 16).arg(y, 0, 'g', 16).arg(f.call(args).toNumber(), 0, 'g', 16);
+        }
+      }
+      sOut << Qt::flush;
+    }
+    break;
+  case BSplineMode: {
+      double firstT=_bSpline->minimumT();
+      double lastT=_bSpline->maximumT();
+      double dt=0.01*(lastT-firstT);
+      if(dt>0.0) {
+        for(double t=firstT; t<=lastT; t+=dt) {
+          sOut << _bSpline->value(t).toString('g', 20) << "\n";
+        }
+      }
+    }
+    break;
+  default:
+    return false;
+  }
+  return true;
+}
