@@ -34,10 +34,11 @@ class CurveReader : public ArgumentStdinReader
   TRANSLATIONS("ArgumentStdinReader")
 public:
   CurveReader();
+  ~CurveReader();
 
   bool setOptions(int& argc, char ** argv);
-  bool isFunctionMode() const {return _mode==ParseFunction;}
-  void generateFunction() const;
+  bool isInputCurveRequired() const;
+  bool execNoInputCurveModes() const;
   bool terminate();
 protected:
   virtual bool parse(QTextStream& s);
@@ -48,28 +49,30 @@ private:
   enum Mode {None, Resample, ResampleExtrapole, Cut, CutInterpole, Swap, Regression, FunctionValue,
              MaxIndex, MaxValue, MinIndex, MinValue, LocalMax, LocalMaxIndex, LocalMaxValue,
              LocalMin, LocalMinIndex, LocalMinValue,
-             Misfit, MergeReplace, MergeInterpolate, Split, ParseFunction, Derivative, Curvature, Angles,
-             Multiply, Log, Power, MinMax, Extrapolate, Smooth};
+             Misfit, MergeReplace, MergeInterpolate, Split, ParseFunction1D, ParseFunction2D, Derivative, Curvature, Angles,
+             Multiply, Log, Power, MinMax, Mean, Stddev, StddevSup, StddevInf, Extrapolate, Smooth,
+             CubicSplineMode, BSplineMode};
   Mode _mode;
   int _nResample;
-  double _minX;
-  double _maxX;
+  double _minX, _maxX, _minY, _maxY, _dx, _dy;
   double _splitMaxX;
   double _splitMaxErr;
   int _splitMinCount;
-  double _dx;
   double _xValue;
   int _columnIndex;
   SamplingOption _samplingType;
   QString _referenceFile;
   Curve<PointND> _referenceCurve;
-  MisfitType _misfitType;
+  Misfit::Type _misfitType;
   double _misfitMin;
   int _misfitDof;
   QString _functionText;
   double _logBase;
   double _multiplyFactor;
   Curve<PointND> _minCurve, _maxCurve;
+  int _curveCount;
+  CubicSpline * _cubicSpline;
+  BSpline * _bSpline;
 };
 
 #endif // CURVEREADER_H
