@@ -66,13 +66,14 @@ int main(int argc, char ** argv)
   // Options
   CurveReader reader;
   if(reader.setOptions(argc, argv)) {
-    if(reader.isFunctionMode()) {
-      reader.generateFunction();
-      return 0;
-    } else if(reader.read(argc, argv)) {
-      return reader.terminate() ? 0 : 2;
+    if(reader.isInputCurveRequired()) {
+      if(reader.read(argc, argv)) {
+        return reader.terminate() ? 0 : 2;
+      } else {
+        return 2;
+      }
     } else {
-      return 2;
+      return reader.execNoInputCurveModes() ? 0 : 2;
     }
   } else {
     return 2;
@@ -85,8 +86,7 @@ ApplicationHelp * help()
   ApplicationHelp * h=new ApplicationHelp;
   h->setOptionSummary( "[OPTIONS]" );
   h->setComments( "Manipulation of curve given through stdin. The same operations are applied to all curves. "
-                  "Various curves are separated by blank lines or comments('#'). There can be as many column as "
-                  "given by option '-columns'. Other columns are ignored." );
+                  "Various curves are separated by blank lines or comments('#'). There can be many columns." );
   h->addGroup("Mutli-column operations", "multi");
   h->addOption("-resample <N>", "Resample curves. N is the number of output samples. If MIN is -std::numeric_limits<double>::infinity(), the minimum "
                "X of curve are kept (same for MAX).");
@@ -100,8 +100,12 @@ ApplicationHelp * help()
   h->addOption("-value <X>", "Return the interpolated value at X");
   h->addOption("-merge-replace <REF>", "Output curves. For all matching x in curve found in REF, the values of REF are output instead.");
   h->addOption("-merge-interpolate <REF>", "Output curves together with the interpolated values of a reference curve in file REF");
-  h->addOption("-split", "Split a curve made of interlaced samples");
-  h->addOption("-minmax", "Output minimum and maximum curves of all input curves which must have the same sampling");
+  h->addOption("-split", "Split a curve made of interlaced samples.");
+  h->addOption("-minmax", "Output minimum and maximum curves of all input curves which must have the same sampling.");
+  h->addOption("-mean", "Output mean curve of all input curves which must have the same sampling.");
+  h->addOption("-stddev", "Output standard deviation curve of all input curves which must have the same sampling.");
+  h->addOption("-stddev-inf", "Output mean minus one standard deviation of all input curves which must have the same sampling.");
+  h->addOption("-stddev-sup", "Output mean plus one standard deviation of all input curves which must have the same sampling.");
   h->addGroup("Single-column operations", "single");
   h->addOption("-column <COL>", "Set column COL as Y affected by the following options (default=1).");
   h->addOption("-swap", "Swap x and y.");
@@ -124,31 +128,37 @@ ApplicationHelp * help()
   h->addOption("-log <BASE>", "Takes log of Y values with base BASE.");
   h->addOption("-extrapolate <N>", "Add N samples at the beginning and at the end extrapolation from least square regression on N first and last samples.");
   h->addGroup("Function mode", "function");
-  h->addOption("-function <FUNC>", "Output values of expression FUNC from MIN to MAX, x must be the variable parameter. "
-                                   "If FUNC contains 'return' then the expression is executed verbatim. Several statements "
-                                   "separated by ';' are allowed. Else a single expression is evaluated. The first form with "
-                                   "'return' is interesting if you want to use internal variables, for instance:\n"
-                                   "  gpcurve -function \"pi=3.141592; h=2.4;return h*Math.cos(x/180*pi)\"");
-  h->addOption("-min <MIN>", "Minimum X value (default=-std::numeric_limits<double>::infinity())");
-  h->addOption("-max <MAX>", "Maximum X value (default=std::numeric_limits<double>::infinity())");
+  h->addOption("-cubic-spline x0 y0 x1 y1 ...", "Builds a cubic spline passing by the knots (x0, y0), (x1, y1),...");
+  h->addOption("-b-spline N, x0 y0 x1 y1 ...", "Builds a B-spline of degree N and control points (x0, y0), (x1, y1),...");
+  h->addOption("-function-1d <FUNC>", "Output values of expression FUNC from MIN to MAX, x must be the variable parameter. "
+                                      "If FUNC contains 'return' then the expression is executed verbatim. Several statements "
+                                      "separated by ';' are allowed. Else a single expression is evaluated. The first form with "
+                                      "'return' is interesting if you want to use internal variables, for instance:\n"
+                                      "  gpcurve -function \"pi=3.141592; h=2.4;return h*Math.cos(x/180*pi)\"");
+  h->addOption("-function-2d <FUNC>", "Same as its 1D equivalent except that the function takes two arguments: x and y.");
+  h->addOption("-min-x <MIN>", "Minimum X value (default=-std::numeric_limits<double>::infinity())");
+  h->addOption("-max-x <MAX>", "Maximum X value (default=std::numeric_limits<double>::infinity())");
   h->addOption("-dx <DX>", "Sample function with DX step, starting from MIN to MAX.");
+  h->addOption("-min-y <MIN>", "Minimum Y value (default=-std::numeric_limits<double>::infinity())");
+  h->addOption("-max-y <MAX>", "Maximum Y value (default=std::numeric_limits<double>::infinity())");
+  h->addOption("-dy <DY>", "Sample function with DY step, starting from MIN to MAX.");
   h->addExample("gpcurve -function \"(-100.378*x+1.3236e+11)\" -min 1318609364 -max 1318609395", "Computes expression from min to max with default step.");
   h->addGroup("Resample mode", "resample");
-  h->addOption("-min <MIN>", "Minimum X value (default=-std::numeric_limits<double>::infinity())");
-  h->addOption("-max <MAX>", "Maximum X value (default=std::numeric_limits<double>::infinity())");
+  h->addOption("-min <MIN>", "Minimum X value (default=-inf)");
+  h->addOption("-max <MAX>", "Maximum X value (default=inf)");
   h->addOption("-sampling <TYPE>","Defines the sampling type:\n"
-                              "  inversed   regular sampling in 1/X\n"
+                              "  inverse    regular sampling in 1/X\n"
                               "  linear     regular sampling in linear(X) (default)\n"
                               "  log        regular sampling in log(X)");
   h->addGroup("Cut mode", "cut");
-  h->addOption("-min <MIN>", "Minimum X value (default=-std::numeric_limits<double>::infinity())");
-  h->addOption("-max <MAX>", "Maximum X value (default=std::numeric_limits<double>::infinity())");
+  h->addOption("-min <MIN>", "Minimum X value (default=-inf)");
+  h->addOption("-max <MAX>", "Maximum X value (default=inf)");
   h->addGroup("Split mode", "split");
   h->addOption("-max-x <X>", "Maximum distance along X axis to associate neighbor samples (factor in case of log sampling, default=1.2)");
   h->addOption("-max-err <ERR>", "Maximum relative y error of associated samples slopes considered at max-x distance (default=1e-4)");
   h->addOption("-min-count <MIN>", "Minimum number of samples in each curve segment (default=4)");
   h->addOption("-sampling <TYPE>","Defines the sampling type:\n"
-                              "  inversed   regular sampling in 1/X\n"
+                              "  inverse    regular sampling in 1/X\n"
                               "  linear     regular sampling in linear(X) (default)\n"
                               "  log        regular sampling in log(X)");
   h->addGroup("Misfit mode", "misfit");
