@@ -41,7 +41,6 @@
 DispersionReader::DispersionReader()
     : ArgumentStdinReader()
 {
-  TRACE;
   _nRayleigh=1;
   _nLove=0;
   _groupSlowness=false;
@@ -55,7 +54,7 @@ DispersionReader::DispersionReader()
   _oneMode=false;
   _force=false;
   _deltaK=false;
-  _halfSpaceIndex=0;
+  _nu=0.35;
 }
 
 DispersionReader::~DispersionReader()
@@ -118,7 +117,13 @@ bool DispersionReader::setOptions(int& argc, char ** argv)
         _groupSlowness=true;
       } else if(arg=="-s") {
         CoreApplication::checkOptionArg(i, argc, argv);
-        _sampling.setScaleType(argv[i]);
+        QString s(argv[i]);
+        bool ok=true;
+        _sampling.setScaleType(SamplingParameters::convertScaleType(s, ok));
+        if(!ok) {
+          App::log(tr("gpdc: bad scale type '%1'\n").arg(argv[i]));
+          return false;
+        }
       } else if(arg=="-min") {
         CoreApplication::checkOptionArg(i, argc, argv);
         _sampling.setMinimum(CoreApplication::toDouble(i, i-1, argv));
@@ -133,10 +138,10 @@ bool DispersionReader::setOptions(int& argc, char ** argv)
         _sampling.setCount(CoreApplication::toInt(i, i-1, argv));
       } else if(arg=="-half-space") {
         CoreApplication::checkOptionArg(i, argc, argv);
-        _halfSpaceIndex=CoreApplication::toInt(i, i-1, argv);
+        _nu=CoreApplication::toDouble(i, i-1, argv);
         _mode=HalfSpace;
       } else {
-        App::log(tr("gpdc: bad option %1, see -help\n").arg(argv[i]) );
+        App::log(tr("gpdc: bad option %1, see -help\n").arg(argv[i]));
         return false;
       }
     } else {
@@ -171,6 +176,20 @@ bool DispersionReader::setOptions(int& argc, char ** argv)
   return true;
 }
 
+bool DispersionReader::modelLessAction()
+{
+  if(_mode==HalfSpace) {
+    QTextStream s(stdout);
+    s.setRealNumberPrecision(20);
+    //Seismic1DModel::timeComparisonRayleighRelativeVelocity();
+    s << Seismic1DModel::rayleighRelativeVelocity(_nu) << " "
+      << Seismic1DModel::rayleighRelativeVelocityEigenvalue(_nu) << " "
+      << Seismic1DModel::rayleighRelativeVelocityMalischewsky(_nu) << "\n";
+    return true;
+  }
+  return false;
+}
+
 bool DispersionReader::parse(QTextStream& s)
 {
   TRACE;
@@ -276,12 +295,6 @@ bool DispersionReader::parse(QTextStream& s)
       }
       break;
     case HalfSpace:
-      if(_halfSpaceIndex<m.layerCount()) {
-        sOut << m.halfSpaceRayleighSlowness(_halfSpaceIndex) << "\n";
-      } else {
-        App::log(tr("gpdc: half-space index out of range\n") );
-        return false;
-      }
       break;
     }
   }
