@@ -284,7 +284,7 @@ int main(int argc, char ** argv)
         return cleanReturn(2);
       }
       int nReportModels=report->countModels();
-      sOut << "# "  << nReportModels << " " << argv[i] << endl;
+      sOut << "# "  << nReportModels << " " << argv[i] << Qt::endl;
       if(outputType==Count) {
         i++;
         continue;
@@ -319,7 +319,7 @@ int main(int argc, char ** argv)
       }
       report->synchronize();
       int nReportModels=report->nModels();
-      sOut << "# "  << nReportModels << " " << argv[i] << endl;
+      sOut << "# "  << nReportModels << " " << argv[i] << Qt::endl;
       if(outputType==Count) {
         i++;
         continue;
@@ -392,7 +392,7 @@ void outputModel(QDataStream& s, int iReportModel, double misfit, ReportReader *
         s >> val;
         sOut << val << " ";
       }
-      sOut << misfit << endl;
+      sOut << misfit << Qt::endl;
       iModel++;
     }
     break;
@@ -460,7 +460,7 @@ void outputDCModel(QDataStream& s, int iReportModel, double misfit, ReportReader
       if(dcBlock.vp()) {
         Profile p;
         p.readReport(s);
-        sOut << QString("# Vp profile %1: value=%2").arg(iReportModel).arg(misfit) << endl;
+        sOut << QString("# Vp profile %1: value=%2").arg(iReportModel).arg(misfit) << Qt::endl;
         p.toStream(sOut, true);
         iModel++;
       }
@@ -469,7 +469,7 @@ void outputDCModel(QDataStream& s, int iReportModel, double misfit, ReportReader
       if(dcBlock.vs()) {
         Profile p;
         p.readReport(s);
-        sOut << QString("# Vs profile %1: value=%2").arg(iReportModel).arg(misfit) << endl;
+        sOut << QString("# Vs profile %1: value=%2").arg(iReportModel).arg(misfit) << Qt::endl;
         p.toStream(sOut, true);
         iModel++;
       }
@@ -478,7 +478,7 @@ void outputDCModel(QDataStream& s, int iReportModel, double misfit, ReportReader
       if(dcBlock.rho()) {
         Profile p;
         p.readReport(s);
-        sOut << QString("# Rho profile %1: value=%2").arg(iReportModel).arg(misfit) << endl;
+        sOut << QString("# Rho profile %1: value=%2").arg(iReportModel).arg(misfit) << Qt::endl;
         p.toStream(sOut, true);
         iModel++;
       }
@@ -487,7 +487,7 @@ void outputDCModel(QDataStream& s, int iReportModel, double misfit, ReportReader
       if(dcBlock.pitch()) {
         Profile p;
         p.readReport(s);
-        sOut << QString("# Pitch profile %1: value=%2").arg(iReportModel).arg(misfit) << endl;
+        sOut << QString("# Pitch profile %1: value=%2").arg(iReportModel).arg(misfit) << Qt::endl;
         p.toStream(sOut, true);
         iModel++;
       }
@@ -496,7 +496,7 @@ void outputDCModel(QDataStream& s, int iReportModel, double misfit, ReportReader
       if(dcBlock.res()) {
         Profile p;
         p.readReport(s);
-        sOut << QString("# Resistivity profile %1: value=%2").arg(iReportModel).arg(misfit) << endl;
+        sOut << QString("# Resistivity profile %1: value=%2").arg(iReportModel).arg(misfit) << Qt::endl;
         p.toStream(sOut, true);
         iModel++;
       }
@@ -504,7 +504,7 @@ void outputDCModel(QDataStream& s, int iReportModel, double misfit, ReportReader
     case GroundModel: {
         Seismic1DModel * m=dcBlock.readSeismicModel();
         if(!m) return;
-        sOut << QString("# Layered model %1: value=%2").arg(iReportModel).arg(misfit) << endl;
+        sOut << QString("# Layered model %1: value=%2").arg(iReportModel).arg(misfit) << Qt::endl;
         m->toStream(sOut);
         delete m;
         iModel++;
@@ -516,7 +516,7 @@ void outputDCModel(QDataStream& s, int iReportModel, double misfit, ReportReader
         if(dcBlock.pitch()) pitch.readReport(s); else return;
         RefractionFactory f;
         if(dcBlock.refractionVp()) f.readReport(dcBlock.stream()); else return;
-        QVector<double> depths;
+        VectorList<double> depths;
         depths << vp.depths();
         depths << pitch.depths();
         std::sort(depths.begin(), depths.end());
@@ -529,7 +529,7 @@ void outputDCModel(QDataStream& s, int iReportModel, double misfit, ReportReader
         tm.setXLeft(f.xLeft());
         tm.setXRight(f.xRight());
         tm.fromSeismic1DModel( *m, pitch.values(), Seismic1DModel::P);
-        sOut << QString("# Vp Tilt Layered model %1: value=%2").arg(iReportModel).arg(misfit) << endl;
+        sOut << QString("# Vp Tilt Layered model %1: value=%2").arg(iReportModel).arg(misfit) << Qt::endl;
         tm.toStream(sOut);
         delete m;
         iModel++;
@@ -541,7 +541,7 @@ void outputDCModel(QDataStream& s, int iReportModel, double misfit, ReportReader
         if(dcBlock.pitch()) pitch.readReport(s); else return;
         RefractionFactory f;
         if(dcBlock.refractionVs()) f.readReport(dcBlock.stream()); else return;
-        QVector<double> depths;
+        VectorList<double> depths;
         depths << vs.depths();
         depths << pitch.depths();
         std::sort(depths.begin(), depths.end());
@@ -554,7 +554,7 @@ void outputDCModel(QDataStream& s, int iReportModel, double misfit, ReportReader
         tm.setXLeft(f.xLeft());
         tm.setXRight(f.xRight());
         tm.fromSeismic1DModel( *m, pitch.values(), Seismic1DModel::S);
-        sOut << QString("# Vs Tilt Layered model %1: value=%2").arg(iReportModel).arg(misfit) << endl;
+        sOut << QString("# Vs Tilt Layered model %1: value=%2").arg(iReportModel).arg(misfit) << Qt::endl;
         tm.toStream(sOut);
         delete m;
         iModel++;
@@ -570,7 +570,7 @@ void outputDCModel(QDataStream& s, int iReportModel, double misfit, ReportReader
             if(m.seek(s, modeIndex)) {
               QTextStream sOut(stdout);
               sOut << QString("# Rayleigh Phase dispersion curve (mode=%1) %2: value=%3")
-                             .arg(modeIndex).arg(iReportModel).arg(misfit) << endl;
+                             .arg(modeIndex).arg(iReportModel).arg(misfit) << Qt::endl;
               ModalStorageReader::toStream(s, sOut);
               iModel++;
             }
@@ -582,7 +582,7 @@ void outputDCModel(QDataStream& s, int iReportModel, double misfit, ReportReader
             ModalStorageReader m(s);
             if(m.seek(s, modeIndex)) {
               sOut << QString("# Rayleigh Phase dispersion curve (mode=%1) %2: value=%3")
-                             .arg(modeIndex).arg(iReportModel).arg(misfit) << endl;
+                             .arg(modeIndex).arg(iReportModel).arg(misfit) << Qt::endl;
               ModalStorageReader::toStream(s, sOut);
               iModel++;
             }
@@ -602,7 +602,7 @@ void outputDCModel(QDataStream& s, int iReportModel, double misfit, ReportReader
             ModalStorageReader m(s);
             if(m.seek(s, modeIndex)) {
               sOut << QString("# Rayleigh Group dispersion curve (mode=%1) %2: value=%3")
-                             .arg(modeIndex).arg(iReportModel).arg(misfit) << endl;
+                             .arg(modeIndex).arg(iReportModel).arg(misfit) << Qt::endl;
               ModalStorageReader::toStream(s, sOut);
               iModel++;
             }
@@ -623,7 +623,7 @@ void outputDCModel(QDataStream& s, int iReportModel, double misfit, ReportReader
             m.setBetaReleaseOffsets(s, false); // Read number of Rayleigh modes
             if(m.seek(s, modeIndex)) {
               sOut << QString("# Love Phase dispersion curve (mode=%1) %2: value=%3")
-                             .arg(modeIndex).arg(iReportModel).arg(misfit) << endl;
+                             .arg(modeIndex).arg(iReportModel).arg(misfit) << Qt::endl;
               ModalStorageReader::toStream(s, sOut);
               iModel++;
             }
@@ -635,7 +635,7 @@ void outputDCModel(QDataStream& s, int iReportModel, double misfit, ReportReader
             ModalStorageReader m(s);
             if(m.seek(s, modeIndex)) {
               sOut << QString("# Love Phase dispersion curve (mode=%1) %2: value=%3")
-                             .arg(modeIndex).arg(iReportModel).arg(misfit) << endl;
+                             .arg(modeIndex).arg(iReportModel).arg(misfit) << Qt::endl;
               ModalStorageReader::toStream(s, sOut);
               iModel++;
             }
@@ -655,7 +655,7 @@ void outputDCModel(QDataStream& s, int iReportModel, double misfit, ReportReader
             ModalStorageReader m(s);
             if(m.seek(s, modeIndex)) {
               sOut << QString("# Love Group dispersion curve (mode=%1) %2: value=%3")
-                             .arg(modeIndex).arg(iReportModel).arg(misfit) << endl;
+                             .arg(modeIndex).arg(iReportModel).arg(misfit) << Qt::endl;
               ModalStorageReader::toStream(s, sOut);
               iModel++;
             }
@@ -675,7 +675,7 @@ void outputDCModel(QDataStream& s, int iReportModel, double misfit, ReportReader
           ModalStorageReader m(s);
           if(m.seek(s, modeIndex)) {
             sOut << QString("# Signed ellipticity curve (mode=%1) %2: value=%3")
-                            .arg(modeIndex).arg(iReportModel).arg(misfit) << endl;
+                            .arg(modeIndex).arg(iReportModel).arg(misfit) << Qt::endl;
             ModalStorageReader::toStream(s, sOut);
             iModel++;
           }
@@ -689,7 +689,7 @@ void outputDCModel(QDataStream& s, int iReportModel, double misfit, ReportReader
           ModalStorageReader m(s);
           if(m.seek(s, modeIndex)) {
             sOut << QString("# Absolute ellipticity curve (mode=%1) %2: value=%3")
-                            .arg(modeIndex).arg(iReportModel).arg(misfit) << endl;
+                            .arg(modeIndex).arg(iReportModel).arg(misfit) << Qt::endl;
             ModalStorageReader::toAbsoluteStream(s, sOut);
             iModel++;
           }
@@ -707,7 +707,7 @@ void outputDCModel(QDataStream& s, int iReportModel, double misfit, ReportReader
               ModalStorageReader m(s);
               if(m.seek(s,modeIndex)) {
                 sOut << QString("# Vertical autocorrelation curve (ring=%1,mode=%2) %3: value=%4")
-                                .arg(*it).arg(modeIndex).arg(iReportModel).arg(misfit) << endl;
+                                .arg(*it).arg(modeIndex).arg(iReportModel).arg(misfit) << Qt::endl;
                 m.toStream(s, sOut);
                 iModel++;
               }
@@ -727,7 +727,7 @@ void outputDCModel(QDataStream& s, int iReportModel, double misfit, ReportReader
               ModalStorageReader m(s);
               if(m.seek(s,modeIndex)) {
                 sOut << QString("# Radial autocorrelation curve (ring=%1,mode=%2) %3: value=%4")
-                                .arg(*it).arg(modeIndex).arg(iReportModel).arg(misfit) << endl;
+                                .arg(*it).arg(modeIndex).arg(iReportModel).arg(misfit) << Qt::endl;
                 m.toStream(s, sOut);
                 iModel++;
               }
@@ -747,7 +747,7 @@ void outputDCModel(QDataStream& s, int iReportModel, double misfit, ReportReader
               ModalStorageReader m(s);
               if(m.seek(s,modeIndex)) {
                 sOut << QString("# Transverse autocorrelation curve (ring=%1,mode=%2) %3: value=%4")
-                                .arg(*it).arg(modeIndex).arg(iReportModel).arg(misfit) << endl;
+                                .arg(*it).arg(modeIndex).arg(iReportModel).arg(misfit) << Qt::endl;
                 m.toStream(s, sOut);
                 iModel++;
               }
@@ -762,7 +762,7 @@ void outputDCModel(QDataStream& s, int iReportModel, double misfit, ReportReader
         f.readReport(dcBlock.stream());
         if(sourceIndex<f.sourceCount()) {
           sOut << QString("# Vp refraction curve (source %1 at %2 m) %3: value=%4")
-                          .arg(sourceIndex).arg(f.sources()[sourceIndex]).arg(iReportModel).arg(misfit) << endl;
+                          .arg(sourceIndex).arg(f.sources()[sourceIndex]).arg(iReportModel).arg(misfit) << Qt::endl;
           f.toStream(sourceIndex, sOut);
           iModel++;
         }
@@ -774,7 +774,7 @@ void outputDCModel(QDataStream& s, int iReportModel, double misfit, ReportReader
         f.readReport(dcBlock.stream());
         if(sourceIndex<f.sourceCount()) {
           sOut << QString("# Vs refraction curve (source %1 at %2 m) %3: value=%4")
-                          .arg(sourceIndex).arg(f.sources()[sourceIndex]).arg(iReportModel).arg(misfit) << endl;
+                          .arg(sourceIndex).arg(f.sources()[sourceIndex]).arg(iReportModel).arg(misfit) << Qt::endl;
           f.toStream(sourceIndex, sOut);
           iModel++;
         }
