@@ -43,7 +43,10 @@ int main(int argc, char ** argv)
   QString parserFile;
   QString sourceFile;
   QStringList scanSources;
-  bool globalMax=false, crossSection=false;
+  Parameters parameters;
+  parameters.setRelativeThreshold(0.01);
+
+  bool crossSection=false;
   double sampling=5.0;
   // Check arguments
   int i, j=1;
@@ -56,14 +59,17 @@ int main(int argc, char ** argv)
       } else if(arg=="-sources") {
           CoreApplication::checkOptionArg(i, argc, argv);
           sourceFile=argv[i];
+      } else if(arg=="-param") {
+          CoreApplication::checkOptionArg(i, argc, argv);
+          if(!parameters.load(argv[i])) {
+            return 2;
+          }
       } else if(arg=="-scan") {
           CoreApplication::checkOptionArg(i, argc, argv);
           scanSources.append(argv[i]);
       } else if(arg=="-sampling") {
           CoreApplication::checkOptionArg(i, argc, argv);
           sampling=CoreApplication::toDouble(i, i-1, argv);
-      } else if(arg=="-global-max") {
-        globalMax=true;
       } else if(arg=="-cross-section") {
         crossSection=true;
       } else {
@@ -96,37 +102,25 @@ int main(int argc, char ** argv)
   } else {
     CoordinateFile cf;
     cf.setParserFile(parserFile);
-    cf.setFile(stationFile);
+    if(!cf.setFile(stationFile)) {
+      return 2;
+    }
     while(!cf.wait()) {}
     points=cf.points();
   }
-  QVector<Point2D> stations;
-  for(QList<NamedPoint>::iterator it=points.begin(); it!=points.end();it++) {
-    stations.append(Point2D(*it));
-  }
-  if(stations.count()<2) {
+  if(points.count()<2) {
     Message::critical(MSG_ID, tr("Loading coordinates"), tr("Less than 2 stations in your array"));
     return 2;
   }
-  // Find gravity center of the array
-  Point2D center;
-  for(QVector<Point2D>::iterator it=stations.begin();it!=stations.end();it++) {
-    center+=*it;
-  }
-  center.setX(center.x()/stations.count());
-  center.setY(center.y()/stations.count());
-  // Center the array around 0,0
-  for(QVector<Point2D>::iterator it=stations.begin();it!=stations.end();it++) {
-    (*it)-=center;
-  }
 
-  SciFigsGlobal s;
+  SciFigsGlobal s(true);
   Simulator * w=new Simulator;
   w->setWindowTitle(w->windowTitle()+" - "+stationFile);
+  w->setParameters(parameters);
+  w->init(points, sampling);
   w->show();
   Settings::getWidget(w, "Simulator");
-  w->init(stations, sampling);
-  w->setGlobalMax(globalMax);
+  w->initUserValues();
   w->setCrossSection(crossSection);
   if(!sourceFile.isEmpty()) {
     w->load(sourceFile);
@@ -152,8 +146,8 @@ ApplicationHelp * help()
   h->addGroup("gpfksimulator", "gpfksimulator");
   h->addOption("-p <PARSER_FILE>","Parser to read station file (default=graphical dialog box).");
   h->addOption("-sources <SOURCE_FILE>","Load a list of sources.");
+  h->addOption("-param <PARAM_FILE>","Load parameter values (example from geopsy-fk -param-example).");
   h->addOption("-scan <SOURCE_NAME>","Loop over azimuth and phase for source SOURCE_NAME. Several scan option can be specified.");
-  h->addOption("-global-max","Only plot the global maximum (default=search for all maxima above 90% of the global maximum).");
   h->addOption("-cross-section","Output cross-section along X axis.");
   h->addOption("-sampling <S>","Number of pixels between two function estimates, can be a float (default=5).\n"
                                "The sampling is also used to control the coarse search step for maxima.");
