@@ -52,41 +52,52 @@ GaussianMixtureOutput::~GaussianMixtureOutput()
 void GaussianMixtureOutput::newValues(int index)
 {
   TRACE;
-  Densities d=filter(index);
-  double x=_densities->histogram()->x(index);
+  GaussianMixtureDistribution d=filter(index);
+  double x=_inversion->histogram(0)->x(index);
+  SamplingOptions ySampling=_inversion->histogram(0)->ySampling();
   RealStatisticalPoint p;
   QTextStream sOut(stdout);
-  for(int i=0; i<d.count(); i++) {
+  for(int i=0; i<d.modeCount(); i++) {
     p.setX(x);
-    p.setMean(d.density(i).mean());
-    p.setStddev(d.density(i).stddev());
+    if(ySampling & LogScale) {
+      p.setMean(exp(d.mode(i).mean(0)));
+      p.setStddev(exp(d.mode(i).stddev(0)));
+    } else if(ySampling & InverseScale) {
+      p.setMean(1.0/d.mode(i).mean(0));
+      p.setStddev(1.0/d.mode(i).stddev(0));
+    } else {
+      p.setMean(d.mode(i).mean(0));
+      p.setStddev(d.mode(i).stddev(0));
+    }
     p.setWeight(d.weight(i));
-    sOut << p.toString() <<endl;
+    sOut << p.toString() << Qt::endl;
   }
 }
 
-Densities GaussianMixtureOutput::filter(int index) const
+GaussianMixtureDistribution GaussianMixtureOutput::filter(int index) const
 {
   TRACE;
-  double x=_densities->histogram()->x(index);
+  double x=_inversion->histogram(0)->x(index);
   App::freeze(false);
-  Densities d=_densities->densities(index);
-  App::log(tr("Best misfit %1 at x %2 (model index %3 over %4)\n")
-                   .arg(_densities->bestMisfit())
+  App::log(tr("Best misfit %1 at x %2 Hz (model index %3 over %4)\n")
+                   .arg(_inversion->bestMisfit())
                    .arg(x)
-                   .arg(_densities->bestMisfitIndex().value())
-                   .arg(_densities->modelCount()));
-  App::log(d.humanInfo("# "));
-  // Remove extremely small modes. Risky to remove weights below 10% before filtering between kmin and kmax
-  d.filterWeight(0.05);
+                   .arg(_inversion->bestMisfitIndex().value())
+                   .arg(_inversion->modelCount()));
+  App::log(_inversion->humanSolution(index, "# "));
+
+  GaussianMixtureDistribution d=_inversion->distribution(index);
   // Exclude outside kmin and kmax
-  if(_densities->parameters().kmin()>0.0 && _densities->parameters().kmax()>_densities->parameters().kmin()) {
+  if(_inversion->parameters().kmin()>0.0 && _inversion->parameters().kmax()>_inversion->parameters().kmin()) {
     // Remove 1% to account for precision errors in parameter discretization
     // We want to remove solution that at too close to limits
-    d.filterRange(1.01*_densities->parameters().kmin(), 0.99*_densities->parameters().kmax());
+    d.filterRange(0, 1.01*_inversion->parameters().kmin(), 0.99*_inversion->parameters().kmax());
   }
-  // Small valid modes inside kmin and kmax have a slightly larger weight than before filtering between kmin and kmax
-  d.filterWeight(0.1);
+  // Remove modes with large standard devition and small amplitude
+  d.filterDominantModes(2.0);
+  // Remove small weights
+  d.filterWeight(0.01);
   App::freeze(true);
   return d;
 }
+
