@@ -25,9 +25,9 @@
 ***************************************************************************/
 
 #include <SciFigs.h>
+#include <QGpGuiStat.h>
 
 #include "HistogramWidget.h"
-#include "GridFilter.h"
 
 /*!
   \class HistogramWidget HistogramWidget.h
@@ -40,7 +40,8 @@
   Description of constructor still missing
 */
 HistogramWidget::HistogramWidget(QWidget * parent)
-    : QWidget(parent)
+    : QWidget(parent),
+      _gaussianMixtureInversion(1)
 {
   TRACE;
   setupUi(this);
@@ -50,13 +51,16 @@ HistogramWidget::HistogramWidget(QWidget * parent)
   _normalize=true;
   _lastX=0;
   _gaussianMixtureCurve=nullptr;
-  _gaussianMixtureOutput.setHistogramDensities(&_gaussianMixtureDensities);
-  connect(&_gaussianMixtureDensities, SIGNAL(histogramFinished(int)),
+  _gaussianMixtureOutput.setHistogramInversion(&_gaussianMixtureInversion);
+  connect(&_gaussianMixtureInversion, SIGNAL(histogramFinished(int)),
           this, SLOT(addGaussianMixture(int)));
 
   AxisWindow * w;
   QAction * a;
 
+  a=curves->addCurveAction(tr("&Adjust"), tr("Adjust current curve to the closest maximum"), true);
+  connect(a, SIGNAL(triggered()), this, SLOT(adjustCurve()));
+
   w=new AxisWindow(this);
   w->setObjectName("Histogram");
   sheet->sheet()->addObject(w);
@@ -65,11 +69,13 @@ HistogramWidget::HistogramWidget(QWidget * parent)
   w->setPrintWidth(16.0);
   w->setPrintHeight(8.0);
   w->updateInternalGeometry();
+  _currentXLayer=new ParallelBands(w);
+  _currentXLayer->addBand(0.0, Pen(Qt::black));
   _histogramLayer=new IrregularGrid2DPlot(w);
   _histogramLayer->setSmooth(false); // Currently a shift is observed for smoothed data
                                      // TODO: check the smooth display algorithm
   ColorMap map;
-  map.generateColorScale(20, ColorPalette::McNamesClip, true);
+  map.generate(0, 19, ColorPalette::defaultSequentialWhite, ColorPalette::Reversed);
   map.setWhiteTransparent(true);
   _histogramLayer->setColorMap(map);
   LineLayer * curveLayer=new LineLayer(w);
@@ -83,13 +89,13 @@ HistogramWidget::HistogramWidget(QWidget * parent)
   sheet->sheet()->showObject(w);
 
   new QShortcut(Qt::Key_Up, this, SLOT(nextX()));
-  new QShortcut(Qt::Key_Up+Qt::SHIFT, this, SLOT(nextXReject()));
+  new QShortcut(Qt::Key_Up | Qt::SHIFT, this, SLOT(nextXReject()));
   new QShortcut(Qt::Key_Down, this, SLOT(previousX()));
-  new QShortcut(Qt::Key_Down+Qt::SHIFT, this, SLOT(previousXReject()));
+  new QShortcut(Qt::Key_Down | Qt::SHIFT, this, SLOT(previousXReject()));
   new QShortcut(Qt::Key_Left, this, SLOT(decreaseLowLimit()));
-  new QShortcut(Qt::Key_Left+Qt::SHIFT, this, SLOT(decreaseHighLimit()));
+  new QShortcut(Qt::Key_Left | Qt::SHIFT, this, SLOT(decreaseHighLimit()));
   new QShortcut(Qt::Key_Right, this, SLOT(increaseLowLimit()));
-  new QShortcut(Qt::Key_Right+Qt::SHIFT, this, SLOT(increaseHighLimit()));
+  new QShortcut(Qt::Key_Right | Qt::SHIFT, this, SLOT(increaseHighLimit()));
 
   // Init the curve menu
   QMenu * m=new QMenu(this);
@@ -211,26 +217,26 @@ void HistogramWidget::setHistogram(Histogram2D * hist)
 
   if(!_hist->xTitle().isNull()) {
     _histogramLayer->graph()->xAxis()->setTitle(_hist->xTitle());
-    _histogramLayer->graph()->xAxis()->setTitleInversedScale(_hist->xTitleInversedScale());
+    _histogramLayer->graph()->xAxis()->setTitleInverseScale(_hist->xTitleInverseScale());
   }
   if(!_hist->yTitle().isNull()) {
     _histogramLayer->graph()->yAxis()->setTitle(_hist->yTitle());
-    _histogramLayer->graph()->yAxis()->setTitleInversedScale(_hist->yTitleInversedScale());
+    _histogramLayer->graph()->yAxis()->setTitleInverseScale(_hist->yTitleInverseScale());
     _densityHistogramLayer->graph()->xAxis()->setTitle(_hist->yTitle());
-    _densityHistogramLayer->graph()->xAxis()->setTitleInversedScale(_hist->yTitleInversedScale());
+    _densityHistogramLayer->graph()->xAxis()->setTitleInverseScale(_hist->yTitleInverseScale());
     _cumulativeCurveLayer->graph()->xAxis()->setTitle(_hist->yTitle());
-    _cumulativeCurveLayer->graph()->xAxis()->setTitleInversedScale(_hist->yTitleInversedScale());
+    _cumulativeCurveLayer->graph()->xAxis()->setTitleInverseScale(_hist->yTitleInverseScale());
   }
 
   _histogramLayer->graph()->xAxis()->setScaleType(hist->xScaleType());
   switch(hist->yScaleType()) {
   case Scale::Linear:
-  case Scale::Inversed:
+  case Scale::Inverse:
   case Scale::AbsoluteTime:
   case Scale::RelativeTime:
     break;
   case Scale::Log:
-  case Scale::InversedLog:
+  case Scale::InverseLog:
     curves->currentLayer()->setErrorBar(LineLayer::VerticalLogBar);
     break;
   }
@@ -238,7 +244,11 @@ void HistogramWidget::setHistogram(Histogram2D * hist)
   _densityHistogramLayer->graph()->xAxis()->setScaleType(hist->yScaleType());
   _cumulativeCurveLayer->graph()->xAxis()->setScaleType(hist->yScaleType());
 
-  _gaussianMixtureDensities.setHistogram(_hist);
+  if(hist->isPeriodic()) {
+    // Implies that periodic values are centered around 0
+    curves->currentLayer()->setSignThreshold(hist->period()*0.25);
+  }
+  _gaussianMixtureInversion.setHistogram(0, _hist);
 
   xScroll->setRange(0, hist->nx()-1);
   on_xScroll_valueChanged();
@@ -248,7 +258,7 @@ void HistogramWidget::setHistogram(Histogram2D * hist)
 void HistogramWidget::setLimits()
 {
   TRACE;
-  GraphContent * gc=_histogramLayer->graphContent();
+  GraphContents * gc=_histogramLayer->graphContents();
   AxisWindow * w=gc->graph();
 
   Rect r=_histogramLayer->boundingRect();
@@ -261,7 +271,7 @@ void HistogramWidget::setLimits()
   if(_normalize) {
     pal.setValues(0.0001*m, m, SamplingParameters::Log);
   } else {
-    pal.generateColorScale(qRound(m+1.0), ColorPalette::McNamesClip, true);
+    pal.generate(0, qRound(m), ColorPalette::defaultSequential, ColorPalette::Reversed);
     pal.setValues(0.5, m-0.5, SamplingParameters::Linear);
   }
   _histogramLayer->setColorMap(pal);
@@ -271,10 +281,13 @@ void HistogramWidget::on_xScroll_valueChanged()
 {
   TRACE;
   int ix=xScroll->value();
+  double x=_hist->x(ix);
+  _currentXLayer->band(0).setValue(x);
+  _currentXLayer->deepUpdate();
   if(_xUnit.isEmpty()) {
-    xEdit->setText(QString::number(_hist->x(ix)));
+    xEdit->setText(QString::number(x));
   } else {
-    xEdit->setText(QString("%1 %2").arg(_hist->x(ix)).arg(_xUnit));
+    xEdit->setText(QString("%1 %2").arg(x).arg(_xUnit));
   }
 
   PlotLine2D * gridDensity=static_cast<PlotLine2D *>(_densityHistogramLayer->line(0));
@@ -301,24 +314,32 @@ void HistogramWidget::on_xScroll_valueChanged()
   if(_hist->ySampling() & LogScale) {
     mean=::log(meanStat.mean());
     stddev=::log(meanStat.stddev());
-  } else if(_hist->ySampling() & InversedScale) {
+  } else if(_hist->ySampling() & InverseScale) {
     mean=1.0/meanStat.mean();
     stddev=1.0/meanStat.stddev();
   } else {
     mean=meanStat.mean();
     stddev=meanStat.stddev();
   }
+  double period=0.0, halfPeriod=0.0;
+  if(_hist->isPeriodic()) {
+    period=_hist->y(_hist->ny()-1)-_hist->y(0);
+    halfPeriod=0.5*period;
+  }
 
   int nSimulated=10*densityCurve.count();
-  densityCurve.resample(nSimulated, densityCurve.firstX(),
-                        densityCurve.lastX(), _hist->ySampling());
+  int firstIndex=0, lastIndex=densityCurve.count()-1;
+  densityCurve.firstValid(firstIndex);
+  densityCurve.lastValid(lastIndex);
+  densityCurve.resample(nSimulated, densityCurve.constAt(firstIndex).x(),
+                        densityCurve.constAt(lastIndex).x(), _hist->ySampling());
   gaussDensityLine->setCurve(densityCurve);
   gaussCumulativeLine->setCurve(densityCurve);
   gaussMixDensityLine->setCurve(densityCurve);
   gaussMixCumulativeLine->setCurve(densityCurve);
 
-  GaussDistribution gd(mean, stddev);
-  Densities mixd=_gaussianMixtureDensities.densities(ix);
+  NormalDistribution gd(mean, stddev);
+  GaussianMixtureDistribution mixd=_gaussianMixtureInversion.distribution(ix);
   for(int i=nSimulated-1; i>=0; i--) {
     Point2D& gaussDens=gaussDensityLine->curve().constXAt(i);
     Point2D& gaussCum=gaussCumulativeLine->curve().constXAt(i);
@@ -326,20 +347,23 @@ void HistogramWidget::on_xScroll_valueChanged()
     Point2D& mixCum=gaussMixCumulativeLine->curve().constXAt(i);
     double x=gaussDens.x();
     if(_hist->ySampling() & LogScale) {
-      gaussDens.setY(gd.rho(::log(x)));
-      gaussCum.setY(gd.part(log(x)));
-      mixDens.setY(mixd.density(log(x)));
-      mixCum.setY(mixd.cumulativeDensity(log(x)));
-    } else if(_hist->ySampling() & InversedScale) {
-      gaussDens.setY(gd.rho(1.0/x));
-      gaussCum.setY(gd.part(1.0/x));
-      mixDens.setY(mixd.density(1.0/x));
-      mixCum.setY(mixd.cumulativeDensity(1.0/x));
+      gaussDens.setY(gd.value(::log(x)));
+      gaussCum.setY(gd.cumulativeValue(log(x)));
+      mixDens.setY(mixd.value1D(0, ::log(x)));
+      mixCum.setY(mixd.cumulativeValue1D(0, ::log(x)));
+    } else if(_hist->ySampling() & InverseScale) {
+      gaussDens.setY(gd.value(1.0/x));
+      gaussCum.setY(gd.cumulativeValue(1.0/x));
+      mixDens.setY(mixd.value1D(0, 1.0/x));
+      mixCum.setY(mixd.cumulativeValue1D(0, 1.0/x));
     } else {
-      gaussDens.setY(gd.rho(x));
-      gaussCum.setY(gd.part(x));
-      mixDens.setY(mixd.density(x));
-      mixCum.setY(mixd.cumulativeDensity(x));
+      if(_hist->isPeriodic()) {
+        PeriodicStatistics::shiftFunction(x, mean, period, halfPeriod);
+      }
+      gaussDens.setY(gd.value(x));
+      gaussCum.setY(gd.cumulativeValue(x));
+      mixDens.setY(mixd.value1D(0, x));
+      mixCum.setY(mixd.cumulativeValue1D(0, x));
     }
   }
 
@@ -351,7 +375,7 @@ void HistogramWidget::on_xScroll_valueChanged()
   } else {
     if(_hist->ySampling() & LogScale) {
       setBand(log(mean-stddev), log(mean+stddev));
-    } else if(_hist->ySampling() & InversedScale) {
+    } else if(_hist->ySampling() & InverseScale) {
       setBand(1.0/(mean-stddev), 1.0/(mean+stddev));
     } else {
       setBand(mean-stddev, mean+stddev);
@@ -377,17 +401,17 @@ void HistogramWidget::on_xScroll_valueChanged()
                             .arg(_hist->misfit(_hist->x(ix), gd)));
 
   Rect r;
-  GraphContent * gc;
+  GraphContents * gc;
   AxisWindow * w;
 
-  gc=_densityBandLayer->graphContent();
+  gc=_densityBandLayer->graphContents();
   w=gc->graph();
   r=gc->boundingRect();
   w->xAxis()->setRange(r.x1(), r.x2());
   w->yAxis()->setRange(r.y1(), r.y2());
   w->deepUpdate();
 
-  gc=_cumulativeBandLayer->graphContent();
+  gc=_cumulativeBandLayer->graphContents();
   w=gc->graph();
   r=gc->boundingRect();
   w->xAxis()->setRange(r.x1(), r.x2());
@@ -398,7 +422,7 @@ void HistogramWidget::saveBand(int ix, double min, double max)
 {
   TRACE;
   double x=_hist->x(ix);
-  CurveProperties * lowProp=curves->find("Low limit");
+  CurvePropertiesWidget * lowProp=curves->find("Low limit");
   if(lowProp) {
     lowProp->beginCurveChange();
   } else if(std::isnormal(min)) {
@@ -406,7 +430,7 @@ void HistogramWidget::saveBand(int ix, double min, double max)
     lowProp->beginCurveChange();
     lowProp->proxy()->setName("Low limit");
   }
-  CurveProperties * highProp=curves->find("High limit");
+  CurvePropertiesWidget * highProp=curves->find("High limit");
   if(highProp) {
     highProp->beginCurveChange();
   } else if(std::isnormal(max)) {
@@ -417,22 +441,9 @@ void HistogramWidget::saveBand(int ix, double min, double max)
 
   if(lowProp && highProp) {
     Curve<RealStatisticalPoint>& lowCurve=static_cast<RealStatisticalProxy *>(lowProp->proxy())->curve();
+    lowCurve.insert(RealStatisticalPoint(x, min));
     Curve<RealStatisticalPoint>& highCurve=static_cast<RealStatisticalProxy *>(highProp->proxy())->curve();
-
-    // TODO RELEASE 3.4: remove these work around
-    if(lowCurve.isEmpty()) {
-      lowCurve.append(RealStatisticalPoint(x, min));
-      lowCurve.sort();
-    } else {
-      lowCurve.insert(RealStatisticalPoint(x, min));
-    }
-    if(highCurve.isEmpty()) {
-      highCurve.append(RealStatisticalPoint(x, min));
-      highCurve.sort();
-    } else {
-      highCurve.insert(RealStatisticalPoint(x, max));
-    }
-
+    highCurve.insert(RealStatisticalPoint(x, max));
     lowProp->endCurveChange();
     highProp->endCurveChange();
   }
@@ -442,14 +453,15 @@ Point2D HistogramWidget::restoreBand(int ix)
 {
   TRACE;
   double x=_hist->x(ix);
-  CurveProperties * lowProp=curves->find("Low limit");
-  CurveProperties * highProp=curves->find("High limit");
+  CurvePropertiesWidget * lowProp=curves->find("Low limit");
+  CurvePropertiesWidget * highProp=curves->find("High limit");
   if(!lowProp || ! highProp) {
     return Point2D(NAN, NAN);
   }
   Curve<RealStatisticalPoint>& lowCurve=static_cast<RealStatisticalProxy *>(lowProp->proxy())->curve();
   Curve<RealStatisticalPoint>& highCurve=static_cast<RealStatisticalProxy *>(highProp->proxy())->curve();
-  return Point2D(lowCurve.interpole(x).y(), highCurve.interpole(x).y());
+  return Point2D(lowCurve.interpole(x, _hist->xSampling(), _hist->ySampling()).y(),
+                 highCurve.interpole(x, _hist->xSampling(), _hist->ySampling()).y());
 }
 
 void HistogramWidget::setBand(double min, double max)
@@ -461,8 +473,8 @@ void HistogramWidget::setBand(double min, double max)
   ParallelBand& b2=_cumulativeBandLayer->band(0);
   b2.setMinimum(min);
   b2.setMaximum(max);
-  _densityBandLayer->graphContent()->deepUpdate();
-  _cumulativeBandLayer->graphContent()->deepUpdate();
+  _densityBandLayer->graphContents()->deepUpdate();
+  _cumulativeBandLayer->graphContents()->deepUpdate();
 }
 
 void HistogramWidget::on_saveBut_clicked()
@@ -533,7 +545,7 @@ void HistogramWidget::on_undoAllBut_clicked()
 void HistogramWidget::shortcutEvents(Shortcuts s)
 {
   TRACE;
-  GraphContent * gc=_densityHistogramLayer->graphContent();
+  GraphContents * gc=_densityHistogramLayer->graphContents();
   const ParallelBand& b=_densityBandLayer->band(0);
   int ix=xScroll->value();
 
@@ -588,8 +600,14 @@ void HistogramWidget::shortcutEvents(Shortcuts s)
 void HistogramWidget::adjustCurve()
 {
   TRACE;
-  AbstractLine * line=curves->currentLayer()->line(curves->currentLine());
-  _hist->followMaximumX<Curve<RealStatisticalPoint>, RealStatisticalPoint>(static_cast<RealStatisticalLine *>(line)->curve(), 0, std::numeric_limits<double>::infinity());
+  int index=curves->currentLine();
+  CurvePropertiesWidget * properties=curves->curves().at(index);
+  CurveProxy * proxy=properties->proxy();
+  properties->beginCurveChange();
+  proxy->sort();
+  proxy->followMaximumX(_hist, proxy->minimumX(), proxy->maximumX());
+  proxy->addLog(tr("Adjust curve to histogram closest modes\n"));
+  properties->endCurveChange();
 }
 
 void HistogramWidget::addCurve(const Curve<RealStatisticalPoint>& c)
@@ -603,28 +621,37 @@ void HistogramWidget::addCurve(const Curve<RealStatisticalPoint>& c)
 void HistogramWidget::addMeanCurve()
 {
   TRACE;
-  Curve<RealStatisticalPoint> c=_hist->meanCurve();
+  RealStatisticalCurve c;
+  RealStatisticalProxy p;
+  p.setCurve(&c);
+  _hist->meanCurve(&p);
   addCurve(c);
 }
 
 void HistogramWidget::addMedianCurve()
 {
   TRACE;
-  Curve<RealStatisticalPoint> c=_hist->medianCurve();
+  RealStatisticalCurve c;
+  RealStatisticalProxy p;
+  p.setCurve(&c);
+  _hist->medianCurve(&p);
   addCurve(c);
 }
 
 void HistogramWidget::addModeCurve()
 {
   TRACE;
-  Curve<RealStatisticalPoint> c=_hist->modeCurve();
+  RealStatisticalCurve c;
+  RealStatisticalProxy p;
+  p.setCurve(&c);
+  _hist->modeCurve(&p);
   addCurve(c);
 }
 
 void HistogramWidget::setGaussianMixtureParameters(const GaussianMixtureParameters& p)
 {
   TRACE;
-  _gaussianMixtureDensities.setParameters(p);
+  _gaussianMixtureInversion.setParameters(p);
 }
 
 void HistogramWidget::addGaussianMixturePoint()
@@ -634,8 +661,8 @@ void HistogramWidget::addGaussianMixturePoint()
   _gaussianMixtureCurve=curves->curves().last();
   _gaussianMixtureCurve->setEditable(false);
   _gaussianMixtureCurve->line()->setPen(Pen(Qt::NoPen));
-  _gaussianMixtureCurve->line()->setSymbol(Symbol(Symbol::Circle, 1.2, Qt::SolidLine, Qt::SolidPattern));
-  _gaussianMixtureDensities.start(xScroll->value());
+  _gaussianMixtureCurve->line()->setSymbol(Symbol(Symbol::Circle, 1.2, Pen::SolidLine, Qt::SolidPattern));
+  _gaussianMixtureInversion.start(xScroll->value());
 }
 
 void HistogramWidget::addGaussianMixtureCurve()
@@ -645,8 +672,8 @@ void HistogramWidget::addGaussianMixtureCurve()
   _gaussianMixtureCurve=curves->curves().last();
   _gaussianMixtureCurve->setEditable(false);
   _gaussianMixtureCurve->line()->setPen(Pen(Qt::NoPen));
-  _gaussianMixtureCurve->line()->setSymbol(Symbol(Symbol::Circle, 1.2, Qt::SolidLine, Qt::SolidPattern));
-  _gaussianMixtureDensities.start();
+  _gaussianMixtureCurve->line()->setSymbol(Symbol(Symbol::Circle, 1.2, Pen::SolidLine, Qt::SolidPattern));
+  _gaussianMixtureInversion.start();
 }
 
 void HistogramWidget::addGaussianMixture(int index)
@@ -655,15 +682,24 @@ void HistogramWidget::addGaussianMixture(int index)
   if(!_gaussianMixtureCurve) {
     return;
   }
-  Densities d=_gaussianMixtureOutput.filter(index);
+  GaussianMixtureDistribution d=_gaussianMixtureOutput.filter(index);
   double x=_hist->x(index);
+  SamplingOptions ySampling=_hist->ySampling();
   RealStatisticalPoint p;
   _gaussianMixtureCurve->beginCurveChange();
   Curve<RealStatisticalPoint>& c=static_cast<RealStatisticalLine *>(_gaussianMixtureCurve->line())->curve();
-  for(int i=0; i<d.count(); i++) {
+  for(int i=0; i<d.modeCount(); i++) {
     p.setX(x);
-    p.setMean(d.density(i).mean());
-    p.setStddev(d.density(i).stddev());
+    if(ySampling & LogScale) {
+      p.setMean(exp(d.mode(i).mean(0)));
+      p.setStddev(exp(d.mode(i).stddev(0)));
+    } else if(ySampling & InverseScale) {
+      p.setMean(1.0/d.mode(i).mean(0));
+      p.setStddev(1.0/d.mode(i).stddev(0));
+    } else {
+      p.setMean(d.mode(i).mean(0));
+      p.setStddev(d.mode(i).stddev(0));
+    }
     p.setWeight(d.weight(i));
     c.append(p);
   }
@@ -676,10 +712,10 @@ void HistogramWidget::pick()
 {
   TRACE;
   addCurve(Curve<RealStatisticalPoint>());
-  CurveProperties * prop=curves->curves().last();
+  CurvePropertiesWidget * prop=curves->curves().last();
   RealStatisticalLine * line=static_cast<RealStatisticalLine *>(prop->line());
   line->setPen(Pen(Qt::NoPen));
-  line->setSymbol(Symbol(Symbol::Circle, 1.2, Qt::SolidLine, Qt::SolidPattern));
+  line->setSymbol(Symbol(Symbol::Circle, 1.2, Pen::SolidLine, Qt::SolidPattern));
   prop->beginCurveChange();
   line->setCurve(_hist->pickAll(4, 0.1, 0.2));
   prop->endCurveChange();
@@ -745,12 +781,12 @@ void HistogramWidget::exportPlot(const ExportOptions& o)
   }
   if(!o.appendLayerFiles().isEmpty()) {
     for(QStringList::const_iterator it=o.appendLayerFiles().begin(); it!=o.appendLayerFiles().end(); it++) {
-      w->graphContent()->appendLayers(*it);
+      w->graphContents()->appendLayers(*it);
     }
   }
   if(!o.prependLayerFiles().isEmpty()) {
     for(QStringList::const_iterator it=o.prependLayerFiles().begin(); it!=o.prependLayerFiles().end(); it++) {
-      w->graphContent()->prependLayers(*it);
+      w->graphContents()->prependLayers(*it);
     }
   }
   foreach(QString m, o.makeupObjectFiles()) {
@@ -764,76 +800,21 @@ void HistogramWidget::exportPlot(const ExportOptions& o)
   }
 }
 
+void HistogramWidget::exportHistogramValues(const ExportOptions& o)
+{
+  TRACE;
+  o.selectObjects(sheet->sheet());
+  o.exportGridValues(sheet->sheet());
+}
+
 /*!
 
 */
 void HistogramWidget::on_gridFilter_clicked()
 {
   TRACE;
-  GridFilter * d=new GridFilter(this);
-  d->setCurveList(curves->curves());
-  Settings::getWidget(d);
-  d->enableWidgets();
-  if(d->exec()==QDialog::Accepted) {
-    Settings::setWidget(d);
-    if(d->absoluteThresholdFilter->isChecked()) {
-      _hist->filterThreshold(d->absoluteThresholdValue->value());
-    } else if(d->relativeThresholdFilter->isChecked()) {
-      _hist->normalizeAmplitude(YAxis);  // filter calls countSamples(), hence histogram value are automatically reset
-      _hist->filterThreshold(d->relativeThresholdValue->value()*0.01);
-    } else if(d->curveRangeFilter->isChecked()) {
-      int index=d->curve1Name->currentIndex();
-      Curve<RealStatisticalPoint>& curve=static_cast<RealStatisticalLine *>(curves->currentLayer()->line(index))->curve();
-      curve.sort();
-      switch(d->curveRangeType->currentIndex()) {
-      default:
-        _hist->filterCurveInsideAbsoluteRange(curve, d->curveRangeFactor->value());
-        break;
-      case 1:
-        _hist->filterCurveInsideRelativeRange(curve, 0.01*d->curveRangeFactor->value());
-        break;
-      case 2:
-        _hist->filterCurveInsideSigmaRange(curve, d->curveRangeFactor->value());
-        break;
-      case 3:
-        _hist->filterCurveOutsideAbsoluteRange(curve, d->curveRangeFactor->value());
-        break;
-      case 4:
-        _hist->filterCurveOutsideRelativeRange(curve, 0.01*d->curveRangeFactor->value());
-        break;
-      case 5:
-        _hist->filterCurveOutsideSigmaRange(curve, d->curveRangeFactor->value());
-        break;
-      }
-    } else if(d->aboveCurveFilter->isChecked()) {
-      int index=d->curve1Name->currentIndex();
-      Curve<RealStatisticalPoint>& curve=static_cast<RealStatisticalLine *>(curves->currentLayer()->line(index))->curve();
-      curve.sort();
-      _hist->filterAboveCurve(curve);
-    } else if(d->belowCurveFilter->isChecked()) {
-      int index=d->curve1Name->currentIndex();
-      Curve<RealStatisticalPoint>& curve=static_cast<RealStatisticalLine *>(curves->currentLayer()->line(index))->curve();
-      curve.sort();
-      _hist->filterBelowCurve(curve);
-    } else if(d->insideCurvesFilter->isChecked()) {
-      int index1=d->curve1Name->currentIndex();
-      int index2=d->curve2Name->currentIndex();
-      Curve<RealStatisticalPoint>& curve1=static_cast<RealStatisticalLine *>(curves->currentLayer()->line(index1))->curve();
-      Curve<RealStatisticalPoint>& curve2=static_cast<RealStatisticalLine *>(curves->currentLayer()->line(index2))->curve();
-      curve1.sort();
-      curve2.sort();
-      _hist->filterInsideCurves(curve1, curve2);
-    } else if(d->outsideCurvesFilter->isChecked()) {
-      int index1=d->curve1Name->currentIndex();
-      int index2=d->curve2Name->currentIndex();
-      Curve<RealStatisticalPoint>& curve1=static_cast<RealStatisticalLine *>(curves->currentLayer()->line(index1))->curve();
-      Curve<RealStatisticalPoint>& curve2=static_cast<RealStatisticalLine *>(curves->currentLayer()->line(index2))->curve();
-      curve1.sort();
-      curve2.sort();
-      _hist->filterOutsideCurves(curve1, curve2);
-    }
+  Legend l;
+  if(SampleClassification::run(curves, &l, _hist)) {
     setHistogram(_hist);
   }
-  delete d;
 }
-
