@@ -42,7 +42,7 @@ int main(int argc, char ** argv)
 {
   Application a(argc, argv, help);
 
-  SciFigsGlobal s;
+  SciFigsGlobal s(true);
   GeopsyCoreEngine e;
 
   // Options
@@ -65,7 +65,7 @@ int main(int argc, char ** argv)
         utmZone.fromString(argv[i]);
         if(!utmZone.isValid()) {
           App::log(tr("gpmaplayer: %1\n").arg(UtmZone::parsingErrorMessage(argv[i])) );
-          return false;
+          return 2;
         }
       } else if (arg=="-z") {
         Application::checkOptionArg(i, argc, argv);
