@@ -151,7 +151,7 @@ int main(int argc, char ** argv)
                                                           vs->resampledProfile().values(),
                                                           rho->resampledProfile().values());
         QTextStream s(stdout);
-        s << QString("# Parameter set %1:").arg(nLines) << endl;
+        s << QString("# Parameter set %1:").arg(nLines) << Qt::endl;
         m->toStream(s);
         delete m;
       }
