@@ -41,7 +41,6 @@
 ProfileReader::ProfileReader()
     : ArgumentStdinReader()
 {
-  TRACE;
   _maxDepth=100.0;
   _nDepths=100;
   _nProfiles=0;
@@ -54,7 +53,6 @@ ProfileReader::ProfileReader()
 
 ProfileReader::~ProfileReader()
 {
-  TRACE;
   switch(_output) {
   case Original:
   case Resample:
@@ -239,7 +237,7 @@ bool ProfileReader::setOptions(int& argc, char ** argv)
     }
     _pseudo3DModels=new Seismic1DModel[3];
     _pseudo3DPositions=new Point[3];
-    sOut << tr("# Reference models at") << endl;
+    sOut << tr("# Reference models at") << Qt::endl;
     break;
   }
   return true;
@@ -307,13 +305,13 @@ bool ProfileReader::parseSurfaceWaveModels(QTextStream& s)
         p.average();
         p.setSamples(_sampling);
         p.inverse();
-        sOut << p.values()[0] << endl;
+        sOut << p.values()[0] << Qt::endl;
       }
       break;
     case At: {
         profileComment(sOut, comments);
         Profile p=profile(m);
-        sOut << p.uniformAt(_maxDepth) << endl;
+        sOut << p.uniformAt(_maxDepth) << Qt::endl;
       }
       break;
     case AverageProfiles: {
@@ -348,14 +346,16 @@ bool ProfileReader::parseSurfaceWaveModels(QTextStream& s)
           return false;
         }
         sOut << comments;
-        QRegExp r("\n?# position ([0-9\\.,\\- ]{3,})[\n$]");
-        if(r.lastIndexIn(comments)<0) {
+        QRegularExpression r("\n?# position ([0-9\\.,\\- ]{3,})[\n$]");
+        QRegularExpressionMatch match;
+        if(comments.lastIndexOf(r, -1, &match)<0) {
           App::log(tr("gpprofile: model index %1 has no position information in its comments, see '-help'\n").arg(_nProfiles) );
           return false;
         }
         _pseudo3DModels[_nProfiles]=m;
-        if(!_pseudo3DPositions[_nProfiles].fromString(r.cap(1))) {
-          App::log(tr("gpprofile: model index %1 has not a readable position in its comments: %2\n").arg(_nProfiles).arg(r.cap(1)) );
+        if(!_pseudo3DPositions[_nProfiles].fromString(match.captured(1))) {
+          App::log(tr("gpprofile: model index %1 has not a readable position in its comments: %2\n")
+                       .arg(_nProfiles).arg(match.captured(1)) );
           return false;
         }
       }
@@ -414,13 +414,13 @@ bool ProfileReader::parseResistivityModels(QTextStream& s)
         p.average();
         p.setSamples(_sampling);
         p.inverse();
-        sOut << p.values()[0] << endl;
+        sOut << p.values()[0] << Qt::endl;
       }
       break;
     case At: {
         profileComment(sOut, comments);
         Profile p=profile(m);
-        sOut << p.uniformAt(_maxDepth) << endl;
+        sOut << p.uniformAt(_maxDepth) << Qt::endl;
       }
       break;
     case AverageProfiles: {
@@ -505,22 +505,22 @@ void ProfileReader::profileComment(QTextStream& sOut, const QString& comments) c
   sOut << comments;
   switch (_profile) {
   case Vp:
-    sOut << "# Vp" << endl;
+    sOut << "# Vp" << Qt::endl;
     break;
   case Vs:
-    sOut << "# Vs" << endl;
+    sOut << "# Vs" << Qt::endl;
     break;
   case Rho:
-    sOut << "# Density" << endl;
+    sOut << "# Density" << Qt::endl;
     break;
   case Poisson:
-    sOut << "# Poisson's ratio" << endl;
+    sOut << "# Poisson's ratio" << Qt::endl;
     break;
   case Impedance:
-    sOut << "# Impedance" << endl;
+    sOut << "# Impedance" << Qt::endl;
     break;
   case Resistivity:
-    sOut << "# Resistivity" << endl;
+    sOut << "# Resistivity" << Qt::endl;
     break;
   case Model:
     break;
@@ -590,7 +590,7 @@ bool ProfileReader::terminate()
         return false;
       }
       profileComment(sOut, QString());
-      sOut << tr("# Interpolated at %1").arg(_pseudo3DAt.toString(20)) << endl;
+      sOut << tr("# Interpolated at %1").arg(_pseudo3DAt.toString('g', 20)) << Qt::endl;
       if(_profile==Model) {
         m.toStream(sOut);
       } else {
