@@ -70,8 +70,9 @@ ApplicationHelp * help()
   h->addOption("-original","Export profiles with original sampling from input models (default)");
   h->addOption("-resample","Export profiles with a custom sampling (see -h sampling for details)");
   h->addOption("-at <DEPTH>","Returns the profile value at DEPTH meters.");
-  h->addOption("-average-profiles","Export averaged profiles with a custom sampling (see '-h sampling' for details). "
+  h->addOption("-average-profiles","Export the average profile with a custom sampling (see '-h sampling' for details). "
                                    "Various profiles are averaged into one single output.");
+  h->addOption("-stddev-profiles","Export the standard deviation profile with a custom sampling (see '-h sampling' for details).");
   h->addOption("-average-depths","Export averaged profiles with a custom sampling (see '-h sampling' for details). "
                                  "Average is performed over the depth axis.");
   h->addOption("-average-at <DEPTH>","Returns the average profile over DEPTH meters.");
