@@ -42,6 +42,9 @@ int main(int argc, char ** argv)
   int seed=0;
   int generationCount=1;
   double min=0.0, max=1.0;
+  double mean=1.0, stddev=1.0;
+  enum Distribution {Uniform, Gaussian};
+  Distribution distribution=Uniform;
   enum Mode {Generate, TestPeriod, TestDistribution};
   Mode mode=Generate;
   double distributionMax=1.0;
@@ -51,7 +54,11 @@ int main(int argc, char ** argv)
   for(i=1; i<argc; i++) {
     QByteArray arg=argv[i];
     if(arg[0]=='-') {
-      if(arg=="-cache") {
+      if(arg=="-uniform") {
+        distribution=Uniform;
+      } else if(arg=="-gaussian") {
+        distribution=Gaussian;
+      } else if(arg=="-cache") {
         CoreApplication::checkOptionArg(i, argc, argv);
         cacheFile=argv[i];
       } else if(arg=="-seed") {
@@ -59,13 +66,19 @@ int main(int argc, char ** argv)
         seed=CoreApplication::toInt(i, i-1, argv);
       } else if(arg=="-n") {
         CoreApplication::checkOptionArg(i, argc, argv);
-        generationCount=atoi(argv[i] );
+        generationCount=CoreApplication::toInt(i, i-1, argv);
       } else if(arg=="-min") {
         CoreApplication::checkOptionArg(i, argc, argv);
-        min=atof(argv[i] );
+        min=CoreApplication::toDouble(i, i-1, argv);
       } else if(arg=="-max") {
         CoreApplication::checkOptionArg(i, argc, argv);
-        max=atof(argv[i] );
+        max=CoreApplication::toDouble(i, i-1, argv);
+      } else if(arg=="-mean") {
+        CoreApplication::checkOptionArg(i, argc, argv);
+        mean=CoreApplication::toDouble(i, i-1, argv);
+      } else if(arg=="-stddev") {
+        CoreApplication::checkOptionArg(i, argc, argv);
+        stddev=CoreApplication::toDouble(i, i-1, argv);
       } else if(arg=="-test-period") {
         mode=TestPeriod;
       } else if(arg=="-test-distribution") {
@@ -118,10 +131,20 @@ int main(int argc, char ** argv)
       engine=new Random(seed);
     }
     QTextStream sOut(stdout);
-    for(int i=0; i<generationCount; i++) {
-      sOut << engine->uniform(min, max) << " ";
+    switch(distribution) {
+    case Uniform:
+      for(int i=0; i<generationCount; i++) {
+        sOut << engine->uniform(min, max) << " ";
+      }
+      break;
+    case Gaussian:
+      for(int i=0; i<generationCount; i++) {
+        sOut << engine->normal(mean, stddev) << " ";
+      }
+      break;
     }
-    sOut << endl;
+
+    sOut << Qt::endl;
     // Saving state
     if(f.open(QIODevice::WriteOnly)) {
       f.write(engine->state());
@@ -144,14 +167,18 @@ ApplicationHelp * help()
   h->setComments("Compute random values with ran2 (uniform probability, support for lot of computations). To force initialization "
                  "of random generation remove the cache file (see option '-cache').");
   h->addGroup("gprandom", "gprandom");
+  h->addOption("-uniform","Uses a uniform distribution to generate random numbers (default).");
+  h->addOption("-gaussian","Uses a Gaussian (normal) distribution to generate random numbers.");
   h->addOption("-n <N>","Generates N pseudo random numbers.");
-  h->addOption("-min <MIN>","Minimum range for random number (default=0).");
-  h->addOption("-max <MAX>","Maximum range for random number (default=1).");
+  h->addOption("-min <VALUE>","Minimum range for random number (default=0).");
+  h->addOption("-max <VALUE>","Maximum range for random number (default=1).");
+  h->addOption("-mean <VALUE>", "Mean for Gaussian distribution (default=1).");
+  h->addOption("-stddev <VALUE>","Standard deviation for Gaussian distribution (default=1).");
   h->addOption("-cache <FILE>","Store cache value in FILE (default='random.cache').");
   h->addOption("-seed <SEED>","Init random generation with SEED (default=current time). This option is ignored "
                               "if a valid cache file is found.");
   h->addOption("-test-period","Calculate the return period of the pseudo random generator.");
-  h->addOption("-test-distribution <RATIO>","Calculate the histogram of the pseudo random generator.");
+  h->addOption("-test-distribution","Calculate the histogram of the pseudo random generator.");
   h->addOption("-distribution-max <MAX>", "MAX can vary from 0 to 1 to zoom only on a precise part of the histogram. "
                                           "1 means no zoom, display the entire historgram, 0.1 means display only the "
                                           "range from 0 to 0.1 (default=1.0).");
