@@ -40,8 +40,8 @@ protected:
   virtual bool parse(QTextStream& s);
 private:
   enum Mode {TravelTimes, RayPaths};
-  QVector<double> _sources;
-  QVector<double> _receivers;
+  VectorList<double> _sources;
+  VectorList<double> _receivers;
   Mode _mode;
 };
 
