@@ -27,7 +27,6 @@
 #include <QGpCoreWave.h>
 
 #include "ShReader.h"
-#include "KennettSH.h"
 
 /*!
   \class ShReader ShReader.h
@@ -42,7 +41,6 @@
 ShReader::ShReader()
     : ArgumentStdinReader()
 {
-  TRACE;
   _nSamples=100;
   _samplingType=LogScale;
   _nSamples=100;
@@ -50,6 +48,8 @@ ShReader::ShReader()
   _maxRange=20.0;
   _qp=0.0;
   _qs=0.0;
+  _receiverDepth=0.0;
+  _referenceDepth=-1.0;
 }
 
 bool ShReader::setOptions(int& argc, char ** argv)
@@ -63,7 +63,7 @@ bool ShReader::setOptions(int& argc, char ** argv)
       if(arg=="-s") {
         CoreApplication::checkOptionArg(i, argc, argv);
         if(strcmp(argv[i],"period")==0) {
-          _samplingType=InversedScale;
+          _samplingType=InverseScale;
         } else if(strcmp(argv[i],"frequency")==0) {
           _samplingType=LinearScale;
         } else {
@@ -72,40 +72,50 @@ bool ShReader::setOptions(int& argc, char ** argv)
       } else if(arg=="-min") {
         CoreApplication::checkOptionArg(i, argc, argv);
         _minRange=CoreApplication::toDouble(i, i-1, argv);
-        if(_minRange<=0) {
-          App::log(tr("gpsh: negative or null value for -min\n") );
+        if(_minRange<=0.0) {
+          App::log(tr("negative or null value for -min\n") );
           return false;
         }
       } else if(arg=="-max") {
         CoreApplication::checkOptionArg(i, argc, argv);
         _maxRange=CoreApplication::toDouble(i, i-1, argv);
-        if(_maxRange<=0) {
-          App::log(tr("gpsh: negative or null value for -max\n") );
+        if(_maxRange<=0.0) {
+          App::log(tr("negative or null value for -max\n") );
           return false;
         }
       } else if(arg=="-qp") {
         CoreApplication::checkOptionArg(i, argc, argv);
-        _qp=CoreApplication::toInt(i, i-1, argv);
-        if(_qp<0) {
-          App::log(tr("gpsh: negative Qp (option -qp)\n") );
+        _qp=CoreApplication::toDouble(i, i-1, argv);
+        if(_qp<=0.0) {
+          App::log(tr("null or negative Qp (option -qp)\n") );
           return false;
         }
       } else if(arg=="-qs") {
         CoreApplication::checkOptionArg(i, argc, argv);
-        _qs=CoreApplication::toInt(i, i-1, argv);
-        if(_qs<0) {
-          App::log(tr("gpsh: negative Qs (option -qs)\n") );
+        _qs=CoreApplication::toDouble(i, i-1, argv);
+        if(_qs<=0.0) {
+          App::log(tr("null or negative Qs (option -qs)\n") );
           return false;
         }
+      } else if(arg=="-receiver-depth") {
+        CoreApplication::checkOptionArg(i, argc, argv);
+        _receiverDepth=CoreApplication::toDouble(i, i-1, argv);
+        if(_receiverDepth<0.0) {
+          App::log(tr("negative receiver depth (option -receiver depth)\n") );
+          return false;
+        }
+      } else if(arg=="-reference-depth") {
+        CoreApplication::checkOptionArg(i, argc, argv);
+        _referenceDepth=CoreApplication::toDouble(i, i-1, argv);
       } else if(arg=="-n") {
         CoreApplication::checkOptionArg(i, argc, argv);
         _nSamples=CoreApplication::toInt(i, i-1, argv);
         if(_nSamples<2) {
-          App::log(tr("gpsh: number of samples less than 2 (option -n)\n") );
+          App::log(tr("number of samples less than 2 (option -n)\n") );
           return false;
         }
       } else {
-        App::log(tr("gpsh: bad option %1, see -help\n").arg(argv[i]) );
+        App::log(tr("bad option %1, see -help\n").arg(argv[i]) );
         return false;
       }
     } else {
@@ -143,18 +153,25 @@ bool ShReader::parse(QTextStream& s)
     // Check that Qp and Qs are properly set
     for(int i=0;i<m.layerCount(); i++) {
       if(m.qp(i)<=0.0) {
-        App::log(tr("gpsh: negative or null value for Qp at layer %1\n").arg(i) );
+        App::log(tr("negative or null value for Qp at layer %1\n").arg(i) );
       }
       if(m.qs(i)<=0.0) {
-        App::log(tr("gpsh: negative or null value for Qs at layer %1\n").arg(i) );
+        App::log(tr("negative or null value for Qs at layer %1\n").arg(i) );
       }
     }
     sOut << "# SH transfer function\n"
          << comments;
     KennettSH kenn(&m);
-    for(int i=0; i<_x.count(); i++) {
-      double f=_x.at(i);
-      sOut << f << " " << kenn.sh(f, 0.0) << "\n";
+    if(_referenceDepth<0.0) {
+      for(int i=0; i<_x.count(); i++) {
+        double f=_x.at(i);
+        sOut << f << " " << kenn.sh(f, _receiverDepth) << "\n";
+      }
+    } else {
+      for(int i=0; i<_x.count(); i++) {
+        double f=_x.at(i);
+        sOut << f << " " << kenn.sh(f, _receiverDepth)/kenn.sh(f, _referenceDepth) << "\n";
+      }
     }
   }
   return true;
