@@ -44,8 +44,9 @@ private:
   double _minRange;
   double _maxRange;
   double _qp, _qs;
+  double _receiverDepth, _referenceDepth;
 
-  QVector<double> _x;
+  VectorList<double> _x;
 };
 
 #endif // SHREADER_H
