@@ -40,7 +40,7 @@
 SpacReader::SpacReader()
     : ArgumentStdinReader()
 {
-  TRACE;
+  _source=LayeredModel;
   _nModes=1;
   _vertical=false;
   _radial=false;
@@ -54,7 +54,6 @@ SpacReader::SpacReader()
 
 SpacReader::~SpacReader()
 {
-  TRACE;
   delete _dispersionFactory;
   delete _autocorrFactory;
 }
@@ -72,8 +71,12 @@ bool SpacReader::setOptions(int& argc, char ** argv)
   for (i=1; i<argc; i++) {
     QByteArray arg=argv[i];
     if(arg[0]=='-') {
-      if(arg=="-vertical") {
-        _vertical=true;
+      if(arg=="-src-model") {
+        _source=LayeredModel;
+      } else if(arg=="-src-curve") {
+        _source=DispersionCurve;
+      } else if(arg=="-vertical") {
+          _vertical=true;
       } else if(arg=="-radial") {
         _radial=true;
       } else if(arg=="-transverse") {
@@ -89,7 +92,7 @@ bool SpacReader::setOptions(int& argc, char ** argv)
       } else if(arg=="-s") {
         CoreApplication::checkOptionArg(i, argc, argv);
         if(strcmp(argv[i],"period")==0) {
-          samplingType=InversedScale;
+          samplingType=InverseScale;
         } else if(strcmp(argv[i],"frequency")==0) {
           samplingType=LinearScale;
         } else {
@@ -122,19 +125,28 @@ bool SpacReader::setOptions(int& argc, char ** argv)
               StringSection fields(buf);
               StringSection field;
               const QChar * p=0;
+              bool ok=true;
               double r1,r2;
               field=fields.nextField(p);
               if(!field.isValid()) {
-                App::log(tr("gpspac: error reading minimum radius at line %1 in file %1\n").arg(iLine).arg(argv[i]) );
+                App::log(tr("gpspac: error reading minimum radius at line %1 in file %1\n").arg(iLine).arg(argv[i]));
+                return false;
+              }
+              r1=field.toDouble(ok);
+              if(!ok) {
+                App::log(tr("gpspac: error reading minimum radius at line %1 in file %1\n").arg(iLine).arg(argv[i]));
                 return false;
               }
-              r1=field.toDouble();
               field=fields.nextField(p);
               if(!field.isValid()) {
-                App::log(tr("gpspac: error reading maximum radius at line %1 in file %1\n").arg(iLine).arg(argv[i]) );
+                App::log(tr("gpspac: error reading maximum radius at line %1 in file %1\n").arg(iLine).arg(argv[i]));
+                return false;
+              }
+              r2=field.toDouble(ok);
+              if(!ok) {
+                App::log(tr("gpspac: error reading maximum radius at line %1 in file %1\n").arg(iLine).arg(argv[i]));
                 return false;
               }
-              r2=field.toDouble();
               _rings.append(AutocorrRing( r1, r2) );
             }
           }
@@ -207,45 +219,62 @@ bool SpacReader::parse(QTextStream& s)
 {
   TRACE;
   QTextStream sOut(stdout);
-  Seismic1DModel m;
   QString comments;
-  if(!m.fromStream(s, &comments)) {
-    return false;
+  switch(_source) {
+  case LayeredModel: {
+      Seismic1DModel m;
+      if(!m.fromStream(s, &comments)) {
+        return false;
+      }
+      if(m.layerCount()==0) {
+        return true;
+      }
+      sOut << comments;
+      _dispersionFactory->calculate(&m, 0);
+    }
+    break;
+  case DispersionCurve: {
+      ModalCurve curve;
+      curve.fromStream(s, &comments);
+      if(curve.isEmpty()) {
+        return false;
+      }
+      curve.addMode(Mode(Mode::Phase, Mode::Rayleigh, 0));
+      sOut << comments;
+      _dispersionFactory->setPhaseRayleigh(curve);
+    }
+    break;
   }
-  if(m.layerCount()>0) {
-    sOut << comments;
-    _dispersionFactory->calculate(&m, 0);
-    if(_vertical) {
-      _autocorrFactory->calculateVertical(_dispersionFactory);
+  if(_vertical) {
+    _autocorrFactory->calculateVertical(_dispersionFactory);
+  }
+  if(_radial || _transverse) {
+    _autocorrFactory->calculateHorizontal(_alpha, _dispersionFactory);
+  }
+  for(int iRing=0; iRing<_rings.count(); iRing++) {
+    if (_vertical) {
+      sOut << QString("# Ring %1 (from %2 to %3), %4 Vertical autocorrelation modes\n")
+                .arg(iRing)
+                .arg(_rings.at(iRing).minRadius())
+                .arg(_rings.at(iRing).maxRadius())
+                .arg(_nModes);
+      _autocorrFactory->vertical(iRing).toStream(sOut, _oneMode ? _nModes-1 : -1);
     }
-    if(_radial || _transverse) {
-      _autocorrFactory->calculateHorizontal(_alpha, _dispersionFactory);
+    if(_radial) {
+      sOut << QString("# Ring %1 (from %2 to %3), %4 Radial autocorrelation modes\n")
+                .arg(iRing)
+                .arg(_rings.at(iRing).minRadius())
+                .arg(_rings.at(iRing).maxRadius())
+                .arg(_nModes);
+      _autocorrFactory->radial(iRing).toStream(sOut, _oneMode ? _nModes-1 : -1);
     }
-    for(int iRing=0; iRing<_rings.count(); iRing++) {
-      if (_vertical) {
-        sOut << QString("# Ring %1 (from %2 to %3), %4 Vertical autocorrelation modes\n")
-                  .arg(iRing)
-                  .arg(_rings.at(iRing).minRadius())
-                  .arg(_rings.at(iRing).maxRadius())
-                  .arg(_nModes);
-        _autocorrFactory->vertical(iRing).toStream(sOut, _oneMode ? _nModes-1 : -1);
-      }
-      if(_radial) {
-        sOut << QString("# Ring %1 (from %2 to %3), %4 Radial autocorrelation modes\n")
-                  .arg(iRing)
-                  .arg(_rings.at(iRing).minRadius())
-                  .arg(_rings.at(iRing).maxRadius())
-                  .arg(_nModes);
-        _autocorrFactory->radial(iRing).toStream(sOut, _oneMode ? _nModes-1 : -1);
-      }
-      if(_transverse) {
-        sOut << QString("# Ring %1 (from %2 to %3), %4 Transverse autocorrelation modes\n")
-                  .arg(iRing)
-                  .arg(_rings.at(iRing).minRadius())
-                  .arg(_rings.at(iRing).maxRadius())
-                  .arg(_nModes);
-        _autocorrFactory->transverse(iRing).toStream(sOut, _oneMode ? _nModes-1 : -1);
-      }
+    if(_transverse) {
+      sOut << QString("# Ring %1 (from %2 to %3), %4 Transverse autocorrelation modes\n")
+                .arg(iRing)
+                .arg(_rings.at(iRing).minRadius())
+                .arg(_rings.at(iRing).maxRadius())
+                .arg(_nModes);
+      _autocorrFactory->transverse(iRing).toStream(sOut, _oneMode ? _nModes-1 : -1);
     }
   }
   return true;
