@@ -40,7 +40,6 @@
 */
 TimeReader::TimeReader()
 {
-  TRACE;
   _action=Convert;
   _mode=Absolute;
   _column=-1;
@@ -114,7 +113,7 @@ bool TimeReader::setOptions(int& argc, char ** argv)
     if(_outFormat.isEmpty()) {
       _outFormat="w";
     } else {
-      if(_outFormat.count()>1) {
+      if(_outFormat.size()>1) {
         App::log(tr("gptime: not a valid format in relative mode (%1).\n").arg(_outFormat) );
         return false;
       }
@@ -162,7 +161,7 @@ bool TimeReader::parse(QTextStream& s)
           }
           buf=buf.trimmed();
           if(_verbose) {
-            sOut << "# converting \"" << buf << "\"" << endl;
+            sOut << "# converting \"" << buf << "\"" << Qt::endl;
           }
           QString str;
           switch(_mode) {
@@ -190,7 +189,7 @@ bool TimeReader::parse(QTextStream& s)
             break;
           }
           if(!str.isNull()) {
-            sOut << textBefore << str << textAfter << endl;
+            sOut << textBefore << str << textAfter << Qt::endl;
           }
         }
         break;
