@@ -40,9 +40,10 @@ ApplicationHelp * help();
 int main(int argc, char ** argv)
 {
   Application a(argc, argv, help);
-  SciFigsGlobal s;
+  SciFigsGlobal s(true);
 
   // Options
+  ExportOptions exportOptions;
   enum PlotType {Profile, Dispersion, Ellipticity, Autocorr, RefraVp, RefraVs};
   PlotType plotType=Profile;
   bool skipDialog=false;
@@ -50,9 +51,6 @@ int main(int argc, char ** argv)
   double maxMisfit=1.0;
   int minIndex=0;
   int maxIndex=0;
-  QString exportFile;
-  QString exportFormat="PAGE";
-  int dpi=0;  // No dpi force
   QString targetFile;
   Mode mode;
   // Check arguments
@@ -90,29 +88,32 @@ int main(int argc, char ** argv)
         skipDialog=true;
       } else if(arg=="-s") {
         CoreApplication::checkOptionArg(i, argc, argv);
-        mode.setSlowness(Mode::slowness(argv[i]));
+        QString s(argv[i]);
+        bool ok=true;
+        mode.setSlowness(Mode::convertSlowness(s, ok));
+        if(!ok) {
+          App::log(tr("gpviewdcreport: bad slowness type '%1'\n").arg(argv[i]));
+          return false;
+        }
         skipDialog=true;
       } else if(arg=="-p") {
         CoreApplication::checkOptionArg(i, argc, argv);
-        mode.setPolarization(Mode::polarization(argv[i]));
+        QString p(argv[i]);
+        bool ok=true;
+        mode.setPolarization(Mode::convertPolarization(p, ok));
+        if(!ok) {
+          App::log(tr("gpviewdcreport: bad polarization '%1'\n").arg(argv[i]));
+          return false;
+        }
+        skipDialog=true;
+      } else if(arg=="-abs") {
+        mode.setValue(Mode::Absolute);
         skipDialog=true;
       } else if(arg=="-target") {
         Application::checkOptionArg(i, argc, argv);
         targetFile=argv[i];
-      } else if(arg=="-export" || arg=="-e") {
-        Application::checkOptionArg(i, argc, argv);
-        exportFile=argv[i];
-      } else if(arg=="-format" || arg=="-f") {
-        Application::checkOptionArg(i, argc, argv);
-        exportFormat=argv[i];
-      } else if(arg=="-dpi") {
-        Application::checkOptionArg(i, argc, argv);
-        dpi=CoreApplication::toInt(i, i-1, argv);
-        if(dpi>1200) dpi=1200;
-        else if(dpi<0) dpi=0;
       } else {
-        App::log(tr("gpviewdcreport: bad option %1, see --help\n").arg(argv[i]) );
-        return 2;
+        argv[j++]=argv[i];
       }
     } else {
       argv[j++]=argv[i];
@@ -122,6 +123,12 @@ int main(int argc, char ** argv)
     argv[j]=nullptr;
     argc=j;
   }
+  if(!exportOptions.read(argc, argv)) {
+    return 2;
+  }
+  if(!Application::checkRemainingArgs(argc, argv)) {
+    return 2;
+  }
 
   QStringList reportList;
   i=1;
@@ -150,6 +157,8 @@ int main(int argc, char ** argv)
       break;
     case Ellipticity:
       w=new EllipticityViewer;
+      w->setMode(mode);
+
       break;
     case Autocorr:
       w=new AutocorrViewer;
@@ -170,6 +179,9 @@ int main(int argc, char ** argv)
       w->setWindowTitle(w->windowTitle()+" "+fi.completeBaseName());
     }
     w->loadModels();
+    if(!exportOptions.colorMapFile().isEmpty()) {
+      w->setColorMap(exportOptions.firstColorMap());
+    }
   } else {
     ViewerParam * d=new ViewerParam();
     switch(plotType) {
@@ -207,11 +219,11 @@ int main(int argc, char ** argv)
     w->setTarget(tl);
   }
 
-  if( !exportFile.isEmpty()) {
-    w->sheet()->exportFile(exportFile, exportFormat, dpi);
-    delete w;
+  w->exportPlot(exportOptions);
+  if(!exportOptions.exportFile().isEmpty()) {
     return 0;
-  } else if(skipDialog) {
+  }
+  if(skipDialog) {
     w->show();
   }
 
@@ -237,9 +249,6 @@ ApplicationHelp * help()
   h->addOption("-min-index <INDEX>","Minimum index to display (default=first)");
   h->addOption("-max-index <INDEX>","Maximum misfit to display (default=last)");
   h->addOption("-target <TARGET>","Set target shown above models read from .report files.");
-  h->addOption("-e, -export <FILE>", "Export sheet contents to FILE. See 'figue -h' for more details.");
-  h->addOption("-f, -format <FORMAT>", "Specify format for option '-export'. See 'figue -h' for more details.");
-  h->addOption("-dpi <DPI>", "Forces resolution to DPI(dot per inch) in export file. See 'figue -h' for more details.");
   h->addGroup("Profile","profile");
   h->addOption("-n <N>", "Number of profiles");
   h->addGroup("Dispersion","dispersion");
@@ -248,10 +257,13 @@ ApplicationHelp * help()
   h->addOption("-p <POLARISATION>", "Polarization: Rayleigh or Love");
   h->addGroup("Ellipticity","ellipticity");
   h->addOption("-n <N>", "Number of modes");
+  h->addOption("-abs", "Plot absolute ellipticity.");
   h->addGroup("Autocorr","autocorr");
   h->addOption("-n <N>", "Number of rigns");
   h->addOption("-p <POLARISATION>", "Polarization: Vertical, Transverse or Radial");
   h->addGroup("Refra","refra");
   h->addOption("-n <N>", "Number of sources");
+  h->addGroup("Plot", "plot", 2);
+  ExportOptions::help(h);
   return h;
 }
