@@ -27,15 +27,16 @@
 #define HISTOGRAMSWIDGET_H
 
 #include <SciFigs.h>
+#include <QGpGuiMath.h>
 #include <QGpCoreWave.h>
 
 #include "Samples.h"
 #include "Reader.h"
-//#include "ui_HistogramsWidget.h"
+#include "ui_HistogramsWidget.h"
 
 class ModeWidgets;
 
-class HistogramsWidget : public GraphicSheetMenu //public QWidget, private Ui::HistogramsWidget
+class HistogramsWidget : public QWidget, private Ui::HistogramsWidget
 {
   Q_OBJECT
 public:
@@ -43,14 +44,29 @@ public:
   ~HistogramsWidget();
 
   void setNormalize(bool n) {_normalize=n;}
-  void setSamples(const Samples& s, const Reader& param);
-  bool splitModes(const Samples& s, const Reader& param);
+  void addWidget(Samples * s, const Reader& param);
+  bool splitModes(const Reader& param);
   void setHistogramComments(QString cmt);
+  bool classifySamples(const QStringList& filters);
   void exportPlot(const ExportOptions& o);
+  void exportHistogramValues(const ExportOptions& o);
+private slots:
+  void setActivePlot(GraphicObject * o);
+  void classifySamples();
+  void exportSamples();
+  void pickToMean();
+  void adjustCurve();
+
+  void addMeanCurve();
+  void addMedianCurve();
+  void addModeCurve();
+  void addGaussianMixtureCurve();
 protected:
   void closeEvent(QCloseEvent * e);
-  bool splitModesFromCurves(const Samples& s, const Reader& param);
-  void splitModesFromEllSign(const Samples& s, const Reader& param);
+  bool splitModesFromCurves(const Reader& param);
+  void splitModesFromEllSign(const Reader& param);
+  ModeWidgets * mode(AxisWindow * w) const;
+  ModeWidgets * currentMode() const;
 private:
   bool _normalize;
   QList<ModeWidgets *> _modes;
