@@ -32,21 +32,40 @@ class Sample
 {
 public:
   Sample();
-  Sample(const Sample& s);
 
-  bool read(const QString& line);
-  void write(QTextStream& s) const;
+  bool read(const QString& line, int timeColumn, int freqColumn,
+            int slowColumn, int azimuthColumn, int ellColumn,
+            int verticalNoiseColumn, int horizontalNoiseColumn,
+            int powerColumn, int validColumn);
+  void writeValues(QTextStream& s) const;
+  void writeLine(QTextStream& s) const {s<< _line << "\n";}
 
-  double time() const {return _time;}
+  const QString& time() const {return _time;}
   double frequency() const {return _frequency;}
   double slowness() const {return _slowness;}
   double ellipticity() const {return _ellipticity;}
-  double noise() const {return _noise;}
+  double verticalNoise() const {return _verticalNoise;}
+  double horizontalNoise() const {return _horizontalNoise;}
+  double totalNoise() const {return 2.0*_horizontalNoise+_verticalNoise;}
+  double deltaNoise() const {return _verticalNoise-_horizontalNoise;}
+  double sigmaNoise() const {return _horizontalNoise/_verticalNoise;}
+  double xixDeviation() const;
+  double xisDeviation() const;
   double azimuth() const {return _azimuth;}
   double power() const {return _power;}
 
+  bool isValid() const {return _valid;}
+  void setValid(bool v) {_valid=v;}
+
+  const QString& line() const {return _line;}
+
+  void convertEllipticity() {_ellipticity=Angle::radiansToDegrees(atan(_ellipticity));}
 private:
-  double _time, _frequency, _slowness, _azimuth, _ellipticity, _noise, _power;
+  QString _time;
+  double _frequency, _slowness, _azimuth, _ellipticity,
+         _verticalNoise, _horizontalNoise, _power;
+  QString _line;
+  bool _valid;
 };
 
 #endif // SAMPLE_H
