@@ -104,6 +104,8 @@ bool MatFormatPrivate::loadHeader(QMap<QByteArray, QVariant>& headerValues, cons
   matClose(fmat);
   return true;
 }
+#else
+QMap<SignalFile *, MatContext *> MatFormat::_contexts;
 #endif // GP_MATLAB_LIBS
 
 /*!
@@ -125,9 +127,8 @@ MatFormat::MatFormat()
   setName("MatlabMat");
   setCaption(tr("Matlab Mat-files"));
   addSuffix("mat");
-
 #ifndef GP_MATLAB_LIBS
-  _context=new MatContext;
+  ASSERT(_contexts.isEmpty());
 #endif
 }
 
@@ -138,7 +139,11 @@ MatFormat::~MatFormat()
 {
   TRACE;
 #ifndef GP_MATLAB_LIBS
-  delete _context;
+  QMap<SignalFile *, MatContext *>::iterator it;
+  for(it=_contexts.begin(); it!=_contexts.end(); it++) {
+    delete it.value();
+  }
+  _contexts.clear();
 #endif
 }
 
@@ -191,8 +196,8 @@ bool MatFormat::load(SignalFile * file) const
     }
     if(!headerValues.contains(variableName)) { // Skip variables used for meta data
       if(mxGetNumberOfDimensions(array)==2) {
-        int nChannels=mxGetDimensions(array)[0];
-        int nSamples=mxGetDimensions(array)[1];
+        int nChannels=mxGetDimensions(array)[1];
+        int nSamples=mxGetDimensions(array)[0];
         int n0=qCeil(log10(nChannels));
         for(int iChan=0; iChan<nChannels; iChan++) {
           Signal * newSignal=new Signal(file->database());
@@ -216,21 +221,29 @@ bool MatFormat::load(SignalFile * file) const
   }
   return false;
 #else
-  MatReader mr(_context);
+  QMap<SignalFile *, MatContext *>::const_iterator it=_contexts.find(file);
+  if(it!=_contexts.end()) {
+    delete it.value();
+    _contexts.remove(file);
+  }
+  MatContext * context=new MatContext;
+  MatReader mr(context);
   if(!mr.read(file->name())) {
+    delete context;
     App::log(tr("Error reading file %1\n").arg(file->name()) );
     return false;
   }
+  _contexts.insert(file, context);
   // Query header information
   //QMap<QByteArray, QVariant> headerValues;
   //MatFormatPrivate::loadHeader(headerValues, file->name());
   // Scan for all the other variables
   int iSig=0;
-  for(int i=0; i<_context->arrayCount(); i++) {
-    MatArray * array=_context->array(i);
+  for(int i=0; i<context->arrayCount(); i++) {
+    MatArray * array=context->array(i);
     //if(!headerValues.contains(array->name())) { // Skip variables used for meta data
-      int nChannels=array->dimension(0);
-      int nSamples=array->dimension(1);
+      int nChannels=array->dimension(1);
+      int nSamples=array->dimension(0);
       int n0=qCeil(log10(nChannels));
       for(int iChan=0; iChan<nChannels; iChan++) {
         Signal * newSignal=new Signal(file->database());
@@ -268,20 +281,33 @@ bool MatFormat::load(const Signal * sig, double * samples) const
   matClose(fmat);
   return true;
 #else
-  MatArray * array=_context->array(variableName.value());
+  MatContext * context;
+  QMap<SignalFile *, MatContext *>::const_iterator it=_contexts.find(sig->file());
+  if(it==_contexts.end()) {
+    context=new MatContext;
+    MatReader mr(context);
+    if(!mr.read(sig->file()->name())) {
+      delete context;
+      App::log(tr("Error reading file %1\n").arg(sig->file()->name()));
+      return false;
+    }
+    _contexts.insert(sig->file(), context);
+  } else {
+    context=it.value();
+  }
+  MatArray * array=context->array(variableName.value());
   if(array) {
     int nSamples=sig->nSamples();
-    double * ptr=array->realDoubleValues()+sig->numberInFile();
-    int delta=array->dimension(0);
+    double * ptr=array->realDoubleValues()+sig->offsetInFile()*array->dimension(0);
     for(int i=0; i<nSamples; i++) {
       samples[i]=*ptr;
-      ptr+=delta;
+      ptr++;
     }
   } else {
-    qWarning("No MatArray available with name %s", variableName.value().toLatin1().data());
+    App::log(tr("No MatArray available with name '%1'\n").arg(variableName.value()));
     return false;
   }
-  return false;
+  return true;
 #endif
 }
 
