@@ -585,38 +585,50 @@ void MaxEntryList::rejectNPeaksPerMinute(double nppm)
     // Look back timeSegment seconds before and after this peak and count available peaks
     progress.setValue(i);
     double t=at(i)->time();
-    double currentNppmB=0.0, currentNppmF=0.0;
-    QMap<double, int>::iterator itForward=times.lowerBound(t);
-    QMap<double, int>::iterator itBack=itForward-1;
-    QList<double> aroundTimes;
-    while(itBack!=times.end() && itBack.key() > t-timeSegment) {
-      aroundTimes.prepend(itBack.key());
-      itBack--;
-      currentNppmB++;
-    }
-    if(currentNppmB>=nppm) {
-      delete at(i);
-      continue;
-    }
-    while(itForward!=times.end() && itForward.key() < t+timeSegment) {
-      aroundTimes.append(itForward.key());
-      itForward++;
-      currentNppmF++;
-    }
-    if(currentNppmF>=nppm) {
-      delete at(i);
-      continue;
-    }
-    // Scan all possible time segment to check if number of time is less than nppm
-    int iAroundTimes, iNppm=(int) nppm - 1;
-    for(iAroundTimes=aroundTimes.count() - iNppm -1; iAroundTimes>=0; iAroundTimes-- ) {
-      if(aroundTimes.at(iAroundTimes+iNppm) - aroundTimes.at(iAroundTimes) < timeSegment) {
-        break;
+    if(!times.isEmpty()) {
+      // Build a list of events (arroundTimes) before and after time t
+      // The events are not sorted by increasing time but by their amplitudes
+      // Largest events are inserted first.
+      double currentNppmB=0.0, currentNppmF=0.0;
+      QList<double> aroundTimes;
+      QMap<double, int>::iterator itForward=times.lowerBound(t);
+      if(itForward!=times.begin()) {
+        QMap<double, int>::iterator itBack=itForward;
+        itBack--;
+        while(itBack!=times.begin() && itBack.key()>t-timeSegment) {
+          aroundTimes.prepend(itBack.key());
+          itBack--;
+          currentNppmB++;
+        }
+        if(itBack==times.begin() && itBack.key()>t-timeSegment) {
+          aroundTimes.prepend(itBack.key());
+          currentNppmB++;
+        }
+        if(currentNppmB>=nppm) {
+          delete at(i);
+          continue;
+        }
+      }
+      while(itForward!=times.end() && itForward.key()<t+timeSegment) {
+        aroundTimes.append(itForward.key());
+        itForward++;
+        currentNppmF++;
+      }
+      if(currentNppmF>=nppm) {
+        delete at(i);
+        continue;
+      }
+      // Scan all possible time segment to check if number of time is less than nppm
+      int iAroundTimes, iNppm=qRound(nppm)-1;
+      for(iAroundTimes=aroundTimes.count()-iNppm-1; iAroundTimes>=0; iAroundTimes--) {
+        if(aroundTimes.at(iAroundTimes+iNppm)-aroundTimes.at(iAroundTimes)<timeSegment) {
+          break;
+        }
+      }
+      if(iAroundTimes>=0) {
+        delete at(i);
+        continue;
       }
-    }
-    if(iAroundTimes>=0) {
-      delete at(i);
-      continue;
     }
     // OK, new time is acceptable
     times.insert(at(i)->time(), i);
