@@ -64,13 +64,13 @@ StatGridAnalyser::StatGridAnalyser(QWidget *parent, Qt::WindowFlags f)
   connect(a, SIGNAL(triggered()), this, SIGNAL(newMode()) );
 
   new QShortcut(Qt::Key_Up, this, SLOT(nextFrequency()) );
-  new QShortcut(Qt::Key_Up+Qt::SHIFT, this, SLOT(nextFrequencyReject()) );
+  new QShortcut(Qt::Key_Up | Qt::SHIFT, this, SLOT(nextFrequencyReject()) );
   new QShortcut(Qt::Key_Down, this, SLOT(previousFrequency()) );
-  new QShortcut(Qt::Key_Down+Qt::SHIFT, this, SLOT(previousFrequencyReject()) );
+  new QShortcut(Qt::Key_Down | Qt::SHIFT, this, SLOT(previousFrequencyReject()) );
   new QShortcut(Qt::Key_Left, this, SLOT(decreaseLowLimit()) );
-  new QShortcut(Qt::Key_Left+Qt::SHIFT, this, SLOT(decreaseHighLimit()) );
+  new QShortcut(Qt::Key_Left | Qt::SHIFT, this, SLOT(decreaseHighLimit()) );
   new QShortcut(Qt::Key_Right, this, SLOT(increaseLowLimit()) );
-  new QShortcut(Qt::Key_Right+Qt::SHIFT, this, SLOT(increaseHighLimit()) );
+  new QShortcut(Qt::Key_Right | Qt::SHIFT, this, SLOT(increaseHighLimit()) );
 
   _partitionBandLayer=0;
   _partitionCurveLayer=0;
@@ -89,7 +89,7 @@ StatGridAnalyser::~StatGridAnalyser()
 void StatGridAnalyser::shortcutEvents(Shortcuts s)
 {
   TRACE;
-  GraphContent * gc=probaDensity->graphContent();
+  GraphContents * gc=probaDensity->graphContents();
   const ParallelBand& b=_densityBandLayer->band(0);
   int iFreq=freqScroll->value();
 
@@ -255,20 +255,20 @@ void StatGridAnalyser::on_freqScroll_valueChanged(int)
     p.setY(sum*grid.height(i));
   }
 
-  GaussDistribution gd(mean, stddev);
+  NormalDistribution gd(mean, stddev);
   for(int i=0;i < n;i++ ) {
     Point2D& p=gaussDensityLine->curve().constXAt(i);
     if(logScale)
-      p.setY(gd.rho(log10( p.x()) ));
+      p.setY(gd.value(log10( p.x()) ));
     else
-      p.setY(gd.rho(p.x()) );
+      p.setY(gd.value(p.x()) );
   }
   for(int i=0;i < n;i++ ) {
     Point2D& p=gaussPartitionLine->curve().constXAt(i);
     if(logScale)
-      p.setY(gd.part(log10( p.x()) ));
+      p.setY(gd.cumulativeValue(log10( p.x()) ));
     else
-      p.setY(gd.part(p.x()) );
+      p.setY(gd.cumulativeValue(p.x()) );
   }
 
   if(_lastFreq<_bands.count()) {
@@ -301,8 +301,8 @@ void StatGridAnalyser::on_freqScroll_valueChanged(int)
                             arg(med, 0, 'g', 3).arg(meddev, 0, 'g', 3).
                             arg(mod, 0, 'g', 3).arg(moddev, 0, 'g', 3).arg(_units));
 
-  probaDensity->graphContent() ->deepUpdate();
-  probaPartition->graphContent() ->deepUpdate();
+  probaDensity->graphContents() ->deepUpdate();
+  probaPartition->graphContents() ->deepUpdate();
 }
 
 /*!
@@ -350,6 +350,6 @@ void StatGridAnalyser::setBand(double min, double max)
   ParallelBand& b2=_partitionBandLayer->band(0);
   b2.setMinimum(min);
   b2.setMaximum(max);
-  probaDensity->graphContent()->deepUpdate();
-  probaPartition->graphContent()->deepUpdate();
+  probaDensity->graphContents()->deepUpdate();
+  probaPartition->graphContents()->deepUpdate();
 }
