@@ -50,7 +50,7 @@ ExportOptions exportOptions;
 int main(int argc, char ** argv)
 {
   Application a(argc, argv, help);
-  SciFigsGlobal s;
+  SciFigsGlobal s(true);
 
   // Options
   QString maxFile;
@@ -161,8 +161,7 @@ int main(int argc, char ** argv)
   }
 
   if(maxFile.isEmpty()) {
-    maxFile=Message::getOpenFileName(tr("Loading max file"),
-                                     tr("max file (*.max)"));
+    maxFile=Message::getOpenFileName(tr("Loading max file"), tr("max file (*.max)"));
     if(maxFile.isEmpty()) return 2;
   }
   MaxEntryList * maxList=new MaxEntryList;
@@ -239,6 +238,7 @@ int main(int argc, char ** argv)
       w->addMedianCurve();
       sOut << QString("# Median curve from file %1\n").arg(maxFile);
       w->toStream(sOut, -1);
+      break;
     case Plot:
       w->exportPlot(exportOptions);
       break;
