@@ -126,7 +126,7 @@ double Spac3CForward::misfit(double * model, bool& ok)
       const ModalCurve& c=_curveList.at(i);
       const FactoryPoint& p=c.constAt(index);
       //printf("%i %lg\n",i,_autocorrFactory.mode(c.modes().first())[ _iOmega ].value());
-      rms_val+=p.misfit(nValues, nData, _autocorrFactory->mode(c.modes().first())[_iOmega], L2, 0.0);
+      rms_val+=p.misfit(nValues, nData, _autocorrFactory->mode(c.modes().first())[_iOmega], Misfit::L2, 0.0);
     }
   }
   if(nValues>0)
