@@ -26,21 +26,15 @@
 #ifndef TAPECOORDINATEDELEGATE_H
 #define TAPECOORDINATEDELEGATE_H
 
-#include <QtGui>
-#if(QT_VERSION > QT_VERSION_CHECK(5, 0, 0))
-#include <QtWidgets>
-#endif
+#include <QGpGuiTools.h>
 
-class TapeCoordinateDelegate : public QItemDelegate
+class TapeCoordinateDelegate : public ItemDelegate
 {
 public:
   TapeCoordinateDelegate(QObject * parent);
 
   QWidget * createEditor(QWidget * parent, const QStyleOptionViewItem &,
                          const QModelIndex & index) const;
-  void setEditorData(QWidget *editor, const QModelIndex &index) const;
-  void setModelData(QWidget *editor, QAbstractItemModel *model,
-                    const QModelIndex &index) const;
 };
 
 #endif // TAPECOORDINATEDELEGATE_H
