@@ -38,57 +38,7 @@ void TapePoint::operator=(const Point2D& o)
   Point::operator=(o);
 }
 
-QString TapePoint::typeString(Type t)
-{
-  TRACE;
-  switch(t) {
-  case Fixed:
-    return tr("Fixed");
-  case North:
-    return tr("North");
-  case Eastward:
-    return tr("Eastward");
-  case Prior:
-    return tr("Prior");
-  case Free:
-    break;
-  }
-  return tr("Free");
-}
+ENUM_AS_STRING_BEGIN(TapePoint, Type)
+ENUM_AS_STRING_DATA_5(Eastward, Fixed, Free, North, Prior);
+ENUM_AS_STRING_END
 
-TapePoint::Type TapePoint::type(const QString& t)
-{
-  TRACE;
-  if(t.count()>3) {
-    switch(t[2].unicode()) {
-    case 'x':
-      if(t==tr("Fixed")) {
-        return Fixed;
-      }
-      break;
-    case 'r':
-      if(t==tr("North")) {
-        return North;
-      }
-      break;
-    case 's':
-      if(t==tr("Eastward")) {
-       return Eastward;
-      }
-      break;
-    case 'i':
-      if(t==tr("Prior")) {
-        return Prior;
-      }
-      break;
-    case 'e':
-      if(t==tr("Free")) {
-        return Free;
-      }
-      break;
-    default:
-      break;
-    }
-  }
-  return Free;
-}
