@@ -47,6 +47,7 @@ WaranGpsWidget::WaranGpsWidget(QWidget * parent)
   TRACE;
   setupUi(this);
 
+  _relativePositions=nullptr;
   _distanceMapErrors=new CircleViewer(distanceMap);
 
   theoreticalResponse->createObjects(true);
@@ -69,7 +70,6 @@ WaranGpsWidget::WaranGpsWidget(QWidget * parent)
 
   connect(&_gpsUpdate, SIGNAL(timeout()), this, SLOT(updateGps()));
   _gpsUpdate.setInterval(10000);
-  _gpsUpdate.start();
 
   updateUtmZone();
 }
@@ -144,10 +144,12 @@ void WaranGpsWidget::setMode(Mode m)
     arrayTable->setEditTriggers(QAbstractItemView::NoEditTriggers);
     arrayTable->setSelectionMode(QAbstractItemView::NoSelection);
     _arrayEditAction->setEnabled(false);
+    _gpsUpdate.start();
   } else {
     arrayTable->setEditTriggers(QAbstractItemView::AllEditTriggers);
     arrayTable->setSelectionMode(QAbstractItemView::SingleSelection);
     _arrayEditAction->setEnabled(true);
+    _gpsUpdate.stop();
   }
   gpsTab->setEnabled(m==Gps);
   distancesTab->setEnabled(m==Gps);
@@ -202,7 +204,7 @@ void WaranGpsWidget::setCoordinates(QString fileName, QString coordinateFormat)
 {
   TRACE;
   CoordinateFileWidget cf;
-  if(cf.read(fileName, coordinateFormat)) {
+  if(cf.read(fileName, coordinateFormat, true)) {
     if(cf.points().count()<=1000) {
       _arrayBase=cf.points();
       _utmZone=cf.utmZone();
@@ -368,6 +370,9 @@ void WaranGpsWidget::arrayMapChanged()
   updateCoArrayMap();
   updateArrayResponse();
   ringEditor->updateProperties();
+  if(_relativePositions) {
+    _relativePositions->setStationList(&_arrayMultiplied);
+  }
 }
 
 void WaranGpsWidget::on_arrayLoadBut_clicked()
@@ -390,12 +395,12 @@ void WaranGpsWidget::on_arrayCoordinateFactor_valueChanged(double)
 void WaranGpsWidget::on_relativePositionBut_clicked()
 {
   TRACE;
-  RelativePositions * d=new RelativePositions(this);
-  d->setStationList(&_arrayMultiplied);
-  Settings::getWidget(d);
-  d->exec();
-  Settings::setWidget(d);
-  delete d;
+  if(!_relativePositions) {
+    _relativePositions=new RelativePositions(this, Qt::Window);
+    Settings::getWidget(_relativePositions);
+  }
+  _relativePositions->setStationList(&_arrayMultiplied);
+  _relativePositions->show();
 }
 
 /*!
@@ -403,7 +408,7 @@ void WaranGpsWidget::on_relativePositionBut_clicked()
 void WaranGpsWidget::updateArrayResponse()
 {
   TRACE;
-  QVector<Point2D> respArray;
+  VectorList<Point2D> respArray;
   for(int i=_arrayMultiplied.count()-1;i>=0;i--) {
     respArray.append(_arrayMultiplied.at(i).coordinates());
   }
@@ -429,7 +434,9 @@ void WaranGpsWidget::updateDistanceMap()
       p.setX(sx.mean());
       p.setY(_yStat.at(i).mean());
       c.append(p);
-      _distanceMapErrors->add(p.x(), p.y(), _xStat.at(i).stddev(), _yStat.at(i).stddev(), 0.0, Qt::black);
+      _distanceMapErrors->add(p.x(), p.y(),
+                              _xStat.at(i).stddev(), _yStat.at(i).stddev(),
+                              0.0, Pen());
     }
   }
 }
