@@ -71,22 +71,28 @@ int main(int argc, char ** argv)
       } else if(arg=="-port") {
         CoreApplication::checkOptionArg(i, argc, argv);
         port=static_cast<short>(CoreApplication::toInt(i, i-1, argv));
+      } else if(arg=="-s") {
+        CoreApplication::checkOptionArg(i, argc, argv);
+        QString s(argv[i]);
+        bool ok=true;
+        frequencySampling.setScaleType(SamplingParameters::convertScaleType(s, ok));
+        if(!ok) {
+          App::log(tr("warangps: bad scale type '%1'\n").arg(argv[i]));
+          return 2;
+        }
+      } else if(arg=="-min") {
+        CoreApplication::checkOptionArg(i, argc, argv);
+        frequencySampling.setMinimum(CoreApplication::toDouble(i, i-1, argv));
+      } else if(arg=="-max") {
+        CoreApplication::checkOptionArg(i, argc, argv);
+        frequencySampling.setMaximum(CoreApplication::toDouble(i, i-1, argv));
+      } else if(arg=="-step") {
+        CoreApplication::checkOptionArg(i, argc, argv);
+        frequencySampling.setStep(CoreApplication::toDouble(i, i-1, argv));
       } else {
         App::log(tr("warangps: bad option %1, see -help\n").arg(argv[i]) );
         return 2;
       }
-    } else if(arg=="-s") {
-      CoreApplication::checkOptionArg(i, argc, argv);
-      frequencySampling.setScaleType(argv[i]);
-    } else if(arg=="-min") {
-      CoreApplication::checkOptionArg(i, argc, argv);
-      frequencySampling.setMinimum(CoreApplication::toDouble(i, i-1, argv));
-    } else if(arg=="-max") {
-      CoreApplication::checkOptionArg(i, argc, argv);
-      frequencySampling.setMinimum(CoreApplication::toDouble(i, i-1, argv));
-    } else if(arg=="-step") {
-      CoreApplication::checkOptionArg(i, argc, argv);
-      frequencySampling.setStep(CoreApplication::toDouble(i, i-1, argv));
     } else {
       argv[j++]=argv[i];
     }
@@ -104,7 +110,7 @@ int main(int argc, char ** argv)
   }
 
   a.setStream(new StandardStream(stdout));
-  SciFigsGlobal s;
+  SciFigsGlobal s(true);
 
   // Create main widget and start gui
   WaranGpsWidget * w=new WaranGpsWidget;
